import { ServiceUpdateMessage } from '../../../../models/';
import { AttachmentsRequestBuilder } from './attachments/attachmentsRequestBuilder';
import { ServiceAnnouncementAttachmentItemRequestBuilder } from './attachments/item/serviceAnnouncementAttachmentItemRequestBuilder';
import { AttachmentsArchiveRequestBuilder } from './attachmentsArchive/attachmentsArchiveRequestBuilder';
import { ServiceUpdateMessageItemRequestBuilderDeleteRequestConfiguration } from './serviceUpdateMessageItemRequestBuilderDeleteRequestConfiguration';
import { ServiceUpdateMessageItemRequestBuilderGetRequestConfiguration } from './serviceUpdateMessageItemRequestBuilderGetRequestConfiguration';
import { ServiceUpdateMessageItemRequestBuilderPatchRequestConfiguration } from './serviceUpdateMessageItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity. */
export declare class ServiceUpdateMessageItemRequestBuilder {
    /** The attachments property */
    get attachments(): AttachmentsRequestBuilder;
    /** The attachmentsArchive property */
    get attachmentsArchive(): AttachmentsArchiveRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.admin.serviceAnnouncement.messages.item.attachments.item collection
     * @param id Unique identifier of the item
     * @returns a serviceAnnouncementAttachmentItemRequestBuilder
     */
    attachmentsById(id: string): ServiceAnnouncementAttachmentItemRequestBuilder;
    /**
     * Instantiates a new ServiceUpdateMessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ServiceUpdateMessageItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ServiceUpdateMessageItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property messages in admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ServiceUpdateMessage | undefined, requestConfiguration?: ServiceUpdateMessageItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property messages for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ServiceUpdateMessageItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessage
     */
    get(requestConfiguration?: ServiceUpdateMessageItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceUpdateMessage | undefined>;
    /**
     * Update the navigation property messages in admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ServiceUpdateMessage | undefined, requestConfiguration?: ServiceUpdateMessageItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
