import { ServiceUpdateMessage, ServiceUpdateMessageCollectionResponse } from '../../../models/';
import { ArchiveRequestBuilder } from './archive/archiveRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { FavoriteRequestBuilder } from './favorite/favoriteRequestBuilder';
import { MarkReadRequestBuilder } from './markRead/markReadRequestBuilder';
import { MarkUnreadRequestBuilder } from './markUnread/markUnreadRequestBuilder';
import { MessagesRequestBuilderGetRequestConfiguration } from './messagesRequestBuilderGetRequestConfiguration';
import { MessagesRequestBuilderPostRequestConfiguration } from './messagesRequestBuilderPostRequestConfiguration';
import { UnarchiveRequestBuilder } from './unarchive/unarchiveRequestBuilder';
import { UnfavoriteRequestBuilder } from './unfavorite/unfavoriteRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity. */
export declare class MessagesRequestBuilder {
    /** The archive property */
    get archive(): ArchiveRequestBuilder;
    /** The count property */
    get count(): CountRequestBuilder;
    /** The favorite property */
    get favorite(): FavoriteRequestBuilder;
    /** The markRead property */
    get markRead(): MarkReadRequestBuilder;
    /** The markUnread property */
    get markUnread(): MarkUnreadRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The unarchive property */
    get unarchive(): UnarchiveRequestBuilder;
    /** The unfavorite property */
    get unfavorite(): UnfavoriteRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new MessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: MessagesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ServiceUpdateMessage | undefined, requestConfiguration?: MessagesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessageCollectionResponse
     */
    get(requestConfiguration?: MessagesRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceUpdateMessageCollectionResponse | undefined>;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessage
     */
    post(body: ServiceUpdateMessage | undefined, requestConfiguration?: MessagesRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceUpdateMessage | undefined>;
}
