import { ServiceAnnouncement } from '../../models/';
import { HealthOverviewsRequestBuilder } from './healthOverviews/healthOverviewsRequestBuilder';
import { ServiceHealthItemRequestBuilder } from './healthOverviews/item/serviceHealthItemRequestBuilder';
import { IssuesRequestBuilder } from './issues/issuesRequestBuilder';
import { ServiceHealthIssueItemRequestBuilder } from './issues/item/serviceHealthIssueItemRequestBuilder';
import { ServiceUpdateMessageItemRequestBuilder } from './messages/item/serviceUpdateMessageItemRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { ServiceAnnouncementRequestBuilderDeleteRequestConfiguration } from './serviceAnnouncementRequestBuilderDeleteRequestConfiguration';
import { ServiceAnnouncementRequestBuilderGetRequestConfiguration } from './serviceAnnouncementRequestBuilderGetRequestConfiguration';
import { ServiceAnnouncementRequestBuilderPatchRequestConfiguration } from './serviceAnnouncementRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the serviceAnnouncement property of the microsoft.graph.admin entity. */
export declare class ServiceAnnouncementRequestBuilder {
    /** The healthOverviews property */
    get healthOverviews(): HealthOverviewsRequestBuilder;
    /** The issues property */
    get issues(): IssuesRequestBuilder;
    /** The messages property */
    get messages(): MessagesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ServiceAnnouncementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property serviceAnnouncement for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ServiceAnnouncementRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * A container for service communications resources. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ServiceAnnouncementRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property serviceAnnouncement in admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ServiceAnnouncement | undefined, requestConfiguration?: ServiceAnnouncementRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property serviceAnnouncement for admin
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ServiceAnnouncementRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * A container for service communications resources. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceAnnouncement
     */
    get(requestConfiguration?: ServiceAnnouncementRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceAnnouncement | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.admin.serviceAnnouncement.healthOverviews.item collection
     * @param id Unique identifier of the item
     * @returns a serviceHealthItemRequestBuilder
     */
    healthOverviewsById(id: string): ServiceHealthItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.admin.serviceAnnouncement.issues.item collection
     * @param id Unique identifier of the item
     * @returns a serviceHealthIssueItemRequestBuilder
     */
    issuesById(id: string): ServiceHealthIssueItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.admin.serviceAnnouncement.messages.item collection
     * @param id Unique identifier of the item
     * @returns a serviceUpdateMessageItemRequestBuilder
     */
    messagesById(id: string): ServiceUpdateMessageItemRequestBuilder;
    /**
     * Update the navigation property serviceAnnouncement in admin
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ServiceAnnouncement | undefined, requestConfiguration?: ServiceAnnouncementRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
