import { AgreementFile } from '../../../models/';
import { FileRequestBuilderDeleteRequestConfiguration } from './fileRequestBuilderDeleteRequestConfiguration';
import { FileRequestBuilderGetRequestConfiguration } from './fileRequestBuilderGetRequestConfiguration';
import { FileRequestBuilderPatchRequestConfiguration } from './fileRequestBuilderPatchRequestConfiguration';
import { AgreementFileLocalizationItemRequestBuilder } from './localizations/item/agreementFileLocalizationItemRequestBuilder';
import { LocalizationsRequestBuilder } from './localizations/localizationsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the file property of the microsoft.graph.agreement entity. */
export declare class FileRequestBuilder {
    /** The localizations property */
    get localizations(): LocalizationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new FileRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property file for agreements
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: FileRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Default PDF linked to this agreement.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: FileRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property file in agreements
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: AgreementFile | undefined, requestConfiguration?: FileRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property file for agreements
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: FileRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Default PDF linked to this agreement.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AgreementFile
     */
    get(requestConfiguration?: FileRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<AgreementFile | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.agreements.item.file.localizations.item collection
     * @param id Unique identifier of the item
     * @returns a agreementFileLocalizationItemRequestBuilder
     */
    localizationsById(id: string): AgreementFileLocalizationItemRequestBuilder;
    /**
     * Update the navigation property file in agreements
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: AgreementFile | undefined, requestConfiguration?: FileRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
