import { TeamworkBot } from '../../../../../../models/';
import { BotRequestBuilderDeleteRequestConfiguration } from './botRequestBuilderDeleteRequestConfiguration';
import { BotRequestBuilderGetRequestConfiguration } from './botRequestBuilderGetRequestConfiguration';
import { BotRequestBuilderPatchRequestConfiguration } from './botRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the bot property of the microsoft.graph.teamsAppDefinition entity. */
export declare class BotRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new BotRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property bot for appCatalogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: BotRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The details of the bot specified in the Teams app manifest.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: BotRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property bot in appCatalogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: TeamworkBot | undefined, requestConfiguration?: BotRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property bot for appCatalogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: BotRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The details of the bot specified in the Teams app manifest.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of TeamworkBot
     */
    get(requestConfiguration?: BotRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<TeamworkBot | undefined>;
    /**
     * Update the navigation property bot in appCatalogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: TeamworkBot | undefined, requestConfiguration?: BotRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
