import { ApplicationTemplate, ApplicationTemplateCollectionResponse } from '../models/';
import { ApplicationTemplatesRequestBuilderGetRequestConfiguration } from './applicationTemplatesRequestBuilderGetRequestConfiguration';
import { ApplicationTemplatesRequestBuilderPostRequestConfiguration } from './applicationTemplatesRequestBuilderPostRequestConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of applicationTemplate entities. */
export declare class ApplicationTemplatesRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ApplicationTemplatesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of [applicationTemplate](../resources/applicationtemplate.md) objects from the Azure AD application gallery.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ApplicationTemplatesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to applicationTemplates
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ApplicationTemplate | undefined, requestConfiguration?: ApplicationTemplatesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a list of [applicationTemplate](../resources/applicationtemplate.md) objects from the Azure AD application gallery.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ApplicationTemplateCollectionResponse
     */
    get(requestConfiguration?: ApplicationTemplatesRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ApplicationTemplateCollectionResponse | undefined>;
    /**
     * Add new entity to applicationTemplates
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ApplicationTemplate
     */
    post(body: ApplicationTemplate | undefined, requestConfiguration?: ApplicationTemplatesRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ApplicationTemplate | undefined>;
}
