import { Application } from '../../models/';
import { AddKeyRequestBuilder } from './addKey/addKeyRequestBuilder';
import { AddPasswordRequestBuilder } from './addPassword/addPasswordRequestBuilder';
import { ApplicationItemRequestBuilderDeleteRequestConfiguration } from './applicationItemRequestBuilderDeleteRequestConfiguration';
import { ApplicationItemRequestBuilderGetRequestConfiguration } from './applicationItemRequestBuilderGetRequestConfiguration';
import { ApplicationItemRequestBuilderPatchRequestConfiguration } from './applicationItemRequestBuilderPatchRequestConfiguration';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/checkMemberGroupsRequestBuilder';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/checkMemberObjectsRequestBuilder';
import { CreatedOnBehalfOfRequestBuilder } from './createdOnBehalfOf/createdOnBehalfOfRequestBuilder';
import { ExtensionPropertiesRequestBuilder } from './extensionProperties/extensionPropertiesRequestBuilder';
import { ExtensionPropertyItemRequestBuilder } from './extensionProperties/item/extensionPropertyItemRequestBuilder';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/getMemberGroupsRequestBuilder';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/getMemberObjectsRequestBuilder';
import { HomeRealmDiscoveryPoliciesRequestBuilder } from './homeRealmDiscoveryPolicies/homeRealmDiscoveryPoliciesRequestBuilder';
import { HomeRealmDiscoveryPolicyItemRequestBuilder } from './homeRealmDiscoveryPolicies/item/homeRealmDiscoveryPolicyItemRequestBuilder';
import { LogoRequestBuilder } from './logo/logoRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './owners/item/directoryObjectItemRequestBuilder';
import { OwnersRequestBuilder } from './owners/ownersRequestBuilder';
import { RemoveKeyRequestBuilder } from './removeKey/removeKeyRequestBuilder';
import { RemovePasswordRequestBuilder } from './removePassword/removePasswordRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { SetVerifiedPublisherRequestBuilder } from './setVerifiedPublisher/setVerifiedPublisherRequestBuilder';
import { TokenIssuancePolicyItemRequestBuilder } from './tokenIssuancePolicies/item/tokenIssuancePolicyItemRequestBuilder';
import { TokenIssuancePoliciesRequestBuilder } from './tokenIssuancePolicies/tokenIssuancePoliciesRequestBuilder';
import { TokenLifetimePolicyItemRequestBuilder } from './tokenLifetimePolicies/item/tokenLifetimePolicyItemRequestBuilder';
import { TokenLifetimePoliciesRequestBuilder } from './tokenLifetimePolicies/tokenLifetimePoliciesRequestBuilder';
import { UnsetVerifiedPublisherRequestBuilder } from './unsetVerifiedPublisher/unsetVerifiedPublisherRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of application entities. */
export declare class ApplicationItemRequestBuilder {
    /** The addKey property */
    get addKey(): AddKeyRequestBuilder;
    /** The addPassword property */
    get addPassword(): AddPasswordRequestBuilder;
    /** The checkMemberGroups property */
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    /** The checkMemberObjects property */
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    /** The createdOnBehalfOf property */
    get createdOnBehalfOf(): CreatedOnBehalfOfRequestBuilder;
    /** The extensionProperties property */
    get extensionProperties(): ExtensionPropertiesRequestBuilder;
    /** The getMemberGroups property */
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    /** The getMemberObjects property */
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    /** The homeRealmDiscoveryPolicies property */
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPoliciesRequestBuilder;
    /** The logo property */
    get logo(): LogoRequestBuilder;
    /** The owners property */
    get owners(): OwnersRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The removeKey property */
    get removeKey(): RemoveKeyRequestBuilder;
    /** The removePassword property */
    get removePassword(): RemovePasswordRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The restore property */
    get restore(): RestoreRequestBuilder;
    /** The setVerifiedPublisher property */
    get setVerifiedPublisher(): SetVerifiedPublisherRequestBuilder;
    /** The tokenIssuancePolicies property */
    get tokenIssuancePolicies(): TokenIssuancePoliciesRequestBuilder;
    /** The tokenLifetimePolicies property */
    get tokenLifetimePolicies(): TokenLifetimePoliciesRequestBuilder;
    /** The unsetVerifiedPublisher property */
    get unsetVerifiedPublisher(): UnsetVerifiedPublisherRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ApplicationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes an application. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ApplicationItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of an [application](../resources/application.md) object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ApplicationItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * However, your app might still temporarily require Azure AD Graph permissions to access resources. This article describes the following four methods for configuring required Azure AD Graph permissions for your app registration:
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Application | undefined, requestConfiguration?: ApplicationItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Deletes an application. When deleted, apps are moved to a temporary container and can be restored within 30 days. After that time, they are permanently deleted.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ApplicationItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.extensionProperties.item collection
     * @param id Unique identifier of the item
     * @returns a extensionPropertyItemRequestBuilder
     */
    extensionPropertiesById(id: string): ExtensionPropertyItemRequestBuilder;
    /**
     * Get the properties and relationships of an [application](../resources/application.md) object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Application
     */
    get(requestConfiguration?: ApplicationItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Application | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.homeRealmDiscoveryPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a homeRealmDiscoveryPolicyItemRequestBuilder
     */
    homeRealmDiscoveryPoliciesById(id: string): HomeRealmDiscoveryPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.owners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    ownersById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * However, your app might still temporarily require Azure AD Graph permissions to access resources. This article describes the following four methods for configuring required Azure AD Graph permissions for your app registration:
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Application | undefined, requestConfiguration?: ApplicationItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenIssuancePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenIssuancePolicyItemRequestBuilder
     */
    tokenIssuancePoliciesById(id: string): TokenIssuancePolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenLifetimePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenLifetimePolicyItemRequestBuilder
     */
    tokenLifetimePoliciesById(id: string): TokenLifetimePolicyItemRequestBuilder;
}
