import { LogoRequestBuilderGetRequestConfiguration } from './logoRequestBuilderGetRequestConfiguration';
import { LogoRequestBuilderPutRequestConfiguration } from './logoRequestBuilderPutRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the media for the application entity. */
export declare class LogoRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new LogoRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The main logo for the application. Not nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: LogoRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * The main logo for the application. Not nullable.
     * @param body Binary request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPutRequestInformation(body: ArrayBuffer, requestConfiguration?: LogoRequestBuilderPutRequestConfiguration | undefined): RequestInformation;
    /**
     * The main logo for the application. Not nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ArrayBuffer
     */
    get(requestConfiguration?: LogoRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ArrayBuffer | undefined>;
    /**
     * The main logo for the application. Not nullable.
     * @param body Binary request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    put(body: ArrayBuffer, requestConfiguration?: LogoRequestBuilderPutRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
