import { AuditLogRoot } from '../models/';
import { AuditLogsRequestBuilderGetRequestConfiguration } from './auditLogsRequestBuilderGetRequestConfiguration';
import { AuditLogsRequestBuilderPatchRequestConfiguration } from './auditLogsRequestBuilderPatchRequestConfiguration';
import { DirectoryAuditsRequestBuilder } from './directoryAudits/directoryAuditsRequestBuilder';
import { DirectoryAuditItemRequestBuilder } from './directoryAudits/item/directoryAuditItemRequestBuilder';
import { ProvisioningObjectSummaryItemRequestBuilder } from './provisioning/item/provisioningObjectSummaryItemRequestBuilder';
import { ProvisioningRequestBuilder } from './provisioning/provisioningRequestBuilder';
import { RestrictedSignInItemRequestBuilder } from './restrictedSignIns/item/restrictedSignInItemRequestBuilder';
import { RestrictedSignInsRequestBuilder } from './restrictedSignIns/restrictedSignInsRequestBuilder';
import { SignInItemRequestBuilder } from './signIns/item/signInItemRequestBuilder';
import { SignInsRequestBuilder } from './signIns/signInsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the auditLogRoot singleton. */
export declare class AuditLogsRequestBuilder {
    /** The directoryAudits property */
    get directoryAudits(): DirectoryAuditsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The provisioning property */
    get provisioning(): ProvisioningRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The restrictedSignIns property */
    get restrictedSignIns(): RestrictedSignInsRequestBuilder;
    /** The signIns property */
    get signIns(): SignInsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new AuditLogsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Contains different types of audit logs. This resources returns a singleton auditLog resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: AuditLogsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update auditLogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: AuditLogRoot | undefined, requestConfiguration?: AuditLogsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.directoryAudits.item collection
     * @param id Unique identifier of the item
     * @returns a directoryAuditItemRequestBuilder
     */
    directoryAuditsById(id: string): DirectoryAuditItemRequestBuilder;
    /**
     * Contains different types of audit logs. This resources returns a singleton auditLog resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AuditLogRoot
     */
    get(requestConfiguration?: AuditLogsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<AuditLogRoot | undefined>;
    /**
     * Update auditLogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: AuditLogRoot | undefined, requestConfiguration?: AuditLogsRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.provisioning.item collection
     * @param id Unique identifier of the item
     * @returns a provisioningObjectSummaryItemRequestBuilder
     */
    provisioningById(id: string): ProvisioningObjectSummaryItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.restrictedSignIns.item collection
     * @param id Unique identifier of the item
     * @returns a restrictedSignInItemRequestBuilder
     */
    restrictedSignInsById(id: string): RestrictedSignInItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.auditLogs.signIns.item collection
     * @param id Unique identifier of the item
     * @returns a signInItemRequestBuilder
     */
    signInsById(id: string): SignInItemRequestBuilder;
}
