import { ProvisioningObjectSummary, ProvisioningObjectSummaryCollectionResponse } from '../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { ProvisioningRequestBuilderGetRequestConfiguration } from './provisioningRequestBuilderGetRequestConfiguration';
import { ProvisioningRequestBuilderPostRequestConfiguration } from './provisioningRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the provisioning property of the microsoft.graph.auditLogRoot entity. */
export declare class ProvisioningRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ProvisioningRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get provisioning from auditLogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ProvisioningRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to provisioning for auditLogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ProvisioningObjectSummary | undefined, requestConfiguration?: ProvisioningRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get provisioning from auditLogs
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ProvisioningObjectSummaryCollectionResponse
     */
    get(requestConfiguration?: ProvisioningRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ProvisioningObjectSummaryCollectionResponse | undefined>;
    /**
     * Create new navigation property to provisioning for auditLogs
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ProvisioningObjectSummary
     */
    post(body: ProvisioningObjectSummary | undefined, requestConfiguration?: ProvisioningRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ProvisioningObjectSummary | undefined>;
}
