"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatItemRequestBuilder = void 0;
const createChatFromDiscriminatorValue_1 = require("../../models/createChatFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const installedAppsRequestBuilder_1 = require("./installedApps/installedAppsRequestBuilder");
const teamsAppInstallationItemRequestBuilder_1 = require("./installedApps/item/teamsAppInstallationItemRequestBuilder");
const conversationMemberItemRequestBuilder_1 = require("./members/item/conversationMemberItemRequestBuilder");
const membersRequestBuilder_1 = require("./members/membersRequestBuilder");
const chatMessageItemRequestBuilder_1 = require("./messages/item/chatMessageItemRequestBuilder");
const messagesRequestBuilder_1 = require("./messages/messagesRequestBuilder");
const sendActivityNotificationRequestBuilder_1 = require("./sendActivityNotification/sendActivityNotificationRequestBuilder");
const teamsTabItemRequestBuilder_1 = require("./tabs/item/teamsTabItemRequestBuilder");
const tabsRequestBuilder_1 = require("./tabs/tabsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of chat entities. */
class ChatItemRequestBuilder {
    /**
     * Instantiates a new ChatItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/chats/{chat%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The installedApps property */
    get installedApps() {
        return new installedAppsRequestBuilder_1.InstalledAppsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The members property */
    get members() {
        return new membersRequestBuilder_1.MembersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The messages property */
    get messages() {
        return new messagesRequestBuilder_1.MessagesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The sendActivityNotification property */
    get sendActivityNotification() {
        return new sendActivityNotificationRequestBuilder_1.SendActivityNotificationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The tabs property */
    get tabs() {
        return new tabsRequestBuilder_1.TabsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete entity from chats
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get entity from chats by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update entity in chats
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete entity from chats
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Get entity from chats by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Chat
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createChatFromDiscriminatorValue_1.createChatFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.chats.item.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["teamsAppInstallation%2Did"] = id;
        return new teamsAppInstallationItemRequestBuilder_1.TeamsAppInstallationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.chats.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["conversationMember%2Did"] = id;
        return new conversationMemberItemRequestBuilder_1.ConversationMemberItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.chats.item.messages.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageItemRequestBuilder
     */
    messagesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["chatMessage%2Did"] = id;
        return new chatMessageItemRequestBuilder_1.ChatMessageItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update entity in chats
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.chats.item.tabs.item collection
     * @param id Unique identifier of the item
     * @returns a teamsTabItemRequestBuilder
     */
    tabsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["teamsTab%2Did"] = id;
        return new teamsTabItemRequestBuilder_1.TeamsTabItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.ChatItemRequestBuilder = ChatItemRequestBuilder;
