import { CallRecord, CallRecordCollectionResponse } from '../../models/callRecords/';
import { CallRecordsRequestBuilderGetRequestConfiguration } from './callRecordsRequestBuilderGetRequestConfiguration';
import { CallRecordsRequestBuilderPostRequestConfiguration } from './callRecordsRequestBuilderPostRequestConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { GetDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder } from './getDirectRoutingCallsWithFromDateTimeWithToDateTime/getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder';
import { GetPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder } from './getPstnCallsWithFromDateTimeWithToDateTime/getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the callRecords property of the microsoft.graph.cloudCommunications entity. */
export declare class CallRecordsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new CallRecordsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get callRecords from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: CallRecordsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to callRecords for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: CallRecord | undefined, requestConfiguration?: CallRecordsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get callRecords from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CallRecordCollectionResponse
     */
    get(requestConfiguration?: CallRecordsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<CallRecordCollectionResponse | undefined>;
    /**
     * Provides operations to call the getDirectRoutingCalls method.
     * @param fromDateTime Usage: fromDateTime='{fromDateTime}'
     * @param toDateTime Usage: toDateTime='{toDateTime}'
     * @returns a getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder
     */
    getDirectRoutingCallsWithFromDateTimeWithToDateTime(fromDateTime: Date | undefined, toDateTime: Date | undefined): GetDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder;
    /**
     * Provides operations to call the getPstnCalls method.
     * @param fromDateTime Usage: fromDateTime='{fromDateTime}'
     * @param toDateTime Usage: toDateTime='{toDateTime}'
     * @returns a getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder
     */
    getPstnCallsWithFromDateTimeWithToDateTime(fromDateTime: Date | undefined, toDateTime: Date | undefined): GetPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder;
    /**
     * Create new navigation property to callRecords for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CallRecord
     */
    post(body: CallRecord | undefined, requestConfiguration?: CallRecordsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<CallRecord | undefined>;
}
