"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallRecordsRequestBuilder = void 0;
const createCallRecordCollectionResponseFromDiscriminatorValue_1 = require("../../models/callRecords/createCallRecordCollectionResponseFromDiscriminatorValue");
const createCallRecordFromDiscriminatorValue_1 = require("../../models/callRecords/createCallRecordFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder_1 = require("./getDirectRoutingCallsWithFromDateTimeWithToDateTime/getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder");
const getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder_1 = require("./getPstnCallsWithFromDateTimeWithToDateTime/getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the callRecords property of the microsoft.graph.cloudCommunications entity. */
class CallRecordsRequestBuilder {
    /**
     * Instantiates a new CallRecordsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/communications/callRecords{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The count property */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Get callRecords from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to callRecords for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Get callRecords from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CallRecordCollectionResponse
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createCallRecordCollectionResponseFromDiscriminatorValue_1.createCallRecordCollectionResponseFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Provides operations to call the getDirectRoutingCalls method.
     * @param fromDateTime Usage: fromDateTime='{fromDateTime}'
     * @param toDateTime Usage: toDateTime='{toDateTime}'
     * @returns a getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder
     */
    getDirectRoutingCallsWithFromDateTimeWithToDateTime(fromDateTime, toDateTime) {
        if (!fromDateTime)
            throw new Error("fromDateTime cannot be undefined");
        if (!toDateTime)
            throw new Error("toDateTime cannot be undefined");
        return new getDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder_1.GetDirectRoutingCallsWithFromDateTimeWithToDateTimeRequestBuilder(this.pathParameters, this.requestAdapter, fromDateTime, toDateTime);
    }
    ;
    /**
     * Provides operations to call the getPstnCalls method.
     * @param fromDateTime Usage: fromDateTime='{fromDateTime}'
     * @param toDateTime Usage: toDateTime='{toDateTime}'
     * @returns a getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder
     */
    getPstnCallsWithFromDateTimeWithToDateTime(fromDateTime, toDateTime) {
        if (!fromDateTime)
            throw new Error("fromDateTime cannot be undefined");
        if (!toDateTime)
            throw new Error("toDateTime cannot be undefined");
        return new getPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder_1.GetPstnCallsWithFromDateTimeWithToDateTimeRequestBuilder(this.pathParameters, this.requestAdapter, fromDateTime, toDateTime);
    }
    ;
    /**
     * Create new navigation property to callRecords for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CallRecord
     */
    post(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPostRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createCallRecordFromDiscriminatorValue_1.createCallRecordFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.CallRecordsRequestBuilder = CallRecordsRequestBuilder;
