import { Call, CallCollectionResponse } from '../../models/';
import { CallsRequestBuilderGetRequestConfiguration } from './callsRequestBuilderGetRequestConfiguration';
import { CallsRequestBuilderPostRequestConfiguration } from './callsRequestBuilderPostRequestConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { LogTeleconferenceDeviceQualityRequestBuilder } from './logTeleconferenceDeviceQuality/logTeleconferenceDeviceQualityRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity. */
export declare class CallsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** The logTeleconferenceDeviceQuality property */
    get logTeleconferenceDeviceQuality(): LogTeleconferenceDeviceQualityRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new CallsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get calls from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: CallsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to calls for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: Call | undefined, requestConfiguration?: CallsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get calls from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CallCollectionResponse
     */
    get(requestConfiguration?: CallsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<CallCollectionResponse | undefined>;
    /**
     * Create new navigation property to calls for communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Call
     */
    post(body: Call | undefined, requestConfiguration?: CallsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Call | undefined>;
}
