import { Call } from '../../../models/';
import { AnswerRequestBuilder } from './answer/answerRequestBuilder';
import { AudioRoutingGroupsRequestBuilder } from './audioRoutingGroups/audioRoutingGroupsRequestBuilder';
import { AudioRoutingGroupItemRequestBuilder } from './audioRoutingGroups/item/audioRoutingGroupItemRequestBuilder';
import { CallItemRequestBuilderDeleteRequestConfiguration } from './callItemRequestBuilderDeleteRequestConfiguration';
import { CallItemRequestBuilderGetRequestConfiguration } from './callItemRequestBuilderGetRequestConfiguration';
import { CallItemRequestBuilderPatchRequestConfiguration } from './callItemRequestBuilderPatchRequestConfiguration';
import { CancelMediaProcessingRequestBuilder } from './cancelMediaProcessing/cancelMediaProcessingRequestBuilder';
import { ChangeScreenSharingRoleRequestBuilder } from './changeScreenSharingRole/changeScreenSharingRoleRequestBuilder';
import { KeepAliveRequestBuilder } from './keepAlive/keepAliveRequestBuilder';
import { MuteRequestBuilder } from './mute/muteRequestBuilder';
import { CommsOperationItemRequestBuilder } from './operations/item/commsOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { ParticipantItemRequestBuilder } from './participants/item/participantItemRequestBuilder';
import { ParticipantsRequestBuilder } from './participants/participantsRequestBuilder';
import { PlayPromptRequestBuilder } from './playPrompt/playPromptRequestBuilder';
import { RecordResponseRequestBuilder } from './recordResponse/recordResponseRequestBuilder';
import { RedirectRequestBuilder } from './redirect/redirectRequestBuilder';
import { RejectRequestBuilder } from './reject/rejectRequestBuilder';
import { SubscribeToToneRequestBuilder } from './subscribeToTone/subscribeToToneRequestBuilder';
import { TransferRequestBuilder } from './transfer/transferRequestBuilder';
import { UnmuteRequestBuilder } from './unmute/unmuteRequestBuilder';
import { UpdateRecordingStatusRequestBuilder } from './updateRecordingStatus/updateRecordingStatusRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity. */
export declare class CallItemRequestBuilder {
    /** The answer property */
    get answer(): AnswerRequestBuilder;
    /** The audioRoutingGroups property */
    get audioRoutingGroups(): AudioRoutingGroupsRequestBuilder;
    /** The cancelMediaProcessing property */
    get cancelMediaProcessing(): CancelMediaProcessingRequestBuilder;
    /** The changeScreenSharingRole property */
    get changeScreenSharingRole(): ChangeScreenSharingRoleRequestBuilder;
    /** The keepAlive property */
    get keepAlive(): KeepAliveRequestBuilder;
    /** The mute property */
    get mute(): MuteRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** The participants property */
    get participants(): ParticipantsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The playPrompt property */
    get playPrompt(): PlayPromptRequestBuilder;
    /** The recordResponse property */
    get recordResponse(): RecordResponseRequestBuilder;
    /** The redirect property */
    get redirect(): RedirectRequestBuilder;
    /** The reject property */
    get reject(): RejectRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The subscribeToTone property */
    get subscribeToTone(): SubscribeToToneRequestBuilder;
    /** The transfer property */
    get transfer(): TransferRequestBuilder;
    /** The unmute property */
    get unmute(): UnmuteRequestBuilder;
    /** The updateRecordingStatus property */
    get updateRecordingStatus(): UpdateRecordingStatusRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.audioRoutingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a audioRoutingGroupItemRequestBuilder
     */
    audioRoutingGroupsById(id: string): AudioRoutingGroupItemRequestBuilder;
    /**
     * Instantiates a new CallItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property calls for communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: CallItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get calls from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: CallItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Call | undefined, requestConfiguration?: CallItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property calls for communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: CallItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get calls from communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Call
     */
    get(requestConfiguration?: CallItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Call | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a commsOperationItemRequestBuilder
     */
    operationsById(id: string): CommsOperationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.participants.item collection
     * @param id Unique identifier of the item
     * @returns a participantItemRequestBuilder
     */
    participantsById(id: string): ParticipantItemRequestBuilder;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Call | undefined, requestConfiguration?: CallItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
