"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommunicationsRequestBuilder = void 0;
const createCloudCommunicationsFromDiscriminatorValue_1 = require("../models/createCloudCommunicationsFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const callRecordsRequestBuilder_1 = require("./callRecords/callRecordsRequestBuilder");
const callRecordItemRequestBuilder_1 = require("./callRecords/item/callRecordItemRequestBuilder");
const callsRequestBuilder_1 = require("./calls/callsRequestBuilder");
const callItemRequestBuilder_1 = require("./calls/item/callItemRequestBuilder");
const getPresencesByUserIdRequestBuilder_1 = require("./getPresencesByUserId/getPresencesByUserIdRequestBuilder");
const onlineMeetingItemRequestBuilder_1 = require("./onlineMeetings/item/onlineMeetingItemRequestBuilder");
const onlineMeetingsRequestBuilder_1 = require("./onlineMeetings/onlineMeetingsRequestBuilder");
const presenceItemRequestBuilder_1 = require("./presences/item/presenceItemRequestBuilder");
const presencesRequestBuilder_1 = require("./presences/presencesRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the cloudCommunications singleton. */
class CommunicationsRequestBuilder {
    /**
     * Instantiates a new CommunicationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/communications{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The callRecords property */
    get callRecords() {
        return new callRecordsRequestBuilder_1.CallRecordsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The calls property */
    get calls() {
        return new callsRequestBuilder_1.CallsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The getPresencesByUserId property */
    get getPresencesByUserId() {
        return new getPresencesByUserIdRequestBuilder_1.GetPresencesByUserIdRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The onlineMeetings property */
    get onlineMeetings() {
        return new onlineMeetingsRequestBuilder_1.OnlineMeetingsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The presences property */
    get presences() {
        return new presencesRequestBuilder_1.PresencesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.callRecords.item collection
     * @param id Unique identifier of the item
     * @returns a callRecordItemRequestBuilder
     */
    callRecordsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["callRecord%2Did"] = id;
        return new callRecordItemRequestBuilder_1.CallRecordItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item collection
     * @param id Unique identifier of the item
     * @returns a callItemRequestBuilder
     */
    callsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["call%2Did"] = id;
        return new callItemRequestBuilder_1.CallItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Get communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Get communications
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CloudCommunications
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createCloudCommunicationsFromDiscriminatorValue_1.createCloudCommunicationsFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.onlineMeetings.item collection
     * @param id Unique identifier of the item
     * @returns a onlineMeetingItemRequestBuilder
     */
    onlineMeetingsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onlineMeeting%2Did"] = id;
        return new onlineMeetingItemRequestBuilder_1.OnlineMeetingItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update communications
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.presences.item collection
     * @param id Unique identifier of the item
     * @returns a presenceItemRequestBuilder
     */
    presencesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["presence%2Did"] = id;
        return new presenceItemRequestBuilder_1.PresenceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.CommunicationsRequestBuilder = CommunicationsRequestBuilder;
