import { ExternalConnection } from '../../models/externalConnectors/';
import { ExternalConnectionItemRequestBuilderDeleteRequestConfiguration } from './externalConnectionItemRequestBuilderDeleteRequestConfiguration';
import { ExternalConnectionItemRequestBuilderGetRequestConfiguration } from './externalConnectionItemRequestBuilderGetRequestConfiguration';
import { ExternalConnectionItemRequestBuilderPatchRequestConfiguration } from './externalConnectionItemRequestBuilderPatchRequestConfiguration';
import { GroupsRequestBuilder } from './groups/groupsRequestBuilder';
import { ExternalGroupItemRequestBuilder } from './groups/item/externalGroupItemRequestBuilder';
import { ExternalItemItemRequestBuilder } from './items/item/externalItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ConnectionOperationItemRequestBuilder } from './operations/item/connectionOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { SchemaRequestBuilder } from './schema/schemaRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of externalConnection entities. */
export declare class ExternalConnectionItemRequestBuilder {
    /** The groups property */
    get groups(): GroupsRequestBuilder;
    /** The items property */
    get items(): ItemsRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The schema property */
    get schema(): SchemaRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ExternalConnectionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from connections
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ExternalConnectionItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entity from connections by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ExternalConnectionItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in connections
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ExternalConnection | undefined, requestConfiguration?: ExternalConnectionItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from connections
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ExternalConnectionItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get entity from connections by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ExternalConnection
     */
    get(requestConfiguration?: ExternalConnectionItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ExternalConnection | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.connections.item.groups.item collection
     * @param id Unique identifier of the item
     * @returns a externalGroupItemRequestBuilder
     */
    groupsById(id: string): ExternalGroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.connections.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a externalItemItemRequestBuilder
     */
    itemsById(id: string): ExternalItemItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.connections.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a connectionOperationItemRequestBuilder
     */
    operationsById(id: string): ConnectionOperationItemRequestBuilder;
    /**
     * Update entity in connections
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ExternalConnection | undefined, requestConfiguration?: ExternalConnectionItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
