import { Contract } from '../../models/';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/checkMemberGroupsRequestBuilder';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/checkMemberObjectsRequestBuilder';
import { ContractItemRequestBuilderDeleteRequestConfiguration } from './contractItemRequestBuilderDeleteRequestConfiguration';
import { ContractItemRequestBuilderGetRequestConfiguration } from './contractItemRequestBuilderGetRequestConfiguration';
import { ContractItemRequestBuilderPatchRequestConfiguration } from './contractItemRequestBuilderPatchRequestConfiguration';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/getMemberGroupsRequestBuilder';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/getMemberObjectsRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of contract entities. */
export declare class ContractItemRequestBuilder {
    /** The checkMemberGroups property */
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    /** The checkMemberObjects property */
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    /** The getMemberGroups property */
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    /** The getMemberObjects property */
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The restore property */
    get restore(): RestoreRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ContractItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from contracts
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ContractItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of [contract](../resources/contract.md) object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ContractItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in contracts
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Contract | undefined, requestConfiguration?: ContractItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from contracts
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ContractItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of [contract](../resources/contract.md) object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Contract
     */
    get(requestConfiguration?: ContractItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Contract | undefined>;
    /**
     * Update entity in contracts
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Contract | undefined, requestConfiguration?: ContractItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
