import { ManagedAppOperation } from '../../../../../models/';
import { ManagedAppOperationItemRequestBuilderDeleteRequestConfiguration } from './managedAppOperationItemRequestBuilderDeleteRequestConfiguration';
import { ManagedAppOperationItemRequestBuilderGetRequestConfiguration } from './managedAppOperationItemRequestBuilderGetRequestConfiguration';
import { ManagedAppOperationItemRequestBuilderPatchRequestConfiguration } from './managedAppOperationItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the operations property of the microsoft.graph.managedAppRegistration entity. */
export declare class ManagedAppOperationItemRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ManagedAppOperationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property operations for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ManagedAppOperationItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Zero or more long running operations triggered on the app registration.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ManagedAppOperationItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property operations in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ManagedAppOperation | undefined, requestConfiguration?: ManagedAppOperationItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property operations for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ManagedAppOperationItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Zero or more long running operations triggered on the app registration.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ManagedAppOperation
     */
    get(requestConfiguration?: ManagedAppOperationItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ManagedAppOperation | undefined>;
    /**
     * Update the navigation property operations in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ManagedAppOperation | undefined, requestConfiguration?: ManagedAppOperationItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
