import { ManagedEBook } from '../../../models/';
import { AssignRequestBuilder } from './assign/assignRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { ManagedEBookAssignmentItemRequestBuilder } from './assignments/item/managedEBookAssignmentItemRequestBuilder';
import { DeviceStatesRequestBuilder } from './deviceStates/deviceStatesRequestBuilder';
import { DeviceInstallStateItemRequestBuilder } from './deviceStates/item/deviceInstallStateItemRequestBuilder';
import { InstallSummaryRequestBuilder } from './installSummary/installSummaryRequestBuilder';
import { ManagedEBookItemRequestBuilderDeleteRequestConfiguration } from './managedEBookItemRequestBuilderDeleteRequestConfiguration';
import { ManagedEBookItemRequestBuilderGetRequestConfiguration } from './managedEBookItemRequestBuilderGetRequestConfiguration';
import { ManagedEBookItemRequestBuilderPatchRequestConfiguration } from './managedEBookItemRequestBuilderPatchRequestConfiguration';
import { UserInstallStateSummaryItemRequestBuilder } from './userStateSummary/item/userInstallStateSummaryItemRequestBuilder';
import { UserStateSummaryRequestBuilder } from './userStateSummary/userStateSummaryRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity. */
export declare class ManagedEBookItemRequestBuilder {
    /** The assign property */
    get assign(): AssignRequestBuilder;
    /** The assignments property */
    get assignments(): AssignmentsRequestBuilder;
    /** The deviceStates property */
    get deviceStates(): DeviceStatesRequestBuilder;
    /** The installSummary property */
    get installSummary(): InstallSummaryRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The userStateSummary property */
    get userStateSummary(): UserStateSummaryRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a managedEBookAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): ManagedEBookAssignmentItemRequestBuilder;
    /**
     * Instantiates a new ManagedEBookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ManagedEBookItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The Managed eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ManagedEBookItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ManagedEBook | undefined, requestConfiguration?: ManagedEBookItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ManagedEBookItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.deviceStates.item collection
     * @param id Unique identifier of the item
     * @returns a deviceInstallStateItemRequestBuilder
     */
    deviceStatesById(id: string): DeviceInstallStateItemRequestBuilder;
    /**
     * The Managed eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ManagedEBook
     */
    get(requestConfiguration?: ManagedEBookItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ManagedEBook | undefined>;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ManagedEBook | undefined, requestConfiguration?: ManagedEBookItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.userStateSummary.item collection
     * @param id Unique identifier of the item
     * @returns a userInstallStateSummaryItemRequestBuilder
     */
    userStateSummaryById(id: string): UserInstallStateSummaryItemRequestBuilder;
}
