"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagedEBookItemRequestBuilder = void 0;
const createManagedEBookFromDiscriminatorValue_1 = require("../../../models/createManagedEBookFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const assignRequestBuilder_1 = require("./assign/assignRequestBuilder");
const assignmentsRequestBuilder_1 = require("./assignments/assignmentsRequestBuilder");
const managedEBookAssignmentItemRequestBuilder_1 = require("./assignments/item/managedEBookAssignmentItemRequestBuilder");
const deviceStatesRequestBuilder_1 = require("./deviceStates/deviceStatesRequestBuilder");
const deviceInstallStateItemRequestBuilder_1 = require("./deviceStates/item/deviceInstallStateItemRequestBuilder");
const installSummaryRequestBuilder_1 = require("./installSummary/installSummaryRequestBuilder");
const userInstallStateSummaryItemRequestBuilder_1 = require("./userStateSummary/item/userInstallStateSummaryItemRequestBuilder");
const userStateSummaryRequestBuilder_1 = require("./userStateSummary/userStateSummaryRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity. */
class ManagedEBookItemRequestBuilder {
    /**
     * Instantiates a new ManagedEBookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/deviceAppManagement/managedEBooks/{managedEBook%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The assign property */
    get assign() {
        return new assignRequestBuilder_1.AssignRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignments property */
    get assignments() {
        return new assignmentsRequestBuilder_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The deviceStates property */
    get deviceStates() {
        return new deviceStatesRequestBuilder_1.DeviceStatesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The installSummary property */
    get installSummary() {
        return new installSummaryRequestBuilder_1.InstallSummaryRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The userStateSummary property */
    get userStateSummary() {
        return new userStateSummaryRequestBuilder_1.UserStateSummaryRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a managedEBookAssignmentItemRequestBuilder
     */
    assignmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["managedEBookAssignment%2Did"] = id;
        return new managedEBookAssignmentItemRequestBuilder_1.ManagedEBookAssignmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * The Managed eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.deviceStates.item collection
     * @param id Unique identifier of the item
     * @returns a deviceInstallStateItemRequestBuilder
     */
    deviceStatesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceInstallState%2Did"] = id;
        return new deviceInstallStateItemRequestBuilder_1.DeviceInstallStateItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * The Managed eBook.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ManagedEBook
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createManagedEBookFromDiscriminatorValue_1.createManagedEBookFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.userStateSummary.item collection
     * @param id Unique identifier of the item
     * @returns a userInstallStateSummaryItemRequestBuilder
     */
    userStateSummaryById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["userInstallStateSummary%2Did"] = id;
        return new userInstallStateSummaryItemRequestBuilder_1.UserInstallStateSummaryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.ManagedEBookItemRequestBuilder = ManagedEBookItemRequestBuilder;
