import { MobileApp } from '../../../models/';
import { AssignRequestBuilder } from './assign/assignRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { MobileAppAssignmentItemRequestBuilder } from './assignments/item/mobileAppAssignmentItemRequestBuilder';
import { CategoriesRequestBuilder } from './categories/categoriesRequestBuilder';
import { MobileAppCategoryItemRequestBuilder } from './categories/item/mobileAppCategoryItemRequestBuilder';
import { ManagedMobileLobAppRequestBuilder } from './managedMobileLobApp/managedMobileLobAppRequestBuilder';
import { MobileAppItemRequestBuilderDeleteRequestConfiguration } from './mobileAppItemRequestBuilderDeleteRequestConfiguration';
import { MobileAppItemRequestBuilderGetRequestConfiguration } from './mobileAppItemRequestBuilderGetRequestConfiguration';
import { MobileAppItemRequestBuilderPatchRequestConfiguration } from './mobileAppItemRequestBuilderPatchRequestConfiguration';
import { MobileLobAppRequestBuilder } from './mobileLobApp/mobileLobAppRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the mobileApps property of the microsoft.graph.deviceAppManagement entity. */
export declare class MobileAppItemRequestBuilder {
    /** The assign property */
    get assign(): AssignRequestBuilder;
    /** The assignments property */
    get assignments(): AssignmentsRequestBuilder;
    /** The categories property */
    get categories(): CategoriesRequestBuilder;
    /** The managedMobileLobApp property */
    get managedMobileLobApp(): ManagedMobileLobAppRequestBuilder;
    /** The mobileLobApp property */
    get mobileLobApp(): MobileLobAppRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.mobileApps.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a mobileAppAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): MobileAppAssignmentItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.mobileApps.item.categories.item collection
     * @param id Unique identifier of the item
     * @returns a mobileAppCategoryItemRequestBuilder
     */
    categoriesById(id: string): MobileAppCategoryItemRequestBuilder;
    /**
     * Instantiates a new MobileAppItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property mobileApps for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: MobileAppItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The mobile apps.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: MobileAppItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property mobileApps in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: MobileApp | undefined, requestConfiguration?: MobileAppItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property mobileApps for deviceAppManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: MobileAppItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The mobile apps.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of MobileApp
     */
    get(requestConfiguration?: MobileAppItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<MobileApp | undefined>;
    /**
     * Update the navigation property mobileApps in deviceAppManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: MobileApp | undefined, requestConfiguration?: MobileAppItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
