"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceCompliancePolicyItemRequestBuilder = void 0;
const createDeviceCompliancePolicyFromDiscriminatorValue_1 = require("../../../models/createDeviceCompliancePolicyFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const assignRequestBuilder_1 = require("./assign/assignRequestBuilder");
const assignmentsRequestBuilder_1 = require("./assignments/assignmentsRequestBuilder");
const deviceCompliancePolicyAssignmentItemRequestBuilder_1 = require("./assignments/item/deviceCompliancePolicyAssignmentItemRequestBuilder");
const deviceSettingStateSummariesRequestBuilder_1 = require("./deviceSettingStateSummaries/deviceSettingStateSummariesRequestBuilder");
const settingStateDeviceSummaryItemRequestBuilder_1 = require("./deviceSettingStateSummaries/item/settingStateDeviceSummaryItemRequestBuilder");
const deviceStatusesRequestBuilder_1 = require("./deviceStatuses/deviceStatusesRequestBuilder");
const deviceComplianceDeviceStatusItemRequestBuilder_1 = require("./deviceStatuses/item/deviceComplianceDeviceStatusItemRequestBuilder");
const deviceStatusOverviewRequestBuilder_1 = require("./deviceStatusOverview/deviceStatusOverviewRequestBuilder");
const scheduleActionsForRulesRequestBuilder_1 = require("./scheduleActionsForRules/scheduleActionsForRulesRequestBuilder");
const deviceComplianceScheduledActionForRuleItemRequestBuilder_1 = require("./scheduledActionsForRule/item/deviceComplianceScheduledActionForRuleItemRequestBuilder");
const scheduledActionsForRuleRequestBuilder_1 = require("./scheduledActionsForRule/scheduledActionsForRuleRequestBuilder");
const deviceComplianceUserStatusItemRequestBuilder_1 = require("./userStatuses/item/deviceComplianceUserStatusItemRequestBuilder");
const userStatusesRequestBuilder_1 = require("./userStatuses/userStatusesRequestBuilder");
const userStatusOverviewRequestBuilder_1 = require("./userStatusOverview/userStatusOverviewRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the deviceCompliancePolicies property of the microsoft.graph.deviceManagement entity. */
class DeviceCompliancePolicyItemRequestBuilder {
    /**
     * Instantiates a new DeviceCompliancePolicyItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/deviceManagement/deviceCompliancePolicies/{deviceCompliancePolicy%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The assign property */
    get assign() {
        return new assignRequestBuilder_1.AssignRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignments property */
    get assignments() {
        return new assignmentsRequestBuilder_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The deviceSettingStateSummaries property */
    get deviceSettingStateSummaries() {
        return new deviceSettingStateSummariesRequestBuilder_1.DeviceSettingStateSummariesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The deviceStatuses property */
    get deviceStatuses() {
        return new deviceStatusesRequestBuilder_1.DeviceStatusesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The deviceStatusOverview property */
    get deviceStatusOverview() {
        return new deviceStatusOverviewRequestBuilder_1.DeviceStatusOverviewRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The scheduleActionsForRules property */
    get scheduleActionsForRules() {
        return new scheduleActionsForRulesRequestBuilder_1.ScheduleActionsForRulesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The scheduledActionsForRule property */
    get scheduledActionsForRule() {
        return new scheduledActionsForRuleRequestBuilder_1.ScheduledActionsForRuleRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The userStatuses property */
    get userStatuses() {
        return new userStatusesRequestBuilder_1.UserStatusesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The userStatusOverview property */
    get userStatusOverview() {
        return new userStatusOverviewRequestBuilder_1.UserStatusOverviewRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a deviceCompliancePolicyAssignmentItemRequestBuilder
     */
    assignmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceCompliancePolicyAssignment%2Did"] = id;
        return new deviceCompliancePolicyAssignmentItemRequestBuilder_1.DeviceCompliancePolicyAssignmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property deviceCompliancePolicies for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * The device compliance policies.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property deviceCompliancePolicies in deviceManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property deviceCompliancePolicies for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.deviceSettingStateSummaries.item collection
     * @param id Unique identifier of the item
     * @returns a settingStateDeviceSummaryItemRequestBuilder
     */
    deviceSettingStateSummariesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["settingStateDeviceSummary%2Did"] = id;
        return new settingStateDeviceSummaryItemRequestBuilder_1.SettingStateDeviceSummaryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.deviceStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceDeviceStatusItemRequestBuilder
     */
    deviceStatusesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceComplianceDeviceStatus%2Did"] = id;
        return new deviceComplianceDeviceStatusItemRequestBuilder_1.DeviceComplianceDeviceStatusItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * The device compliance policies.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DeviceCompliancePolicy
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDeviceCompliancePolicyFromDiscriminatorValue_1.createDeviceCompliancePolicyFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property deviceCompliancePolicies in deviceManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.scheduledActionsForRule.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceScheduledActionForRuleItemRequestBuilder
     */
    scheduledActionsForRuleById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceComplianceScheduledActionForRule%2Did"] = id;
        return new deviceComplianceScheduledActionForRuleItemRequestBuilder_1.DeviceComplianceScheduledActionForRuleItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.userStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceUserStatusItemRequestBuilder
     */
    userStatusesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceComplianceUserStatus%2Did"] = id;
        return new deviceComplianceUserStatusItemRequestBuilder_1.DeviceComplianceUserStatusItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.DeviceCompliancePolicyItemRequestBuilder = DeviceCompliancePolicyItemRequestBuilder;
