"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceComplianceScheduledActionForRuleItemRequestBuilder = void 0;
const createDeviceComplianceScheduledActionForRuleFromDiscriminatorValue_1 = require("../../../../../models/createDeviceComplianceScheduledActionForRuleFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const deviceComplianceActionItemItemRequestBuilder_1 = require("./scheduledActionConfigurations/item/deviceComplianceActionItemItemRequestBuilder");
const scheduledActionConfigurationsRequestBuilder_1 = require("./scheduledActionConfigurations/scheduledActionConfigurationsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the scheduledActionsForRule property of the microsoft.graph.deviceCompliancePolicy entity. */
class DeviceComplianceScheduledActionForRuleItemRequestBuilder {
    /**
     * Instantiates a new DeviceComplianceScheduledActionForRuleItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/deviceManagement/deviceCompliancePolicies/{deviceCompliancePolicy%2Did}/scheduledActionsForRule/{deviceComplianceScheduledActionForRule%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The scheduledActionConfigurations property */
    get scheduledActionConfigurations() {
        return new scheduledActionConfigurationsRequestBuilder_1.ScheduledActionConfigurationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property scheduledActionsForRule for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * The list of scheduled action for this rule
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property scheduledActionsForRule in deviceManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property scheduledActionsForRule for deviceManagement
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The list of scheduled action for this rule
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DeviceComplianceScheduledActionForRule
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDeviceComplianceScheduledActionForRuleFromDiscriminatorValue_1.createDeviceComplianceScheduledActionForRuleFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property scheduledActionsForRule in deviceManagement
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.scheduledActionsForRule.item.scheduledActionConfigurations.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceActionItemItemRequestBuilder
     */
    scheduledActionConfigurationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceComplianceActionItem%2Did"] = id;
        return new deviceComplianceActionItemItemRequestBuilder_1.DeviceComplianceActionItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.DeviceComplianceScheduledActionForRuleItemRequestBuilder = DeviceComplianceScheduledActionForRuleItemRequestBuilder;
