import { Device } from '../../models/';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/checkMemberGroupsRequestBuilder';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/checkMemberObjectsRequestBuilder';
import { DeviceItemRequestBuilderDeleteRequestConfiguration } from './deviceItemRequestBuilderDeleteRequestConfiguration';
import { DeviceItemRequestBuilderGetRequestConfiguration } from './deviceItemRequestBuilderGetRequestConfiguration';
import { DeviceItemRequestBuilderPatchRequestConfiguration } from './deviceItemRequestBuilderPatchRequestConfiguration';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/getMemberGroupsRequestBuilder';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/getMemberObjectsRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i0ebb124b96530fe08eb93f26bd86e265f47c94af705d2cfa5a0c53127776ca6b } from './memberOf/item/directoryObjectItemRequestBuilder';
import { MemberOfRequestBuilder } from './memberOf/memberOfRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i720ad37b97930b80b3f5bbb1b4038448eafad717077bb859fd252be562580268 } from './registeredOwners/item/directoryObjectItemRequestBuilder';
import { RegisteredOwnersRequestBuilder } from './registeredOwners/registeredOwnersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i1be53fb9da2e6be012ab05199d1fe3393dcc20ebd6426818051576508fe78f50 } from './registeredUsers/item/directoryObjectItemRequestBuilder';
import { RegisteredUsersRequestBuilder } from './registeredUsers/registeredUsersRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { DirectoryObjectItemRequestBuilder as ia4ba2f426acff50051cf7d673bd053995c3a14a065718acaea9557282dfae069 } from './transitiveMemberOf/item/directoryObjectItemRequestBuilder';
import { TransitiveMemberOfRequestBuilder } from './transitiveMemberOf/transitiveMemberOfRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of device entities. */
export declare class DeviceItemRequestBuilder {
    /** The checkMemberGroups property */
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    /** The checkMemberObjects property */
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The getMemberGroups property */
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    /** The getMemberObjects property */
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    /** The memberOf property */
    get memberOf(): MemberOfRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The registeredOwners property */
    get registeredOwners(): RegisteredOwnersRequestBuilder;
    /** The registeredUsers property */
    get registeredUsers(): RegisteredUsersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The restore property */
    get restore(): RestoreRequestBuilder;
    /** The transitiveMemberOf property */
    get transitiveMemberOf(): TransitiveMemberOfRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DeviceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a registered device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DeviceItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get the properties and relationships of a device object. Since the **device** resource supports [extensions](/graph/extensibility-overview), you can also use the `GET` operation to get custom properties and extension data in a **device** instance.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DeviceItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of a device. Only certain properties of a device can be updated through approved Mobile Device Management (MDM) apps.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Device | undefined, requestConfiguration?: DeviceItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete a registered device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DeviceItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * Get the properties and relationships of a device object. Since the **device** resource supports [extensions](/graph/extensibility-overview), you can also use the `GET` operation to get custom properties and extension data in a **device** instance.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Device
     */
    get(requestConfiguration?: DeviceItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Device | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.memberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    memberOfById(id: string): i0ebb124b96530fe08eb93f26bd86e265f47c94af705d2cfa5a0c53127776ca6b;
    /**
     * Update the properties of a device. Only certain properties of a device can be updated through approved Mobile Device Management (MDM) apps.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Device | undefined, requestConfiguration?: DeviceItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.registeredOwners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredOwnersById(id: string): i720ad37b97930b80b3f5bbb1b4038448eafad717077bb859fd252be562580268;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.registeredUsers.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredUsersById(id: string): i1be53fb9da2e6be012ab05199d1fe3393dcc20ebd6426818051576508fe78f50;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.devices.item.transitiveMemberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    transitiveMemberOfById(id: string): ia4ba2f426acff50051cf7d673bd053995c3a14a065718acaea9557282dfae069;
}
