import { Directory } from '../models/';
import { AdministrativeUnitsRequestBuilder } from './administrativeUnits/administrativeUnitsRequestBuilder';
import { AdministrativeUnitItemRequestBuilder } from './administrativeUnits/item/administrativeUnitItemRequestBuilder';
import { DeletedItemsRequestBuilder } from './deletedItems/deletedItemsRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './deletedItems/item/directoryObjectItemRequestBuilder';
import { DirectoryRequestBuilderGetRequestConfiguration } from './directoryRequestBuilderGetRequestConfiguration';
import { DirectoryRequestBuilderPatchRequestConfiguration } from './directoryRequestBuilderPatchRequestConfiguration';
import { FederationConfigurationsRequestBuilder } from './federationConfigurations/federationConfigurationsRequestBuilder';
import { IdentityProviderBaseItemRequestBuilder } from './federationConfigurations/item/identityProviderBaseItemRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the directory singleton. */
export declare class DirectoryRequestBuilder {
    /** The administrativeUnits property */
    get administrativeUnits(): AdministrativeUnitsRequestBuilder;
    /** The deletedItems property */
    get deletedItems(): DeletedItemsRequestBuilder;
    /** The federationConfigurations property */
    get federationConfigurations(): FederationConfigurationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.directory.administrativeUnits.item collection
     * @param id Unique identifier of the item
     * @returns a administrativeUnitItemRequestBuilder
     */
    administrativeUnitsById(id: string): AdministrativeUnitItemRequestBuilder;
    /**
     * Instantiates a new DirectoryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DirectoryRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update directory
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Directory | undefined, requestConfiguration?: DirectoryRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.directory.deletedItems.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    deletedItemsById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.directory.federationConfigurations.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderBaseItemRequestBuilder
     */
    federationConfigurationsById(id: string): IdentityProviderBaseItemRequestBuilder;
    /**
     * Get directory
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Directory
     */
    get(requestConfiguration?: DirectoryRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Directory | undefined>;
    /**
     * Update directory
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Directory | undefined, requestConfiguration?: DirectoryRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
