import { IdentityProviderBase, IdentityProviderBaseCollectionResponse } from '../../models/';
import { AvailableProviderTypesRequestBuilder } from './availableProviderTypes/availableProviderTypesRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { FederationConfigurationsRequestBuilderGetRequestConfiguration } from './federationConfigurationsRequestBuilderGetRequestConfiguration';
import { FederationConfigurationsRequestBuilderPostRequestConfiguration } from './federationConfigurationsRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the federationConfigurations property of the microsoft.graph.directory entity. */
export declare class FederationConfigurationsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Provides operations to call the availableProviderTypes method.
     * @returns a availableProviderTypesRequestBuilder
     */
    availableProviderTypes(): AvailableProviderTypesRequestBuilder;
    /**
     * Instantiates a new FederationConfigurationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Configure domain federation with organizations whose identity provider (IdP) supports either the SAML or WS-Fed protocol.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: FederationConfigurationsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to federationConfigurations for directory
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: IdentityProviderBase | undefined, requestConfiguration?: FederationConfigurationsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Configure domain federation with organizations whose identity provider (IdP) supports either the SAML or WS-Fed protocol.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProviderBaseCollectionResponse
     */
    get(requestConfiguration?: FederationConfigurationsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProviderBaseCollectionResponse | undefined>;
    /**
     * Create new navigation property to federationConfigurations for directory
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProviderBase
     */
    post(body: IdentityProviderBase | undefined, requestConfiguration?: FederationConfigurationsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProviderBase | undefined>;
}
