import { DirectoryObject, DirectoryObjectCollectionResponse } from '../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DirectoryObjectsRequestBuilderGetRequestConfiguration } from './directoryObjectsRequestBuilderGetRequestConfiguration';
import { DirectoryObjectsRequestBuilderPostRequestConfiguration } from './directoryObjectsRequestBuilderPostRequestConfiguration';
import { GetAvailableExtensionPropertiesRequestBuilder } from './getAvailableExtensionProperties/getAvailableExtensionPropertiesRequestBuilder';
import { GetByIdsRequestBuilder } from './getByIds/getByIdsRequestBuilder';
import { ValidatePropertiesRequestBuilder } from './validateProperties/validatePropertiesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of directoryObject entities. */
export declare class DirectoryObjectsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** The getAvailableExtensionProperties property */
    get getAvailableExtensionProperties(): GetAvailableExtensionPropertiesRequestBuilder;
    /** The getByIds property */
    get getByIds(): GetByIdsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The validateProperties property */
    get validateProperties(): ValidatePropertiesRequestBuilder;
    /**
     * Instantiates a new DirectoryObjectsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from directoryObjects
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DirectoryObjectsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to directoryObjects
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: DirectoryObject | undefined, requestConfiguration?: DirectoryObjectsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entities from directoryObjects
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObjectCollectionResponse
     */
    get(requestConfiguration?: DirectoryObjectsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DirectoryObjectCollectionResponse | undefined>;
    /**
     * Add new entity to directoryObjects
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObject
     */
    post(body: DirectoryObject | undefined, requestConfiguration?: DirectoryObjectsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DirectoryObject | undefined>;
}
