import { DirectoryRole } from '../../models/';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/checkMemberGroupsRequestBuilder';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/checkMemberObjectsRequestBuilder';
import { DirectoryRoleItemRequestBuilderDeleteRequestConfiguration } from './directoryRoleItemRequestBuilderDeleteRequestConfiguration';
import { DirectoryRoleItemRequestBuilderGetRequestConfiguration } from './directoryRoleItemRequestBuilderGetRequestConfiguration';
import { DirectoryRoleItemRequestBuilderPatchRequestConfiguration } from './directoryRoleItemRequestBuilderPatchRequestConfiguration';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/getMemberGroupsRequestBuilder';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/getMemberObjectsRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './members/item/directoryObjectItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { ScopedRoleMembershipItemRequestBuilder } from './scopedMembers/item/scopedRoleMembershipItemRequestBuilder';
import { ScopedMembersRequestBuilder } from './scopedMembers/scopedMembersRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of directoryRole entities. */
export declare class DirectoryRoleItemRequestBuilder {
    /** The checkMemberGroups property */
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    /** The checkMemberObjects property */
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    /** The getMemberGroups property */
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    /** The getMemberObjects property */
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    /** The members property */
    get members(): MembersRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The restore property */
    get restore(): RestoreRequestBuilder;
    /** The scopedMembers property */
    get scopedMembers(): ScopedMembersRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DirectoryRoleItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from directoryRoles
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DirectoryRoleItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties of a directoryRole object. You can use both the object ID and template ID of the **directoryRole** with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see [Role template IDs](/azure/active-directory/users-groups-roles/directory-assign-admin-roles#role-template-ids).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DirectoryRoleItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in directoryRoles
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DirectoryRole | undefined, requestConfiguration?: DirectoryRoleItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from directoryRoles
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DirectoryRoleItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Retrieve the properties of a directoryRole object. You can use both the object ID and template ID of the **directoryRole** with this API. The template ID of a built-in role is immutable and can be seen in the role description on the Azure portal. For details, see [Role template IDs](/azure/active-directory/users-groups-roles/directory-assign-admin-roles#role-template-ids).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryRole
     */
    get(requestConfiguration?: DirectoryRoleItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DirectoryRole | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.directoryRoles.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    membersById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * Update entity in directoryRoles
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DirectoryRole | undefined, requestConfiguration?: DirectoryRoleItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.directoryRoles.item.scopedMembers.item collection
     * @param id Unique identifier of the item
     * @returns a scopedRoleMembershipItemRequestBuilder
     */
    scopedMembersById(id: string): ScopedRoleMembershipItemRequestBuilder;
}
