import { Domain } from '../../models/';
import { DomainItemRequestBuilderDeleteRequestConfiguration } from './domainItemRequestBuilderDeleteRequestConfiguration';
import { DomainItemRequestBuilderGetRequestConfiguration } from './domainItemRequestBuilderGetRequestConfiguration';
import { DomainItemRequestBuilderPatchRequestConfiguration } from './domainItemRequestBuilderPatchRequestConfiguration';
import { DomainNameReferencesRequestBuilder } from './domainNameReferences/domainNameReferencesRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './domainNameReferences/item/directoryObjectItemRequestBuilder';
import { FederationConfigurationRequestBuilder } from './federationConfiguration/federationConfigurationRequestBuilder';
import { InternalDomainFederationItemRequestBuilder } from './federationConfiguration/item/internalDomainFederationItemRequestBuilder';
import { ForceDeleteRequestBuilder } from './forceDelete/forceDeleteRequestBuilder';
import { DomainDnsRecordItemRequestBuilder as if42c50e3e2ba9cccdeb447503ef296586e785bdceb37d68d3f26a20ec7a74730 } from './serviceConfigurationRecords/item/domainDnsRecordItemRequestBuilder';
import { ServiceConfigurationRecordsRequestBuilder } from './serviceConfigurationRecords/serviceConfigurationRecordsRequestBuilder';
import { DomainDnsRecordItemRequestBuilder as i34c2b049a11a56a0e845314c4913041442dc5d005e49ac8abe88e67f09a2a130 } from './verificationDnsRecords/item/domainDnsRecordItemRequestBuilder';
import { VerificationDnsRecordsRequestBuilder } from './verificationDnsRecords/verificationDnsRecordsRequestBuilder';
import { VerifyRequestBuilder } from './verify/verifyRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of domain entities. */
export declare class DomainItemRequestBuilder {
    /** The domainNameReferences property */
    get domainNameReferences(): DomainNameReferencesRequestBuilder;
    /** The federationConfiguration property */
    get federationConfiguration(): FederationConfigurationRequestBuilder;
    /** The forceDelete property */
    get forceDelete(): ForceDeleteRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The serviceConfigurationRecords property */
    get serviceConfigurationRecords(): ServiceConfigurationRecordsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The verificationDnsRecords property */
    get verificationDnsRecords(): VerificationDnsRecordsRequestBuilder;
    /** The verify property */
    get verify(): VerifyRequestBuilder;
    /**
     * Instantiates a new DomainItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Deletes a domain from a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DomainItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of domain object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DomainItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of domain object.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Domain | undefined, requestConfiguration?: DomainItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Deletes a domain from a tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DomainItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.domainNameReferences.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    domainNameReferencesById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.federationConfiguration.item collection
     * @param id Unique identifier of the item
     * @returns a internalDomainFederationItemRequestBuilder
     */
    federationConfigurationById(id: string): InternalDomainFederationItemRequestBuilder;
    /**
     * Retrieve the properties and relationships of domain object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Domain
     */
    get(requestConfiguration?: DomainItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Domain | undefined>;
    /**
     * Update the properties of domain object.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Domain | undefined, requestConfiguration?: DomainItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.serviceConfigurationRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    serviceConfigurationRecordsById(id: string): if42c50e3e2ba9cccdeb447503ef296586e785bdceb37d68d3f26a20ec7a74730;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.verificationDnsRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    verificationDnsRecordsById(id: string): i34c2b049a11a56a0e845314c4913041442dc5d005e49ac8abe88e67f09a2a130;
}
