import { Drive } from '../models/';
import { BundlesRequestBuilder } from './bundles/bundlesRequestBuilder';
import { DriveItemItemRequestBuilder as i8206508961c572e18e631114dbc7102078ce94aab7b8e2ace987563ef389a2b2 } from './bundles/item/driveItemItemRequestBuilder';
import { DriveRequestBuilderGetRequestConfiguration } from './driveRequestBuilderGetRequestConfiguration';
import { DriveRequestBuilderPatchRequestConfiguration } from './driveRequestBuilderPatchRequestConfiguration';
import { FollowingRequestBuilder } from './following/followingRequestBuilder';
import { DriveItemItemRequestBuilder as i6131ecb129fca5d2c95f365ce93927497eaeadbbd709849676be27876dbdb482 } from './following/item/driveItemItemRequestBuilder';
import { DriveItemItemRequestBuilder as if6641a0c0f7d5944718f22b718fe31af69df3042eacd0757d2f0374e4c5080dd } from './items/item/driveItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListRequestBuilder } from './list/listRequestBuilder';
import { RecentRequestBuilder } from './recent/recentRequestBuilder';
import { RootRequestBuilder } from './root/rootRequestBuilder';
import { SearchWithQRequestBuilder } from './searchWithQ/searchWithQRequestBuilder';
import { SharedWithMeRequestBuilder } from './sharedWithMe/sharedWithMeRequestBuilder';
import { DriveItemItemRequestBuilder as i804e640d2b824d667662b3596525b21e5d37b8f7eb021c8974a3cd25c8aa1519 } from './special/item/driveItemItemRequestBuilder';
import { SpecialRequestBuilder } from './special/specialRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the drive singleton. */
export declare class DriveRequestBuilder {
    /** The bundles property */
    get bundles(): BundlesRequestBuilder;
    /** The following property */
    get following(): FollowingRequestBuilder;
    /** The items property */
    get items(): ItemsRequestBuilder;
    /** The list property */
    get list(): ListRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The root property */
    get root(): RootRequestBuilder;
    /** The special property */
    get special(): SpecialRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.bundles.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    bundlesById(id: string): i8206508961c572e18e631114dbc7102078ce94aab7b8e2ace987563ef389a2b2;
    /**
     * Instantiates a new DriveRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get drive
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DriveRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update drive
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Drive | undefined, requestConfiguration?: DriveRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.following.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    followingById(id: string): i6131ecb129fca5d2c95f365ce93927497eaeadbbd709849676be27876dbdb482;
    /**
     * Get drive
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Drive
     */
    get(requestConfiguration?: DriveRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Drive | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.items.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    itemsById(id: string): if6641a0c0f7d5944718f22b718fe31af69df3042eacd0757d2f0374e4c5080dd;
    /**
     * Update drive
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Drive | undefined, requestConfiguration?: DriveRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the recent method.
     * @returns a recentRequestBuilder
     */
    recent(): RecentRequestBuilder;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q: string | undefined): SearchWithQRequestBuilder;
    /**
     * Provides operations to call the sharedWithMe method.
     * @returns a sharedWithMeRequestBuilder
     */
    sharedWithMe(): SharedWithMeRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.special.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    specialById(id: string): i804e640d2b824d667662b3596525b21e5d37b8f7eb021c8974a3cd25c8aa1519;
}
