import { List } from '../../models/';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ColumnDefinitionItemRequestBuilder } from './columns/item/columnDefinitionItemRequestBuilder';
import { ContentTypesRequestBuilder } from './contentTypes/contentTypesRequestBuilder';
import { ContentTypeItemRequestBuilder } from './contentTypes/item/contentTypeItemRequestBuilder';
import { DriveRequestBuilder } from './drive/driveRequestBuilder';
import { ListItemItemRequestBuilder } from './items/item/listItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListRequestBuilderDeleteRequestConfiguration } from './listRequestBuilderDeleteRequestConfiguration';
import { ListRequestBuilderGetRequestConfiguration } from './listRequestBuilderGetRequestConfiguration';
import { ListRequestBuilderPatchRequestConfiguration } from './listRequestBuilderPatchRequestConfiguration';
import { RichLongRunningOperationItemRequestBuilder } from './operations/item/richLongRunningOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the list property of the microsoft.graph.drive entity. */
export declare class ListRequestBuilder {
    /** The columns property */
    get columns(): ColumnsRequestBuilder;
    /** The contentTypes property */
    get contentTypes(): ContentTypesRequestBuilder;
    /** The drive property */
    get drive(): DriveRequestBuilder;
    /** The items property */
    get items(): ItemsRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The subscriptions property */
    get subscriptions(): SubscriptionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.list.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id: string): ColumnDefinitionItemRequestBuilder;
    /**
     * Instantiates a new ListRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.list.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id: string): ContentTypeItemRequestBuilder;
    /**
     * Delete navigation property list for drive
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ListRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ListRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property list in drive
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: List | undefined, requestConfiguration?: ListRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property list for drive
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ListRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of List
     */
    get(requestConfiguration?: ListRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<List | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.list.items.item collection
     * @param id Unique identifier of the item
     * @returns a listItemItemRequestBuilder
     */
    itemsById(id: string): ListItemItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.list.operations.item collection
     * @param id Unique identifier of the item
     * @returns a richLongRunningOperationItemRequestBuilder
     */
    operationsById(id: string): RichLongRunningOperationItemRequestBuilder;
    /**
     * Update the navigation property list in drive
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: List | undefined, requestConfiguration?: ListRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drive.list.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
}
