import { EducationAssignment } from '../../../../../models/';
import { CategoriesRequestBuilder } from './categories/categoriesRequestBuilder';
import { EducationCategoryItemRequestBuilder } from './categories/item/educationCategoryItemRequestBuilder';
import { EducationAssignmentItemRequestBuilderDeleteRequestConfiguration } from './educationAssignmentItemRequestBuilderDeleteRequestConfiguration';
import { EducationAssignmentItemRequestBuilderGetRequestConfiguration } from './educationAssignmentItemRequestBuilderGetRequestConfiguration';
import { EducationAssignmentItemRequestBuilderPatchRequestConfiguration } from './educationAssignmentItemRequestBuilderPatchRequestConfiguration';
import { PublishRequestBuilder } from './publish/publishRequestBuilder';
import { EducationAssignmentResourceItemRequestBuilder } from './resources/item/educationAssignmentResourceItemRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { RubricRequestBuilder } from './rubric/rubricRequestBuilder';
import { SetUpResourcesFolderRequestBuilder } from './setUpResourcesFolder/setUpResourcesFolderRequestBuilder';
import { EducationSubmissionItemRequestBuilder } from './submissions/item/educationSubmissionItemRequestBuilder';
import { SubmissionsRequestBuilder } from './submissions/submissionsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the assignments property of the microsoft.graph.educationClass entity. */
export declare class EducationAssignmentItemRequestBuilder {
    /** The categories property */
    get categories(): CategoriesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The publish property */
    get publish(): PublishRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The resources property */
    get resources(): ResourcesRequestBuilder;
    /** The rubric property */
    get rubric(): RubricRequestBuilder;
    /** The setUpResourcesFolder property */
    get setUpResourcesFolder(): SetUpResourcesFolderRequestBuilder;
    /** The submissions property */
    get submissions(): SubmissionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.assignments.item.categories.item collection
     * @param id Unique identifier of the item
     * @returns a educationCategoryItemRequestBuilder
     */
    categoriesById(id: string): EducationCategoryItemRequestBuilder;
    /**
     * Instantiates a new EducationAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignments for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: EducationAssignmentItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * All assignments associated with this class. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: EducationAssignmentItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: EducationAssignment | undefined, requestConfiguration?: EducationAssignmentItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property assignments for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: EducationAssignmentItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * All assignments associated with this class. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationAssignment
     */
    get(requestConfiguration?: EducationAssignmentItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: EducationAssignment | undefined, requestConfiguration?: EducationAssignmentItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.assignments.item.resources.item collection
     * @param id Unique identifier of the item
     * @returns a educationAssignmentResourceItemRequestBuilder
     */
    resourcesById(id: string): EducationAssignmentResourceItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.assignments.item.submissions.item collection
     * @param id Unique identifier of the item
     * @returns a educationSubmissionItemRequestBuilder
     */
    submissionsById(id: string): EducationSubmissionItemRequestBuilder;
}
