"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EducationClassItemRequestBuilder = void 0;
const createEducationClassFromDiscriminatorValue_1 = require("../../../models/createEducationClassFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const assignmentCategoriesRequestBuilder_1 = require("./assignmentCategories/assignmentCategoriesRequestBuilder");
const educationCategoryItemRequestBuilder_1 = require("./assignmentCategories/item/educationCategoryItemRequestBuilder");
const assignmentDefaultsRequestBuilder_1 = require("./assignmentDefaults/assignmentDefaultsRequestBuilder");
const assignmentsRequestBuilder_1 = require("./assignments/assignmentsRequestBuilder");
const educationAssignmentItemRequestBuilder_1 = require("./assignments/item/educationAssignmentItemRequestBuilder");
const assignmentSettingsRequestBuilder_1 = require("./assignmentSettings/assignmentSettingsRequestBuilder");
const groupRequestBuilder_1 = require("./group/groupRequestBuilder");
const educationUserItemRequestBuilder_1 = require("./members/item/educationUserItemRequestBuilder");
const membersRequestBuilder_1 = require("./members/membersRequestBuilder");
const educationSchoolItemRequestBuilder_1 = require("./schools/item/educationSchoolItemRequestBuilder");
const schoolsRequestBuilder_1 = require("./schools/schoolsRequestBuilder");
const educationUserItemRequestBuilder_2 = require("./teachers/item/educationUserItemRequestBuilder");
const teachersRequestBuilder_1 = require("./teachers/teachersRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the classes property of the microsoft.graph.educationRoot entity. */
class EducationClassItemRequestBuilder {
    /**
     * Instantiates a new EducationClassItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/education/classes/{educationClass%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The assignmentCategories property */
    get assignmentCategories() {
        return new assignmentCategoriesRequestBuilder_1.AssignmentCategoriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignmentDefaults property */
    get assignmentDefaults() {
        return new assignmentDefaultsRequestBuilder_1.AssignmentDefaultsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignments property */
    get assignments() {
        return new assignmentsRequestBuilder_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignmentSettings property */
    get assignmentSettings() {
        return new assignmentSettingsRequestBuilder_1.AssignmentSettingsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The group property */
    get group() {
        return new groupRequestBuilder_1.GroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The members property */
    get members() {
        return new membersRequestBuilder_1.MembersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The schools property */
    get schools() {
        return new schoolsRequestBuilder_1.SchoolsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The teachers property */
    get teachers() {
        return new teachersRequestBuilder_1.TeachersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.assignmentCategories.item collection
     * @param id Unique identifier of the item
     * @returns a educationCategoryItemRequestBuilder
     */
    assignmentCategoriesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationCategory%2Did"] = id;
        return new educationCategoryItemRequestBuilder_1.EducationCategoryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a educationAssignmentItemRequestBuilder
     */
    assignmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationAssignment%2Did"] = id;
        return new educationAssignmentItemRequestBuilder_1.EducationAssignmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property classes for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get classes from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property classes in education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property classes for education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Get classes from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationClass
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createEducationClassFromDiscriminatorValue_1.createEducationClassFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a educationUserItemRequestBuilder
     */
    membersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationUser%2Did"] = id;
        return new educationUserItemRequestBuilder_1.EducationUserItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property classes in education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.schools.item collection
     * @param id Unique identifier of the item
     * @returns a educationSchoolItemRequestBuilder
     */
    schoolsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationSchool%2Did"] = id;
        return new educationSchoolItemRequestBuilder_1.EducationSchoolItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item.teachers.item collection
     * @param id Unique identifier of the item
     * @returns a educationUserItemRequestBuilder
     */
    teachersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationUser%2Did"] = id;
        return new educationUserItemRequestBuilder_2.EducationUserItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.EducationClassItemRequestBuilder = EducationClassItemRequestBuilder;
