import { EducationRoot } from '../models/';
import { ClassesRequestBuilder } from './classes/classesRequestBuilder';
import { EducationClassItemRequestBuilder } from './classes/item/educationClassItemRequestBuilder';
import { EducationRequestBuilderGetRequestConfiguration } from './educationRequestBuilderGetRequestConfiguration';
import { EducationRequestBuilderPatchRequestConfiguration } from './educationRequestBuilderPatchRequestConfiguration';
import { MeRequestBuilder } from './me/meRequestBuilder';
import { EducationSchoolItemRequestBuilder } from './schools/item/educationSchoolItemRequestBuilder';
import { SchoolsRequestBuilder } from './schools/schoolsRequestBuilder';
import { EducationUserItemRequestBuilder } from './users/item/educationUserItemRequestBuilder';
import { UsersRequestBuilder } from './users/usersRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the educationRoot singleton. */
export declare class EducationRequestBuilder {
    /** The classes property */
    get classes(): ClassesRequestBuilder;
    /** The me property */
    get me(): MeRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The schools property */
    get schools(): SchoolsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The users property */
    get users(): UsersRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.classes.item collection
     * @param id Unique identifier of the item
     * @returns a educationClassItemRequestBuilder
     */
    classesById(id: string): EducationClassItemRequestBuilder;
    /**
     * Instantiates a new EducationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: EducationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: EducationRoot | undefined, requestConfiguration?: EducationRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationRoot
     */
    get(requestConfiguration?: EducationRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<EducationRoot | undefined>;
    /**
     * Update education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: EducationRoot | undefined, requestConfiguration?: EducationRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.schools.item collection
     * @param id Unique identifier of the item
     * @returns a educationSchoolItemRequestBuilder
     */
    schoolsById(id: string): EducationSchoolItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.users.item collection
     * @param id Unique identifier of the item
     * @returns a educationUserItemRequestBuilder
     */
    usersById(id: string): EducationUserItemRequestBuilder;
}
