import { EducationUser, EducationUserCollectionResponse } from '../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DeltaRequestBuilder } from './delta/deltaRequestBuilder';
import { UsersRequestBuilderGetRequestConfiguration } from './usersRequestBuilderGetRequestConfiguration';
import { UsersRequestBuilderPostRequestConfiguration } from './usersRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the users property of the microsoft.graph.educationRoot entity. */
export declare class UsersRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new UsersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get users from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: UsersRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to users for education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: EducationUser | undefined, requestConfiguration?: UsersRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Provides operations to call the delta method.
     * @returns a deltaRequestBuilder
     */
    delta(): DeltaRequestBuilder;
    /**
     * Get users from education
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationUserCollectionResponse
     */
    get(requestConfiguration?: UsersRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<EducationUserCollectionResponse | undefined>;
    /**
     * Create new navigation property to users for education
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationUser
     */
    post(body: EducationUser | undefined, requestConfiguration?: UsersRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<EducationUser | undefined>;
}
