import { Calendar } from '../../../models/';
import { AllowedCalendarSharingRolesWithUserRequestBuilder } from './allowedCalendarSharingRolesWithUser/allowedCalendarSharingRolesWithUserRequestBuilder';
import { CalendarPermissionsRequestBuilder } from './calendarPermissions/calendarPermissionsRequestBuilder';
import { CalendarPermissionItemRequestBuilder } from './calendarPermissions/item/calendarPermissionItemRequestBuilder';
import { CalendarRequestBuilderDeleteRequestConfiguration } from './calendarRequestBuilderDeleteRequestConfiguration';
import { CalendarRequestBuilderGetRequestConfiguration } from './calendarRequestBuilderGetRequestConfiguration';
import { CalendarRequestBuilderPatchRequestConfiguration } from './calendarRequestBuilderPatchRequestConfiguration';
import { CalendarViewRequestBuilder } from './calendarView/calendarViewRequestBuilder';
import { EventItemRequestBuilder as iea1155139f798ddd94c4e9832632c5ff47ffbb516f56ba3e8549194afb0fb4fa } from './calendarView/item/eventItemRequestBuilder';
import { EventsRequestBuilder } from './events/eventsRequestBuilder';
import { EventItemRequestBuilder as i60e104fbd3b2a0999f9c81c8734623e3f3fed4d20973bfab1eec2c875c8d4016 } from './events/item/eventItemRequestBuilder';
import { GetScheduleRequestBuilder } from './getSchedule/getScheduleRequestBuilder';
import { MultiValueLegacyExtendedPropertyItemRequestBuilder } from './multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder';
import { MultiValueExtendedPropertiesRequestBuilder } from './multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder';
import { SingleValueLegacyExtendedPropertyItemRequestBuilder } from './singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder';
import { SingleValueExtendedPropertiesRequestBuilder } from './singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the calendar property of the microsoft.graph.group entity. */
export declare class CalendarRequestBuilder {
    /** The calendarPermissions property */
    get calendarPermissions(): CalendarPermissionsRequestBuilder;
    /** The calendarView property */
    get calendarView(): CalendarViewRequestBuilder;
    /** The events property */
    get events(): EventsRequestBuilder;
    /** The getSchedule property */
    get getSchedule(): GetScheduleRequestBuilder;
    /** The multiValueExtendedProperties property */
    get multiValueExtendedProperties(): MultiValueExtendedPropertiesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The singleValueExtendedProperties property */
    get singleValueExtendedProperties(): SingleValueExtendedPropertiesRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Provides operations to call the allowedCalendarSharingRoles method.
     * @param User Usage: User='{User}'
     * @returns a allowedCalendarSharingRolesWithUserRequestBuilder
     */
    allowedCalendarSharingRolesWithUser(user: string | undefined): AllowedCalendarSharingRolesWithUserRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.calendar.calendarPermissions.item collection
     * @param id Unique identifier of the item
     * @returns a calendarPermissionItemRequestBuilder
     */
    calendarPermissionsById(id: string): CalendarPermissionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.calendar.calendarView.item collection
     * @param id Unique identifier of the item
     * @returns a eventItemRequestBuilder
     */
    calendarViewById(id: string): iea1155139f798ddd94c4e9832632c5ff47ffbb516f56ba3e8549194afb0fb4fa;
    /**
     * Instantiates a new CalendarRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property calendar for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: CalendarRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The group's calendar. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: CalendarRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property calendar in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Calendar | undefined, requestConfiguration?: CalendarRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property calendar for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: CalendarRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.calendar.events.item collection
     * @param id Unique identifier of the item
     * @returns a eventItemRequestBuilder
     */
    eventsById(id: string): i60e104fbd3b2a0999f9c81c8734623e3f3fed4d20973bfab1eec2c875c8d4016;
    /**
     * The group's calendar. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Calendar
     */
    get(requestConfiguration?: CalendarRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Calendar | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.calendar.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id: string): MultiValueLegacyExtendedPropertyItemRequestBuilder;
    /**
     * Update the navigation property calendar in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Calendar | undefined, requestConfiguration?: CalendarRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.calendar.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id: string): SingleValueLegacyExtendedPropertyItemRequestBuilder;
}
