import { Post } from '../../../../../../../../../models/';
import { AttachmentsRequestBuilder } from './attachments/attachmentsRequestBuilder';
import { AttachmentItemRequestBuilder } from './attachments/item/attachmentItemRequestBuilder';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { ForwardRequestBuilder } from './forward/forwardRequestBuilder';
import { InReplyToRequestBuilderDeleteRequestConfiguration } from './inReplyToRequestBuilderDeleteRequestConfiguration';
import { InReplyToRequestBuilderGetRequestConfiguration } from './inReplyToRequestBuilderGetRequestConfiguration';
import { InReplyToRequestBuilderPatchRequestConfiguration } from './inReplyToRequestBuilderPatchRequestConfiguration';
import { MultiValueLegacyExtendedPropertyItemRequestBuilder } from './multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder';
import { MultiValueExtendedPropertiesRequestBuilder } from './multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder';
import { ReplyRequestBuilder } from './reply/replyRequestBuilder';
import { SingleValueLegacyExtendedPropertyItemRequestBuilder } from './singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder';
import { SingleValueExtendedPropertiesRequestBuilder } from './singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the inReplyTo property of the microsoft.graph.post entity. */
export declare class InReplyToRequestBuilder {
    /** The attachments property */
    get attachments(): AttachmentsRequestBuilder;
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The forward property */
    get forward(): ForwardRequestBuilder;
    /** The multiValueExtendedProperties property */
    get multiValueExtendedProperties(): MultiValueExtendedPropertiesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The reply property */
    get reply(): ReplyRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The singleValueExtendedProperties property */
    get singleValueExtendedProperties(): SingleValueExtendedPropertiesRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.conversations.item.threads.item.posts.item.inReplyTo.attachments.item collection
     * @param id Unique identifier of the item
     * @returns a attachmentItemRequestBuilder
     */
    attachmentsById(id: string): AttachmentItemRequestBuilder;
    /**
     * Instantiates a new InReplyToRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property inReplyTo for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: InReplyToRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The earlier post that this post is replying to in the conversationThread. Read-only. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: InReplyToRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property inReplyTo in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Post | undefined, requestConfiguration?: InReplyToRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property inReplyTo for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: InReplyToRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.conversations.item.threads.item.posts.item.inReplyTo.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The earlier post that this post is replying to in the conversationThread. Read-only. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Post
     */
    get(requestConfiguration?: InReplyToRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Post | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.conversations.item.threads.item.posts.item.inReplyTo.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id: string): MultiValueLegacyExtendedPropertyItemRequestBuilder;
    /**
     * Update the navigation property inReplyTo in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Post | undefined, requestConfiguration?: InReplyToRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.conversations.item.threads.item.posts.item.inReplyTo.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id: string): SingleValueLegacyExtendedPropertyItemRequestBuilder;
}
