"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GroupRequestBuilder = void 0;
const createGroupFromDiscriminatorValue_1 = require("../../../../../models/createGroupFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const addFavoriteRequestBuilder_1 = require("./addFavorite/addFavoriteRequestBuilder");
const assignLicenseRequestBuilder_1 = require("./assignLicense/assignLicenseRequestBuilder");
const checkGrantedPermissionsForAppRequestBuilder_1 = require("./checkGrantedPermissionsForApp/checkGrantedPermissionsForAppRequestBuilder");
const checkMemberGroupsRequestBuilder_1 = require("./checkMemberGroups/checkMemberGroupsRequestBuilder");
const checkMemberObjectsRequestBuilder_1 = require("./checkMemberObjects/checkMemberObjectsRequestBuilder");
const getMemberGroupsRequestBuilder_1 = require("./getMemberGroups/getMemberGroupsRequestBuilder");
const getMemberObjectsRequestBuilder_1 = require("./getMemberObjects/getMemberObjectsRequestBuilder");
const removeFavoriteRequestBuilder_1 = require("./removeFavorite/removeFavoriteRequestBuilder");
const renewRequestBuilder_1 = require("./renew/renewRequestBuilder");
const resetUnseenCountRequestBuilder_1 = require("./resetUnseenCount/resetUnseenCountRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const subscribeByMailRequestBuilder_1 = require("./subscribeByMail/subscribeByMailRequestBuilder");
const unsubscribeByMailRequestBuilder_1 = require("./unsubscribeByMail/unsubscribeByMailRequestBuilder");
const validatePropertiesRequestBuilder_1 = require("./validateProperties/validatePropertiesRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Casts the previous resource to group. */
class GroupRequestBuilder {
    /**
     * Instantiates a new GroupRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/groups/{group%2Did}/memberOf/{directoryObject%2Did}/microsoft.graph.group{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The addFavorite property */
    get addFavorite() {
        return new addFavoriteRequestBuilder_1.AddFavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The assignLicense property */
    get assignLicense() {
        return new assignLicenseRequestBuilder_1.AssignLicenseRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The checkGrantedPermissionsForApp property */
    get checkGrantedPermissionsForApp() {
        return new checkGrantedPermissionsForAppRequestBuilder_1.CheckGrantedPermissionsForAppRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The checkMemberGroups property */
    get checkMemberGroups() {
        return new checkMemberGroupsRequestBuilder_1.CheckMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The checkMemberObjects property */
    get checkMemberObjects() {
        return new checkMemberObjectsRequestBuilder_1.CheckMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The getMemberGroups property */
    get getMemberGroups() {
        return new getMemberGroupsRequestBuilder_1.GetMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The getMemberObjects property */
    get getMemberObjects() {
        return new getMemberObjectsRequestBuilder_1.GetMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The removeFavorite property */
    get removeFavorite() {
        return new removeFavoriteRequestBuilder_1.RemoveFavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The renew property */
    get renew() {
        return new renewRequestBuilder_1.RenewRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The resetUnseenCount property */
    get resetUnseenCount() {
        return new resetUnseenCountRequestBuilder_1.ResetUnseenCountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The restore property */
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The subscribeByMail property */
    get subscribeByMail() {
        return new subscribeByMailRequestBuilder_1.SubscribeByMailRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The unsubscribeByMail property */
    get unsubscribeByMail() {
        return new unsubscribeByMailRequestBuilder_1.UnsubscribeByMailRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The validateProperties property */
    get validateProperties() {
        return new validatePropertiesRequestBuilder_1.ValidatePropertiesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Get the item of type microsoft.graph.directoryObject as microsoft.graph.group
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get the item of type microsoft.graph.directoryObject as microsoft.graph.group
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Group
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createGroupFromDiscriminatorValue_1.createGroupFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.GroupRequestBuilder = GroupRequestBuilder;
