import { ProfilePhoto, ProfilePhotoCollectionResponse } from '../../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { PhotosRequestBuilderGetRequestConfiguration } from './photosRequestBuilderGetRequestConfiguration';
import { PhotosRequestBuilderPostRequestConfiguration } from './photosRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the photos property of the microsoft.graph.group entity. */
export declare class PhotosRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PhotosRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The profile photos owned by the group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PhotosRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to photos for groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ProfilePhoto | undefined, requestConfiguration?: PhotosRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * The profile photos owned by the group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ProfilePhotoCollectionResponse
     */
    get(requestConfiguration?: PhotosRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ProfilePhotoCollectionResponse | undefined>;
    /**
     * Create new navigation property to photos for groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ProfilePhoto
     */
    post(body: ProfilePhoto | undefined, requestConfiguration?: PhotosRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ProfilePhoto | undefined>;
}
