import { Store } from '../../../../../../models/termStore/';
import { GroupsRequestBuilder } from './groups/groupsRequestBuilder';
import { GroupItemRequestBuilder } from './groups/item/groupItemRequestBuilder';
import { SetItemRequestBuilder } from './sets/item/setItemRequestBuilder';
import { SetsRequestBuilder } from './sets/setsRequestBuilder';
import { StoreItemRequestBuilderDeleteRequestConfiguration } from './storeItemRequestBuilderDeleteRequestConfiguration';
import { StoreItemRequestBuilderGetRequestConfiguration } from './storeItemRequestBuilderGetRequestConfiguration';
import { StoreItemRequestBuilderPatchRequestConfiguration } from './storeItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the termStores property of the microsoft.graph.site entity. */
export declare class StoreItemRequestBuilder {
    /** The groups property */
    get groups(): GroupsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The sets property */
    get sets(): SetsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new StoreItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property termStores for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: StoreItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: StoreItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property termStores in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Store | undefined, requestConfiguration?: StoreItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property termStores for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: StoreItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The collection of termStores under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Store
     */
    get(requestConfiguration?: StoreItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Store | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.termStores.item.groups.item collection
     * @param id Unique identifier of the item
     * @returns a groupItemRequestBuilder
     */
    groupsById(id: string): GroupItemRequestBuilder;
    /**
     * Update the navigation property termStores in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Store | undefined, requestConfiguration?: StoreItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.termStores.item.sets.item collection
     * @param id Unique identifier of the item
     * @returns a setItemRequestBuilder
     */
    setsById(id: string): SetItemRequestBuilder;
}
