import { ChatMessage } from '../../../../../../models/';
import { ChatMessageItemRequestBuilderDeleteRequestConfiguration } from './chatMessageItemRequestBuilderDeleteRequestConfiguration';
import { ChatMessageItemRequestBuilderGetRequestConfiguration } from './chatMessageItemRequestBuilderGetRequestConfiguration';
import { ChatMessageItemRequestBuilderPatchRequestConfiguration } from './chatMessageItemRequestBuilderPatchRequestConfiguration';
import { HostedContentsRequestBuilder } from './hostedContents/hostedContentsRequestBuilder';
import { ChatMessageHostedContentItemRequestBuilder } from './hostedContents/item/chatMessageHostedContentItemRequestBuilder';
import { ChatMessageItemRequestBuilder as i10b9ea335bd6b596cfc2f04b8c4eb4aca1a8b1eb27e6c271fad88d8814af1797 } from './replies/item/chatMessageItemRequestBuilder';
import { RepliesRequestBuilder } from './replies/repliesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.channel entity. */
export declare class ChatMessageItemRequestBuilder {
    /** The hostedContents property */
    get hostedContents(): HostedContentsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The replies property */
    get replies(): RepliesRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ChatMessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ChatMessageItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * A collection of all the messages in the channel. A navigation property. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ChatMessageItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property messages in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ChatMessage | undefined, requestConfiguration?: ChatMessageItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property messages for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ChatMessageItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * A collection of all the messages in the channel. A navigation property. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ChatMessage
     */
    get(requestConfiguration?: ChatMessageItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ChatMessage | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.primaryChannel.messages.item.hostedContents.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageHostedContentItemRequestBuilder
     */
    hostedContentsById(id: string): ChatMessageHostedContentItemRequestBuilder;
    /**
     * Update the navigation property messages in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ChatMessage | undefined, requestConfiguration?: ChatMessageItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.primaryChannel.messages.item.replies.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageItemRequestBuilder
     */
    repliesById(id: string): i10b9ea335bd6b596cfc2f04b8c4eb4aca1a8b1eb27e6c271fad88d8814af1797;
}
