import { Schedule } from '../../../../models/';
import { OfferShiftRequestItemRequestBuilder } from './offerShiftRequests/item/offerShiftRequestItemRequestBuilder';
import { OfferShiftRequestsRequestBuilder } from './offerShiftRequests/offerShiftRequestsRequestBuilder';
import { OpenShiftChangeRequestItemRequestBuilder } from './openShiftChangeRequests/item/openShiftChangeRequestItemRequestBuilder';
import { OpenShiftChangeRequestsRequestBuilder } from './openShiftChangeRequests/openShiftChangeRequestsRequestBuilder';
import { OpenShiftItemRequestBuilder } from './openShifts/item/openShiftItemRequestBuilder';
import { OpenShiftsRequestBuilder } from './openShifts/openShiftsRequestBuilder';
import { ScheduleRequestBuilderDeleteRequestConfiguration } from './scheduleRequestBuilderDeleteRequestConfiguration';
import { ScheduleRequestBuilderGetRequestConfiguration } from './scheduleRequestBuilderGetRequestConfiguration';
import { ScheduleRequestBuilderPatchRequestConfiguration } from './scheduleRequestBuilderPatchRequestConfiguration';
import { SchedulingGroupItemRequestBuilder } from './schedulingGroups/item/schedulingGroupItemRequestBuilder';
import { SchedulingGroupsRequestBuilder } from './schedulingGroups/schedulingGroupsRequestBuilder';
import { ShareRequestBuilder } from './share/shareRequestBuilder';
import { ShiftItemRequestBuilder } from './shifts/item/shiftItemRequestBuilder';
import { ShiftsRequestBuilder } from './shifts/shiftsRequestBuilder';
import { SwapShiftsChangeRequestItemRequestBuilder } from './swapShiftsChangeRequests/item/swapShiftsChangeRequestItemRequestBuilder';
import { SwapShiftsChangeRequestsRequestBuilder } from './swapShiftsChangeRequests/swapShiftsChangeRequestsRequestBuilder';
import { TimeOffReasonItemRequestBuilder } from './timeOffReasons/item/timeOffReasonItemRequestBuilder';
import { TimeOffReasonsRequestBuilder } from './timeOffReasons/timeOffReasonsRequestBuilder';
import { TimeOffRequestItemRequestBuilder } from './timeOffRequests/item/timeOffRequestItemRequestBuilder';
import { TimeOffRequestsRequestBuilder } from './timeOffRequests/timeOffRequestsRequestBuilder';
import { TimeOffItemRequestBuilder } from './timesOff/item/timeOffItemRequestBuilder';
import { TimesOffRequestBuilder } from './timesOff/timesOffRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the schedule property of the microsoft.graph.team entity. */
export declare class ScheduleRequestBuilder {
    /** The offerShiftRequests property */
    get offerShiftRequests(): OfferShiftRequestsRequestBuilder;
    /** The openShiftChangeRequests property */
    get openShiftChangeRequests(): OpenShiftChangeRequestsRequestBuilder;
    /** The openShifts property */
    get openShifts(): OpenShiftsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The schedulingGroups property */
    get schedulingGroups(): SchedulingGroupsRequestBuilder;
    /** The share property */
    get share(): ShareRequestBuilder;
    /** The shifts property */
    get shifts(): ShiftsRequestBuilder;
    /** The swapShiftsChangeRequests property */
    get swapShiftsChangeRequests(): SwapShiftsChangeRequestsRequestBuilder;
    /** The timeOffReasons property */
    get timeOffReasons(): TimeOffReasonsRequestBuilder;
    /** The timeOffRequests property */
    get timeOffRequests(): TimeOffRequestsRequestBuilder;
    /** The timesOff property */
    get timesOff(): TimesOffRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ScheduleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property schedule for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ScheduleRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The schedule of shifts for this team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ScheduleRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property schedule in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Schedule | undefined, requestConfiguration?: ScheduleRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property schedule for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ScheduleRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The schedule of shifts for this team.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Schedule
     */
    get(requestConfiguration?: ScheduleRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Schedule | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.offerShiftRequests.item collection
     * @param id Unique identifier of the item
     * @returns a offerShiftRequestItemRequestBuilder
     */
    offerShiftRequestsById(id: string): OfferShiftRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.openShiftChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftChangeRequestItemRequestBuilder
     */
    openShiftChangeRequestsById(id: string): OpenShiftChangeRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.openShifts.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftItemRequestBuilder
     */
    openShiftsById(id: string): OpenShiftItemRequestBuilder;
    /**
     * Update the navigation property schedule in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Schedule | undefined, requestConfiguration?: ScheduleRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.schedulingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a schedulingGroupItemRequestBuilder
     */
    schedulingGroupsById(id: string): SchedulingGroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.shifts.item collection
     * @param id Unique identifier of the item
     * @returns a shiftItemRequestBuilder
     */
    shiftsById(id: string): ShiftItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.swapShiftsChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a swapShiftsChangeRequestItemRequestBuilder
     */
    swapShiftsChangeRequestsById(id: string): SwapShiftsChangeRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timeOffReasons.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffReasonItemRequestBuilder
     */
    timeOffReasonsById(id: string): TimeOffReasonItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timeOffRequests.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffRequestItemRequestBuilder
     */
    timeOffRequestsById(id: string): TimeOffRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timesOff.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffItemRequestBuilder
     */
    timesOffById(id: string): TimeOffItemRequestBuilder;
}
