import { Team } from '../../../models/';
import { ChannelsRequestBuilder } from './channels/channelsRequestBuilder';
import { ChannelItemRequestBuilder } from './channels/item/channelItemRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { TeamsAppInstallationItemRequestBuilder } from './installedApps/item/teamsAppInstallationItemRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { TeamsAsyncOperationItemRequestBuilder } from './operations/item/teamsAsyncOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrimaryChannelRequestBuilder } from './primaryChannel/primaryChannelRequestBuilder';
import { ScheduleRequestBuilder } from './schedule/scheduleRequestBuilder';
import { TeamRequestBuilderDeleteRequestConfiguration } from './teamRequestBuilderDeleteRequestConfiguration';
import { TeamRequestBuilderGetRequestConfiguration } from './teamRequestBuilderGetRequestConfiguration';
import { TeamRequestBuilderPatchRequestConfiguration } from './teamRequestBuilderPatchRequestConfiguration';
import { TemplateRequestBuilder } from './template/templateRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the team property of the microsoft.graph.group entity. */
export declare class TeamRequestBuilder {
    /** The channels property */
    get channels(): ChannelsRequestBuilder;
    /** The group property */
    get group(): GroupRequestBuilder;
    /** The installedApps property */
    get installedApps(): InstalledAppsRequestBuilder;
    /** The members property */
    get members(): MembersRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The primaryChannel property */
    get primaryChannel(): PrimaryChannelRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The schedule property */
    get schedule(): ScheduleRequestBuilder;
    /** The template property */
    get template(): TemplateRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.channels.item collection
     * @param id Unique identifier of the item
     * @returns a channelItemRequestBuilder
     */
    channelsById(id: string): ChannelItemRequestBuilder;
    /**
     * Instantiates a new TeamRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property team for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: TeamRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The team associated with this group.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TeamRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property team in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Team | undefined, requestConfiguration?: TeamRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property team for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: TeamRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The team associated with this group.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    get(requestConfiguration?: TeamRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Team | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id: string): TeamsAppInstallationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.operations.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAsyncOperationItemRequestBuilder
     */
    operationsById(id: string): TeamsAsyncOperationItemRequestBuilder;
    /**
     * Update the navigation property team in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Team | undefined, requestConfiguration?: TeamRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
