import { ConversationThread } from '../../../../models/';
import { ConversationThreadItemRequestBuilderDeleteRequestConfiguration } from './conversationThreadItemRequestBuilderDeleteRequestConfiguration';
import { ConversationThreadItemRequestBuilderGetRequestConfiguration } from './conversationThreadItemRequestBuilderGetRequestConfiguration';
import { ConversationThreadItemRequestBuilderPatchRequestConfiguration } from './conversationThreadItemRequestBuilderPatchRequestConfiguration';
import { PostItemRequestBuilder } from './posts/item/postItemRequestBuilder';
import { PostsRequestBuilder } from './posts/postsRequestBuilder';
import { ReplyRequestBuilder } from './reply/replyRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the threads property of the microsoft.graph.group entity. */
export declare class ConversationThreadItemRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The posts property */
    get posts(): PostsRequestBuilder;
    /** The reply property */
    get reply(): ReplyRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ConversationThreadItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property threads for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ConversationThreadItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The group's conversation threads. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ConversationThreadItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property threads in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ConversationThread | undefined, requestConfiguration?: ConversationThreadItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property threads for groups
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ConversationThreadItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The group's conversation threads. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ConversationThread
     */
    get(requestConfiguration?: ConversationThreadItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ConversationThread | undefined>;
    /**
     * Update the navigation property threads in groups
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ConversationThread | undefined, requestConfiguration?: ConversationThreadItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.threads.item.posts.item collection
     * @param id Unique identifier of the item
     * @returns a postItemRequestBuilder
     */
    postsById(id: string): PostItemRequestBuilder;
}
