import { B2xIdentityUserFlow } from '../../../models/';
import { B2xIdentityUserFlowItemRequestBuilderDeleteRequestConfiguration } from './b2xIdentityUserFlowItemRequestBuilderDeleteRequestConfiguration';
import { B2xIdentityUserFlowItemRequestBuilderGetRequestConfiguration } from './b2xIdentityUserFlowItemRequestBuilderGetRequestConfiguration';
import { B2xIdentityUserFlowItemRequestBuilderPatchRequestConfiguration } from './b2xIdentityUserFlowItemRequestBuilderPatchRequestConfiguration';
import { IdentityProvidersRequestBuilder } from './identityProviders/identityProvidersRequestBuilder';
import { IdentityProviderItemRequestBuilder } from './identityProviders/item/identityProviderItemRequestBuilder';
import { UserFlowLanguageConfigurationItemRequestBuilder } from './languages/item/userFlowLanguageConfigurationItemRequestBuilder';
import { LanguagesRequestBuilder } from './languages/languagesRequestBuilder';
import { IdentityUserFlowAttributeAssignmentItemRequestBuilder } from './userAttributeAssignments/item/identityUserFlowAttributeAssignmentItemRequestBuilder';
import { UserAttributeAssignmentsRequestBuilder } from './userAttributeAssignments/userAttributeAssignmentsRequestBuilder';
import { IdentityProviderBaseItemRequestBuilder } from './userFlowIdentityProviders/item/identityProviderBaseItemRequestBuilder';
import { UserFlowIdentityProvidersRequestBuilder } from './userFlowIdentityProviders/userFlowIdentityProvidersRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the b2xUserFlows property of the microsoft.graph.identityContainer entity. */
export declare class B2xIdentityUserFlowItemRequestBuilder {
    /** The identityProviders property */
    get identityProviders(): IdentityProvidersRequestBuilder;
    /** The languages property */
    get languages(): LanguagesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The userAttributeAssignments property */
    get userAttributeAssignments(): UserAttributeAssignmentsRequestBuilder;
    /** The userFlowIdentityProviders property */
    get userFlowIdentityProviders(): UserFlowIdentityProvidersRequestBuilder;
    /**
     * Instantiates a new B2xIdentityUserFlowItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property b2xUserFlows for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents entry point for B2X and self-service sign-up identity userflows.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: B2xIdentityUserFlow | undefined, requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property b2xUserFlows for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Represents entry point for B2X and self-service sign-up identity userflows.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of B2xIdentityUserFlow
     */
    get(requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<B2xIdentityUserFlow | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.identityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderItemRequestBuilder
     */
    identityProvidersById(id: string): IdentityProviderItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.languages.item collection
     * @param id Unique identifier of the item
     * @returns a userFlowLanguageConfigurationItemRequestBuilder
     */
    languagesById(id: string): UserFlowLanguageConfigurationItemRequestBuilder;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: B2xIdentityUserFlow | undefined, requestConfiguration?: B2xIdentityUserFlowItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.userAttributeAssignments.item collection
     * @param id Unique identifier of the item
     * @returns a identityUserFlowAttributeAssignmentItemRequestBuilder
     */
    userAttributeAssignmentsById(id: string): IdentityUserFlowAttributeAssignmentItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.userFlowIdentityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderBaseItemRequestBuilder
     */
    userFlowIdentityProvidersById(id: string): IdentityProviderBaseItemRequestBuilder;
}
