import { ConditionalAccessRoot } from '../../models/';
import { ConditionalAccessRequestBuilderDeleteRequestConfiguration } from './conditionalAccessRequestBuilderDeleteRequestConfiguration';
import { ConditionalAccessRequestBuilderGetRequestConfiguration } from './conditionalAccessRequestBuilderGetRequestConfiguration';
import { ConditionalAccessRequestBuilderPatchRequestConfiguration } from './conditionalAccessRequestBuilderPatchRequestConfiguration';
import { NamedLocationItemRequestBuilder } from './namedLocations/item/namedLocationItemRequestBuilder';
import { NamedLocationsRequestBuilder } from './namedLocations/namedLocationsRequestBuilder';
import { ConditionalAccessPolicyItemRequestBuilder } from './policies/item/conditionalAccessPolicyItemRequestBuilder';
import { PoliciesRequestBuilder } from './policies/policiesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the conditionalAccess property of the microsoft.graph.identityContainer entity. */
export declare class ConditionalAccessRequestBuilder {
    /** The namedLocations property */
    get namedLocations(): NamedLocationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The policies property */
    get policies(): PoliciesRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ConditionalAccessRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property conditionalAccess for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ConditionalAccessRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * the entry point for the Conditional Access (CA) object model.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ConditionalAccessRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property conditionalAccess in identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ConditionalAccessRoot | undefined, requestConfiguration?: ConditionalAccessRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property conditionalAccess for identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ConditionalAccessRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * the entry point for the Conditional Access (CA) object model.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ConditionalAccessRoot
     */
    get(requestConfiguration?: ConditionalAccessRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ConditionalAccessRoot | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.conditionalAccess.namedLocations.item collection
     * @param id Unique identifier of the item
     * @returns a namedLocationItemRequestBuilder
     */
    namedLocationsById(id: string): NamedLocationItemRequestBuilder;
    /**
     * Update the navigation property conditionalAccess in identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ConditionalAccessRoot | undefined, requestConfiguration?: ConditionalAccessRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.conditionalAccess.policies.item collection
     * @param id Unique identifier of the item
     * @returns a conditionalAccessPolicyItemRequestBuilder
     */
    policiesById(id: string): ConditionalAccessPolicyItemRequestBuilder;
}
