import { IdentityContainer } from '../models/';
import { ApiConnectorsRequestBuilder } from './apiConnectors/apiConnectorsRequestBuilder';
import { IdentityApiConnectorItemRequestBuilder } from './apiConnectors/item/identityApiConnectorItemRequestBuilder';
import { B2xUserFlowsRequestBuilder } from './b2xUserFlows/b2xUserFlowsRequestBuilder';
import { B2xIdentityUserFlowItemRequestBuilder } from './b2xUserFlows/item/b2xIdentityUserFlowItemRequestBuilder';
import { ConditionalAccessRequestBuilder } from './conditionalAccess/conditionalAccessRequestBuilder';
import { IdentityProvidersRequestBuilder } from './identityProviders/identityProvidersRequestBuilder';
import { IdentityProviderBaseItemRequestBuilder } from './identityProviders/item/identityProviderBaseItemRequestBuilder';
import { IdentityRequestBuilderGetRequestConfiguration } from './identityRequestBuilderGetRequestConfiguration';
import { IdentityRequestBuilderPatchRequestConfiguration } from './identityRequestBuilderPatchRequestConfiguration';
import { IdentityUserFlowAttributeItemRequestBuilder } from './userFlowAttributes/item/identityUserFlowAttributeItemRequestBuilder';
import { UserFlowAttributesRequestBuilder } from './userFlowAttributes/userFlowAttributesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityContainer singleton. */
export declare class IdentityRequestBuilder {
    /** The apiConnectors property */
    get apiConnectors(): ApiConnectorsRequestBuilder;
    /** The b2xUserFlows property */
    get b2xUserFlows(): B2xUserFlowsRequestBuilder;
    /** The conditionalAccess property */
    get conditionalAccess(): ConditionalAccessRequestBuilder;
    /** The identityProviders property */
    get identityProviders(): IdentityProvidersRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The userFlowAttributes property */
    get userFlowAttributes(): UserFlowAttributesRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.apiConnectors.item collection
     * @param id Unique identifier of the item
     * @returns a identityApiConnectorItemRequestBuilder
     */
    apiConnectorsById(id: string): IdentityApiConnectorItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item collection
     * @param id Unique identifier of the item
     * @returns a b2xIdentityUserFlowItemRequestBuilder
     */
    b2xUserFlowsById(id: string): B2xIdentityUserFlowItemRequestBuilder;
    /**
     * Instantiates a new IdentityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: IdentityRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: IdentityContainer | undefined, requestConfiguration?: IdentityRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityContainer
     */
    get(requestConfiguration?: IdentityRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityContainer | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.identityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderBaseItemRequestBuilder
     */
    identityProvidersById(id: string): IdentityProviderBaseItemRequestBuilder;
    /**
     * Update identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: IdentityContainer | undefined, requestConfiguration?: IdentityRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.userFlowAttributes.item collection
     * @param id Unique identifier of the item
     * @returns a identityUserFlowAttributeItemRequestBuilder
     */
    userFlowAttributesById(id: string): IdentityUserFlowAttributeItemRequestBuilder;
}
