"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IdentityRequestBuilder = void 0;
const createIdentityContainerFromDiscriminatorValue_1 = require("../models/createIdentityContainerFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const apiConnectorsRequestBuilder_1 = require("./apiConnectors/apiConnectorsRequestBuilder");
const identityApiConnectorItemRequestBuilder_1 = require("./apiConnectors/item/identityApiConnectorItemRequestBuilder");
const b2xUserFlowsRequestBuilder_1 = require("./b2xUserFlows/b2xUserFlowsRequestBuilder");
const b2xIdentityUserFlowItemRequestBuilder_1 = require("./b2xUserFlows/item/b2xIdentityUserFlowItemRequestBuilder");
const conditionalAccessRequestBuilder_1 = require("./conditionalAccess/conditionalAccessRequestBuilder");
const identityProvidersRequestBuilder_1 = require("./identityProviders/identityProvidersRequestBuilder");
const identityProviderBaseItemRequestBuilder_1 = require("./identityProviders/item/identityProviderBaseItemRequestBuilder");
const identityUserFlowAttributeItemRequestBuilder_1 = require("./userFlowAttributes/item/identityUserFlowAttributeItemRequestBuilder");
const userFlowAttributesRequestBuilder_1 = require("./userFlowAttributes/userFlowAttributesRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the identityContainer singleton. */
class IdentityRequestBuilder {
    /**
     * Instantiates a new IdentityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/identity{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The apiConnectors property */
    get apiConnectors() {
        return new apiConnectorsRequestBuilder_1.ApiConnectorsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The b2xUserFlows property */
    get b2xUserFlows() {
        return new b2xUserFlowsRequestBuilder_1.B2xUserFlowsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The conditionalAccess property */
    get conditionalAccess() {
        return new conditionalAccessRequestBuilder_1.ConditionalAccessRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The identityProviders property */
    get identityProviders() {
        return new identityProvidersRequestBuilder_1.IdentityProvidersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The userFlowAttributes property */
    get userFlowAttributes() {
        return new userFlowAttributesRequestBuilder_1.UserFlowAttributesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.apiConnectors.item collection
     * @param id Unique identifier of the item
     * @returns a identityApiConnectorItemRequestBuilder
     */
    apiConnectorsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["identityApiConnector%2Did"] = id;
        return new identityApiConnectorItemRequestBuilder_1.IdentityApiConnectorItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item collection
     * @param id Unique identifier of the item
     * @returns a b2xIdentityUserFlowItemRequestBuilder
     */
    b2xUserFlowsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["b2xIdentityUserFlow%2Did"] = id;
        return new b2xIdentityUserFlowItemRequestBuilder_1.B2xIdentityUserFlowItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Get identity
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityContainer
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createIdentityContainerFromDiscriminatorValue_1.createIdentityContainerFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.identityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderBaseItemRequestBuilder
     */
    identityProvidersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["identityProviderBase%2Did"] = id;
        return new identityProviderBaseItemRequestBuilder_1.IdentityProviderBaseItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update identity
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.userFlowAttributes.item collection
     * @param id Unique identifier of the item
     * @returns a identityUserFlowAttributeItemRequestBuilder
     */
    userFlowAttributesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["identityUserFlowAttribute%2Did"] = id;
        return new identityUserFlowAttributeItemRequestBuilder_1.IdentityUserFlowAttributeItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.IdentityRequestBuilder = IdentityRequestBuilder;
