"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccessReviewInstanceItemRequestBuilder = void 0;
const createAccessReviewInstanceFromDiscriminatorValue_1 = require("../../../../../../models/createAccessReviewInstanceFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const acceptRecommendationsRequestBuilder_1 = require("./acceptRecommendations/acceptRecommendationsRequestBuilder");
const applyDecisionsRequestBuilder_1 = require("./applyDecisions/applyDecisionsRequestBuilder");
const batchRecordDecisionsRequestBuilder_1 = require("./batchRecordDecisions/batchRecordDecisionsRequestBuilder");
const contactedReviewersRequestBuilder_1 = require("./contactedReviewers/contactedReviewersRequestBuilder");
const accessReviewReviewerItemRequestBuilder_1 = require("./contactedReviewers/item/accessReviewReviewerItemRequestBuilder");
const decisionsRequestBuilder_1 = require("./decisions/decisionsRequestBuilder");
const accessReviewInstanceDecisionItemItemRequestBuilder_1 = require("./decisions/item/accessReviewInstanceDecisionItemItemRequestBuilder");
const resetDecisionsRequestBuilder_1 = require("./resetDecisions/resetDecisionsRequestBuilder");
const sendReminderRequestBuilder_1 = require("./sendReminder/sendReminderRequestBuilder");
const stopRequestBuilder_1 = require("./stop/stopRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the instances property of the microsoft.graph.accessReviewScheduleDefinition entity. */
class AccessReviewInstanceItemRequestBuilder {
    /**
     * Instantiates a new AccessReviewInstanceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/identityGovernance/accessReviews/definitions/{accessReviewScheduleDefinition%2Did}/instances/{accessReviewInstance%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The acceptRecommendations property */
    get acceptRecommendations() {
        return new acceptRecommendationsRequestBuilder_1.AcceptRecommendationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The applyDecisions property */
    get applyDecisions() {
        return new applyDecisionsRequestBuilder_1.ApplyDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The batchRecordDecisions property */
    get batchRecordDecisions() {
        return new batchRecordDecisionsRequestBuilder_1.BatchRecordDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The contactedReviewers property */
    get contactedReviewers() {
        return new contactedReviewersRequestBuilder_1.ContactedReviewersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The decisions property */
    get decisions() {
        return new decisionsRequestBuilder_1.DecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The resetDecisions property */
    get resetDecisions() {
        return new resetDecisionsRequestBuilder_1.ResetDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The sendReminder property */
    get sendReminder() {
        return new sendReminderRequestBuilder_1.SendReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The stop property */
    get stop() {
        return new stopRequestBuilder_1.StopRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.accessReviews.definitions.item.instances.item.contactedReviewers.item collection
     * @param id Unique identifier of the item
     * @returns a accessReviewReviewerItemRequestBuilder
     */
    contactedReviewersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["accessReviewReviewer%2Did"] = id;
        return new accessReviewReviewerItemRequestBuilder_1.AccessReviewReviewerItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property instances for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Set of access reviews instances for this access review series. Access reviews that do not recur will only have one instance; otherwise, there is an instance for each recurrence.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property instances in identityGovernance
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.accessReviews.definitions.item.instances.item.decisions.item collection
     * @param id Unique identifier of the item
     * @returns a accessReviewInstanceDecisionItemItemRequestBuilder
     */
    decisionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["accessReviewInstanceDecisionItem%2Did"] = id;
        return new accessReviewInstanceDecisionItemItemRequestBuilder_1.AccessReviewInstanceDecisionItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property instances for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Set of access reviews instances for this access review series. Access reviews that do not recur will only have one instance; otherwise, there is an instance for each recurrence.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AccessReviewInstance
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createAccessReviewInstanceFromDiscriminatorValue_1.createAccessReviewInstanceFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property instances in identityGovernance
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.AccessReviewInstanceItemRequestBuilder = AccessReviewInstanceItemRequestBuilder;
