import { Approval } from '../../../../../../../models/';
import { ApprovalRequestBuilderDeleteRequestConfiguration } from './approvalRequestBuilderDeleteRequestConfiguration';
import { ApprovalRequestBuilderGetRequestConfiguration } from './approvalRequestBuilderGetRequestConfiguration';
import { ApprovalRequestBuilderPatchRequestConfiguration } from './approvalRequestBuilderPatchRequestConfiguration';
import { ApprovalStageItemRequestBuilder } from './stages/item/approvalStageItemRequestBuilder';
import { StagesRequestBuilder } from './stages/stagesRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the approval property of the microsoft.graph.userConsentRequest entity. */
export declare class ApprovalRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The stages property */
    get stages(): StagesRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ApprovalRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property approval for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ApprovalRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Approval decisions associated with a request.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ApprovalRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property approval in identityGovernance
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Approval | undefined, requestConfiguration?: ApprovalRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property approval for identityGovernance
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ApprovalRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Approval decisions associated with a request.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Approval
     */
    get(requestConfiguration?: ApprovalRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Approval | undefined>;
    /**
     * Update the navigation property approval in identityGovernance
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Approval | undefined, requestConfiguration?: ApprovalRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.appConsent.appConsentRequests.item.userConsentRequests.item.approval.stages.item collection
     * @param id Unique identifier of the item
     * @returns a approvalStageItemRequestBuilder
     */
    stagesById(id: string): ApprovalStageItemRequestBuilder;
}
