import { IdentityProtectionRoot } from '../models/';
import { IdentityProtectionRequestBuilderGetRequestConfiguration } from './identityProtectionRequestBuilderGetRequestConfiguration';
import { IdentityProtectionRequestBuilderPatchRequestConfiguration } from './identityProtectionRequestBuilderPatchRequestConfiguration';
import { RiskDetectionItemRequestBuilder } from './riskDetections/item/riskDetectionItemRequestBuilder';
import { RiskDetectionsRequestBuilder } from './riskDetections/riskDetectionsRequestBuilder';
import { RiskyUserItemRequestBuilder } from './riskyUsers/item/riskyUserItemRequestBuilder';
import { RiskyUsersRequestBuilder } from './riskyUsers/riskyUsersRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityProtectionRoot singleton. */
export declare class IdentityProtectionRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The riskDetections property */
    get riskDetections(): RiskDetectionsRequestBuilder;
    /** The riskyUsers property */
    get riskyUsers(): RiskyUsersRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new IdentityProtectionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: IdentityProtectionRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: IdentityProtectionRoot | undefined, requestConfiguration?: IdentityProtectionRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProtectionRoot
     */
    get(requestConfiguration?: IdentityProtectionRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProtectionRoot | undefined>;
    /**
     * Update identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: IdentityProtectionRoot | undefined, requestConfiguration?: IdentityProtectionRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityProtection.riskDetections.item collection
     * @param id Unique identifier of the item
     * @returns a riskDetectionItemRequestBuilder
     */
    riskDetectionsById(id: string): RiskDetectionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityProtection.riskyUsers.item collection
     * @param id Unique identifier of the item
     * @returns a riskyUserItemRequestBuilder
     */
    riskyUsersById(id: string): RiskyUserItemRequestBuilder;
}
