import { RiskyUser } from '../../../models/';
import { HistoryRequestBuilder } from './history/historyRequestBuilder';
import { RiskyUserHistoryItemItemRequestBuilder } from './history/item/riskyUserHistoryItemItemRequestBuilder';
import { RiskyUserItemRequestBuilderDeleteRequestConfiguration } from './riskyUserItemRequestBuilderDeleteRequestConfiguration';
import { RiskyUserItemRequestBuilderGetRequestConfiguration } from './riskyUserItemRequestBuilderGetRequestConfiguration';
import { RiskyUserItemRequestBuilderPatchRequestConfiguration } from './riskyUserItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity. */
export declare class RiskyUserItemRequestBuilder {
    /** The history property */
    get history(): HistoryRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new RiskyUserItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property riskyUsers for identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: RiskyUserItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Users that are flagged as at-risk by Azure AD Identity Protection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: RiskyUserItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property riskyUsers in identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: RiskyUser | undefined, requestConfiguration?: RiskyUserItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property riskyUsers for identityProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: RiskyUserItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Users that are flagged as at-risk by Azure AD Identity Protection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of RiskyUser
     */
    get(requestConfiguration?: RiskyUserItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<RiskyUser | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityProtection.riskyUsers.item.history.item collection
     * @param id Unique identifier of the item
     * @returns a riskyUserHistoryItemItemRequestBuilder
     */
    historyById(id: string): RiskyUserHistoryItemItemRequestBuilder;
    /**
     * Update the navigation property riskyUsers in identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: RiskyUser | undefined, requestConfiguration?: RiskyUserItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
