import { RiskyUser, RiskyUserCollectionResponse } from '../../models/';
import { ConfirmCompromisedRequestBuilder } from './confirmCompromised/confirmCompromisedRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DismissRequestBuilder } from './dismiss/dismissRequestBuilder';
import { RiskyUsersRequestBuilderGetRequestConfiguration } from './riskyUsersRequestBuilderGetRequestConfiguration';
import { RiskyUsersRequestBuilderPostRequestConfiguration } from './riskyUsersRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the riskyUsers property of the microsoft.graph.identityProtectionRoot entity. */
export declare class RiskyUsersRequestBuilder {
    /** The confirmCompromised property */
    get confirmCompromised(): ConfirmCompromisedRequestBuilder;
    /** The count property */
    get count(): CountRequestBuilder;
    /** The dismiss property */
    get dismiss(): DismissRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new RiskyUsersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Users that are flagged as at-risk by Azure AD Identity Protection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: RiskyUsersRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to riskyUsers for identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: RiskyUser | undefined, requestConfiguration?: RiskyUsersRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Users that are flagged as at-risk by Azure AD Identity Protection.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of RiskyUserCollectionResponse
     */
    get(requestConfiguration?: RiskyUsersRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<RiskyUserCollectionResponse | undefined>;
    /**
     * Create new navigation property to riskyUsers for identityProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of RiskyUser
     */
    post(body: RiskyUser | undefined, requestConfiguration?: RiskyUsersRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<RiskyUser | undefined>;
}
