import { IdentityProvider, IdentityProviderCollectionResponse } from '../models/';
import { AvailableProviderTypesRequestBuilder } from './availableProviderTypes/availableProviderTypesRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { IdentityProvidersRequestBuilderGetRequestConfiguration } from './identityProvidersRequestBuilderGetRequestConfiguration';
import { IdentityProvidersRequestBuilderPostRequestConfiguration } from './identityProvidersRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of identityProvider entities. */
export declare class IdentityProvidersRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Provides operations to call the availableProviderTypes method.
     * @returns a availableProviderTypesRequestBuilder
     */
    availableProviderTypes(): AvailableProviderTypesRequestBuilder;
    /**
     * Instantiates a new IdentityProvidersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Retrieve a list of [identityProviders](../resources/identityprovider.md) objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: IdentityProvidersRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new [identityProvider](../resources/identityprovider.md) object.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: IdentityProvider | undefined, requestConfiguration?: IdentityProvidersRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve a list of [identityProviders](../resources/identityprovider.md) objects.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProviderCollectionResponse
     */
    get(requestConfiguration?: IdentityProvidersRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProviderCollectionResponse | undefined>;
    /**
     * Create a new [identityProvider](../resources/identityprovider.md) object.
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProvider
     */
    post(body: IdentityProvider | undefined, requestConfiguration?: IdentityProvidersRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProvider | undefined>;
}
