import { Bitlocker } from '../../models/';
import { BitlockerRequestBuilderDeleteRequestConfiguration } from './bitlockerRequestBuilderDeleteRequestConfiguration';
import { BitlockerRequestBuilderGetRequestConfiguration } from './bitlockerRequestBuilderGetRequestConfiguration';
import { BitlockerRequestBuilderPatchRequestConfiguration } from './bitlockerRequestBuilderPatchRequestConfiguration';
import { BitlockerRecoveryKeyItemRequestBuilder } from './recoveryKeys/item/bitlockerRecoveryKeyItemRequestBuilder';
import { RecoveryKeysRequestBuilder } from './recoveryKeys/recoveryKeysRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the bitlocker property of the microsoft.graph.informationProtection entity. */
export declare class BitlockerRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The recoveryKeys property */
    get recoveryKeys(): RecoveryKeysRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new BitlockerRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property bitlocker for informationProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: BitlockerRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get bitlocker from informationProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: BitlockerRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property bitlocker in informationProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Bitlocker | undefined, requestConfiguration?: BitlockerRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property bitlocker for informationProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: BitlockerRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get bitlocker from informationProtection
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Bitlocker
     */
    get(requestConfiguration?: BitlockerRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Bitlocker | undefined>;
    /**
     * Update the navigation property bitlocker in informationProtection
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Bitlocker | undefined, requestConfiguration?: BitlockerRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.informationProtection.bitlocker.recoveryKeys.item collection
     * @param id Unique identifier of the item
     * @returns a bitlockerRecoveryKeyItemRequestBuilder
     */
    recoveryKeysById(id: string): BitlockerRecoveryKeyItemRequestBuilder;
}
