import { UserActivity } from '../../../models/';
import { HistoryItemsRequestBuilder } from './historyItems/historyItemsRequestBuilder';
import { ActivityHistoryItemItemRequestBuilder } from './historyItems/item/activityHistoryItemItemRequestBuilder';
import { UserActivityItemRequestBuilderDeleteRequestConfiguration } from './userActivityItemRequestBuilderDeleteRequestConfiguration';
import { UserActivityItemRequestBuilderGetRequestConfiguration } from './userActivityItemRequestBuilderGetRequestConfiguration';
import { UserActivityItemRequestBuilderPatchRequestConfiguration } from './userActivityItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the activities property of the microsoft.graph.user entity. */
export declare class UserActivityItemRequestBuilder {
    /** The historyItems property */
    get historyItems(): HistoryItemsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new UserActivityItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property activities for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: UserActivityItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The user's activities across devices. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: UserActivityItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property activities in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: UserActivity | undefined, requestConfiguration?: UserActivityItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property activities for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: UserActivityItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The user's activities across devices. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of UserActivity
     */
    get(requestConfiguration?: UserActivityItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<UserActivity | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.activities.item.historyItems.item collection
     * @param id Unique identifier of the item
     * @returns a activityHistoryItemItemRequestBuilder
     */
    historyItemsById(id: string): ActivityHistoryItemItemRequestBuilder;
    /**
     * Update the navigation property activities in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: UserActivity | undefined, requestConfiguration?: UserActivityItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
