import { Fido2AuthenticationMethod, Fido2AuthenticationMethodCollectionResponse } from '../../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { Fido2MethodsRequestBuilderGetRequestConfiguration } from './fido2MethodsRequestBuilderGetRequestConfiguration';
import { Fido2MethodsRequestBuilderPostRequestConfiguration } from './fido2MethodsRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the fido2Methods property of the microsoft.graph.authentication entity. */
export declare class Fido2MethodsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new Fido2MethodsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Represents the FIDO2 security keys registered to a user for authentication.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: Fido2MethodsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to fido2Methods for me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: Fido2AuthenticationMethod | undefined, requestConfiguration?: Fido2MethodsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the FIDO2 security keys registered to a user for authentication.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Fido2AuthenticationMethodCollectionResponse
     */
    get(requestConfiguration?: Fido2MethodsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Fido2AuthenticationMethodCollectionResponse | undefined>;
    /**
     * Create new navigation property to fido2Methods for me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Fido2AuthenticationMethod
     */
    post(body: Fido2AuthenticationMethod | undefined, requestConfiguration?: Fido2MethodsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Fido2AuthenticationMethod | undefined>;
}
