import { Device } from '../../../../../models/';
import { DeviceRequestBuilderDeleteRequestConfiguration } from './deviceRequestBuilderDeleteRequestConfiguration';
import { DeviceRequestBuilderGetRequestConfiguration } from './deviceRequestBuilderGetRequestConfiguration';
import { DeviceRequestBuilderPatchRequestConfiguration } from './deviceRequestBuilderPatchRequestConfiguration';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i42b3ea028c2f714ff5f51f541a86f9fc0a9c848343c9b57cb0e4baba6cf2ad14 } from './memberOf/item/directoryObjectItemRequestBuilder';
import { MemberOfRequestBuilder } from './memberOf/memberOfRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i09ee47e74d54130296c55f4360138c7793c4b263514c486217313b1eedbe0aed } from './registeredOwners/item/directoryObjectItemRequestBuilder';
import { RegisteredOwnersRequestBuilder } from './registeredOwners/registeredOwnersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i318df47a6391bfbf2fc6eefba4a9beac1c790a6d96c3767a564e9759a235ab89 } from './registeredUsers/item/directoryObjectItemRequestBuilder';
import { RegisteredUsersRequestBuilder } from './registeredUsers/registeredUsersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i508c4cf0f5585228a3b9aa7443d2c2172a337d8b78dfd4d1b29ff17f00ca2b86 } from './transitiveMemberOf/item/directoryObjectItemRequestBuilder';
import { TransitiveMemberOfRequestBuilder } from './transitiveMemberOf/transitiveMemberOfRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the device property of the microsoft.graph.microsoftAuthenticatorAuthenticationMethod entity. */
export declare class DeviceRequestBuilder {
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The memberOf property */
    get memberOf(): MemberOfRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The registeredOwners property */
    get registeredOwners(): RegisteredOwnersRequestBuilder;
    /** The registeredUsers property */
    get registeredUsers(): RegisteredUsersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The transitiveMemberOf property */
    get transitiveMemberOf(): TransitiveMemberOfRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DeviceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property device for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The registered device on which Microsoft Authenticator resides. This property is null if the device is not registered for passwordless Phone Sign-In.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property device in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property device for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.microsoftAuthenticatorMethods.item.device.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The registered device on which Microsoft Authenticator resides. This property is null if the device is not registered for passwordless Phone Sign-In.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Device
     */
    get(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Device | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.microsoftAuthenticatorMethods.item.device.memberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    memberOfById(id: string): i42b3ea028c2f714ff5f51f541a86f9fc0a9c848343c9b57cb0e4baba6cf2ad14;
    /**
     * Update the navigation property device in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.microsoftAuthenticatorMethods.item.device.registeredOwners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredOwnersById(id: string): i09ee47e74d54130296c55f4360138c7793c4b263514c486217313b1eedbe0aed;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.microsoftAuthenticatorMethods.item.device.registeredUsers.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredUsersById(id: string): i318df47a6391bfbf2fc6eefba4a9beac1c790a6d96c3767a564e9759a235ab89;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.microsoftAuthenticatorMethods.item.device.transitiveMemberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    transitiveMemberOfById(id: string): i508c4cf0f5585228a3b9aa7443d2c2172a337d8b78dfd4d1b29ff17f00ca2b86;
}
