import { Device } from '../../../../../models/';
import { DeviceRequestBuilderDeleteRequestConfiguration } from './deviceRequestBuilderDeleteRequestConfiguration';
import { DeviceRequestBuilderGetRequestConfiguration } from './deviceRequestBuilderGetRequestConfiguration';
import { DeviceRequestBuilderPatchRequestConfiguration } from './deviceRequestBuilderPatchRequestConfiguration';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i8a8383253fcd5a21c35c5c8dee8d83195be6a4871220632a479f331dcd9ac79a } from './memberOf/item/directoryObjectItemRequestBuilder';
import { MemberOfRequestBuilder } from './memberOf/memberOfRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i98e75702b3a8275a006ead3fcbd2a79bc9e58753ff70eb0137aa91a8bac1c183 } from './registeredOwners/item/directoryObjectItemRequestBuilder';
import { RegisteredOwnersRequestBuilder } from './registeredOwners/registeredOwnersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as ieb0981796e327751c10af6bccd605d525ecd4b4c08a7358c1606cf5a14999dd0 } from './registeredUsers/item/directoryObjectItemRequestBuilder';
import { RegisteredUsersRequestBuilder } from './registeredUsers/registeredUsersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i6f38ee384b10320bfe694fe3b57fada14cdc67634a1c63d56028ad8eaf6ab61e } from './transitiveMemberOf/item/directoryObjectItemRequestBuilder';
import { TransitiveMemberOfRequestBuilder } from './transitiveMemberOf/transitiveMemberOfRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the device property of the microsoft.graph.windowsHelloForBusinessAuthenticationMethod entity. */
export declare class DeviceRequestBuilder {
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The memberOf property */
    get memberOf(): MemberOfRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The registeredOwners property */
    get registeredOwners(): RegisteredOwnersRequestBuilder;
    /** The registeredUsers property */
    get registeredUsers(): RegisteredUsersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The transitiveMemberOf property */
    get transitiveMemberOf(): TransitiveMemberOfRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DeviceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property device for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property device in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property device for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.windowsHelloForBusinessMethods.item.device.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Device
     */
    get(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Device | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.windowsHelloForBusinessMethods.item.device.memberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    memberOfById(id: string): i8a8383253fcd5a21c35c5c8dee8d83195be6a4871220632a479f331dcd9ac79a;
    /**
     * Update the navigation property device in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.windowsHelloForBusinessMethods.item.device.registeredOwners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredOwnersById(id: string): i98e75702b3a8275a006ead3fcbd2a79bc9e58753ff70eb0137aa91a8bac1c183;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.windowsHelloForBusinessMethods.item.device.registeredUsers.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredUsersById(id: string): ieb0981796e327751c10af6bccd605d525ecd4b4c08a7358c1606cf5a14999dd0;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.authentication.windowsHelloForBusinessMethods.item.device.transitiveMemberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    transitiveMemberOfById(id: string): i6f38ee384b10320bfe694fe3b57fada14cdc67634a1c63d56028ad8eaf6ab61e;
}
