import { Notebook } from '../../../../models/';
import { CopyNotebookRequestBuilder } from './copyNotebook/copyNotebookRequestBuilder';
import { NotebookItemRequestBuilderDeleteRequestConfiguration } from './notebookItemRequestBuilderDeleteRequestConfiguration';
import { NotebookItemRequestBuilderGetRequestConfiguration } from './notebookItemRequestBuilderGetRequestConfiguration';
import { NotebookItemRequestBuilderPatchRequestConfiguration } from './notebookItemRequestBuilderPatchRequestConfiguration';
import { SectionGroupItemRequestBuilder } from './sectionGroups/item/sectionGroupItemRequestBuilder';
import { SectionGroupsRequestBuilder } from './sectionGroups/sectionGroupsRequestBuilder';
import { OnenoteSectionItemRequestBuilder } from './sections/item/onenoteSectionItemRequestBuilder';
import { SectionsRequestBuilder } from './sections/sectionsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the notebooks property of the microsoft.graph.onenote entity. */
export declare class NotebookItemRequestBuilder {
    /** The copyNotebook property */
    get copyNotebook(): CopyNotebookRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The sectionGroups property */
    get sectionGroups(): SectionGroupsRequestBuilder;
    /** The sections property */
    get sections(): SectionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new NotebookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property notebooks for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: NotebookItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: NotebookItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property notebooks in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Notebook | undefined, requestConfiguration?: NotebookItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property notebooks for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: NotebookItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Notebook
     */
    get(requestConfiguration?: NotebookItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Notebook | undefined>;
    /**
     * Update the navigation property notebooks in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Notebook | undefined, requestConfiguration?: NotebookItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.onenote.notebooks.item.sectionGroups.item collection
     * @param id Unique identifier of the item
     * @returns a sectionGroupItemRequestBuilder
     */
    sectionGroupsById(id: string): SectionGroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.onenote.notebooks.item.sections.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteSectionItemRequestBuilder
     */
    sectionsById(id: string): OnenoteSectionItemRequestBuilder;
}
