import { OutlookUser } from '../../models/';
import { OutlookCategoryItemRequestBuilder } from './masterCategories/item/outlookCategoryItemRequestBuilder';
import { MasterCategoriesRequestBuilder } from './masterCategories/masterCategoriesRequestBuilder';
import { OutlookRequestBuilderDeleteRequestConfiguration } from './outlookRequestBuilderDeleteRequestConfiguration';
import { OutlookRequestBuilderGetRequestConfiguration } from './outlookRequestBuilderGetRequestConfiguration';
import { OutlookRequestBuilderPatchRequestConfiguration } from './outlookRequestBuilderPatchRequestConfiguration';
import { SupportedLanguagesRequestBuilder } from './supportedLanguages/supportedLanguagesRequestBuilder';
import { SupportedTimeZonesRequestBuilder } from './supportedTimeZones/supportedTimeZonesRequestBuilder';
import { SupportedTimeZonesWithTimeZoneStandardRequestBuilder } from './supportedTimeZonesWithTimeZoneStandard/supportedTimeZonesWithTimeZoneStandardRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the outlook property of the microsoft.graph.user entity. */
export declare class OutlookRequestBuilder {
    /** The masterCategories property */
    get masterCategories(): MasterCategoriesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new OutlookRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property outlook for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: OutlookRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Selective Outlook services available to the user. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: OutlookRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property outlook in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OutlookUser | undefined, requestConfiguration?: OutlookRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property outlook for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: OutlookRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Selective Outlook services available to the user. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OutlookUser
     */
    get(requestConfiguration?: OutlookRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<OutlookUser | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.outlook.masterCategories.item collection
     * @param id Unique identifier of the item
     * @returns a outlookCategoryItemRequestBuilder
     */
    masterCategoriesById(id: string): OutlookCategoryItemRequestBuilder;
    /**
     * Update the navigation property outlook in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OutlookUser | undefined, requestConfiguration?: OutlookRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the supportedLanguages method.
     * @returns a supportedLanguagesRequestBuilder
     */
    supportedLanguages(): SupportedLanguagesRequestBuilder;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @returns a supportedTimeZonesRequestBuilder
     */
    supportedTimeZones(): SupportedTimeZonesRequestBuilder;
    /**
     * Provides operations to call the supportedTimeZones method.
     * @param TimeZoneStandard Usage: TimeZoneStandard='{TimeZoneStandard}'
     * @returns a supportedTimeZonesWithTimeZoneStandardRequestBuilder
     */
    supportedTimeZonesWithTimeZoneStandard(timeZoneStandard: string | undefined): SupportedTimeZonesWithTimeZoneStandardRequestBuilder;
}
