import { Presence } from '../../models/';
import { ClearPresenceRequestBuilder } from './clearPresence/clearPresenceRequestBuilder';
import { PresenceRequestBuilderDeleteRequestConfiguration } from './presenceRequestBuilderDeleteRequestConfiguration';
import { PresenceRequestBuilderGetRequestConfiguration } from './presenceRequestBuilderGetRequestConfiguration';
import { PresenceRequestBuilderPatchRequestConfiguration } from './presenceRequestBuilderPatchRequestConfiguration';
import { SetPresenceRequestBuilder } from './setPresence/setPresenceRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the presence property of the microsoft.graph.user entity. */
export declare class PresenceRequestBuilder {
    /** The clearPresence property */
    get clearPresence(): ClearPresenceRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The setPresence property */
    get setPresence(): SetPresenceRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PresenceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property presence for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: PresenceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get presence from me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PresenceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property presence in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Presence | undefined, requestConfiguration?: PresenceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property presence for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: PresenceRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get presence from me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Presence
     */
    get(requestConfiguration?: PresenceRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Presence | undefined>;
    /**
     * Update the navigation property presence in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Presence | undefined, requestConfiguration?: PresenceRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
