import { TodoTask } from '../../../../../../models/';
import { ChecklistItemsRequestBuilder } from './checklistItems/checklistItemsRequestBuilder';
import { ChecklistItemItemRequestBuilder } from './checklistItems/item/checklistItemItemRequestBuilder';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { LinkedResourceItemRequestBuilder } from './linkedResources/item/linkedResourceItemRequestBuilder';
import { LinkedResourcesRequestBuilder } from './linkedResources/linkedResourcesRequestBuilder';
import { TodoTaskItemRequestBuilderDeleteRequestConfiguration } from './todoTaskItemRequestBuilderDeleteRequestConfiguration';
import { TodoTaskItemRequestBuilderGetRequestConfiguration } from './todoTaskItemRequestBuilderGetRequestConfiguration';
import { TodoTaskItemRequestBuilderPatchRequestConfiguration } from './todoTaskItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the tasks property of the microsoft.graph.todoTaskList entity. */
export declare class TodoTaskItemRequestBuilder {
    /** The checklistItems property */
    get checklistItems(): ChecklistItemsRequestBuilder;
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The linkedResources property */
    get linkedResources(): LinkedResourcesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.todo.lists.item.tasks.item.checklistItems.item collection
     * @param id Unique identifier of the item
     * @returns a checklistItemItemRequestBuilder
     */
    checklistItemsById(id: string): ChecklistItemItemRequestBuilder;
    /**
     * Instantiates a new TodoTaskItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property tasks for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: TodoTaskItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The tasks in this task list. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TodoTaskItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property tasks in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: TodoTask | undefined, requestConfiguration?: TodoTaskItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property tasks for me
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: TodoTaskItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.todo.lists.item.tasks.item.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The tasks in this task list. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of TodoTask
     */
    get(requestConfiguration?: TodoTaskItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<TodoTask | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.todo.lists.item.tasks.item.linkedResources.item collection
     * @param id Unique identifier of the item
     * @returns a linkedResourceItemRequestBuilder
     */
    linkedResourcesById(id: string): LinkedResourceItemRequestBuilder;
    /**
     * Update the navigation property tasks in me
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: TodoTask | undefined, requestConfiguration?: TodoTaskItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
