"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Agreement = void 0;
const createAgreementAcceptanceFromDiscriminatorValue_1 = require("./createAgreementAcceptanceFromDiscriminatorValue");
const createAgreementFileFromDiscriminatorValue_1 = require("./createAgreementFileFromDiscriminatorValue");
const createAgreementFileLocalizationFromDiscriminatorValue_1 = require("./createAgreementFileLocalizationFromDiscriminatorValue");
const createTermsExpirationFromDiscriminatorValue_1 = require("./createTermsExpirationFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the collection of agreement entities. */
class Agreement extends index_1.Entity {
    /**
     * Instantiates a new agreement and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the acceptances property value. Read-only. Information about acceptances of this agreement.
     * @returns a agreementAcceptance
     */
    get acceptances() {
        return this._acceptances;
    }
    ;
    /**
     * Sets the acceptances property value. Read-only. Information about acceptances of this agreement.
     * @param value Value to set for the acceptances property.
     */
    set acceptances(value) {
        this._acceptances = value;
    }
    ;
    ;
    /**
     * Gets the displayName property value. Display name of the agreement. The display name is used for internal tracking of the agreement but is not shown to end users who view the agreement. Supports $filter (eq).
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. Display name of the agreement. The display name is used for internal tracking of the agreement but is not shown to end users who view the agreement. Supports $filter (eq).
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * Gets the file property value. Default PDF linked to this agreement.
     * @returns a agreementFile
     */
    get file() {
        return this._file;
    }
    ;
    /**
     * Sets the file property value. Default PDF linked to this agreement.
     * @param value Value to set for the file property.
     */
    set file(value) {
        this._file = value;
    }
    ;
    /**
     * Gets the files property value. PDFs linked to this agreement. Note: This property is in the process of being deprecated. Use the  file property instead.
     * @returns a agreementFileLocalization
     */
    get files() {
        return this._files;
    }
    ;
    /**
     * Sets the files property value. PDFs linked to this agreement. Note: This property is in the process of being deprecated. Use the  file property instead.
     * @param value Value to set for the files property.
     */
    set files(value) {
        this._files = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "acceptances": n => { this.acceptances = n.getCollectionOfObjectValues(createAgreementAcceptanceFromDiscriminatorValue_1.createAgreementAcceptanceFromDiscriminatorValue); }, "displayName": n => { this.displayName = n.getStringValue(); }, "file": n => { this.file = n.getObjectValue(createAgreementFileFromDiscriminatorValue_1.createAgreementFileFromDiscriminatorValue); }, "files": n => { this.files = n.getCollectionOfObjectValues(createAgreementFileLocalizationFromDiscriminatorValue_1.createAgreementFileLocalizationFromDiscriminatorValue); }, "isPerDeviceAcceptanceRequired": n => { this.isPerDeviceAcceptanceRequired = n.getBooleanValue(); }, "isViewingBeforeAcceptanceRequired": n => { this.isViewingBeforeAcceptanceRequired = n.getBooleanValue(); }, "termsExpiration": n => { this.termsExpiration = n.getObjectValue(createTermsExpirationFromDiscriminatorValue_1.createTermsExpirationFromDiscriminatorValue); }, "userReacceptRequiredFrequency": n => { this.userReacceptRequiredFrequency = n.getDurationValue(); } });
    }
    ;
    /**
     * Gets the isPerDeviceAcceptanceRequired property value. This setting enables you to require end users to accept this agreement on every device that they are accessing it from. The end user will be required to register their device in Azure AD, if they haven't already done so. Supports $filter (eq).
     * @returns a boolean
     */
    get isPerDeviceAcceptanceRequired() {
        return this._isPerDeviceAcceptanceRequired;
    }
    ;
    /**
     * Sets the isPerDeviceAcceptanceRequired property value. This setting enables you to require end users to accept this agreement on every device that they are accessing it from. The end user will be required to register their device in Azure AD, if they haven't already done so. Supports $filter (eq).
     * @param value Value to set for the isPerDeviceAcceptanceRequired property.
     */
    set isPerDeviceAcceptanceRequired(value) {
        this._isPerDeviceAcceptanceRequired = value;
    }
    ;
    /**
     * Gets the isViewingBeforeAcceptanceRequired property value. Indicates whether the user has to expand the agreement before accepting. Supports $filter (eq).
     * @returns a boolean
     */
    get isViewingBeforeAcceptanceRequired() {
        return this._isViewingBeforeAcceptanceRequired;
    }
    ;
    /**
     * Sets the isViewingBeforeAcceptanceRequired property value. Indicates whether the user has to expand the agreement before accepting. Supports $filter (eq).
     * @param value Value to set for the isViewingBeforeAcceptanceRequired property.
     */
    set isViewingBeforeAcceptanceRequired(value) {
        this._isViewingBeforeAcceptanceRequired = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("acceptances", this.acceptances);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeObjectValue("file", this.file);
        writer.writeCollectionOfObjectValues("files", this.files);
        writer.writeBooleanValue("isPerDeviceAcceptanceRequired", this.isPerDeviceAcceptanceRequired);
        writer.writeBooleanValue("isViewingBeforeAcceptanceRequired", this.isViewingBeforeAcceptanceRequired);
        writer.writeObjectValue("termsExpiration", this.termsExpiration);
        writer.writeDurationValue("userReacceptRequiredFrequency", this.userReacceptRequiredFrequency);
    }
    ;
    /**
     * Gets the termsExpiration property value. Expiration schedule and frequency of agreement for all users.  Supports $filter (eq).
     * @returns a termsExpiration
     */
    get termsExpiration() {
        return this._termsExpiration;
    }
    ;
    /**
     * Sets the termsExpiration property value. Expiration schedule and frequency of agreement for all users.  Supports $filter (eq).
     * @param value Value to set for the termsExpiration property.
     */
    set termsExpiration(value) {
        this._termsExpiration = value;
    }
    ;
    /**
     * Gets the userReacceptRequiredFrequency property value. The duration after which the user must re-accept the terms of use. The value is represented in ISO 8601 format for durations.
     * @returns a Duration
     */
    get userReacceptRequiredFrequency() {
        return this._userReacceptRequiredFrequency;
    }
    ;
    /**
     * Sets the userReacceptRequiredFrequency property value. The duration after which the user must re-accept the terms of use. The value is represented in ISO 8601 format for durations.
     * @param value Value to set for the userReacceptRequiredFrequency property.
     */
    set userReacceptRequiredFrequency(value) {
        this._userReacceptRequiredFrequency = value;
    }
    ;
}
exports.Agreement = Agreement;
