"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Application = void 0;
const createAddInFromDiscriminatorValue_1 = require("./createAddInFromDiscriminatorValue");
const createApiApplicationFromDiscriminatorValue_1 = require("./createApiApplicationFromDiscriminatorValue");
const createAppRoleFromDiscriminatorValue_1 = require("./createAppRoleFromDiscriminatorValue");
const createDirectoryObjectFromDiscriminatorValue_1 = require("./createDirectoryObjectFromDiscriminatorValue");
const createExtensionPropertyFromDiscriminatorValue_1 = require("./createExtensionPropertyFromDiscriminatorValue");
const createHomeRealmDiscoveryPolicyFromDiscriminatorValue_1 = require("./createHomeRealmDiscoveryPolicyFromDiscriminatorValue");
const createInformationalUrlFromDiscriminatorValue_1 = require("./createInformationalUrlFromDiscriminatorValue");
const createKeyCredentialFromDiscriminatorValue_1 = require("./createKeyCredentialFromDiscriminatorValue");
const createOptionalClaimsFromDiscriminatorValue_1 = require("./createOptionalClaimsFromDiscriminatorValue");
const createParentalControlSettingsFromDiscriminatorValue_1 = require("./createParentalControlSettingsFromDiscriminatorValue");
const createPasswordCredentialFromDiscriminatorValue_1 = require("./createPasswordCredentialFromDiscriminatorValue");
const createPublicClientApplicationFromDiscriminatorValue_1 = require("./createPublicClientApplicationFromDiscriminatorValue");
const createRequiredResourceAccessFromDiscriminatorValue_1 = require("./createRequiredResourceAccessFromDiscriminatorValue");
const createSpaApplicationFromDiscriminatorValue_1 = require("./createSpaApplicationFromDiscriminatorValue");
const createTokenIssuancePolicyFromDiscriminatorValue_1 = require("./createTokenIssuancePolicyFromDiscriminatorValue");
const createTokenLifetimePolicyFromDiscriminatorValue_1 = require("./createTokenLifetimePolicyFromDiscriminatorValue");
const createVerifiedPublisherFromDiscriminatorValue_1 = require("./createVerifiedPublisherFromDiscriminatorValue");
const createWebApplicationFromDiscriminatorValue_1 = require("./createWebApplicationFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the collection of application entities. */
class Application extends index_1.DirectoryObject {
    /**
     * Instantiates a new application and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the addIns property value. Defines custom behavior that a consuming service can use to call an app in specific contexts. For example, applications that can render file streams may set the addIns property for its 'FileHandler' functionality. This will let services like Office 365 call the application in the context of a document the user is working on.
     * @returns a addIn
     */
    get addIns() {
        return this._addIns;
    }
    ;
    /**
     * Sets the addIns property value. Defines custom behavior that a consuming service can use to call an app in specific contexts. For example, applications that can render file streams may set the addIns property for its 'FileHandler' functionality. This will let services like Office 365 call the application in the context of a document the user is working on.
     * @param value Value to set for the addIns property.
     */
    set addIns(value) {
        this._addIns = value;
    }
    ;
    /**
     * Gets the api property value. Specifies settings for an application that implements a web API.
     * @returns a apiApplication
     */
    get api() {
        return this._api;
    }
    ;
    /**
     * Sets the api property value. Specifies settings for an application that implements a web API.
     * @param value Value to set for the api property.
     */
    set api(value) {
        this._api = value;
    }
    ;
    /**
     * Gets the appId property value. The unique identifier for the application that is assigned by Azure AD. Not nullable. Read-only.
     * @returns a string
     */
    get appId() {
        return this._appId;
    }
    ;
    /**
     * Sets the appId property value. The unique identifier for the application that is assigned by Azure AD. Not nullable. Read-only.
     * @param value Value to set for the appId property.
     */
    set appId(value) {
        this._appId = value;
    }
    ;
    /**
     * Gets the applicationTemplateId property value. Unique identifier of the applicationTemplate. Supports $filter (eq, not, ne).
     * @returns a string
     */
    get applicationTemplateId() {
        return this._applicationTemplateId;
    }
    ;
    /**
     * Sets the applicationTemplateId property value. Unique identifier of the applicationTemplate. Supports $filter (eq, not, ne).
     * @param value Value to set for the applicationTemplateId property.
     */
    set applicationTemplateId(value) {
        this._applicationTemplateId = value;
    }
    ;
    /**
     * Gets the appRoles property value. The collection of roles assigned to the application. With app role assignments, these roles can be assigned to users, groups, or service principals associated with other applications. Not nullable.
     * @returns a appRole
     */
    get appRoles() {
        return this._appRoles;
    }
    ;
    /**
     * Sets the appRoles property value. The collection of roles assigned to the application. With app role assignments, these roles can be assigned to users, groups, or service principals associated with other applications. Not nullable.
     * @param value Value to set for the appRoles property.
     */
    set appRoles(value) {
        this._appRoles = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. The date and time the application was registered. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  Supports $filter (eq, ne, not, ge, le, in, and eq on null values) and $orderBy.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. The date and time the application was registered. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  Supports $filter (eq, ne, not, ge, le, in, and eq on null values) and $orderBy.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the createdOnBehalfOf property value. Read-only.
     * @returns a directoryObject
     */
    get createdOnBehalfOf() {
        return this._createdOnBehalfOf;
    }
    ;
    /**
     * Sets the createdOnBehalfOf property value. Read-only.
     * @param value Value to set for the createdOnBehalfOf property.
     */
    set createdOnBehalfOf(value) {
        this._createdOnBehalfOf = value;
    }
    ;
    /**
     * Gets the description property value. Free text field to provide a description of the application object to end users. The maximum allowed size is 1024 characters. Returned by default. Supports $filter (eq, ne, not, ge, le, startsWith) and $search.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Free text field to provide a description of the application object to end users. The maximum allowed size is 1024 characters. Returned by default. Supports $filter (eq, ne, not, ge, le, startsWith) and $search.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * Gets the disabledByMicrosoftStatus property value. Specifies whether Microsoft has disabled the registered application. Possible values are: null (default value), NotDisabled, and DisabledDueToViolationOfServicesAgreement (reasons may include suspicious, abusive, or malicious activity, or a violation of the Microsoft Services Agreement).  Supports $filter (eq, ne, not).
     * @returns a string
     */
    get disabledByMicrosoftStatus() {
        return this._disabledByMicrosoftStatus;
    }
    ;
    /**
     * Sets the disabledByMicrosoftStatus property value. Specifies whether Microsoft has disabled the registered application. Possible values are: null (default value), NotDisabled, and DisabledDueToViolationOfServicesAgreement (reasons may include suspicious, abusive, or malicious activity, or a violation of the Microsoft Services Agreement).  Supports $filter (eq, ne, not).
     * @param value Value to set for the disabledByMicrosoftStatus property.
     */
    set disabledByMicrosoftStatus(value) {
        this._disabledByMicrosoftStatus = value;
    }
    ;
    /**
     * Gets the displayName property value. The display name for the application. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq on null values), $search, and $orderBy.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The display name for the application. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq on null values), $search, and $orderBy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * Gets the extensionProperties property value. Read-only. Nullable. Supports $expand and $filter (eq when counting empty collections).
     * @returns a extensionProperty
     */
    get extensionProperties() {
        return this._extensionProperties;
    }
    ;
    /**
     * Sets the extensionProperties property value. Read-only. Nullable. Supports $expand and $filter (eq when counting empty collections).
     * @param value Value to set for the extensionProperties property.
     */
    set extensionProperties(value) {
        this._extensionProperties = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "addIns": n => { this.addIns = n.getCollectionOfObjectValues(createAddInFromDiscriminatorValue_1.createAddInFromDiscriminatorValue); }, "api": n => { this.api = n.getObjectValue(createApiApplicationFromDiscriminatorValue_1.createApiApplicationFromDiscriminatorValue); }, "appId": n => { this.appId = n.getStringValue(); }, "applicationTemplateId": n => { this.applicationTemplateId = n.getStringValue(); }, "appRoles": n => { this.appRoles = n.getCollectionOfObjectValues(createAppRoleFromDiscriminatorValue_1.createAppRoleFromDiscriminatorValue); }, "createdDateTime": n => { this.createdDateTime = n.getDateValue(); }, "createdOnBehalfOf": n => { this.createdOnBehalfOf = n.getObjectValue(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "description": n => { this.description = n.getStringValue(); }, "disabledByMicrosoftStatus": n => { this.disabledByMicrosoftStatus = n.getStringValue(); }, "displayName": n => { this.displayName = n.getStringValue(); }, "extensionProperties": n => { this.extensionProperties = n.getCollectionOfObjectValues(createExtensionPropertyFromDiscriminatorValue_1.createExtensionPropertyFromDiscriminatorValue); }, "groupMembershipClaims": n => { this.groupMembershipClaims = n.getStringValue(); }, "homeRealmDiscoveryPolicies": n => { this.homeRealmDiscoveryPolicies = n.getCollectionOfObjectValues(createHomeRealmDiscoveryPolicyFromDiscriminatorValue_1.createHomeRealmDiscoveryPolicyFromDiscriminatorValue); }, "identifierUris": n => { this.identifierUris = n.getCollectionOfPrimitiveValues(); }, "info": n => { this.info = n.getObjectValue(createInformationalUrlFromDiscriminatorValue_1.createInformationalUrlFromDiscriminatorValue); }, "isDeviceOnlyAuthSupported": n => { this.isDeviceOnlyAuthSupported = n.getBooleanValue(); }, "isFallbackPublicClient": n => { this.isFallbackPublicClient = n.getBooleanValue(); }, "keyCredentials": n => { this.keyCredentials = n.getCollectionOfObjectValues(createKeyCredentialFromDiscriminatorValue_1.createKeyCredentialFromDiscriminatorValue); }, "logo": n => { this.logo = n.getStringValue(); }, "notes": n => { this.notes = n.getStringValue(); }, "oauth2RequirePostResponse": n => { this.oauth2RequirePostResponse = n.getBooleanValue(); }, "optionalClaims": n => { this.optionalClaims = n.getObjectValue(createOptionalClaimsFromDiscriminatorValue_1.createOptionalClaimsFromDiscriminatorValue); }, "owners": n => { this.owners = n.getCollectionOfObjectValues(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "parentalControlSettings": n => { this.parentalControlSettings = n.getObjectValue(createParentalControlSettingsFromDiscriminatorValue_1.createParentalControlSettingsFromDiscriminatorValue); }, "passwordCredentials": n => { this.passwordCredentials = n.getCollectionOfObjectValues(createPasswordCredentialFromDiscriminatorValue_1.createPasswordCredentialFromDiscriminatorValue); }, "publicClient": n => { this.publicClient = n.getObjectValue(createPublicClientApplicationFromDiscriminatorValue_1.createPublicClientApplicationFromDiscriminatorValue); }, "publisherDomain": n => { this.publisherDomain = n.getStringValue(); }, "requiredResourceAccess": n => { this.requiredResourceAccess = n.getCollectionOfObjectValues(createRequiredResourceAccessFromDiscriminatorValue_1.createRequiredResourceAccessFromDiscriminatorValue); }, "serviceManagementReference": n => { this.serviceManagementReference = n.getStringValue(); }, "signInAudience": n => { this.signInAudience = n.getStringValue(); }, "spa": n => { this.spa = n.getObjectValue(createSpaApplicationFromDiscriminatorValue_1.createSpaApplicationFromDiscriminatorValue); }, "tags": n => { this.tags = n.getCollectionOfPrimitiveValues(); }, "tokenEncryptionKeyId": n => { this.tokenEncryptionKeyId = n.getStringValue(); }, "tokenIssuancePolicies": n => { this.tokenIssuancePolicies = n.getCollectionOfObjectValues(createTokenIssuancePolicyFromDiscriminatorValue_1.createTokenIssuancePolicyFromDiscriminatorValue); }, "tokenLifetimePolicies": n => { this.tokenLifetimePolicies = n.getCollectionOfObjectValues(createTokenLifetimePolicyFromDiscriminatorValue_1.createTokenLifetimePolicyFromDiscriminatorValue); }, "verifiedPublisher": n => { this.verifiedPublisher = n.getObjectValue(createVerifiedPublisherFromDiscriminatorValue_1.createVerifiedPublisherFromDiscriminatorValue); }, "web": n => { this.web = n.getObjectValue(createWebApplicationFromDiscriminatorValue_1.createWebApplicationFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the groupMembershipClaims property value. Configures the groups claim issued in a user or OAuth 2.0 access token that the application expects. To set this attribute, use one of the following string values: None, SecurityGroup (for security groups and Azure AD roles), All (this gets all security groups, distribution groups, and Azure AD directory roles that the signed-in user is a member of).
     * @returns a string
     */
    get groupMembershipClaims() {
        return this._groupMembershipClaims;
    }
    ;
    /**
     * Sets the groupMembershipClaims property value. Configures the groups claim issued in a user or OAuth 2.0 access token that the application expects. To set this attribute, use one of the following string values: None, SecurityGroup (for security groups and Azure AD roles), All (this gets all security groups, distribution groups, and Azure AD directory roles that the signed-in user is a member of).
     * @param value Value to set for the groupMembershipClaims property.
     */
    set groupMembershipClaims(value) {
        this._groupMembershipClaims = value;
    }
    ;
    /**
     * Gets the homeRealmDiscoveryPolicies property value. The homeRealmDiscoveryPolicies property
     * @returns a homeRealmDiscoveryPolicy
     */
    get homeRealmDiscoveryPolicies() {
        return this._homeRealmDiscoveryPolicies;
    }
    ;
    /**
     * Sets the homeRealmDiscoveryPolicies property value. The homeRealmDiscoveryPolicies property
     * @param value Value to set for the homeRealmDiscoveryPolicies property.
     */
    set homeRealmDiscoveryPolicies(value) {
        this._homeRealmDiscoveryPolicies = value;
    }
    ;
    /**
     * Gets the identifierUris property value. Also known as App ID URI, this value is set when an application is used as a resource app. The identifierUris acts as the prefix for the scopes you'll reference in your API's code, and it must be globally unique. You can use the default value provided, which is in the form api://<application-client-id>, or specify a more readable URI like https://contoso.com/api. For more information on valid identifierUris patterns and best practices, see Azure AD application registration security best practices. Not nullable. Supports $filter (eq, ne, ge, le, startsWith).
     * @returns a string
     */
    get identifierUris() {
        return this._identifierUris;
    }
    ;
    /**
     * Sets the identifierUris property value. Also known as App ID URI, this value is set when an application is used as a resource app. The identifierUris acts as the prefix for the scopes you'll reference in your API's code, and it must be globally unique. You can use the default value provided, which is in the form api://<application-client-id>, or specify a more readable URI like https://contoso.com/api. For more information on valid identifierUris patterns and best practices, see Azure AD application registration security best practices. Not nullable. Supports $filter (eq, ne, ge, le, startsWith).
     * @param value Value to set for the identifierUris property.
     */
    set identifierUris(value) {
        this._identifierUris = value;
    }
    ;
    /**
     * Gets the info property value. Basic profile information of the application, such as it's marketing, support, terms of service, and privacy statement URLs. The terms of service and privacy statement are surfaced to users through the user consent experience. For more information, see How to: Add Terms of service and privacy statement for registered Azure AD apps. Supports $filter (eq, ne, not, ge, le, and eq on null values).
     * @returns a informationalUrl
     */
    get info() {
        return this._info;
    }
    ;
    /**
     * Sets the info property value. Basic profile information of the application, such as it's marketing, support, terms of service, and privacy statement URLs. The terms of service and privacy statement are surfaced to users through the user consent experience. For more information, see How to: Add Terms of service and privacy statement for registered Azure AD apps. Supports $filter (eq, ne, not, ge, le, and eq on null values).
     * @param value Value to set for the info property.
     */
    set info(value) {
        this._info = value;
    }
    ;
    /**
     * Gets the isDeviceOnlyAuthSupported property value. Specifies whether this application supports device authentication without a user. The default is false.
     * @returns a boolean
     */
    get isDeviceOnlyAuthSupported() {
        return this._isDeviceOnlyAuthSupported;
    }
    ;
    /**
     * Sets the isDeviceOnlyAuthSupported property value. Specifies whether this application supports device authentication without a user. The default is false.
     * @param value Value to set for the isDeviceOnlyAuthSupported property.
     */
    set isDeviceOnlyAuthSupported(value) {
        this._isDeviceOnlyAuthSupported = value;
    }
    ;
    /**
     * Gets the isFallbackPublicClient property value. Specifies the fallback application type as public client, such as an installed application running on a mobile device. The default value is false which means the fallback application type is confidential client such as a web app. There are certain scenarios where Azure AD cannot determine the client application type. For example, the ROPC flow where the application is configured without specifying a redirect URI. In those cases Azure AD interprets the application type based on the value of this property.
     * @returns a boolean
     */
    get isFallbackPublicClient() {
        return this._isFallbackPublicClient;
    }
    ;
    /**
     * Sets the isFallbackPublicClient property value. Specifies the fallback application type as public client, such as an installed application running on a mobile device. The default value is false which means the fallback application type is confidential client such as a web app. There are certain scenarios where Azure AD cannot determine the client application type. For example, the ROPC flow where the application is configured without specifying a redirect URI. In those cases Azure AD interprets the application type based on the value of this property.
     * @param value Value to set for the isFallbackPublicClient property.
     */
    set isFallbackPublicClient(value) {
        this._isFallbackPublicClient = value;
    }
    ;
    /**
     * Gets the keyCredentials property value. The collection of key credentials associated with the application. Not nullable. Supports $filter (eq, not, ge, le).
     * @returns a keyCredential
     */
    get keyCredentials() {
        return this._keyCredentials;
    }
    ;
    /**
     * Sets the keyCredentials property value. The collection of key credentials associated with the application. Not nullable. Supports $filter (eq, not, ge, le).
     * @param value Value to set for the keyCredentials property.
     */
    set keyCredentials(value) {
        this._keyCredentials = value;
    }
    ;
    /**
     * Gets the logo property value. The main logo for the application. Not nullable.
     * @returns a binary
     */
    get logo() {
        return this._logo;
    }
    ;
    /**
     * Sets the logo property value. The main logo for the application. Not nullable.
     * @param value Value to set for the logo property.
     */
    set logo(value) {
        this._logo = value;
    }
    ;
    /**
     * Gets the notes property value. Notes relevant for the management of the application.
     * @returns a string
     */
    get notes() {
        return this._notes;
    }
    ;
    /**
     * Sets the notes property value. Notes relevant for the management of the application.
     * @param value Value to set for the notes property.
     */
    set notes(value) {
        this._notes = value;
    }
    ;
    /**
     * Gets the oauth2RequirePostResponse property value. The oauth2RequirePostResponse property
     * @returns a boolean
     */
    get oauth2RequirePostResponse() {
        return this._oauth2RequirePostResponse;
    }
    ;
    /**
     * Sets the oauth2RequirePostResponse property value. The oauth2RequirePostResponse property
     * @param value Value to set for the oauth2RequirePostResponse property.
     */
    set oauth2RequirePostResponse(value) {
        this._oauth2RequirePostResponse = value;
    }
    ;
    /**
     * Gets the optionalClaims property value. Application developers can configure optional claims in their Azure AD applications to specify the claims that are sent to their application by the Microsoft security token service. For more information, see How to: Provide optional claims to your app.
     * @returns a optionalClaims
     */
    get optionalClaims() {
        return this._optionalClaims;
    }
    ;
    /**
     * Sets the optionalClaims property value. Application developers can configure optional claims in their Azure AD applications to specify the claims that are sent to their application by the Microsoft security token service. For more information, see How to: Provide optional claims to your app.
     * @param value Value to set for the optionalClaims property.
     */
    set optionalClaims(value) {
        this._optionalClaims = value;
    }
    ;
    /**
     * Gets the owners property value. Directory objects that are owners of the application. Read-only. Nullable. Supports $expand.
     * @returns a directoryObject
     */
    get owners() {
        return this._owners;
    }
    ;
    /**
     * Sets the owners property value. Directory objects that are owners of the application. Read-only. Nullable. Supports $expand.
     * @param value Value to set for the owners property.
     */
    set owners(value) {
        this._owners = value;
    }
    ;
    /**
     * Gets the parentalControlSettings property value. Specifies parental control settings for an application.
     * @returns a parentalControlSettings
     */
    get parentalControlSettings() {
        return this._parentalControlSettings;
    }
    ;
    /**
     * Sets the parentalControlSettings property value. Specifies parental control settings for an application.
     * @param value Value to set for the parentalControlSettings property.
     */
    set parentalControlSettings(value) {
        this._parentalControlSettings = value;
    }
    ;
    /**
     * Gets the passwordCredentials property value. The collection of password credentials associated with the application. Not nullable.
     * @returns a passwordCredential
     */
    get passwordCredentials() {
        return this._passwordCredentials;
    }
    ;
    /**
     * Sets the passwordCredentials property value. The collection of password credentials associated with the application. Not nullable.
     * @param value Value to set for the passwordCredentials property.
     */
    set passwordCredentials(value) {
        this._passwordCredentials = value;
    }
    ;
    /**
     * Gets the publicClient property value. Specifies settings for installed clients such as desktop or mobile devices.
     * @returns a publicClientApplication
     */
    get publicClient() {
        return this._publicClient;
    }
    ;
    /**
     * Sets the publicClient property value. Specifies settings for installed clients such as desktop or mobile devices.
     * @param value Value to set for the publicClient property.
     */
    set publicClient(value) {
        this._publicClient = value;
    }
    ;
    /**
     * Gets the publisherDomain property value. The verified publisher domain for the application. Read-only. Supports $filter (eq, ne, ge, le, startsWith).
     * @returns a string
     */
    get publisherDomain() {
        return this._publisherDomain;
    }
    ;
    /**
     * Sets the publisherDomain property value. The verified publisher domain for the application. Read-only. Supports $filter (eq, ne, ge, le, startsWith).
     * @param value Value to set for the publisherDomain property.
     */
    set publisherDomain(value) {
        this._publisherDomain = value;
    }
    ;
    /**
     * Gets the requiredResourceAccess property value. Specifies the resources that the application needs to access. This property also specifies the set of delegated permissions and application roles that it needs for each of those resources. This configuration of access to the required resources drives the consent experience. No more than 50 resource services (APIs) can be configured. Beginning mid-October 2021, the total number of required permissions must not exceed 400. Not nullable. Supports $filter (eq, not, ge, le).
     * @returns a requiredResourceAccess
     */
    get requiredResourceAccess() {
        return this._requiredResourceAccess;
    }
    ;
    /**
     * Sets the requiredResourceAccess property value. Specifies the resources that the application needs to access. This property also specifies the set of delegated permissions and application roles that it needs for each of those resources. This configuration of access to the required resources drives the consent experience. No more than 50 resource services (APIs) can be configured. Beginning mid-October 2021, the total number of required permissions must not exceed 400. Not nullable. Supports $filter (eq, not, ge, le).
     * @param value Value to set for the requiredResourceAccess property.
     */
    set requiredResourceAccess(value) {
        this._requiredResourceAccess = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("addIns", this.addIns);
        writer.writeObjectValue("api", this.api);
        writer.writeStringValue("appId", this.appId);
        writer.writeStringValue("applicationTemplateId", this.applicationTemplateId);
        writer.writeCollectionOfObjectValues("appRoles", this.appRoles);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeObjectValue("createdOnBehalfOf", this.createdOnBehalfOf);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("disabledByMicrosoftStatus", this.disabledByMicrosoftStatus);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeCollectionOfObjectValues("extensionProperties", this.extensionProperties);
        writer.writeStringValue("groupMembershipClaims", this.groupMembershipClaims);
        writer.writeCollectionOfObjectValues("homeRealmDiscoveryPolicies", this.homeRealmDiscoveryPolicies);
        writer.writeCollectionOfPrimitiveValues("identifierUris", this.identifierUris);
        writer.writeObjectValue("info", this.info);
        writer.writeBooleanValue("isDeviceOnlyAuthSupported", this.isDeviceOnlyAuthSupported);
        writer.writeBooleanValue("isFallbackPublicClient", this.isFallbackPublicClient);
        writer.writeCollectionOfObjectValues("keyCredentials", this.keyCredentials);
        writer.writeStringValue("logo", this.logo);
        writer.writeStringValue("notes", this.notes);
        writer.writeBooleanValue("oauth2RequirePostResponse", this.oauth2RequirePostResponse);
        writer.writeObjectValue("optionalClaims", this.optionalClaims);
        writer.writeCollectionOfObjectValues("owners", this.owners);
        writer.writeObjectValue("parentalControlSettings", this.parentalControlSettings);
        writer.writeCollectionOfObjectValues("passwordCredentials", this.passwordCredentials);
        writer.writeObjectValue("publicClient", this.publicClient);
        writer.writeStringValue("publisherDomain", this.publisherDomain);
        writer.writeCollectionOfObjectValues("requiredResourceAccess", this.requiredResourceAccess);
        writer.writeStringValue("serviceManagementReference", this.serviceManagementReference);
        writer.writeStringValue("signInAudience", this.signInAudience);
        writer.writeObjectValue("spa", this.spa);
        writer.writeCollectionOfPrimitiveValues("tags", this.tags);
        writer.writeStringValue("tokenEncryptionKeyId", this.tokenEncryptionKeyId);
        writer.writeCollectionOfObjectValues("tokenIssuancePolicies", this.tokenIssuancePolicies);
        writer.writeCollectionOfObjectValues("tokenLifetimePolicies", this.tokenLifetimePolicies);
        writer.writeObjectValue("verifiedPublisher", this.verifiedPublisher);
        writer.writeObjectValue("web", this.web);
    }
    ;
    /**
     * Gets the serviceManagementReference property value. References application or service contact information from a Service or Asset Management database. Nullable.
     * @returns a string
     */
    get serviceManagementReference() {
        return this._serviceManagementReference;
    }
    ;
    /**
     * Sets the serviceManagementReference property value. References application or service contact information from a Service or Asset Management database. Nullable.
     * @param value Value to set for the serviceManagementReference property.
     */
    set serviceManagementReference(value) {
        this._serviceManagementReference = value;
    }
    ;
    /**
     * Gets the signInAudience property value. Specifies the Microsoft accounts that are supported for the current application. The possible values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount (default), and PersonalMicrosoftAccount. See more in the table below. Supports $filter (eq, ne, not).
     * @returns a string
     */
    get signInAudience() {
        return this._signInAudience;
    }
    ;
    /**
     * Sets the signInAudience property value. Specifies the Microsoft accounts that are supported for the current application. The possible values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount (default), and PersonalMicrosoftAccount. See more in the table below. Supports $filter (eq, ne, not).
     * @param value Value to set for the signInAudience property.
     */
    set signInAudience(value) {
        this._signInAudience = value;
    }
    ;
    /**
     * Gets the spa property value. Specifies settings for a single-page application, including sign out URLs and redirect URIs for authorization codes and access tokens.
     * @returns a spaApplication
     */
    get spa() {
        return this._spa;
    }
    ;
    /**
     * Sets the spa property value. Specifies settings for a single-page application, including sign out URLs and redirect URIs for authorization codes and access tokens.
     * @param value Value to set for the spa property.
     */
    set spa(value) {
        this._spa = value;
    }
    ;
    /**
     * Gets the tags property value. Custom strings that can be used to categorize and identify the application. Not nullable.Supports $filter (eq, not, ge, le, startsWith).
     * @returns a string
     */
    get tags() {
        return this._tags;
    }
    ;
    /**
     * Sets the tags property value. Custom strings that can be used to categorize and identify the application. Not nullable.Supports $filter (eq, not, ge, le, startsWith).
     * @param value Value to set for the tags property.
     */
    set tags(value) {
        this._tags = value;
    }
    ;
    /**
     * Gets the tokenEncryptionKeyId property value. Specifies the keyId of a public key from the keyCredentials collection. When configured, Azure AD encrypts all the tokens it emits by using the key this property points to. The application code that receives the encrypted token must use the matching private key to decrypt the token before it can be used for the signed-in user.
     * @returns a string
     */
    get tokenEncryptionKeyId() {
        return this._tokenEncryptionKeyId;
    }
    ;
    /**
     * Sets the tokenEncryptionKeyId property value. Specifies the keyId of a public key from the keyCredentials collection. When configured, Azure AD encrypts all the tokens it emits by using the key this property points to. The application code that receives the encrypted token must use the matching private key to decrypt the token before it can be used for the signed-in user.
     * @param value Value to set for the tokenEncryptionKeyId property.
     */
    set tokenEncryptionKeyId(value) {
        this._tokenEncryptionKeyId = value;
    }
    ;
    /**
     * Gets the tokenIssuancePolicies property value. The tokenIssuancePolicies property
     * @returns a tokenIssuancePolicy
     */
    get tokenIssuancePolicies() {
        return this._tokenIssuancePolicies;
    }
    ;
    /**
     * Sets the tokenIssuancePolicies property value. The tokenIssuancePolicies property
     * @param value Value to set for the tokenIssuancePolicies property.
     */
    set tokenIssuancePolicies(value) {
        this._tokenIssuancePolicies = value;
    }
    ;
    /**
     * Gets the tokenLifetimePolicies property value. The tokenLifetimePolicies assigned to this application. Supports $expand.
     * @returns a tokenLifetimePolicy
     */
    get tokenLifetimePolicies() {
        return this._tokenLifetimePolicies;
    }
    ;
    /**
     * Sets the tokenLifetimePolicies property value. The tokenLifetimePolicies assigned to this application. Supports $expand.
     * @param value Value to set for the tokenLifetimePolicies property.
     */
    set tokenLifetimePolicies(value) {
        this._tokenLifetimePolicies = value;
    }
    ;
    /**
     * Gets the verifiedPublisher property value. Specifies the verified publisher of the application. For more information about how publisher verification helps support application security, trustworthiness, and compliance, see Publisher verification.
     * @returns a verifiedPublisher
     */
    get verifiedPublisher() {
        return this._verifiedPublisher;
    }
    ;
    /**
     * Sets the verifiedPublisher property value. Specifies the verified publisher of the application. For more information about how publisher verification helps support application security, trustworthiness, and compliance, see Publisher verification.
     * @param value Value to set for the verifiedPublisher property.
     */
    set verifiedPublisher(value) {
        this._verifiedPublisher = value;
    }
    ;
    /**
     * Gets the web property value. Specifies settings for a web application.
     * @returns a webApplication
     */
    get web() {
        return this._web;
    }
    ;
    /**
     * Sets the web property value. Specifies settings for a web application.
     * @param value Value to set for the web property.
     */
    set web(value) {
        this._web = value;
    }
    ;
}
exports.Application = Application;
