import { Entity, Identity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityGovernance singleton. */
export declare class ApprovalStage extends Entity implements Parsable {
    /** Indicates whether the stage is assigned to the calling user to review. Read-only. */
    private _assignedToMe?;
    /** The label provided by the policy creator to identify an approval stage. Read-only. */
    private _displayName?;
    /** The justification associated with the approval stage decision. */
    private _justification?;
    /** The identifier of the reviewer. Read-only. */
    private _reviewedBy?;
    /** The date and time when a decision was recorded. The date and time information uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only. */
    private _reviewedDateTime?;
    /** The result of this approval record. Possible values include: NotReviewed, Approved, Denied. */
    private _reviewResult?;
    /** The stage status. Possible values: InProgress, Initializing, Completed, Expired. Read-only. */
    private _status?;
    /**
     * Gets the assignedToMe property value. Indicates whether the stage is assigned to the calling user to review. Read-only.
     * @returns a boolean
     */
    get assignedToMe(): boolean | undefined;
    /**
     * Sets the assignedToMe property value. Indicates whether the stage is assigned to the calling user to review. Read-only.
     * @param value Value to set for the assignedToMe property.
     */
    set assignedToMe(value: boolean | undefined);
    /**
     * Instantiates a new approvalStage and sets the default values.
     */
    constructor();
    /**
     * Gets the displayName property value. The label provided by the policy creator to identify an approval stage. Read-only.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The label provided by the policy creator to identify an approval stage. Read-only.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the justification property value. The justification associated with the approval stage decision.
     * @returns a string
     */
    get justification(): string | undefined;
    /**
     * Sets the justification property value. The justification associated with the approval stage decision.
     * @param value Value to set for the justification property.
     */
    set justification(value: string | undefined);
    /**
     * Gets the reviewedBy property value. The identifier of the reviewer. Read-only.
     * @returns a identity
     */
    get reviewedBy(): Identity | undefined;
    /**
     * Sets the reviewedBy property value. The identifier of the reviewer. Read-only.
     * @param value Value to set for the reviewedBy property.
     */
    set reviewedBy(value: Identity | undefined);
    /**
     * Gets the reviewedDateTime property value. The date and time when a decision was recorded. The date and time information uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @returns a Date
     */
    get reviewedDateTime(): Date | undefined;
    /**
     * Sets the reviewedDateTime property value. The date and time when a decision was recorded. The date and time information uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @param value Value to set for the reviewedDateTime property.
     */
    set reviewedDateTime(value: Date | undefined);
    /**
     * Gets the reviewResult property value. The result of this approval record. Possible values include: NotReviewed, Approved, Denied.
     * @returns a string
     */
    get reviewResult(): string | undefined;
    /**
     * Sets the reviewResult property value. The result of this approval record. Possible values include: NotReviewed, Approved, Denied.
     * @param value Value to set for the reviewResult property.
     */
    set reviewResult(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. The stage status. Possible values: InProgress, Initializing, Completed, Expired. Read-only.
     * @returns a string
     */
    get status(): string | undefined;
    /**
     * Sets the status property value. The stage status. Possible values: InProgress, Initializing, Completed, Expired. Read-only.
     * @param value Value to set for the status property.
     */
    set status(value: string | undefined);
}
