import { AuthenticationMethod, Entity, Fido2AuthenticationMethod, MicrosoftAuthenticatorAuthenticationMethod, WindowsHelloForBusinessAuthenticationMethod } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Authentication extends Entity implements Parsable {
    /** Represents the FIDO2 security keys registered to a user for authentication. */
    private _fido2Methods?;
    /** Represents all authentication methods registered to a user. */
    private _methods?;
    /** The details of the Microsoft Authenticator app registered to a user for authentication. */
    private _microsoftAuthenticatorMethods?;
    /** Represents the Windows Hello for Business authentication method registered to a user for authentication. */
    private _windowsHelloForBusinessMethods?;
    /**
     * Instantiates a new authentication and sets the default values.
     */
    constructor();
    /**
     * Gets the fido2Methods property value. Represents the FIDO2 security keys registered to a user for authentication.
     * @returns a fido2AuthenticationMethod
     */
    get fido2Methods(): Fido2AuthenticationMethod[] | undefined;
    /**
     * Sets the fido2Methods property value. Represents the FIDO2 security keys registered to a user for authentication.
     * @param value Value to set for the fido2Methods property.
     */
    set fido2Methods(value: Fido2AuthenticationMethod[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the methods property value. Represents all authentication methods registered to a user.
     * @returns a authenticationMethod
     */
    get methods(): AuthenticationMethod[] | undefined;
    /**
     * Sets the methods property value. Represents all authentication methods registered to a user.
     * @param value Value to set for the methods property.
     */
    set methods(value: AuthenticationMethod[] | undefined);
    /**
     * Gets the microsoftAuthenticatorMethods property value. The details of the Microsoft Authenticator app registered to a user for authentication.
     * @returns a microsoftAuthenticatorAuthenticationMethod
     */
    get microsoftAuthenticatorMethods(): MicrosoftAuthenticatorAuthenticationMethod[] | undefined;
    /**
     * Sets the microsoftAuthenticatorMethods property value. The details of the Microsoft Authenticator app registered to a user for authentication.
     * @param value Value to set for the microsoftAuthenticatorMethods property.
     */
    set microsoftAuthenticatorMethods(value: MicrosoftAuthenticatorAuthenticationMethod[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the windowsHelloForBusinessMethods property value. Represents the Windows Hello for Business authentication method registered to a user for authentication.
     * @returns a windowsHelloForBusinessAuthenticationMethod
     */
    get windowsHelloForBusinessMethods(): WindowsHelloForBusinessAuthenticationMethod[] | undefined;
    /**
     * Sets the windowsHelloForBusinessMethods property value. Represents the Windows Hello for Business authentication method registered to a user for authentication.
     * @param value Value to set for the windowsHelloForBusinessMethods property.
     */
    set windowsHelloForBusinessMethods(value: WindowsHelloForBusinessAuthenticationMethod[] | undefined);
}
