import { AuthenticationMethodConfiguration, Entity, RegistrationEnforcement } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the authenticationMethodsPolicy singleton. */
export declare class AuthenticationMethodsPolicy extends Entity implements Parsable {
    /** Represents the settings for each authentication method. Automatically expanded on GET /policies/authenticationMethodsPolicy. */
    private _authenticationMethodConfigurations?;
    /** A description of the policy. */
    private _description?;
    /** The name of the policy. */
    private _displayName?;
    /** The date and time of the last update to the policy. */
    private _lastModifiedDateTime?;
    /** The version of the policy in use. */
    private _policyVersion?;
    /** The reconfirmationInDays property */
    private _reconfirmationInDays?;
    /** Enforce registration at sign-in time. This property can be used to remind users to set up targeted authentication methods. */
    private _registrationEnforcement?;
    /**
     * Gets the authenticationMethodConfigurations property value. Represents the settings for each authentication method. Automatically expanded on GET /policies/authenticationMethodsPolicy.
     * @returns a authenticationMethodConfiguration
     */
    get authenticationMethodConfigurations(): AuthenticationMethodConfiguration[] | undefined;
    /**
     * Sets the authenticationMethodConfigurations property value. Represents the settings for each authentication method. Automatically expanded on GET /policies/authenticationMethodsPolicy.
     * @param value Value to set for the authenticationMethodConfigurations property.
     */
    set authenticationMethodConfigurations(value: AuthenticationMethodConfiguration[] | undefined);
    /**
     * Instantiates a new authenticationMethodsPolicy and sets the default values.
     */
    constructor();
    /**
     * Gets the description property value. A description of the policy.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. A description of the policy.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. The name of the policy.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the policy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. The date and time of the last update to the policy.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The date and time of the last update to the policy.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the policyVersion property value. The version of the policy in use.
     * @returns a string
     */
    get policyVersion(): string | undefined;
    /**
     * Sets the policyVersion property value. The version of the policy in use.
     * @param value Value to set for the policyVersion property.
     */
    set policyVersion(value: string | undefined);
    /**
     * Gets the reconfirmationInDays property value. The reconfirmationInDays property
     * @returns a integer
     */
    get reconfirmationInDays(): number | undefined;
    /**
     * Sets the reconfirmationInDays property value. The reconfirmationInDays property
     * @param value Value to set for the reconfirmationInDays property.
     */
    set reconfirmationInDays(value: number | undefined);
    /**
     * Gets the registrationEnforcement property value. Enforce registration at sign-in time. This property can be used to remind users to set up targeted authentication methods.
     * @returns a registrationEnforcement
     */
    get registrationEnforcement(): RegistrationEnforcement | undefined;
    /**
     * Sets the registrationEnforcement property value. Enforce registration at sign-in time. This property can be used to remind users to set up targeted authentication methods.
     * @param value Value to set for the registrationEnforcement property.
     */
    set registrationEnforcement(value: RegistrationEnforcement | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
