import { AutomaticRepliesStatus } from './automaticRepliesStatus';
import { ExternalAudienceScope } from './externalAudienceScope';
import { DateTimeTimeZone } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class AutomaticRepliesSetting implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** The set of audience external to the signed-in user's organization who will receive the ExternalReplyMessage, if Status is AlwaysEnabled or Scheduled. Possible values are: none, contactsOnly, all. */
    private _externalAudience?;
    /** The automatic reply to send to the specified external audience, if Status is AlwaysEnabled or Scheduled. */
    private _externalReplyMessage?;
    /** The automatic reply to send to the audience internal to the signed-in user's organization, if Status is AlwaysEnabled or Scheduled. */
    private _internalReplyMessage?;
    /** The date and time that automatic replies are set to end, if Status is set to Scheduled. */
    private _scheduledEndDateTime?;
    /** The date and time that automatic replies are set to begin, if Status is set to Scheduled. */
    private _scheduledStartDateTime?;
    /** Configurations status for automatic replies. Possible values are: disabled, alwaysEnabled, scheduled. */
    private _status?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new automaticRepliesSetting and sets the default values.
     */
    constructor();
    /**
     * Gets the externalAudience property value. The set of audience external to the signed-in user's organization who will receive the ExternalReplyMessage, if Status is AlwaysEnabled or Scheduled. Possible values are: none, contactsOnly, all.
     * @returns a externalAudienceScope
     */
    get externalAudience(): ExternalAudienceScope | undefined;
    /**
     * Sets the externalAudience property value. The set of audience external to the signed-in user's organization who will receive the ExternalReplyMessage, if Status is AlwaysEnabled or Scheduled. Possible values are: none, contactsOnly, all.
     * @param value Value to set for the externalAudience property.
     */
    set externalAudience(value: ExternalAudienceScope | undefined);
    /**
     * Gets the externalReplyMessage property value. The automatic reply to send to the specified external audience, if Status is AlwaysEnabled or Scheduled.
     * @returns a string
     */
    get externalReplyMessage(): string | undefined;
    /**
     * Sets the externalReplyMessage property value. The automatic reply to send to the specified external audience, if Status is AlwaysEnabled or Scheduled.
     * @param value Value to set for the externalReplyMessage property.
     */
    set externalReplyMessage(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the internalReplyMessage property value. The automatic reply to send to the audience internal to the signed-in user's organization, if Status is AlwaysEnabled or Scheduled.
     * @returns a string
     */
    get internalReplyMessage(): string | undefined;
    /**
     * Sets the internalReplyMessage property value. The automatic reply to send to the audience internal to the signed-in user's organization, if Status is AlwaysEnabled or Scheduled.
     * @param value Value to set for the internalReplyMessage property.
     */
    set internalReplyMessage(value: string | undefined);
    /**
     * Gets the scheduledEndDateTime property value. The date and time that automatic replies are set to end, if Status is set to Scheduled.
     * @returns a dateTimeTimeZone
     */
    get scheduledEndDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the scheduledEndDateTime property value. The date and time that automatic replies are set to end, if Status is set to Scheduled.
     * @param value Value to set for the scheduledEndDateTime property.
     */
    set scheduledEndDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Gets the scheduledStartDateTime property value. The date and time that automatic replies are set to begin, if Status is set to Scheduled.
     * @returns a dateTimeTimeZone
     */
    get scheduledStartDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the scheduledStartDateTime property value. The date and time that automatic replies are set to begin, if Status is set to Scheduled.
     * @param value Value to set for the scheduledStartDateTime property.
     */
    set scheduledStartDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. Configurations status for automatic replies. Possible values are: disabled, alwaysEnabled, scheduled.
     * @returns a automaticRepliesStatus
     */
    get status(): AutomaticRepliesStatus | undefined;
    /**
     * Sets the status property value. Configurations status for automatic replies. Possible values are: disabled, alwaysEnabled, scheduled.
     * @param value Value to set for the status property.
     */
    set status(value: AutomaticRepliesStatus | undefined);
}
