import { BookingPriceType } from './bookingPriceType';
import { BookingCustomerInformationBase, BookingReminder, DateTimeTimeZone, Entity, Location } from './index';
import { Duration, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Represents a booked appointment of a service by a customer in a business. */
export declare class BookingAppointment extends Entity implements Parsable {
    /** Additional information that is sent to the customer when an appointment is confirmed. */
    private _additionalInformation?;
    /** It lists down the customer properties for an appointment. An appointment will contain a list of customer information and each unit will indicate the properties of a customer who is part of that appointment. Optional. */
    private _customers?;
    /** The time zone of the customer. For a list of possible values, see dateTimeTimeZone. */
    private _customerTimeZone?;
    /** The length of the appointment, denoted in ISO8601 format. */
    private _duration?;
    /** The endDateTime property */
    private _endDateTime?;
    /** The current number of customers in the appointment. */
    private _filledAttendeesCount?;
    /** True indicates that the appointment will be held online. Default value is false. */
    private _isLocationOnline?;
    /** The URL of the online meeting for the appointment. */
    private _joinWebUrl?;
    /** The maximum number of customers allowed in an appointment. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation. */
    private _maximumAttendeesCount?;
    /** True indicates that the bookingCustomer for this appointment does not wish to receive a confirmation for this appointment. */
    private _optOutOfCustomerEmail?;
    /** The amount of time to reserve after the appointment ends, for cleaning up, as an example. The value is expressed in ISO8601 format. */
    private _postBuffer?;
    /** The amount of time to reserve before the appointment begins, for preparation, as an example. The value is expressed in ISO8601 format. */
    private _preBuffer?;
    /** The regular price for an appointment for the specified bookingService. */
    private _price?;
    /** A setting to provide flexibility for the pricing structure of services. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue. */
    private _priceType?;
    /** The collection of customer reminders sent for this appointment. The value of this property is available only when reading this bookingAppointment by its ID. */
    private _reminders?;
    /** An additional tracking ID for the appointment, if the appointment has been created directly by the customer on the scheduling page, as opposed to by a staff member on the behalf of the customer. */
    private _selfServiceAppointmentId?;
    /** The ID of the bookingService associated with this appointment. */
    private _serviceId?;
    /** The location where the service is delivered. */
    private _serviceLocation?;
    /** The name of the bookingService associated with this appointment.This property is optional when creating a new appointment. If not specified, it is computed from the service associated with the appointment by the serviceId property. */
    private _serviceName?;
    /** Notes from a bookingStaffMember. The value of this property is available only when reading this bookingAppointment by its ID. */
    private _serviceNotes?;
    /** True indicates SMS notifications will be sent to the customers for the appointment. Default value is false. */
    private _smsNotificationsEnabled?;
    /** The ID of each bookingStaffMember who is scheduled in this appointment. */
    private _staffMemberIds?;
    /** The startDateTime property */
    private _startDateTime?;
    /**
     * Gets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @returns a string
     */
    get additionalInformation(): string | undefined;
    /**
     * Sets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @param value Value to set for the additionalInformation property.
     */
    set additionalInformation(value: string | undefined);
    /**
     * Instantiates a new bookingAppointment and sets the default values.
     */
    constructor();
    /**
     * Gets the customers property value. It lists down the customer properties for an appointment. An appointment will contain a list of customer information and each unit will indicate the properties of a customer who is part of that appointment. Optional.
     * @returns a bookingCustomerInformationBase
     */
    get customers(): BookingCustomerInformationBase[] | undefined;
    /**
     * Sets the customers property value. It lists down the customer properties for an appointment. An appointment will contain a list of customer information and each unit will indicate the properties of a customer who is part of that appointment. Optional.
     * @param value Value to set for the customers property.
     */
    set customers(value: BookingCustomerInformationBase[] | undefined);
    /**
     * Gets the customerTimeZone property value. The time zone of the customer. For a list of possible values, see dateTimeTimeZone.
     * @returns a string
     */
    get customerTimeZone(): string | undefined;
    /**
     * Sets the customerTimeZone property value. The time zone of the customer. For a list of possible values, see dateTimeTimeZone.
     * @param value Value to set for the customerTimeZone property.
     */
    set customerTimeZone(value: string | undefined);
    /**
     * Gets the duration property value. The length of the appointment, denoted in ISO8601 format.
     * @returns a Duration
     */
    get duration(): Duration | undefined;
    /**
     * Sets the duration property value. The length of the appointment, denoted in ISO8601 format.
     * @param value Value to set for the duration property.
     */
    set duration(value: Duration | undefined);
    /**
     * Gets the endDateTime property value. The endDateTime property
     * @returns a dateTimeTimeZone
     */
    get endDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the endDateTime property value. The endDateTime property
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Gets the filledAttendeesCount property value. The current number of customers in the appointment.
     * @returns a integer
     */
    get filledAttendeesCount(): number | undefined;
    /**
     * Sets the filledAttendeesCount property value. The current number of customers in the appointment.
     * @param value Value to set for the filledAttendeesCount property.
     */
    set filledAttendeesCount(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isLocationOnline property value. True indicates that the appointment will be held online. Default value is false.
     * @returns a boolean
     */
    get isLocationOnline(): boolean | undefined;
    /**
     * Sets the isLocationOnline property value. True indicates that the appointment will be held online. Default value is false.
     * @param value Value to set for the isLocationOnline property.
     */
    set isLocationOnline(value: boolean | undefined);
    /**
     * Gets the joinWebUrl property value. The URL of the online meeting for the appointment.
     * @returns a string
     */
    get joinWebUrl(): string | undefined;
    /**
     * Sets the joinWebUrl property value. The URL of the online meeting for the appointment.
     * @param value Value to set for the joinWebUrl property.
     */
    set joinWebUrl(value: string | undefined);
    /**
     * Gets the maximumAttendeesCount property value. The maximum number of customers allowed in an appointment. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @returns a integer
     */
    get maximumAttendeesCount(): number | undefined;
    /**
     * Sets the maximumAttendeesCount property value. The maximum number of customers allowed in an appointment. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @param value Value to set for the maximumAttendeesCount property.
     */
    set maximumAttendeesCount(value: number | undefined);
    /**
     * Gets the optOutOfCustomerEmail property value. True indicates that the bookingCustomer for this appointment does not wish to receive a confirmation for this appointment.
     * @returns a boolean
     */
    get optOutOfCustomerEmail(): boolean | undefined;
    /**
     * Sets the optOutOfCustomerEmail property value. True indicates that the bookingCustomer for this appointment does not wish to receive a confirmation for this appointment.
     * @param value Value to set for the optOutOfCustomerEmail property.
     */
    set optOutOfCustomerEmail(value: boolean | undefined);
    /**
     * Gets the postBuffer property value. The amount of time to reserve after the appointment ends, for cleaning up, as an example. The value is expressed in ISO8601 format.
     * @returns a Duration
     */
    get postBuffer(): Duration | undefined;
    /**
     * Sets the postBuffer property value. The amount of time to reserve after the appointment ends, for cleaning up, as an example. The value is expressed in ISO8601 format.
     * @param value Value to set for the postBuffer property.
     */
    set postBuffer(value: Duration | undefined);
    /**
     * Gets the preBuffer property value. The amount of time to reserve before the appointment begins, for preparation, as an example. The value is expressed in ISO8601 format.
     * @returns a Duration
     */
    get preBuffer(): Duration | undefined;
    /**
     * Sets the preBuffer property value. The amount of time to reserve before the appointment begins, for preparation, as an example. The value is expressed in ISO8601 format.
     * @param value Value to set for the preBuffer property.
     */
    set preBuffer(value: Duration | undefined);
    /**
     * Gets the price property value. The regular price for an appointment for the specified bookingService.
     * @returns a double
     */
    get price(): number | undefined;
    /**
     * Sets the price property value. The regular price for an appointment for the specified bookingService.
     * @param value Value to set for the price property.
     */
    set price(value: number | undefined);
    /**
     * Gets the priceType property value. A setting to provide flexibility for the pricing structure of services. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @returns a bookingPriceType
     */
    get priceType(): BookingPriceType | undefined;
    /**
     * Sets the priceType property value. A setting to provide flexibility for the pricing structure of services. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @param value Value to set for the priceType property.
     */
    set priceType(value: BookingPriceType | undefined);
    /**
     * Gets the reminders property value. The collection of customer reminders sent for this appointment. The value of this property is available only when reading this bookingAppointment by its ID.
     * @returns a bookingReminder
     */
    get reminders(): BookingReminder[] | undefined;
    /**
     * Sets the reminders property value. The collection of customer reminders sent for this appointment. The value of this property is available only when reading this bookingAppointment by its ID.
     * @param value Value to set for the reminders property.
     */
    set reminders(value: BookingReminder[] | undefined);
    /**
     * Gets the selfServiceAppointmentId property value. An additional tracking ID for the appointment, if the appointment has been created directly by the customer on the scheduling page, as opposed to by a staff member on the behalf of the customer.
     * @returns a string
     */
    get selfServiceAppointmentId(): string | undefined;
    /**
     * Sets the selfServiceAppointmentId property value. An additional tracking ID for the appointment, if the appointment has been created directly by the customer on the scheduling page, as opposed to by a staff member on the behalf of the customer.
     * @param value Value to set for the selfServiceAppointmentId property.
     */
    set selfServiceAppointmentId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the serviceId property value. The ID of the bookingService associated with this appointment.
     * @returns a string
     */
    get serviceId(): string | undefined;
    /**
     * Sets the serviceId property value. The ID of the bookingService associated with this appointment.
     * @param value Value to set for the serviceId property.
     */
    set serviceId(value: string | undefined);
    /**
     * Gets the serviceLocation property value. The location where the service is delivered.
     * @returns a location
     */
    get serviceLocation(): Location | undefined;
    /**
     * Sets the serviceLocation property value. The location where the service is delivered.
     * @param value Value to set for the serviceLocation property.
     */
    set serviceLocation(value: Location | undefined);
    /**
     * Gets the serviceName property value. The name of the bookingService associated with this appointment.This property is optional when creating a new appointment. If not specified, it is computed from the service associated with the appointment by the serviceId property.
     * @returns a string
     */
    get serviceName(): string | undefined;
    /**
     * Sets the serviceName property value. The name of the bookingService associated with this appointment.This property is optional when creating a new appointment. If not specified, it is computed from the service associated with the appointment by the serviceId property.
     * @param value Value to set for the serviceName property.
     */
    set serviceName(value: string | undefined);
    /**
     * Gets the serviceNotes property value. Notes from a bookingStaffMember. The value of this property is available only when reading this bookingAppointment by its ID.
     * @returns a string
     */
    get serviceNotes(): string | undefined;
    /**
     * Sets the serviceNotes property value. Notes from a bookingStaffMember. The value of this property is available only when reading this bookingAppointment by its ID.
     * @param value Value to set for the serviceNotes property.
     */
    set serviceNotes(value: string | undefined);
    /**
     * Gets the smsNotificationsEnabled property value. True indicates SMS notifications will be sent to the customers for the appointment. Default value is false.
     * @returns a boolean
     */
    get smsNotificationsEnabled(): boolean | undefined;
    /**
     * Sets the smsNotificationsEnabled property value. True indicates SMS notifications will be sent to the customers for the appointment. Default value is false.
     * @param value Value to set for the smsNotificationsEnabled property.
     */
    set smsNotificationsEnabled(value: boolean | undefined);
    /**
     * Gets the staffMemberIds property value. The ID of each bookingStaffMember who is scheduled in this appointment.
     * @returns a string
     */
    get staffMemberIds(): string[] | undefined;
    /**
     * Sets the staffMemberIds property value. The ID of each bookingStaffMember who is scheduled in this appointment.
     * @param value Value to set for the staffMemberIds property.
     */
    set staffMemberIds(value: string[] | undefined);
    /**
     * Gets the startDateTime property value. The startDateTime property
     * @returns a dateTimeTimeZone
     */
    get startDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the startDateTime property value. The startDateTime property
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: DateTimeTimeZone | undefined);
}
