"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BookingAppointment = void 0;
const bookingPriceType_1 = require("./bookingPriceType");
const createBookingCustomerInformationBaseFromDiscriminatorValue_1 = require("./createBookingCustomerInformationBaseFromDiscriminatorValue");
const createBookingReminderFromDiscriminatorValue_1 = require("./createBookingReminderFromDiscriminatorValue");
const createDateTimeTimeZoneFromDiscriminatorValue_1 = require("./createDateTimeTimeZoneFromDiscriminatorValue");
const createLocationFromDiscriminatorValue_1 = require("./createLocationFromDiscriminatorValue");
const index_1 = require("./index");
/** Represents a booked appointment of a service by a customer in a business. */
class BookingAppointment extends index_1.Entity {
    /**
     * Instantiates a new bookingAppointment and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @returns a string
     */
    get additionalInformation() {
        return this._additionalInformation;
    }
    ;
    /**
     * Sets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @param value Value to set for the additionalInformation property.
     */
    set additionalInformation(value) {
        this._additionalInformation = value;
    }
    ;
    ;
    /**
     * Gets the customers property value. It lists down the customer properties for an appointment. An appointment will contain a list of customer information and each unit will indicate the properties of a customer who is part of that appointment. Optional.
     * @returns a bookingCustomerInformationBase
     */
    get customers() {
        return this._customers;
    }
    ;
    /**
     * Sets the customers property value. It lists down the customer properties for an appointment. An appointment will contain a list of customer information and each unit will indicate the properties of a customer who is part of that appointment. Optional.
     * @param value Value to set for the customers property.
     */
    set customers(value) {
        this._customers = value;
    }
    ;
    /**
     * Gets the customerTimeZone property value. The time zone of the customer. For a list of possible values, see dateTimeTimeZone.
     * @returns a string
     */
    get customerTimeZone() {
        return this._customerTimeZone;
    }
    ;
    /**
     * Sets the customerTimeZone property value. The time zone of the customer. For a list of possible values, see dateTimeTimeZone.
     * @param value Value to set for the customerTimeZone property.
     */
    set customerTimeZone(value) {
        this._customerTimeZone = value;
    }
    ;
    /**
     * Gets the duration property value. The length of the appointment, denoted in ISO8601 format.
     * @returns a Duration
     */
    get duration() {
        return this._duration;
    }
    ;
    /**
     * Sets the duration property value. The length of the appointment, denoted in ISO8601 format.
     * @param value Value to set for the duration property.
     */
    set duration(value) {
        this._duration = value;
    }
    ;
    /**
     * Gets the endDateTime property value. The endDateTime property
     * @returns a dateTimeTimeZone
     */
    get endDateTime() {
        return this._endDateTime;
    }
    ;
    /**
     * Sets the endDateTime property value. The endDateTime property
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value) {
        this._endDateTime = value;
    }
    ;
    /**
     * Gets the filledAttendeesCount property value. The current number of customers in the appointment.
     * @returns a integer
     */
    get filledAttendeesCount() {
        return this._filledAttendeesCount;
    }
    ;
    /**
     * Sets the filledAttendeesCount property value. The current number of customers in the appointment.
     * @param value Value to set for the filledAttendeesCount property.
     */
    set filledAttendeesCount(value) {
        this._filledAttendeesCount = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "additionalInformation": n => { this.additionalInformation = n.getStringValue(); }, "customers": n => { this.customers = n.getCollectionOfObjectValues(createBookingCustomerInformationBaseFromDiscriminatorValue_1.createBookingCustomerInformationBaseFromDiscriminatorValue); }, "customerTimeZone": n => { this.customerTimeZone = n.getStringValue(); }, "duration": n => { this.duration = n.getDurationValue(); }, "endDateTime": n => { this.endDateTime = n.getObjectValue(createDateTimeTimeZoneFromDiscriminatorValue_1.createDateTimeTimeZoneFromDiscriminatorValue); }, "filledAttendeesCount": n => { this.filledAttendeesCount = n.getNumberValue(); }, "isLocationOnline": n => { this.isLocationOnline = n.getBooleanValue(); }, "joinWebUrl": n => { this.joinWebUrl = n.getStringValue(); }, "maximumAttendeesCount": n => { this.maximumAttendeesCount = n.getNumberValue(); }, "optOutOfCustomerEmail": n => { this.optOutOfCustomerEmail = n.getBooleanValue(); }, "postBuffer": n => { this.postBuffer = n.getDurationValue(); }, "preBuffer": n => { this.preBuffer = n.getDurationValue(); }, "price": n => { this.price = n.getNumberValue(); }, "priceType": n => { this.priceType = n.getEnumValue(bookingPriceType_1.BookingPriceType); }, "reminders": n => { this.reminders = n.getCollectionOfObjectValues(createBookingReminderFromDiscriminatorValue_1.createBookingReminderFromDiscriminatorValue); }, "selfServiceAppointmentId": n => { this.selfServiceAppointmentId = n.getStringValue(); }, "serviceId": n => { this.serviceId = n.getStringValue(); }, "serviceLocation": n => { this.serviceLocation = n.getObjectValue(createLocationFromDiscriminatorValue_1.createLocationFromDiscriminatorValue); }, "serviceName": n => { this.serviceName = n.getStringValue(); }, "serviceNotes": n => { this.serviceNotes = n.getStringValue(); }, "smsNotificationsEnabled": n => { this.smsNotificationsEnabled = n.getBooleanValue(); }, "staffMemberIds": n => { this.staffMemberIds = n.getCollectionOfPrimitiveValues(); }, "startDateTime": n => { this.startDateTime = n.getObjectValue(createDateTimeTimeZoneFromDiscriminatorValue_1.createDateTimeTimeZoneFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the isLocationOnline property value. True indicates that the appointment will be held online. Default value is false.
     * @returns a boolean
     */
    get isLocationOnline() {
        return this._isLocationOnline;
    }
    ;
    /**
     * Sets the isLocationOnline property value. True indicates that the appointment will be held online. Default value is false.
     * @param value Value to set for the isLocationOnline property.
     */
    set isLocationOnline(value) {
        this._isLocationOnline = value;
    }
    ;
    /**
     * Gets the joinWebUrl property value. The URL of the online meeting for the appointment.
     * @returns a string
     */
    get joinWebUrl() {
        return this._joinWebUrl;
    }
    ;
    /**
     * Sets the joinWebUrl property value. The URL of the online meeting for the appointment.
     * @param value Value to set for the joinWebUrl property.
     */
    set joinWebUrl(value) {
        this._joinWebUrl = value;
    }
    ;
    /**
     * Gets the maximumAttendeesCount property value. The maximum number of customers allowed in an appointment. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @returns a integer
     */
    get maximumAttendeesCount() {
        return this._maximumAttendeesCount;
    }
    ;
    /**
     * Sets the maximumAttendeesCount property value. The maximum number of customers allowed in an appointment. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @param value Value to set for the maximumAttendeesCount property.
     */
    set maximumAttendeesCount(value) {
        this._maximumAttendeesCount = value;
    }
    ;
    /**
     * Gets the optOutOfCustomerEmail property value. True indicates that the bookingCustomer for this appointment does not wish to receive a confirmation for this appointment.
     * @returns a boolean
     */
    get optOutOfCustomerEmail() {
        return this._optOutOfCustomerEmail;
    }
    ;
    /**
     * Sets the optOutOfCustomerEmail property value. True indicates that the bookingCustomer for this appointment does not wish to receive a confirmation for this appointment.
     * @param value Value to set for the optOutOfCustomerEmail property.
     */
    set optOutOfCustomerEmail(value) {
        this._optOutOfCustomerEmail = value;
    }
    ;
    /**
     * Gets the postBuffer property value. The amount of time to reserve after the appointment ends, for cleaning up, as an example. The value is expressed in ISO8601 format.
     * @returns a Duration
     */
    get postBuffer() {
        return this._postBuffer;
    }
    ;
    /**
     * Sets the postBuffer property value. The amount of time to reserve after the appointment ends, for cleaning up, as an example. The value is expressed in ISO8601 format.
     * @param value Value to set for the postBuffer property.
     */
    set postBuffer(value) {
        this._postBuffer = value;
    }
    ;
    /**
     * Gets the preBuffer property value. The amount of time to reserve before the appointment begins, for preparation, as an example. The value is expressed in ISO8601 format.
     * @returns a Duration
     */
    get preBuffer() {
        return this._preBuffer;
    }
    ;
    /**
     * Sets the preBuffer property value. The amount of time to reserve before the appointment begins, for preparation, as an example. The value is expressed in ISO8601 format.
     * @param value Value to set for the preBuffer property.
     */
    set preBuffer(value) {
        this._preBuffer = value;
    }
    ;
    /**
     * Gets the price property value. The regular price for an appointment for the specified bookingService.
     * @returns a double
     */
    get price() {
        return this._price;
    }
    ;
    /**
     * Sets the price property value. The regular price for an appointment for the specified bookingService.
     * @param value Value to set for the price property.
     */
    set price(value) {
        this._price = value;
    }
    ;
    /**
     * Gets the priceType property value. A setting to provide flexibility for the pricing structure of services. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @returns a bookingPriceType
     */
    get priceType() {
        return this._priceType;
    }
    ;
    /**
     * Sets the priceType property value. A setting to provide flexibility for the pricing structure of services. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @param value Value to set for the priceType property.
     */
    set priceType(value) {
        this._priceType = value;
    }
    ;
    /**
     * Gets the reminders property value. The collection of customer reminders sent for this appointment. The value of this property is available only when reading this bookingAppointment by its ID.
     * @returns a bookingReminder
     */
    get reminders() {
        return this._reminders;
    }
    ;
    /**
     * Sets the reminders property value. The collection of customer reminders sent for this appointment. The value of this property is available only when reading this bookingAppointment by its ID.
     * @param value Value to set for the reminders property.
     */
    set reminders(value) {
        this._reminders = value;
    }
    ;
    /**
     * Gets the selfServiceAppointmentId property value. An additional tracking ID for the appointment, if the appointment has been created directly by the customer on the scheduling page, as opposed to by a staff member on the behalf of the customer.
     * @returns a string
     */
    get selfServiceAppointmentId() {
        return this._selfServiceAppointmentId;
    }
    ;
    /**
     * Sets the selfServiceAppointmentId property value. An additional tracking ID for the appointment, if the appointment has been created directly by the customer on the scheduling page, as opposed to by a staff member on the behalf of the customer.
     * @param value Value to set for the selfServiceAppointmentId property.
     */
    set selfServiceAppointmentId(value) {
        this._selfServiceAppointmentId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("additionalInformation", this.additionalInformation);
        writer.writeCollectionOfObjectValues("customers", this.customers);
        writer.writeStringValue("customerTimeZone", this.customerTimeZone);
        writer.writeDurationValue("duration", this.duration);
        writer.writeObjectValue("endDateTime", this.endDateTime);
        writer.writeNumberValue("filledAttendeesCount", this.filledAttendeesCount);
        writer.writeBooleanValue("isLocationOnline", this.isLocationOnline);
        writer.writeStringValue("joinWebUrl", this.joinWebUrl);
        writer.writeNumberValue("maximumAttendeesCount", this.maximumAttendeesCount);
        writer.writeBooleanValue("optOutOfCustomerEmail", this.optOutOfCustomerEmail);
        writer.writeDurationValue("postBuffer", this.postBuffer);
        writer.writeDurationValue("preBuffer", this.preBuffer);
        writer.writeNumberValue("price", this.price);
        writer.writeEnumValue("priceType", this.priceType);
        writer.writeCollectionOfObjectValues("reminders", this.reminders);
        writer.writeStringValue("selfServiceAppointmentId", this.selfServiceAppointmentId);
        writer.writeStringValue("serviceId", this.serviceId);
        writer.writeObjectValue("serviceLocation", this.serviceLocation);
        writer.writeStringValue("serviceName", this.serviceName);
        writer.writeStringValue("serviceNotes", this.serviceNotes);
        writer.writeBooleanValue("smsNotificationsEnabled", this.smsNotificationsEnabled);
        writer.writeCollectionOfPrimitiveValues("staffMemberIds", this.staffMemberIds);
        writer.writeObjectValue("startDateTime", this.startDateTime);
    }
    ;
    /**
     * Gets the serviceId property value. The ID of the bookingService associated with this appointment.
     * @returns a string
     */
    get serviceId() {
        return this._serviceId;
    }
    ;
    /**
     * Sets the serviceId property value. The ID of the bookingService associated with this appointment.
     * @param value Value to set for the serviceId property.
     */
    set serviceId(value) {
        this._serviceId = value;
    }
    ;
    /**
     * Gets the serviceLocation property value. The location where the service is delivered.
     * @returns a location
     */
    get serviceLocation() {
        return this._serviceLocation;
    }
    ;
    /**
     * Sets the serviceLocation property value. The location where the service is delivered.
     * @param value Value to set for the serviceLocation property.
     */
    set serviceLocation(value) {
        this._serviceLocation = value;
    }
    ;
    /**
     * Gets the serviceName property value. The name of the bookingService associated with this appointment.This property is optional when creating a new appointment. If not specified, it is computed from the service associated with the appointment by the serviceId property.
     * @returns a string
     */
    get serviceName() {
        return this._serviceName;
    }
    ;
    /**
     * Sets the serviceName property value. The name of the bookingService associated with this appointment.This property is optional when creating a new appointment. If not specified, it is computed from the service associated with the appointment by the serviceId property.
     * @param value Value to set for the serviceName property.
     */
    set serviceName(value) {
        this._serviceName = value;
    }
    ;
    /**
     * Gets the serviceNotes property value. Notes from a bookingStaffMember. The value of this property is available only when reading this bookingAppointment by its ID.
     * @returns a string
     */
    get serviceNotes() {
        return this._serviceNotes;
    }
    ;
    /**
     * Sets the serviceNotes property value. Notes from a bookingStaffMember. The value of this property is available only when reading this bookingAppointment by its ID.
     * @param value Value to set for the serviceNotes property.
     */
    set serviceNotes(value) {
        this._serviceNotes = value;
    }
    ;
    /**
     * Gets the smsNotificationsEnabled property value. True indicates SMS notifications will be sent to the customers for the appointment. Default value is false.
     * @returns a boolean
     */
    get smsNotificationsEnabled() {
        return this._smsNotificationsEnabled;
    }
    ;
    /**
     * Sets the smsNotificationsEnabled property value. True indicates SMS notifications will be sent to the customers for the appointment. Default value is false.
     * @param value Value to set for the smsNotificationsEnabled property.
     */
    set smsNotificationsEnabled(value) {
        this._smsNotificationsEnabled = value;
    }
    ;
    /**
     * Gets the staffMemberIds property value. The ID of each bookingStaffMember who is scheduled in this appointment.
     * @returns a string
     */
    get staffMemberIds() {
        return this._staffMemberIds;
    }
    ;
    /**
     * Sets the staffMemberIds property value. The ID of each bookingStaffMember who is scheduled in this appointment.
     * @param value Value to set for the staffMemberIds property.
     */
    set staffMemberIds(value) {
        this._staffMemberIds = value;
    }
    ;
    /**
     * Gets the startDateTime property value. The startDateTime property
     * @returns a dateTimeTimeZone
     */
    get startDateTime() {
        return this._startDateTime;
    }
    ;
    /**
     * Sets the startDateTime property value. The startDateTime property
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value) {
        this._startDateTime = value;
    }
    ;
}
exports.BookingAppointment = BookingAppointment;
