import { BookingAppointment, BookingCustomerBase, BookingCustomQuestion, BookingSchedulingPolicy, BookingService, BookingStaffMemberBase, BookingWorkHours, Entity, PhysicalAddress } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Represents a Microsot Bookings Business. */
export declare class BookingBusiness extends Entity implements Parsable {
    /** The street address of the business. The address property, together with phone and webSiteUrl, appear in the footer of a business scheduling page. */
    private _address?;
    /** All the appointments of this business. Read-only. Nullable. */
    private _appointments?;
    /** The hours of operation for the business. */
    private _businessHours?;
    /** The type of business. */
    private _businessType?;
    /** The set of appointments of this business in a specified date range. Read-only. Nullable. */
    private _calendarView?;
    /** All the customers of this business. Read-only. Nullable. */
    private _customers?;
    /** All the custom questions of this business. Read-only. Nullable. */
    private _customQuestions?;
    /** The code for the currency that the business operates in on Microsoft Bookings. */
    private _defaultCurrencyIso?;
    /** The name of the business, which interfaces with customers. This name appears at the top of the business scheduling page. */
    private _displayName?;
    /** The email address for the business. */
    private _email?;
    /** The scheduling page has been made available to external customers. Use the publish and unpublish actions to set this property. Read-only. */
    private _isPublished?;
    /** The telephone number for the business. The phone property, together with address and webSiteUrl, appear in the footer of a business scheduling page. */
    private _phone?;
    /** The URL for the scheduling page, which is set after you publish or unpublish the page. Read-only. */
    private _publicUrl?;
    /** Specifies how bookings can be created for this business. */
    private _schedulingPolicy?;
    /** All the services offered by this business. Read-only. Nullable. */
    private _services?;
    /** All the staff members that provide services in this business. Read-only. Nullable. */
    private _staffMembers?;
    /** The URL of the business web site. The webSiteUrl property, together with address, phone, appear in the footer of a business scheduling page. */
    private _webSiteUrl?;
    /**
     * Gets the address property value. The street address of the business. The address property, together with phone and webSiteUrl, appear in the footer of a business scheduling page.
     * @returns a physicalAddress
     */
    get address(): PhysicalAddress | undefined;
    /**
     * Sets the address property value. The street address of the business. The address property, together with phone and webSiteUrl, appear in the footer of a business scheduling page.
     * @param value Value to set for the address property.
     */
    set address(value: PhysicalAddress | undefined);
    /**
     * Gets the appointments property value. All the appointments of this business. Read-only. Nullable.
     * @returns a bookingAppointment
     */
    get appointments(): BookingAppointment[] | undefined;
    /**
     * Sets the appointments property value. All the appointments of this business. Read-only. Nullable.
     * @param value Value to set for the appointments property.
     */
    set appointments(value: BookingAppointment[] | undefined);
    /**
     * Gets the businessHours property value. The hours of operation for the business.
     * @returns a bookingWorkHours
     */
    get businessHours(): BookingWorkHours[] | undefined;
    /**
     * Sets the businessHours property value. The hours of operation for the business.
     * @param value Value to set for the businessHours property.
     */
    set businessHours(value: BookingWorkHours[] | undefined);
    /**
     * Gets the businessType property value. The type of business.
     * @returns a string
     */
    get businessType(): string | undefined;
    /**
     * Sets the businessType property value. The type of business.
     * @param value Value to set for the businessType property.
     */
    set businessType(value: string | undefined);
    /**
     * Gets the calendarView property value. The set of appointments of this business in a specified date range. Read-only. Nullable.
     * @returns a bookingAppointment
     */
    get calendarView(): BookingAppointment[] | undefined;
    /**
     * Sets the calendarView property value. The set of appointments of this business in a specified date range. Read-only. Nullable.
     * @param value Value to set for the calendarView property.
     */
    set calendarView(value: BookingAppointment[] | undefined);
    /**
     * Instantiates a new bookingBusiness and sets the default values.
     */
    constructor();
    /**
     * Gets the customers property value. All the customers of this business. Read-only. Nullable.
     * @returns a bookingCustomerBase
     */
    get customers(): BookingCustomerBase[] | undefined;
    /**
     * Sets the customers property value. All the customers of this business. Read-only. Nullable.
     * @param value Value to set for the customers property.
     */
    set customers(value: BookingCustomerBase[] | undefined);
    /**
     * Gets the customQuestions property value. All the custom questions of this business. Read-only. Nullable.
     * @returns a bookingCustomQuestion
     */
    get customQuestions(): BookingCustomQuestion[] | undefined;
    /**
     * Sets the customQuestions property value. All the custom questions of this business. Read-only. Nullable.
     * @param value Value to set for the customQuestions property.
     */
    set customQuestions(value: BookingCustomQuestion[] | undefined);
    /**
     * Gets the defaultCurrencyIso property value. The code for the currency that the business operates in on Microsoft Bookings.
     * @returns a string
     */
    get defaultCurrencyIso(): string | undefined;
    /**
     * Sets the defaultCurrencyIso property value. The code for the currency that the business operates in on Microsoft Bookings.
     * @param value Value to set for the defaultCurrencyIso property.
     */
    set defaultCurrencyIso(value: string | undefined);
    /**
     * Gets the displayName property value. The name of the business, which interfaces with customers. This name appears at the top of the business scheduling page.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the business, which interfaces with customers. This name appears at the top of the business scheduling page.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the email property value. The email address for the business.
     * @returns a string
     */
    get email(): string | undefined;
    /**
     * Sets the email property value. The email address for the business.
     * @param value Value to set for the email property.
     */
    set email(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isPublished property value. The scheduling page has been made available to external customers. Use the publish and unpublish actions to set this property. Read-only.
     * @returns a boolean
     */
    get isPublished(): boolean | undefined;
    /**
     * Sets the isPublished property value. The scheduling page has been made available to external customers. Use the publish and unpublish actions to set this property. Read-only.
     * @param value Value to set for the isPublished property.
     */
    set isPublished(value: boolean | undefined);
    /**
     * Gets the phone property value. The telephone number for the business. The phone property, together with address and webSiteUrl, appear in the footer of a business scheduling page.
     * @returns a string
     */
    get phone(): string | undefined;
    /**
     * Sets the phone property value. The telephone number for the business. The phone property, together with address and webSiteUrl, appear in the footer of a business scheduling page.
     * @param value Value to set for the phone property.
     */
    set phone(value: string | undefined);
    /**
     * Gets the publicUrl property value. The URL for the scheduling page, which is set after you publish or unpublish the page. Read-only.
     * @returns a string
     */
    get publicUrl(): string | undefined;
    /**
     * Sets the publicUrl property value. The URL for the scheduling page, which is set after you publish or unpublish the page. Read-only.
     * @param value Value to set for the publicUrl property.
     */
    set publicUrl(value: string | undefined);
    /**
     * Gets the schedulingPolicy property value. Specifies how bookings can be created for this business.
     * @returns a bookingSchedulingPolicy
     */
    get schedulingPolicy(): BookingSchedulingPolicy | undefined;
    /**
     * Sets the schedulingPolicy property value. Specifies how bookings can be created for this business.
     * @param value Value to set for the schedulingPolicy property.
     */
    set schedulingPolicy(value: BookingSchedulingPolicy | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the services property value. All the services offered by this business. Read-only. Nullable.
     * @returns a bookingService
     */
    get services(): BookingService[] | undefined;
    /**
     * Sets the services property value. All the services offered by this business. Read-only. Nullable.
     * @param value Value to set for the services property.
     */
    set services(value: BookingService[] | undefined);
    /**
     * Gets the staffMembers property value. All the staff members that provide services in this business. Read-only. Nullable.
     * @returns a bookingStaffMemberBase
     */
    get staffMembers(): BookingStaffMemberBase[] | undefined;
    /**
     * Sets the staffMembers property value. All the staff members that provide services in this business. Read-only. Nullable.
     * @param value Value to set for the staffMembers property.
     */
    set staffMembers(value: BookingStaffMemberBase[] | undefined);
    /**
     * Gets the webSiteUrl property value. The URL of the business web site. The webSiteUrl property, together with address, phone, appear in the footer of a business scheduling page.
     * @returns a string
     */
    get webSiteUrl(): string | undefined;
    /**
     * Sets the webSiteUrl property value. The URL of the business web site. The webSiteUrl property, together with address, phone, appear in the footer of a business scheduling page.
     * @param value Value to set for the webSiteUrl property.
     */
    set webSiteUrl(value: string | undefined);
}
