import { CalendarRoleType } from './calendarRoleType';
import { EmailAddress, Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class CalendarPermission extends Entity implements Parsable {
    /** List of allowed sharing or delegating permission levels for the calendar. Possible values are: none, freeBusyRead, limitedRead, read, write, delegateWithoutPrivateEventAccess, delegateWithPrivateEventAccess, custom. */
    private _allowedRoles?;
    /** Represents a sharee or delegate who has access to the calendar. For the 'My Organization' sharee, the address property is null. Read-only. */
    private _emailAddress?;
    /** True if the user in context (sharee or delegate) is inside the same organization as the calendar owner. */
    private _isInsideOrganization?;
    /** True if the user can be removed from the list of sharees or delegates for the specified calendar, false otherwise. The 'My organization' user determines the permissions other people within your organization have to the given calendar. You cannot remove 'My organization' as a sharee to a calendar. */
    private _isRemovable?;
    /** Current permission level of the calendar sharee or delegate. */
    private _role?;
    /**
     * Gets the allowedRoles property value. List of allowed sharing or delegating permission levels for the calendar. Possible values are: none, freeBusyRead, limitedRead, read, write, delegateWithoutPrivateEventAccess, delegateWithPrivateEventAccess, custom.
     * @returns a string
     */
    get allowedRoles(): string[] | undefined;
    /**
     * Sets the allowedRoles property value. List of allowed sharing or delegating permission levels for the calendar. Possible values are: none, freeBusyRead, limitedRead, read, write, delegateWithoutPrivateEventAccess, delegateWithPrivateEventAccess, custom.
     * @param value Value to set for the allowedRoles property.
     */
    set allowedRoles(value: string[] | undefined);
    /**
     * Instantiates a new calendarPermission and sets the default values.
     */
    constructor();
    /**
     * Gets the emailAddress property value. Represents a sharee or delegate who has access to the calendar. For the 'My Organization' sharee, the address property is null. Read-only.
     * @returns a emailAddress
     */
    get emailAddress(): EmailAddress | undefined;
    /**
     * Sets the emailAddress property value. Represents a sharee or delegate who has access to the calendar. For the 'My Organization' sharee, the address property is null. Read-only.
     * @param value Value to set for the emailAddress property.
     */
    set emailAddress(value: EmailAddress | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isInsideOrganization property value. True if the user in context (sharee or delegate) is inside the same organization as the calendar owner.
     * @returns a boolean
     */
    get isInsideOrganization(): boolean | undefined;
    /**
     * Sets the isInsideOrganization property value. True if the user in context (sharee or delegate) is inside the same organization as the calendar owner.
     * @param value Value to set for the isInsideOrganization property.
     */
    set isInsideOrganization(value: boolean | undefined);
    /**
     * Gets the isRemovable property value. True if the user can be removed from the list of sharees or delegates for the specified calendar, false otherwise. The 'My organization' user determines the permissions other people within your organization have to the given calendar. You cannot remove 'My organization' as a sharee to a calendar.
     * @returns a boolean
     */
    get isRemovable(): boolean | undefined;
    /**
     * Sets the isRemovable property value. True if the user can be removed from the list of sharees or delegates for the specified calendar, false otherwise. The 'My organization' user determines the permissions other people within your organization have to the given calendar. You cannot remove 'My organization' as a sharee to a calendar.
     * @param value Value to set for the isRemovable property.
     */
    set isRemovable(value: boolean | undefined);
    /**
     * Gets the role property value. Current permission level of the calendar sharee or delegate.
     * @returns a calendarRoleType
     */
    get role(): CalendarRoleType | undefined;
    /**
     * Sets the role property value. Current permission level of the calendar sharee or delegate.
     * @param value Value to set for the role property.
     */
    set role(value: CalendarRoleType | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
