import { CallDirection } from './callDirection';
import { CallState } from './callState';
import { AudioRoutingGroup, CallMediaState, CallOptions, CallRoute, CallTranscriptionInfo, ChatInfo, CommsOperation, Entity, IncomingContext, InvitationParticipantInfo, MediaConfig, MeetingInfo, Participant, ParticipantInfo, ResultInfo, ToneInfo } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the cloudCommunications singleton. */
export declare class Call extends Entity implements Parsable {
    /** Read-only. Nullable. */
    private _audioRoutingGroups?;
    /** The callback URL on which callbacks will be delivered. Must be https. */
    private _callbackUri?;
    /** A unique identifier for all the participant calls in a conference or a unique identifier for two participant calls in a P2P call.  This needs to be copied over from Microsoft.Graph.Call.CallChainId. */
    private _callChainId?;
    /** Contains the optional features for the call. */
    private _callOptions?;
    /** The routing information on how the call was retargeted. Read-only. */
    private _callRoutes?;
    /** The chat information. Required information for meeting scenarios. */
    private _chatInfo?;
    /** The direction of the call. The possible value are incoming or outgoing. Read-only. */
    private _direction?;
    /** The context associated with an incoming call. Read-only. Server generated. */
    private _incomingContext?;
    /** The media configuration. Required information for creating peer to peer calls or joining meetings. */
    private _mediaConfig?;
    /** Read-only. The call media state. */
    private _mediaState?;
    /** The meeting information. Required information for meeting scenarios. */
    private _meetingInfo?;
    /** The myParticipantId property */
    private _myParticipantId?;
    /** Read-only. Nullable. */
    private _operations?;
    /** Read-only. Nullable. */
    private _participants?;
    /** The requestedModalities property */
    private _requestedModalities?;
    /** The resultInfo property */
    private _resultInfo?;
    /** The source property */
    private _source?;
    /** The state property */
    private _state?;
    /** The subject property */
    private _subject?;
    /** The targets property */
    private _targets?;
    /** The tenantId property */
    private _tenantId?;
    /** The toneInfo property */
    private _toneInfo?;
    /** The transcription information for the call. Read-only. */
    private _transcription?;
    /**
     * Gets the audioRoutingGroups property value. Read-only. Nullable.
     * @returns a audioRoutingGroup
     */
    get audioRoutingGroups(): AudioRoutingGroup[] | undefined;
    /**
     * Sets the audioRoutingGroups property value. Read-only. Nullable.
     * @param value Value to set for the audioRoutingGroups property.
     */
    set audioRoutingGroups(value: AudioRoutingGroup[] | undefined);
    /**
     * Gets the callbackUri property value. The callback URL on which callbacks will be delivered. Must be https.
     * @returns a string
     */
    get callbackUri(): string | undefined;
    /**
     * Sets the callbackUri property value. The callback URL on which callbacks will be delivered. Must be https.
     * @param value Value to set for the callbackUri property.
     */
    set callbackUri(value: string | undefined);
    /**
     * Gets the callChainId property value. A unique identifier for all the participant calls in a conference or a unique identifier for two participant calls in a P2P call.  This needs to be copied over from Microsoft.Graph.Call.CallChainId.
     * @returns a string
     */
    get callChainId(): string | undefined;
    /**
     * Sets the callChainId property value. A unique identifier for all the participant calls in a conference or a unique identifier for two participant calls in a P2P call.  This needs to be copied over from Microsoft.Graph.Call.CallChainId.
     * @param value Value to set for the callChainId property.
     */
    set callChainId(value: string | undefined);
    /**
     * Gets the callOptions property value. Contains the optional features for the call.
     * @returns a callOptions
     */
    get callOptions(): CallOptions | undefined;
    /**
     * Sets the callOptions property value. Contains the optional features for the call.
     * @param value Value to set for the callOptions property.
     */
    set callOptions(value: CallOptions | undefined);
    /**
     * Gets the callRoutes property value. The routing information on how the call was retargeted. Read-only.
     * @returns a callRoute
     */
    get callRoutes(): CallRoute[] | undefined;
    /**
     * Sets the callRoutes property value. The routing information on how the call was retargeted. Read-only.
     * @param value Value to set for the callRoutes property.
     */
    set callRoutes(value: CallRoute[] | undefined);
    /**
     * Gets the chatInfo property value. The chat information. Required information for meeting scenarios.
     * @returns a chatInfo
     */
    get chatInfo(): ChatInfo | undefined;
    /**
     * Sets the chatInfo property value. The chat information. Required information for meeting scenarios.
     * @param value Value to set for the chatInfo property.
     */
    set chatInfo(value: ChatInfo | undefined);
    /**
     * Instantiates a new call and sets the default values.
     */
    constructor();
    /**
     * Gets the direction property value. The direction of the call. The possible value are incoming or outgoing. Read-only.
     * @returns a callDirection
     */
    get direction(): CallDirection | undefined;
    /**
     * Sets the direction property value. The direction of the call. The possible value are incoming or outgoing. Read-only.
     * @param value Value to set for the direction property.
     */
    set direction(value: CallDirection | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the incomingContext property value. The context associated with an incoming call. Read-only. Server generated.
     * @returns a incomingContext
     */
    get incomingContext(): IncomingContext | undefined;
    /**
     * Sets the incomingContext property value. The context associated with an incoming call. Read-only. Server generated.
     * @param value Value to set for the incomingContext property.
     */
    set incomingContext(value: IncomingContext | undefined);
    /**
     * Gets the mediaConfig property value. The media configuration. Required information for creating peer to peer calls or joining meetings.
     * @returns a mediaConfig
     */
    get mediaConfig(): MediaConfig | undefined;
    /**
     * Sets the mediaConfig property value. The media configuration. Required information for creating peer to peer calls or joining meetings.
     * @param value Value to set for the mediaConfig property.
     */
    set mediaConfig(value: MediaConfig | undefined);
    /**
     * Gets the mediaState property value. Read-only. The call media state.
     * @returns a callMediaState
     */
    get mediaState(): CallMediaState | undefined;
    /**
     * Sets the mediaState property value. Read-only. The call media state.
     * @param value Value to set for the mediaState property.
     */
    set mediaState(value: CallMediaState | undefined);
    /**
     * Gets the meetingInfo property value. The meeting information. Required information for meeting scenarios.
     * @returns a meetingInfo
     */
    get meetingInfo(): MeetingInfo | undefined;
    /**
     * Sets the meetingInfo property value. The meeting information. Required information for meeting scenarios.
     * @param value Value to set for the meetingInfo property.
     */
    set meetingInfo(value: MeetingInfo | undefined);
    /**
     * Gets the myParticipantId property value. The myParticipantId property
     * @returns a string
     */
    get myParticipantId(): string | undefined;
    /**
     * Sets the myParticipantId property value. The myParticipantId property
     * @param value Value to set for the myParticipantId property.
     */
    set myParticipantId(value: string | undefined);
    /**
     * Gets the operations property value. Read-only. Nullable.
     * @returns a commsOperation
     */
    get operations(): CommsOperation[] | undefined;
    /**
     * Sets the operations property value. Read-only. Nullable.
     * @param value Value to set for the operations property.
     */
    set operations(value: CommsOperation[] | undefined);
    /**
     * Gets the participants property value. Read-only. Nullable.
     * @returns a participant
     */
    get participants(): Participant[] | undefined;
    /**
     * Sets the participants property value. Read-only. Nullable.
     * @param value Value to set for the participants property.
     */
    set participants(value: Participant[] | undefined);
    /**
     * Gets the requestedModalities property value. The requestedModalities property
     * @returns a string
     */
    get requestedModalities(): string[] | undefined;
    /**
     * Sets the requestedModalities property value. The requestedModalities property
     * @param value Value to set for the requestedModalities property.
     */
    set requestedModalities(value: string[] | undefined);
    /**
     * Gets the resultInfo property value. The resultInfo property
     * @returns a resultInfo
     */
    get resultInfo(): ResultInfo | undefined;
    /**
     * Sets the resultInfo property value. The resultInfo property
     * @param value Value to set for the resultInfo property.
     */
    set resultInfo(value: ResultInfo | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the source property value. The source property
     * @returns a participantInfo
     */
    get source(): ParticipantInfo | undefined;
    /**
     * Sets the source property value. The source property
     * @param value Value to set for the source property.
     */
    set source(value: ParticipantInfo | undefined);
    /**
     * Gets the state property value. The state property
     * @returns a callState
     */
    get state(): CallState | undefined;
    /**
     * Sets the state property value. The state property
     * @param value Value to set for the state property.
     */
    set state(value: CallState | undefined);
    /**
     * Gets the subject property value. The subject property
     * @returns a string
     */
    get subject(): string | undefined;
    /**
     * Sets the subject property value. The subject property
     * @param value Value to set for the subject property.
     */
    set subject(value: string | undefined);
    /**
     * Gets the targets property value. The targets property
     * @returns a invitationParticipantInfo
     */
    get targets(): InvitationParticipantInfo[] | undefined;
    /**
     * Sets the targets property value. The targets property
     * @param value Value to set for the targets property.
     */
    set targets(value: InvitationParticipantInfo[] | undefined);
    /**
     * Gets the tenantId property value. The tenantId property
     * @returns a string
     */
    get tenantId(): string | undefined;
    /**
     * Sets the tenantId property value. The tenantId property
     * @param value Value to set for the tenantId property.
     */
    set tenantId(value: string | undefined);
    /**
     * Gets the toneInfo property value. The toneInfo property
     * @returns a toneInfo
     */
    get toneInfo(): ToneInfo | undefined;
    /**
     * Sets the toneInfo property value. The toneInfo property
     * @param value Value to set for the toneInfo property.
     */
    set toneInfo(value: ToneInfo | undefined);
    /**
     * Gets the transcription property value. The transcription information for the call. Read-only.
     * @returns a callTranscriptionInfo
     */
    get transcription(): CallTranscriptionInfo | undefined;
    /**
     * Sets the transcription property value. The transcription information for the call. Read-only.
     * @param value Value to set for the transcription property.
     */
    set transcription(value: CallTranscriptionInfo | undefined);
}
