import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DeviceInfo implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Name of the capture device driver used by the media endpoint. */
    private _captureDeviceDriver?;
    /** Name of the capture device used by the media endpoint. */
    private _captureDeviceName?;
    /** Fraction of the call that the media endpoint detected the capture device was not working properly. */
    private _captureNotFunctioningEventRatio?;
    /** Fraction of the call that the media endpoint detected the CPU resources available were insufficient and caused poor quality of the audio sent and received. */
    private _cpuInsufficentEventRatio?;
    /** Fraction of the call that the media endpoint detected clipping in the captured audio that caused poor quality of the audio being sent. */
    private _deviceClippingEventRatio?;
    /** Fraction of the call that the media endpoint detected glitches or gaps in the audio played or captured that caused poor quality of the audio being sent or received. */
    private _deviceGlitchEventRatio?;
    /** Number of times during the call that the media endpoint detected howling or screeching audio. */
    private _howlingEventCount?;
    /** The root mean square (RMS) of the incoming signal of up to the first 30 seconds of the call. */
    private _initialSignalLevelRootMeanSquare?;
    /** Fraction of the call that the media endpoint detected low speech level that caused poor quality of the audio being sent. */
    private _lowSpeechLevelEventRatio?;
    /** Fraction of the call that the media endpoint detected low speech to noise level that caused poor quality of the audio being sent. */
    private _lowSpeechToNoiseEventRatio?;
    /** Glitches per 5 minute interval for the media endpoint's microphone. */
    private _micGlitchRate?;
    /** Average energy level of received audio for audio classified as mono noise or left channel of stereo noise by the media endpoint. */
    private _receivedNoiseLevel?;
    /** Average energy level of received audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint. */
    private _receivedSignalLevel?;
    /** Name of the render device driver used by the media endpoint. */
    private _renderDeviceDriver?;
    /** Name of the render device used by the media endpoint. */
    private _renderDeviceName?;
    /** Fraction of the call that media endpoint detected device render is muted. */
    private _renderMuteEventRatio?;
    /** Fraction of the call that the media endpoint detected the render device was not working properly. */
    private _renderNotFunctioningEventRatio?;
    /** Fraction of the call that media endpoint detected device render volume is set to 0. */
    private _renderZeroVolumeEventRatio?;
    /** Average energy level of sent audio for audio classified as mono noise or left channel of stereo noise by the media endpoint. */
    private _sentNoiseLevel?;
    /** Average energy level of sent audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint. */
    private _sentSignalLevel?;
    /** Glitches per 5 minute internal for the media endpoint's loudspeaker. */
    private _speakerGlitchRate?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the captureDeviceDriver property value. Name of the capture device driver used by the media endpoint.
     * @returns a string
     */
    get captureDeviceDriver(): string | undefined;
    /**
     * Sets the captureDeviceDriver property value. Name of the capture device driver used by the media endpoint.
     * @param value Value to set for the captureDeviceDriver property.
     */
    set captureDeviceDriver(value: string | undefined);
    /**
     * Gets the captureDeviceName property value. Name of the capture device used by the media endpoint.
     * @returns a string
     */
    get captureDeviceName(): string | undefined;
    /**
     * Sets the captureDeviceName property value. Name of the capture device used by the media endpoint.
     * @param value Value to set for the captureDeviceName property.
     */
    set captureDeviceName(value: string | undefined);
    /**
     * Gets the captureNotFunctioningEventRatio property value. Fraction of the call that the media endpoint detected the capture device was not working properly.
     * @returns a float
     */
    get captureNotFunctioningEventRatio(): number | undefined;
    /**
     * Sets the captureNotFunctioningEventRatio property value. Fraction of the call that the media endpoint detected the capture device was not working properly.
     * @param value Value to set for the captureNotFunctioningEventRatio property.
     */
    set captureNotFunctioningEventRatio(value: number | undefined);
    /**
     * Instantiates a new deviceInfo and sets the default values.
     */
    constructor();
    /**
     * Gets the cpuInsufficentEventRatio property value. Fraction of the call that the media endpoint detected the CPU resources available were insufficient and caused poor quality of the audio sent and received.
     * @returns a float
     */
    get cpuInsufficentEventRatio(): number | undefined;
    /**
     * Sets the cpuInsufficentEventRatio property value. Fraction of the call that the media endpoint detected the CPU resources available were insufficient and caused poor quality of the audio sent and received.
     * @param value Value to set for the cpuInsufficentEventRatio property.
     */
    set cpuInsufficentEventRatio(value: number | undefined);
    /**
     * Gets the deviceClippingEventRatio property value. Fraction of the call that the media endpoint detected clipping in the captured audio that caused poor quality of the audio being sent.
     * @returns a float
     */
    get deviceClippingEventRatio(): number | undefined;
    /**
     * Sets the deviceClippingEventRatio property value. Fraction of the call that the media endpoint detected clipping in the captured audio that caused poor quality of the audio being sent.
     * @param value Value to set for the deviceClippingEventRatio property.
     */
    set deviceClippingEventRatio(value: number | undefined);
    /**
     * Gets the deviceGlitchEventRatio property value. Fraction of the call that the media endpoint detected glitches or gaps in the audio played or captured that caused poor quality of the audio being sent or received.
     * @returns a float
     */
    get deviceGlitchEventRatio(): number | undefined;
    /**
     * Sets the deviceGlitchEventRatio property value. Fraction of the call that the media endpoint detected glitches or gaps in the audio played or captured that caused poor quality of the audio being sent or received.
     * @param value Value to set for the deviceGlitchEventRatio property.
     */
    set deviceGlitchEventRatio(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the howlingEventCount property value. Number of times during the call that the media endpoint detected howling or screeching audio.
     * @returns a integer
     */
    get howlingEventCount(): number | undefined;
    /**
     * Sets the howlingEventCount property value. Number of times during the call that the media endpoint detected howling or screeching audio.
     * @param value Value to set for the howlingEventCount property.
     */
    set howlingEventCount(value: number | undefined);
    /**
     * Gets the initialSignalLevelRootMeanSquare property value. The root mean square (RMS) of the incoming signal of up to the first 30 seconds of the call.
     * @returns a float
     */
    get initialSignalLevelRootMeanSquare(): number | undefined;
    /**
     * Sets the initialSignalLevelRootMeanSquare property value. The root mean square (RMS) of the incoming signal of up to the first 30 seconds of the call.
     * @param value Value to set for the initialSignalLevelRootMeanSquare property.
     */
    set initialSignalLevelRootMeanSquare(value: number | undefined);
    /**
     * Gets the lowSpeechLevelEventRatio property value. Fraction of the call that the media endpoint detected low speech level that caused poor quality of the audio being sent.
     * @returns a float
     */
    get lowSpeechLevelEventRatio(): number | undefined;
    /**
     * Sets the lowSpeechLevelEventRatio property value. Fraction of the call that the media endpoint detected low speech level that caused poor quality of the audio being sent.
     * @param value Value to set for the lowSpeechLevelEventRatio property.
     */
    set lowSpeechLevelEventRatio(value: number | undefined);
    /**
     * Gets the lowSpeechToNoiseEventRatio property value. Fraction of the call that the media endpoint detected low speech to noise level that caused poor quality of the audio being sent.
     * @returns a float
     */
    get lowSpeechToNoiseEventRatio(): number | undefined;
    /**
     * Sets the lowSpeechToNoiseEventRatio property value. Fraction of the call that the media endpoint detected low speech to noise level that caused poor quality of the audio being sent.
     * @param value Value to set for the lowSpeechToNoiseEventRatio property.
     */
    set lowSpeechToNoiseEventRatio(value: number | undefined);
    /**
     * Gets the micGlitchRate property value. Glitches per 5 minute interval for the media endpoint's microphone.
     * @returns a float
     */
    get micGlitchRate(): number | undefined;
    /**
     * Sets the micGlitchRate property value. Glitches per 5 minute interval for the media endpoint's microphone.
     * @param value Value to set for the micGlitchRate property.
     */
    set micGlitchRate(value: number | undefined);
    /**
     * Gets the receivedNoiseLevel property value. Average energy level of received audio for audio classified as mono noise or left channel of stereo noise by the media endpoint.
     * @returns a integer
     */
    get receivedNoiseLevel(): number | undefined;
    /**
     * Sets the receivedNoiseLevel property value. Average energy level of received audio for audio classified as mono noise or left channel of stereo noise by the media endpoint.
     * @param value Value to set for the receivedNoiseLevel property.
     */
    set receivedNoiseLevel(value: number | undefined);
    /**
     * Gets the receivedSignalLevel property value. Average energy level of received audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint.
     * @returns a integer
     */
    get receivedSignalLevel(): number | undefined;
    /**
     * Sets the receivedSignalLevel property value. Average energy level of received audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint.
     * @param value Value to set for the receivedSignalLevel property.
     */
    set receivedSignalLevel(value: number | undefined);
    /**
     * Gets the renderDeviceDriver property value. Name of the render device driver used by the media endpoint.
     * @returns a string
     */
    get renderDeviceDriver(): string | undefined;
    /**
     * Sets the renderDeviceDriver property value. Name of the render device driver used by the media endpoint.
     * @param value Value to set for the renderDeviceDriver property.
     */
    set renderDeviceDriver(value: string | undefined);
    /**
     * Gets the renderDeviceName property value. Name of the render device used by the media endpoint.
     * @returns a string
     */
    get renderDeviceName(): string | undefined;
    /**
     * Sets the renderDeviceName property value. Name of the render device used by the media endpoint.
     * @param value Value to set for the renderDeviceName property.
     */
    set renderDeviceName(value: string | undefined);
    /**
     * Gets the renderMuteEventRatio property value. Fraction of the call that media endpoint detected device render is muted.
     * @returns a float
     */
    get renderMuteEventRatio(): number | undefined;
    /**
     * Sets the renderMuteEventRatio property value. Fraction of the call that media endpoint detected device render is muted.
     * @param value Value to set for the renderMuteEventRatio property.
     */
    set renderMuteEventRatio(value: number | undefined);
    /**
     * Gets the renderNotFunctioningEventRatio property value. Fraction of the call that the media endpoint detected the render device was not working properly.
     * @returns a float
     */
    get renderNotFunctioningEventRatio(): number | undefined;
    /**
     * Sets the renderNotFunctioningEventRatio property value. Fraction of the call that the media endpoint detected the render device was not working properly.
     * @param value Value to set for the renderNotFunctioningEventRatio property.
     */
    set renderNotFunctioningEventRatio(value: number | undefined);
    /**
     * Gets the renderZeroVolumeEventRatio property value. Fraction of the call that media endpoint detected device render volume is set to 0.
     * @returns a float
     */
    get renderZeroVolumeEventRatio(): number | undefined;
    /**
     * Sets the renderZeroVolumeEventRatio property value. Fraction of the call that media endpoint detected device render volume is set to 0.
     * @param value Value to set for the renderZeroVolumeEventRatio property.
     */
    set renderZeroVolumeEventRatio(value: number | undefined);
    /**
     * Gets the sentNoiseLevel property value. Average energy level of sent audio for audio classified as mono noise or left channel of stereo noise by the media endpoint.
     * @returns a integer
     */
    get sentNoiseLevel(): number | undefined;
    /**
     * Sets the sentNoiseLevel property value. Average energy level of sent audio for audio classified as mono noise or left channel of stereo noise by the media endpoint.
     * @param value Value to set for the sentNoiseLevel property.
     */
    set sentNoiseLevel(value: number | undefined);
    /**
     * Gets the sentSignalLevel property value. Average energy level of sent audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint.
     * @returns a integer
     */
    get sentSignalLevel(): number | undefined;
    /**
     * Sets the sentSignalLevel property value. Average energy level of sent audio for audio classified as mono speech, or left channel of stereo speech by the media endpoint.
     * @param value Value to set for the sentSignalLevel property.
     */
    set sentSignalLevel(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the speakerGlitchRate property value. Glitches per 5 minute internal for the media endpoint's loudspeaker.
     * @returns a float
     */
    get speakerGlitchRate(): number | undefined;
    /**
     * Sets the speakerGlitchRate property value. Glitches per 5 minute internal for the media endpoint's loudspeaker.
     * @param value Value to set for the speakerGlitchRate property.
     */
    set speakerGlitchRate(value: number | undefined);
}
