import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DirectRoutingLogRow implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Number of the user or bot who received the call. E.164 format, but may include additional data. */
    private _calleeNumber?;
    /** In addition to the SIP codes, Microsoft has own subcodes that indicate the specific issue. */
    private _callEndSubReason?;
    /** Number of the user or bot who made the call. E.164 format, but may include additional data. */
    private _callerNumber?;
    /** Call type and direction. */
    private _callType?;
    /** Identifier for the call that you can use when calling Microsoft Support. GUID. */
    private _correlationId?;
    /** Duration of the call in seconds. */
    private _duration?;
    /** Only exists for successful (fully established) calls. Time when call ended. */
    private _endDateTime?;
    /** Only exists for failed (not fully established) calls. */
    private _failureDateTime?;
    /** The code with which the call ended, RFC 3261. */
    private _finalSipCode?;
    /** Description of the SIP code and Microsoft subcode. */
    private _finalSipCodePhrase?;
    /** Unique call identifier. GUID. */
    private _id?;
    /** When the initial invite was sent. */
    private _inviteDateTime?;
    /** Indicates if the trunk was enabled for media bypass or not. */
    private _mediaBypassEnabled?;
    /** The datacenter used for media path in non-bypass call. */
    private _mediaPathLocation?;
    /** The datacenter used for signaling for both bypass and non-bypass calls. */
    private _signalingLocation?;
    /** Call start time.For failed and unanswered calls, this can be equal to invite or failure time. */
    private _startDateTime?;
    /** Success or attempt. */
    private _successfulCall?;
    /** Fully qualified domain name of the session border controller. */
    private _trunkFullyQualifiedDomainName?;
    /** Display name of the user. */
    private _userDisplayName?;
    /** Calling user's ID in Graph. This and other user info will be null/empty for bot call types. GUID. */
    private _userId?;
    /** UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address. */
    private _userPrincipalName?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the calleeNumber property value. Number of the user or bot who received the call. E.164 format, but may include additional data.
     * @returns a string
     */
    get calleeNumber(): string | undefined;
    /**
     * Sets the calleeNumber property value. Number of the user or bot who received the call. E.164 format, but may include additional data.
     * @param value Value to set for the calleeNumber property.
     */
    set calleeNumber(value: string | undefined);
    /**
     * Gets the callEndSubReason property value. In addition to the SIP codes, Microsoft has own subcodes that indicate the specific issue.
     * @returns a integer
     */
    get callEndSubReason(): number | undefined;
    /**
     * Sets the callEndSubReason property value. In addition to the SIP codes, Microsoft has own subcodes that indicate the specific issue.
     * @param value Value to set for the callEndSubReason property.
     */
    set callEndSubReason(value: number | undefined);
    /**
     * Gets the callerNumber property value. Number of the user or bot who made the call. E.164 format, but may include additional data.
     * @returns a string
     */
    get callerNumber(): string | undefined;
    /**
     * Sets the callerNumber property value. Number of the user or bot who made the call. E.164 format, but may include additional data.
     * @param value Value to set for the callerNumber property.
     */
    set callerNumber(value: string | undefined);
    /**
     * Gets the callType property value. Call type and direction.
     * @returns a string
     */
    get callType(): string | undefined;
    /**
     * Sets the callType property value. Call type and direction.
     * @param value Value to set for the callType property.
     */
    set callType(value: string | undefined);
    /**
     * Instantiates a new directRoutingLogRow and sets the default values.
     */
    constructor();
    /**
     * Gets the correlationId property value. Identifier for the call that you can use when calling Microsoft Support. GUID.
     * @returns a string
     */
    get correlationId(): string | undefined;
    /**
     * Sets the correlationId property value. Identifier for the call that you can use when calling Microsoft Support. GUID.
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value: string | undefined);
    /**
     * Gets the duration property value. Duration of the call in seconds.
     * @returns a integer
     */
    get duration(): number | undefined;
    /**
     * Sets the duration property value. Duration of the call in seconds.
     * @param value Value to set for the duration property.
     */
    set duration(value: number | undefined);
    /**
     * Gets the endDateTime property value. Only exists for successful (fully established) calls. Time when call ended.
     * @returns a Date
     */
    get endDateTime(): Date | undefined;
    /**
     * Sets the endDateTime property value. Only exists for successful (fully established) calls. Time when call ended.
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value: Date | undefined);
    /**
     * Gets the failureDateTime property value. Only exists for failed (not fully established) calls.
     * @returns a Date
     */
    get failureDateTime(): Date | undefined;
    /**
     * Sets the failureDateTime property value. Only exists for failed (not fully established) calls.
     * @param value Value to set for the failureDateTime property.
     */
    set failureDateTime(value: Date | undefined);
    /**
     * Gets the finalSipCode property value. The code with which the call ended, RFC 3261.
     * @returns a integer
     */
    get finalSipCode(): number | undefined;
    /**
     * Sets the finalSipCode property value. The code with which the call ended, RFC 3261.
     * @param value Value to set for the finalSipCode property.
     */
    set finalSipCode(value: number | undefined);
    /**
     * Gets the finalSipCodePhrase property value. Description of the SIP code and Microsoft subcode.
     * @returns a string
     */
    get finalSipCodePhrase(): string | undefined;
    /**
     * Sets the finalSipCodePhrase property value. Description of the SIP code and Microsoft subcode.
     * @param value Value to set for the finalSipCodePhrase property.
     */
    set finalSipCodePhrase(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the id property value. Unique call identifier. GUID.
     * @returns a string
     */
    get id(): string | undefined;
    /**
     * Sets the id property value. Unique call identifier. GUID.
     * @param value Value to set for the id property.
     */
    set id(value: string | undefined);
    /**
     * Gets the inviteDateTime property value. When the initial invite was sent.
     * @returns a Date
     */
    get inviteDateTime(): Date | undefined;
    /**
     * Sets the inviteDateTime property value. When the initial invite was sent.
     * @param value Value to set for the inviteDateTime property.
     */
    set inviteDateTime(value: Date | undefined);
    /**
     * Gets the mediaBypassEnabled property value. Indicates if the trunk was enabled for media bypass or not.
     * @returns a boolean
     */
    get mediaBypassEnabled(): boolean | undefined;
    /**
     * Sets the mediaBypassEnabled property value. Indicates if the trunk was enabled for media bypass or not.
     * @param value Value to set for the mediaBypassEnabled property.
     */
    set mediaBypassEnabled(value: boolean | undefined);
    /**
     * Gets the mediaPathLocation property value. The datacenter used for media path in non-bypass call.
     * @returns a string
     */
    get mediaPathLocation(): string | undefined;
    /**
     * Sets the mediaPathLocation property value. The datacenter used for media path in non-bypass call.
     * @param value Value to set for the mediaPathLocation property.
     */
    set mediaPathLocation(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the signalingLocation property value. The datacenter used for signaling for both bypass and non-bypass calls.
     * @returns a string
     */
    get signalingLocation(): string | undefined;
    /**
     * Sets the signalingLocation property value. The datacenter used for signaling for both bypass and non-bypass calls.
     * @param value Value to set for the signalingLocation property.
     */
    set signalingLocation(value: string | undefined);
    /**
     * Gets the startDateTime property value. Call start time.For failed and unanswered calls, this can be equal to invite or failure time.
     * @returns a Date
     */
    get startDateTime(): Date | undefined;
    /**
     * Sets the startDateTime property value. Call start time.For failed and unanswered calls, this can be equal to invite or failure time.
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: Date | undefined);
    /**
     * Gets the successfulCall property value. Success or attempt.
     * @returns a boolean
     */
    get successfulCall(): boolean | undefined;
    /**
     * Sets the successfulCall property value. Success or attempt.
     * @param value Value to set for the successfulCall property.
     */
    set successfulCall(value: boolean | undefined);
    /**
     * Gets the trunkFullyQualifiedDomainName property value. Fully qualified domain name of the session border controller.
     * @returns a string
     */
    get trunkFullyQualifiedDomainName(): string | undefined;
    /**
     * Sets the trunkFullyQualifiedDomainName property value. Fully qualified domain name of the session border controller.
     * @param value Value to set for the trunkFullyQualifiedDomainName property.
     */
    set trunkFullyQualifiedDomainName(value: string | undefined);
    /**
     * Gets the userDisplayName property value. Display name of the user.
     * @returns a string
     */
    get userDisplayName(): string | undefined;
    /**
     * Sets the userDisplayName property value. Display name of the user.
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value: string | undefined);
    /**
     * Gets the userId property value. Calling user's ID in Graph. This and other user info will be null/empty for bot call types. GUID.
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. Calling user's ID in Graph. This and other user info will be null/empty for bot call types. GUID.
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
    /**
     * Gets the userPrincipalName property value. UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
}
