import { PstnCallDurationSource } from './pstnCallDurationSource';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PstnCallLogRow implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** The source of the call duration data. If the call uses a third-party telecommunications operator via the Operator Connect Program, the operator may provide their own call duration data. In this case, the property value is operator. Otherwise, the value is microsoft. */
    private _callDurationSource?;
    /** Number dialed in E.164 format. */
    private _calleeNumber?;
    /** Number that received the call for inbound calls or the number dialed for outbound calls. E.164 format. */
    private _callerNumber?;
    /** Call identifier. Not guaranteed to be unique. */
    private _callId?;
    /** Whether the call was a PSTN outbound or inbound call and the type of call such as a call placed by a user or an audio conference. */
    private _callType?;
    /** Amount of money or cost of the call that is charged to your account. */
    private _charge?;
    /** ID of the audio conference. */
    private _conferenceId?;
    /** Connection fee price. */
    private _connectionCharge?;
    /** Type of currency used to calculate the cost of the call (ISO 4217). */
    private _currency?;
    /** Whether the call was domestic (within a country or region) or international (outside a country or region) based on the user's location. */
    private _destinationContext?;
    /** Country or region dialed. */
    private _destinationName?;
    /** How long the call was connected, in seconds. */
    private _duration?;
    /** Call end time. */
    private _endDateTime?;
    /** Unique call identifier. GUID. */
    private _id?;
    /** User's phone number type, such as a service of toll-free number. */
    private _inventoryType?;
    /** The license used for the call. */
    private _licenseCapability?;
    /** The telecommunications operator which provided PSTN services for this call. This may be Microsoft, or it may be a third-party operator via the Operator Connect Program. */
    private _operator?;
    /** Call start time. */
    private _startDateTime?;
    /** Country code of the tenant, ISO 3166-1 alpha-2. */
    private _tenantCountryCode?;
    /** Country code of the user, ISO 3166-1 alpha-2. */
    private _usageCountryCode?;
    /** Display name of the user. */
    private _userDisplayName?;
    /** Calling user's ID in Graph. GUID. This and other user info will be null/empty for bot call types (ucap_in, ucap_out). */
    private _userId?;
    /** UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address. */
    private _userPrincipalName?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the callDurationSource property value. The source of the call duration data. If the call uses a third-party telecommunications operator via the Operator Connect Program, the operator may provide their own call duration data. In this case, the property value is operator. Otherwise, the value is microsoft.
     * @returns a pstnCallDurationSource
     */
    get callDurationSource(): PstnCallDurationSource | undefined;
    /**
     * Sets the callDurationSource property value. The source of the call duration data. If the call uses a third-party telecommunications operator via the Operator Connect Program, the operator may provide their own call duration data. In this case, the property value is operator. Otherwise, the value is microsoft.
     * @param value Value to set for the callDurationSource property.
     */
    set callDurationSource(value: PstnCallDurationSource | undefined);
    /**
     * Gets the calleeNumber property value. Number dialed in E.164 format.
     * @returns a string
     */
    get calleeNumber(): string | undefined;
    /**
     * Sets the calleeNumber property value. Number dialed in E.164 format.
     * @param value Value to set for the calleeNumber property.
     */
    set calleeNumber(value: string | undefined);
    /**
     * Gets the callerNumber property value. Number that received the call for inbound calls or the number dialed for outbound calls. E.164 format.
     * @returns a string
     */
    get callerNumber(): string | undefined;
    /**
     * Sets the callerNumber property value. Number that received the call for inbound calls or the number dialed for outbound calls. E.164 format.
     * @param value Value to set for the callerNumber property.
     */
    set callerNumber(value: string | undefined);
    /**
     * Gets the callId property value. Call identifier. Not guaranteed to be unique.
     * @returns a string
     */
    get callId(): string | undefined;
    /**
     * Sets the callId property value. Call identifier. Not guaranteed to be unique.
     * @param value Value to set for the callId property.
     */
    set callId(value: string | undefined);
    /**
     * Gets the callType property value. Whether the call was a PSTN outbound or inbound call and the type of call such as a call placed by a user or an audio conference.
     * @returns a string
     */
    get callType(): string | undefined;
    /**
     * Sets the callType property value. Whether the call was a PSTN outbound or inbound call and the type of call such as a call placed by a user or an audio conference.
     * @param value Value to set for the callType property.
     */
    set callType(value: string | undefined);
    /**
     * Gets the charge property value. Amount of money or cost of the call that is charged to your account.
     * @returns a decimal
     */
    get charge(): number | undefined;
    /**
     * Sets the charge property value. Amount of money or cost of the call that is charged to your account.
     * @param value Value to set for the charge property.
     */
    set charge(value: number | undefined);
    /**
     * Gets the conferenceId property value. ID of the audio conference.
     * @returns a string
     */
    get conferenceId(): string | undefined;
    /**
     * Sets the conferenceId property value. ID of the audio conference.
     * @param value Value to set for the conferenceId property.
     */
    set conferenceId(value: string | undefined);
    /**
     * Gets the connectionCharge property value. Connection fee price.
     * @returns a decimal
     */
    get connectionCharge(): number | undefined;
    /**
     * Sets the connectionCharge property value. Connection fee price.
     * @param value Value to set for the connectionCharge property.
     */
    set connectionCharge(value: number | undefined);
    /**
     * Instantiates a new pstnCallLogRow and sets the default values.
     */
    constructor();
    /**
     * Gets the currency property value. Type of currency used to calculate the cost of the call (ISO 4217).
     * @returns a string
     */
    get currency(): string | undefined;
    /**
     * Sets the currency property value. Type of currency used to calculate the cost of the call (ISO 4217).
     * @param value Value to set for the currency property.
     */
    set currency(value: string | undefined);
    /**
     * Gets the destinationContext property value. Whether the call was domestic (within a country or region) or international (outside a country or region) based on the user's location.
     * @returns a string
     */
    get destinationContext(): string | undefined;
    /**
     * Sets the destinationContext property value. Whether the call was domestic (within a country or region) or international (outside a country or region) based on the user's location.
     * @param value Value to set for the destinationContext property.
     */
    set destinationContext(value: string | undefined);
    /**
     * Gets the destinationName property value. Country or region dialed.
     * @returns a string
     */
    get destinationName(): string | undefined;
    /**
     * Sets the destinationName property value. Country or region dialed.
     * @param value Value to set for the destinationName property.
     */
    set destinationName(value: string | undefined);
    /**
     * Gets the duration property value. How long the call was connected, in seconds.
     * @returns a integer
     */
    get duration(): number | undefined;
    /**
     * Sets the duration property value. How long the call was connected, in seconds.
     * @param value Value to set for the duration property.
     */
    set duration(value: number | undefined);
    /**
     * Gets the endDateTime property value. Call end time.
     * @returns a Date
     */
    get endDateTime(): Date | undefined;
    /**
     * Sets the endDateTime property value. Call end time.
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the id property value. Unique call identifier. GUID.
     * @returns a string
     */
    get id(): string | undefined;
    /**
     * Sets the id property value. Unique call identifier. GUID.
     * @param value Value to set for the id property.
     */
    set id(value: string | undefined);
    /**
     * Gets the inventoryType property value. User's phone number type, such as a service of toll-free number.
     * @returns a string
     */
    get inventoryType(): string | undefined;
    /**
     * Sets the inventoryType property value. User's phone number type, such as a service of toll-free number.
     * @param value Value to set for the inventoryType property.
     */
    set inventoryType(value: string | undefined);
    /**
     * Gets the licenseCapability property value. The license used for the call.
     * @returns a string
     */
    get licenseCapability(): string | undefined;
    /**
     * Sets the licenseCapability property value. The license used for the call.
     * @param value Value to set for the licenseCapability property.
     */
    set licenseCapability(value: string | undefined);
    /**
     * Gets the operator property value. The telecommunications operator which provided PSTN services for this call. This may be Microsoft, or it may be a third-party operator via the Operator Connect Program.
     * @returns a string
     */
    get operator(): string | undefined;
    /**
     * Sets the operator property value. The telecommunications operator which provided PSTN services for this call. This may be Microsoft, or it may be a third-party operator via the Operator Connect Program.
     * @param value Value to set for the operator property.
     */
    set operator(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the startDateTime property value. Call start time.
     * @returns a Date
     */
    get startDateTime(): Date | undefined;
    /**
     * Sets the startDateTime property value. Call start time.
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: Date | undefined);
    /**
     * Gets the tenantCountryCode property value. Country code of the tenant, ISO 3166-1 alpha-2.
     * @returns a string
     */
    get tenantCountryCode(): string | undefined;
    /**
     * Sets the tenantCountryCode property value. Country code of the tenant, ISO 3166-1 alpha-2.
     * @param value Value to set for the tenantCountryCode property.
     */
    set tenantCountryCode(value: string | undefined);
    /**
     * Gets the usageCountryCode property value. Country code of the user, ISO 3166-1 alpha-2.
     * @returns a string
     */
    get usageCountryCode(): string | undefined;
    /**
     * Sets the usageCountryCode property value. Country code of the user, ISO 3166-1 alpha-2.
     * @param value Value to set for the usageCountryCode property.
     */
    set usageCountryCode(value: string | undefined);
    /**
     * Gets the userDisplayName property value. Display name of the user.
     * @returns a string
     */
    get userDisplayName(): string | undefined;
    /**
     * Sets the userDisplayName property value. Display name of the user.
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value: string | undefined);
    /**
     * Gets the userId property value. Calling user's ID in Graph. GUID. This and other user info will be null/empty for bot call types (ucap_in, ucap_out).
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. Calling user's ID in Graph. GUID. This and other user info will be null/empty for bot call types (ucap_in, ucap_out).
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
    /**
     * Gets the userPrincipalName property value. UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. UserPrincipalName (sign-in name) in Azure Active Directory. This is usually the same as user's SIP Address, and can be same as user's e-mail address.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
}
