import { Entity } from '../';
import { Endpoint, FailureInfo, Media } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the cloudCommunications singleton. */
export declare class Segment extends Entity implements Parsable {
    /** Endpoint that answered this segment. */
    private _callee?;
    /** Endpoint that initiated this segment. */
    private _caller?;
    /** UTC time when the segment ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _endDateTime?;
    /** Failure information associated with the segment if it failed. */
    private _failureInfo?;
    /** Media associated with this segment. */
    private _media?;
    /** UTC time when the segment started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _startDateTime?;
    /**
     * Gets the callee property value. Endpoint that answered this segment.
     * @returns a endpoint
     */
    get callee(): Endpoint | undefined;
    /**
     * Sets the callee property value. Endpoint that answered this segment.
     * @param value Value to set for the callee property.
     */
    set callee(value: Endpoint | undefined);
    /**
     * Gets the caller property value. Endpoint that initiated this segment.
     * @returns a endpoint
     */
    get caller(): Endpoint | undefined;
    /**
     * Sets the caller property value. Endpoint that initiated this segment.
     * @param value Value to set for the caller property.
     */
    set caller(value: Endpoint | undefined);
    /**
     * Instantiates a new segment and sets the default values.
     */
    constructor();
    /**
     * Gets the endDateTime property value. UTC time when the segment ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get endDateTime(): Date | undefined;
    /**
     * Sets the endDateTime property value. UTC time when the segment ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value: Date | undefined);
    /**
     * Gets the failureInfo property value. Failure information associated with the segment if it failed.
     * @returns a failureInfo
     */
    get failureInfo(): FailureInfo | undefined;
    /**
     * Sets the failureInfo property value. Failure information associated with the segment if it failed.
     * @param value Value to set for the failureInfo property.
     */
    set failureInfo(value: FailureInfo | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the media property value. Media associated with this segment.
     * @returns a media
     */
    get media(): Media[] | undefined;
    /**
     * Sets the media property value. Media associated with this segment.
     * @param value Value to set for the media property.
     */
    set media(value: Media[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the startDateTime property value. UTC time when the segment started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get startDateTime(): Date | undefined;
    /**
     * Sets the startDateTime property value. UTC time when the segment started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: Date | undefined);
}
