"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Segment = void 0;
const __1 = require("../");
const createEndpointFromDiscriminatorValue_1 = require("./createEndpointFromDiscriminatorValue");
const createFailureInfoFromDiscriminatorValue_1 = require("./createFailureInfoFromDiscriminatorValue");
const createMediaFromDiscriminatorValue_1 = require("./createMediaFromDiscriminatorValue");
/** Provides operations to manage the cloudCommunications singleton. */
class Segment extends __1.Entity {
    /**
     * Instantiates a new segment and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the callee property value. Endpoint that answered this segment.
     * @returns a endpoint
     */
    get callee() {
        return this._callee;
    }
    ;
    /**
     * Sets the callee property value. Endpoint that answered this segment.
     * @param value Value to set for the callee property.
     */
    set callee(value) {
        this._callee = value;
    }
    ;
    /**
     * Gets the caller property value. Endpoint that initiated this segment.
     * @returns a endpoint
     */
    get caller() {
        return this._caller;
    }
    ;
    /**
     * Sets the caller property value. Endpoint that initiated this segment.
     * @param value Value to set for the caller property.
     */
    set caller(value) {
        this._caller = value;
    }
    ;
    ;
    /**
     * Gets the endDateTime property value. UTC time when the segment ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get endDateTime() {
        return this._endDateTime;
    }
    ;
    /**
     * Sets the endDateTime property value. UTC time when the segment ended. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value) {
        this._endDateTime = value;
    }
    ;
    /**
     * Gets the failureInfo property value. Failure information associated with the segment if it failed.
     * @returns a failureInfo
     */
    get failureInfo() {
        return this._failureInfo;
    }
    ;
    /**
     * Sets the failureInfo property value. Failure information associated with the segment if it failed.
     * @param value Value to set for the failureInfo property.
     */
    set failureInfo(value) {
        this._failureInfo = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "callee": n => { this.callee = n.getObjectValue(createEndpointFromDiscriminatorValue_1.createEndpointFromDiscriminatorValue); }, "caller": n => { this.caller = n.getObjectValue(createEndpointFromDiscriminatorValue_1.createEndpointFromDiscriminatorValue); }, "endDateTime": n => { this.endDateTime = n.getDateValue(); }, "failureInfo": n => { this.failureInfo = n.getObjectValue(createFailureInfoFromDiscriminatorValue_1.createFailureInfoFromDiscriminatorValue); }, "media": n => { this.media = n.getCollectionOfObjectValues(createMediaFromDiscriminatorValue_1.createMediaFromDiscriminatorValue); }, "startDateTime": n => { this.startDateTime = n.getDateValue(); } });
    }
    ;
    /**
     * Gets the media property value. Media associated with this segment.
     * @returns a media
     */
    get media() {
        return this._media;
    }
    ;
    /**
     * Sets the media property value. Media associated with this segment.
     * @param value Value to set for the media property.
     */
    set media(value) {
        this._media = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("callee", this.callee);
        writer.writeObjectValue("caller", this.caller);
        writer.writeDateValue("endDateTime", this.endDateTime);
        writer.writeObjectValue("failureInfo", this.failureInfo);
        writer.writeCollectionOfObjectValues("media", this.media);
        writer.writeDateValue("startDateTime", this.startDateTime);
    }
    ;
    /**
     * Gets the startDateTime property value. UTC time when the segment started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get startDateTime() {
        return this._startDateTime;
    }
    ;
    /**
     * Sets the startDateTime property value. UTC time when the segment started. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value) {
        this._startDateTime = value;
    }
    ;
}
exports.Segment = Segment;
