import { ChannelMembershipType } from './channelMembershipType';
import { ChatMessage, ConversationMember, DriveItem, Entity, TeamsTab } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Channel extends Entity implements Parsable {
    /** Read only. Timestamp at which the channel was created. */
    private _createdDateTime?;
    /** Optional textual description for the channel. */
    private _description?;
    /** Channel name as it will appear to the user in Microsoft Teams. */
    private _displayName?;
    /** The email address for sending messages to the channel. Read-only. */
    private _email?;
    /** Metadata for the location where the channel's files are stored. */
    private _filesFolder?;
    /** Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false. */
    private _isFavoriteByDefault?;
    /** A collection of membership records associated with the channel. */
    private _members?;
    /** The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared. */
    private _membershipType?;
    /** A collection of all the messages in the channel. A navigation property. Nullable. */
    private _messages?;
    /** A collection of all the tabs in the channel. A navigation property. */
    private _tabs?;
    /** A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only. */
    private _webUrl?;
    /**
     * Instantiates a new channel and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Read only. Timestamp at which the channel was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Read only. Timestamp at which the channel was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. Optional textual description for the channel.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Optional textual description for the channel.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. Channel name as it will appear to the user in Microsoft Teams.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Channel name as it will appear to the user in Microsoft Teams.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the email property value. The email address for sending messages to the channel. Read-only.
     * @returns a string
     */
    get email(): string | undefined;
    /**
     * Sets the email property value. The email address for sending messages to the channel. Read-only.
     * @param value Value to set for the email property.
     */
    set email(value: string | undefined);
    /**
     * Gets the filesFolder property value. Metadata for the location where the channel's files are stored.
     * @returns a driveItem
     */
    get filesFolder(): DriveItem | undefined;
    /**
     * Sets the filesFolder property value. Metadata for the location where the channel's files are stored.
     * @param value Value to set for the filesFolder property.
     */
    set filesFolder(value: DriveItem | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isFavoriteByDefault property value. Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false.
     * @returns a boolean
     */
    get isFavoriteByDefault(): boolean | undefined;
    /**
     * Sets the isFavoriteByDefault property value. Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false.
     * @param value Value to set for the isFavoriteByDefault property.
     */
    set isFavoriteByDefault(value: boolean | undefined);
    /**
     * Gets the members property value. A collection of membership records associated with the channel.
     * @returns a conversationMember
     */
    get members(): ConversationMember[] | undefined;
    /**
     * Sets the members property value. A collection of membership records associated with the channel.
     * @param value Value to set for the members property.
     */
    set members(value: ConversationMember[] | undefined);
    /**
     * Gets the membershipType property value. The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared.
     * @returns a channelMembershipType
     */
    get membershipType(): ChannelMembershipType | undefined;
    /**
     * Sets the membershipType property value. The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared.
     * @param value Value to set for the membershipType property.
     */
    set membershipType(value: ChannelMembershipType | undefined);
    /**
     * Gets the messages property value. A collection of all the messages in the channel. A navigation property. Nullable.
     * @returns a chatMessage
     */
    get messages(): ChatMessage[] | undefined;
    /**
     * Sets the messages property value. A collection of all the messages in the channel. A navigation property. Nullable.
     * @param value Value to set for the messages property.
     */
    set messages(value: ChatMessage[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the tabs property value. A collection of all the tabs in the channel. A navigation property.
     * @returns a teamsTab
     */
    get tabs(): TeamsTab[] | undefined;
    /**
     * Sets the tabs property value. A collection of all the tabs in the channel. A navigation property.
     * @param value Value to set for the tabs property.
     */
    set tabs(value: TeamsTab[] | undefined);
    /**
     * Gets the webUrl property value. A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
