"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Channel = void 0;
const channelMembershipType_1 = require("./channelMembershipType");
const createChatMessageFromDiscriminatorValue_1 = require("./createChatMessageFromDiscriminatorValue");
const createConversationMemberFromDiscriminatorValue_1 = require("./createConversationMemberFromDiscriminatorValue");
const createDriveItemFromDiscriminatorValue_1 = require("./createDriveItemFromDiscriminatorValue");
const createTeamsTabFromDiscriminatorValue_1 = require("./createTeamsTabFromDiscriminatorValue");
const index_1 = require("./index");
/** Casts the previous resource to user. */
class Channel extends index_1.Entity {
    /**
     * Instantiates a new channel and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the createdDateTime property value. Read only. Timestamp at which the channel was created.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Read only. Timestamp at which the channel was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the description property value. Optional textual description for the channel.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Optional textual description for the channel.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * Gets the displayName property value. Channel name as it will appear to the user in Microsoft Teams.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. Channel name as it will appear to the user in Microsoft Teams.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * Gets the email property value. The email address for sending messages to the channel. Read-only.
     * @returns a string
     */
    get email() {
        return this._email;
    }
    ;
    /**
     * Sets the email property value. The email address for sending messages to the channel. Read-only.
     * @param value Value to set for the email property.
     */
    set email(value) {
        this._email = value;
    }
    ;
    /**
     * Gets the filesFolder property value. Metadata for the location where the channel's files are stored.
     * @returns a driveItem
     */
    get filesFolder() {
        return this._filesFolder;
    }
    ;
    /**
     * Sets the filesFolder property value. Metadata for the location where the channel's files are stored.
     * @param value Value to set for the filesFolder property.
     */
    set filesFolder(value) {
        this._filesFolder = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "createdDateTime": n => { this.createdDateTime = n.getDateValue(); }, "description": n => { this.description = n.getStringValue(); }, "displayName": n => { this.displayName = n.getStringValue(); }, "email": n => { this.email = n.getStringValue(); }, "filesFolder": n => { this.filesFolder = n.getObjectValue(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "isFavoriteByDefault": n => { this.isFavoriteByDefault = n.getBooleanValue(); }, "members": n => { this.members = n.getCollectionOfObjectValues(createConversationMemberFromDiscriminatorValue_1.createConversationMemberFromDiscriminatorValue); }, "membershipType": n => { this.membershipType = n.getEnumValue(channelMembershipType_1.ChannelMembershipType); }, "messages": n => { this.messages = n.getCollectionOfObjectValues(createChatMessageFromDiscriminatorValue_1.createChatMessageFromDiscriminatorValue); }, "tabs": n => { this.tabs = n.getCollectionOfObjectValues(createTeamsTabFromDiscriminatorValue_1.createTeamsTabFromDiscriminatorValue); }, "webUrl": n => { this.webUrl = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the isFavoriteByDefault property value. Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false.
     * @returns a boolean
     */
    get isFavoriteByDefault() {
        return this._isFavoriteByDefault;
    }
    ;
    /**
     * Sets the isFavoriteByDefault property value. Indicates whether the channel should automatically be marked 'favorite' for all members of the team. Can only be set programmatically with Create team. Default: false.
     * @param value Value to set for the isFavoriteByDefault property.
     */
    set isFavoriteByDefault(value) {
        this._isFavoriteByDefault = value;
    }
    ;
    /**
     * Gets the members property value. A collection of membership records associated with the channel.
     * @returns a conversationMember
     */
    get members() {
        return this._members;
    }
    ;
    /**
     * Sets the members property value. A collection of membership records associated with the channel.
     * @param value Value to set for the members property.
     */
    set members(value) {
        this._members = value;
    }
    ;
    /**
     * Gets the membershipType property value. The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared.
     * @returns a channelMembershipType
     */
    get membershipType() {
        return this._membershipType;
    }
    ;
    /**
     * Sets the membershipType property value. The type of the channel. Can be set during creation and can't be changed. The possible values are: standard, private, unknownFutureValue, shared. The default value is standard. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: shared.
     * @param value Value to set for the membershipType property.
     */
    set membershipType(value) {
        this._membershipType = value;
    }
    ;
    /**
     * Gets the messages property value. A collection of all the messages in the channel. A navigation property. Nullable.
     * @returns a chatMessage
     */
    get messages() {
        return this._messages;
    }
    ;
    /**
     * Sets the messages property value. A collection of all the messages in the channel. A navigation property. Nullable.
     * @param value Value to set for the messages property.
     */
    set messages(value) {
        this._messages = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeStringValue("email", this.email);
        writer.writeObjectValue("filesFolder", this.filesFolder);
        writer.writeBooleanValue("isFavoriteByDefault", this.isFavoriteByDefault);
        writer.writeCollectionOfObjectValues("members", this.members);
        writer.writeEnumValue("membershipType", this.membershipType);
        writer.writeCollectionOfObjectValues("messages", this.messages);
        writer.writeCollectionOfObjectValues("tabs", this.tabs);
        writer.writeStringValue("webUrl", this.webUrl);
    }
    ;
    /**
     * Gets the tabs property value. A collection of all the tabs in the channel. A navigation property.
     * @returns a teamsTab
     */
    get tabs() {
        return this._tabs;
    }
    ;
    /**
     * Sets the tabs property value. A collection of all the tabs in the channel. A navigation property.
     * @param value Value to set for the tabs property.
     */
    set tabs(value) {
        this._tabs = value;
    }
    ;
    /**
     * Gets the webUrl property value. A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only.
     * @returns a string
     */
    get webUrl() {
        return this._webUrl;
    }
    ;
    /**
     * Sets the webUrl property value. A hyperlink that will go to the channel in Microsoft Teams. This is the URL that you get when you right-click a channel in Microsoft Teams and select Get link to channel. This URL should be treated as an opaque blob, and not parsed. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value) {
        this._webUrl = value;
    }
    ;
}
exports.Channel = Channel;
