import { ChatType } from './chatType';
import { ChatMessage, ConversationMember, Entity, TeamsAppInstallation, TeamsTab, TeamworkOnlineMeetingInfo } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of chat entities. */
export declare class Chat extends Entity implements Parsable {
    /** Specifies the type of chat. Possible values are: group, oneOnOne, meeting, unknownFutureValue. */
    private _chatType?;
    /** Date and time at which the chat was created. Read-only. */
    private _createdDateTime?;
    /** A collection of all the apps in the chat. Nullable. */
    private _installedApps?;
    /** Date and time at which the chat was renamed or list of members were last changed. Read-only. */
    private _lastUpdatedDateTime?;
    /** A collection of all the members in the chat. Nullable. */
    private _members?;
    /** A collection of all the messages in the chat. Nullable. */
    private _messages?;
    /** Represents details about an online meeting. If the chat isn't associated with an online meeting, the property is empty. Read-only. */
    private _onlineMeetingInfo?;
    /** A collection of all the tabs in the chat. Nullable. */
    private _tabs?;
    /** The identifier of the tenant in which the chat was created. Read-only. */
    private _tenantId?;
    /** (Optional) Subject or topic for the chat. Only available for group chats. */
    private _topic?;
    /** The URL for the chat in Microsoft Teams. The URL should be treated as an opaque blob, and not parsed. Read-only. */
    private _webUrl?;
    /**
     * Gets the chatType property value. Specifies the type of chat. Possible values are: group, oneOnOne, meeting, unknownFutureValue.
     * @returns a chatType
     */
    get chatType(): ChatType | undefined;
    /**
     * Sets the chatType property value. Specifies the type of chat. Possible values are: group, oneOnOne, meeting, unknownFutureValue.
     * @param value Value to set for the chatType property.
     */
    set chatType(value: ChatType | undefined);
    /**
     * Instantiates a new chat and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Date and time at which the chat was created. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Date and time at which the chat was created. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the installedApps property value. A collection of all the apps in the chat. Nullable.
     * @returns a teamsAppInstallation
     */
    get installedApps(): TeamsAppInstallation[] | undefined;
    /**
     * Sets the installedApps property value. A collection of all the apps in the chat. Nullable.
     * @param value Value to set for the installedApps property.
     */
    set installedApps(value: TeamsAppInstallation[] | undefined);
    /**
     * Gets the lastUpdatedDateTime property value. Date and time at which the chat was renamed or list of members were last changed. Read-only.
     * @returns a Date
     */
    get lastUpdatedDateTime(): Date | undefined;
    /**
     * Sets the lastUpdatedDateTime property value. Date and time at which the chat was renamed or list of members were last changed. Read-only.
     * @param value Value to set for the lastUpdatedDateTime property.
     */
    set lastUpdatedDateTime(value: Date | undefined);
    /**
     * Gets the members property value. A collection of all the members in the chat. Nullable.
     * @returns a conversationMember
     */
    get members(): ConversationMember[] | undefined;
    /**
     * Sets the members property value. A collection of all the members in the chat. Nullable.
     * @param value Value to set for the members property.
     */
    set members(value: ConversationMember[] | undefined);
    /**
     * Gets the messages property value. A collection of all the messages in the chat. Nullable.
     * @returns a chatMessage
     */
    get messages(): ChatMessage[] | undefined;
    /**
     * Sets the messages property value. A collection of all the messages in the chat. Nullable.
     * @param value Value to set for the messages property.
     */
    set messages(value: ChatMessage[] | undefined);
    /**
     * Gets the onlineMeetingInfo property value. Represents details about an online meeting. If the chat isn't associated with an online meeting, the property is empty. Read-only.
     * @returns a teamworkOnlineMeetingInfo
     */
    get onlineMeetingInfo(): TeamworkOnlineMeetingInfo | undefined;
    /**
     * Sets the onlineMeetingInfo property value. Represents details about an online meeting. If the chat isn't associated with an online meeting, the property is empty. Read-only.
     * @param value Value to set for the onlineMeetingInfo property.
     */
    set onlineMeetingInfo(value: TeamworkOnlineMeetingInfo | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the tabs property value. A collection of all the tabs in the chat. Nullable.
     * @returns a teamsTab
     */
    get tabs(): TeamsTab[] | undefined;
    /**
     * Sets the tabs property value. A collection of all the tabs in the chat. Nullable.
     * @param value Value to set for the tabs property.
     */
    set tabs(value: TeamsTab[] | undefined);
    /**
     * Gets the tenantId property value. The identifier of the tenant in which the chat was created. Read-only.
     * @returns a string
     */
    get tenantId(): string | undefined;
    /**
     * Sets the tenantId property value. The identifier of the tenant in which the chat was created. Read-only.
     * @param value Value to set for the tenantId property.
     */
    set tenantId(value: string | undefined);
    /**
     * Gets the topic property value. (Optional) Subject or topic for the chat. Only available for group chats.
     * @returns a string
     */
    get topic(): string | undefined;
    /**
     * Sets the topic property value. (Optional) Subject or topic for the chat. Only available for group chats.
     * @param value Value to set for the topic property.
     */
    set topic(value: string | undefined);
    /**
     * Gets the webUrl property value. The URL for the chat in Microsoft Teams. The URL should be treated as an opaque blob, and not parsed. Read-only.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. The URL for the chat in Microsoft Teams. The URL should be treated as an opaque blob, and not parsed. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
