import { ApplicationEnforcedRestrictionsSessionControl, CloudAppSecuritySessionControl, PersistentBrowserSessionControl, SignInFrequencySessionControl } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ConditionalAccessSessionControls implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Session control to enforce application restrictions. Only Exchange Online and Sharepoint Online support this session control. */
    private _applicationEnforcedRestrictions?;
    /** Session control to apply cloud app security. */
    private _cloudAppSecurity?;
    /** Session control that determines whether it is acceptable for Azure AD to extend existing sessions based on information collected prior to an outage or not. */
    private _disableResilienceDefaults?;
    /** Session control to define whether to persist cookies or not. All apps should be selected for this session control to work correctly. */
    private _persistentBrowser?;
    /** Session control to enforce signin frequency. */
    private _signInFrequency?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the applicationEnforcedRestrictions property value. Session control to enforce application restrictions. Only Exchange Online and Sharepoint Online support this session control.
     * @returns a applicationEnforcedRestrictionsSessionControl
     */
    get applicationEnforcedRestrictions(): ApplicationEnforcedRestrictionsSessionControl | undefined;
    /**
     * Sets the applicationEnforcedRestrictions property value. Session control to enforce application restrictions. Only Exchange Online and Sharepoint Online support this session control.
     * @param value Value to set for the applicationEnforcedRestrictions property.
     */
    set applicationEnforcedRestrictions(value: ApplicationEnforcedRestrictionsSessionControl | undefined);
    /**
     * Gets the cloudAppSecurity property value. Session control to apply cloud app security.
     * @returns a cloudAppSecuritySessionControl
     */
    get cloudAppSecurity(): CloudAppSecuritySessionControl | undefined;
    /**
     * Sets the cloudAppSecurity property value. Session control to apply cloud app security.
     * @param value Value to set for the cloudAppSecurity property.
     */
    set cloudAppSecurity(value: CloudAppSecuritySessionControl | undefined);
    /**
     * Instantiates a new conditionalAccessSessionControls and sets the default values.
     */
    constructor();
    /**
     * Gets the disableResilienceDefaults property value. Session control that determines whether it is acceptable for Azure AD to extend existing sessions based on information collected prior to an outage or not.
     * @returns a boolean
     */
    get disableResilienceDefaults(): boolean | undefined;
    /**
     * Sets the disableResilienceDefaults property value. Session control that determines whether it is acceptable for Azure AD to extend existing sessions based on information collected prior to an outage or not.
     * @param value Value to set for the disableResilienceDefaults property.
     */
    set disableResilienceDefaults(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the persistentBrowser property value. Session control to define whether to persist cookies or not. All apps should be selected for this session control to work correctly.
     * @returns a persistentBrowserSessionControl
     */
    get persistentBrowser(): PersistentBrowserSessionControl | undefined;
    /**
     * Sets the persistentBrowser property value. Session control to define whether to persist cookies or not. All apps should be selected for this session control to work correctly.
     * @param value Value to set for the persistentBrowser property.
     */
    set persistentBrowser(value: PersistentBrowserSessionControl | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the signInFrequency property value. Session control to enforce signin frequency.
     * @returns a signInFrequencySessionControl
     */
    get signInFrequency(): SignInFrequencySessionControl | undefined;
    /**
     * Sets the signInFrequency property value. Session control to enforce signin frequency.
     * @param value Value to set for the signInFrequency property.
     */
    set signInFrequency(value: SignInFrequencySessionControl | undefined);
}
