import { EmailAddress, Extension, MultiValueLegacyExtendedProperty, OutlookItem, PhysicalAddress, ProfilePhoto, SingleValueLegacyExtendedProperty } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Contact extends OutlookItem implements Parsable {
    /** The name of the contact's assistant. */
    private _assistantName?;
    /** The contact's birthday. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _birthday?;
    /** The contact's business address. */
    private _businessAddress?;
    /** The business home page of the contact. */
    private _businessHomePage?;
    /** The contact's business phone numbers. */
    private _businessPhones?;
    /** The names of the contact's children. */
    private _children?;
    /** The name of the contact's company. */
    private _companyName?;
    /** The contact's department. */
    private _department?;
    /** The contact's display name. You can specify the display name in a create or update operation. Note that later updates to other properties may cause an automatically generated value to overwrite the displayName value you have specified. To preserve a pre-existing value, always include it as displayName in an update operation. */
    private _displayName?;
    /** The contact's email addresses. */
    private _emailAddresses?;
    /** The collection of open extensions defined for the contact. Nullable. */
    private _extensions?;
    /** The name the contact is filed under. */
    private _fileAs?;
    /** The contact's generation. */
    private _generation?;
    /** The contact's given name. */
    private _givenName?;
    /** The contact's home address. */
    private _homeAddress?;
    /** The contact's home phone numbers. */
    private _homePhones?;
    /** The imAddresses property */
    private _imAddresses?;
    /** The initials property */
    private _initials?;
    /** The jobTitle property */
    private _jobTitle?;
    /** The manager property */
    private _manager?;
    /** The middleName property */
    private _middleName?;
    /** The mobilePhone property */
    private _mobilePhone?;
    /** The collection of multi-value extended properties defined for the contact. Read-only. Nullable. */
    private _multiValueExtendedProperties?;
    /** The nickName property */
    private _nickName?;
    /** The officeLocation property */
    private _officeLocation?;
    /** The otherAddress property */
    private _otherAddress?;
    /** The parentFolderId property */
    private _parentFolderId?;
    /** The personalNotes property */
    private _personalNotes?;
    /** Optional contact picture. You can get or set a photo for a contact. */
    private _photo?;
    /** The profession property */
    private _profession?;
    /** The collection of single-value extended properties defined for the contact. Read-only. Nullable. */
    private _singleValueExtendedProperties?;
    /** The spouseName property */
    private _spouseName?;
    /** The surname property */
    private _surname?;
    /** The title property */
    private _title?;
    /** The yomiCompanyName property */
    private _yomiCompanyName?;
    /** The yomiGivenName property */
    private _yomiGivenName?;
    /** The yomiSurname property */
    private _yomiSurname?;
    /**
     * Gets the assistantName property value. The name of the contact's assistant.
     * @returns a string
     */
    get assistantName(): string | undefined;
    /**
     * Sets the assistantName property value. The name of the contact's assistant.
     * @param value Value to set for the assistantName property.
     */
    set assistantName(value: string | undefined);
    /**
     * Gets the birthday property value. The contact's birthday. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get birthday(): Date | undefined;
    /**
     * Sets the birthday property value. The contact's birthday. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the birthday property.
     */
    set birthday(value: Date | undefined);
    /**
     * Gets the businessAddress property value. The contact's business address.
     * @returns a physicalAddress
     */
    get businessAddress(): PhysicalAddress | undefined;
    /**
     * Sets the businessAddress property value. The contact's business address.
     * @param value Value to set for the businessAddress property.
     */
    set businessAddress(value: PhysicalAddress | undefined);
    /**
     * Gets the businessHomePage property value. The business home page of the contact.
     * @returns a string
     */
    get businessHomePage(): string | undefined;
    /**
     * Sets the businessHomePage property value. The business home page of the contact.
     * @param value Value to set for the businessHomePage property.
     */
    set businessHomePage(value: string | undefined);
    /**
     * Gets the businessPhones property value. The contact's business phone numbers.
     * @returns a string
     */
    get businessPhones(): string[] | undefined;
    /**
     * Sets the businessPhones property value. The contact's business phone numbers.
     * @param value Value to set for the businessPhones property.
     */
    set businessPhones(value: string[] | undefined);
    /**
     * Gets the children property value. The names of the contact's children.
     * @returns a string
     */
    get children(): string[] | undefined;
    /**
     * Sets the children property value. The names of the contact's children.
     * @param value Value to set for the children property.
     */
    set children(value: string[] | undefined);
    /**
     * Gets the companyName property value. The name of the contact's company.
     * @returns a string
     */
    get companyName(): string | undefined;
    /**
     * Sets the companyName property value. The name of the contact's company.
     * @param value Value to set for the companyName property.
     */
    set companyName(value: string | undefined);
    /**
     * Instantiates a new contact and sets the default values.
     */
    constructor();
    /**
     * Gets the department property value. The contact's department.
     * @returns a string
     */
    get department(): string | undefined;
    /**
     * Sets the department property value. The contact's department.
     * @param value Value to set for the department property.
     */
    set department(value: string | undefined);
    /**
     * Gets the displayName property value. The contact's display name. You can specify the display name in a create or update operation. Note that later updates to other properties may cause an automatically generated value to overwrite the displayName value you have specified. To preserve a pre-existing value, always include it as displayName in an update operation.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The contact's display name. You can specify the display name in a create or update operation. Note that later updates to other properties may cause an automatically generated value to overwrite the displayName value you have specified. To preserve a pre-existing value, always include it as displayName in an update operation.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the emailAddresses property value. The contact's email addresses.
     * @returns a emailAddress
     */
    get emailAddresses(): EmailAddress[] | undefined;
    /**
     * Sets the emailAddresses property value. The contact's email addresses.
     * @param value Value to set for the emailAddresses property.
     */
    set emailAddresses(value: EmailAddress[] | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the contact. Nullable.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the contact. Nullable.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * Gets the fileAs property value. The name the contact is filed under.
     * @returns a string
     */
    get fileAs(): string | undefined;
    /**
     * Sets the fileAs property value. The name the contact is filed under.
     * @param value Value to set for the fileAs property.
     */
    set fileAs(value: string | undefined);
    /**
     * Gets the generation property value. The contact's generation.
     * @returns a string
     */
    get generation(): string | undefined;
    /**
     * Sets the generation property value. The contact's generation.
     * @param value Value to set for the generation property.
     */
    set generation(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the givenName property value. The contact's given name.
     * @returns a string
     */
    get givenName(): string | undefined;
    /**
     * Sets the givenName property value. The contact's given name.
     * @param value Value to set for the givenName property.
     */
    set givenName(value: string | undefined);
    /**
     * Gets the homeAddress property value. The contact's home address.
     * @returns a physicalAddress
     */
    get homeAddress(): PhysicalAddress | undefined;
    /**
     * Sets the homeAddress property value. The contact's home address.
     * @param value Value to set for the homeAddress property.
     */
    set homeAddress(value: PhysicalAddress | undefined);
    /**
     * Gets the homePhones property value. The contact's home phone numbers.
     * @returns a string
     */
    get homePhones(): string[] | undefined;
    /**
     * Sets the homePhones property value. The contact's home phone numbers.
     * @param value Value to set for the homePhones property.
     */
    set homePhones(value: string[] | undefined);
    /**
     * Gets the imAddresses property value. The imAddresses property
     * @returns a string
     */
    get imAddresses(): string[] | undefined;
    /**
     * Sets the imAddresses property value. The imAddresses property
     * @param value Value to set for the imAddresses property.
     */
    set imAddresses(value: string[] | undefined);
    /**
     * Gets the initials property value. The initials property
     * @returns a string
     */
    get initials(): string | undefined;
    /**
     * Sets the initials property value. The initials property
     * @param value Value to set for the initials property.
     */
    set initials(value: string | undefined);
    /**
     * Gets the jobTitle property value. The jobTitle property
     * @returns a string
     */
    get jobTitle(): string | undefined;
    /**
     * Sets the jobTitle property value. The jobTitle property
     * @param value Value to set for the jobTitle property.
     */
    set jobTitle(value: string | undefined);
    /**
     * Gets the manager property value. The manager property
     * @returns a string
     */
    get manager(): string | undefined;
    /**
     * Sets the manager property value. The manager property
     * @param value Value to set for the manager property.
     */
    set manager(value: string | undefined);
    /**
     * Gets the middleName property value. The middleName property
     * @returns a string
     */
    get middleName(): string | undefined;
    /**
     * Sets the middleName property value. The middleName property
     * @param value Value to set for the middleName property.
     */
    set middleName(value: string | undefined);
    /**
     * Gets the mobilePhone property value. The mobilePhone property
     * @returns a string
     */
    get mobilePhone(): string | undefined;
    /**
     * Sets the mobilePhone property value. The mobilePhone property
     * @param value Value to set for the mobilePhone property.
     */
    set mobilePhone(value: string | undefined);
    /**
     * Gets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the contact. Read-only. Nullable.
     * @returns a multiValueLegacyExtendedProperty
     */
    get multiValueExtendedProperties(): MultiValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the contact. Read-only. Nullable.
     * @param value Value to set for the multiValueExtendedProperties property.
     */
    set multiValueExtendedProperties(value: MultiValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the nickName property value. The nickName property
     * @returns a string
     */
    get nickName(): string | undefined;
    /**
     * Sets the nickName property value. The nickName property
     * @param value Value to set for the nickName property.
     */
    set nickName(value: string | undefined);
    /**
     * Gets the officeLocation property value. The officeLocation property
     * @returns a string
     */
    get officeLocation(): string | undefined;
    /**
     * Sets the officeLocation property value. The officeLocation property
     * @param value Value to set for the officeLocation property.
     */
    set officeLocation(value: string | undefined);
    /**
     * Gets the otherAddress property value. The otherAddress property
     * @returns a physicalAddress
     */
    get otherAddress(): PhysicalAddress | undefined;
    /**
     * Sets the otherAddress property value. The otherAddress property
     * @param value Value to set for the otherAddress property.
     */
    set otherAddress(value: PhysicalAddress | undefined);
    /**
     * Gets the parentFolderId property value. The parentFolderId property
     * @returns a string
     */
    get parentFolderId(): string | undefined;
    /**
     * Sets the parentFolderId property value. The parentFolderId property
     * @param value Value to set for the parentFolderId property.
     */
    set parentFolderId(value: string | undefined);
    /**
     * Gets the personalNotes property value. The personalNotes property
     * @returns a string
     */
    get personalNotes(): string | undefined;
    /**
     * Sets the personalNotes property value. The personalNotes property
     * @param value Value to set for the personalNotes property.
     */
    set personalNotes(value: string | undefined);
    /**
     * Gets the photo property value. Optional contact picture. You can get or set a photo for a contact.
     * @returns a profilePhoto
     */
    get photo(): ProfilePhoto | undefined;
    /**
     * Sets the photo property value. Optional contact picture. You can get or set a photo for a contact.
     * @param value Value to set for the photo property.
     */
    set photo(value: ProfilePhoto | undefined);
    /**
     * Gets the profession property value. The profession property
     * @returns a string
     */
    get profession(): string | undefined;
    /**
     * Sets the profession property value. The profession property
     * @param value Value to set for the profession property.
     */
    set profession(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the contact. Read-only. Nullable.
     * @returns a singleValueLegacyExtendedProperty
     */
    get singleValueExtendedProperties(): SingleValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the contact. Read-only. Nullable.
     * @param value Value to set for the singleValueExtendedProperties property.
     */
    set singleValueExtendedProperties(value: SingleValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the spouseName property value. The spouseName property
     * @returns a string
     */
    get spouseName(): string | undefined;
    /**
     * Sets the spouseName property value. The spouseName property
     * @param value Value to set for the spouseName property.
     */
    set spouseName(value: string | undefined);
    /**
     * Gets the surname property value. The surname property
     * @returns a string
     */
    get surname(): string | undefined;
    /**
     * Sets the surname property value. The surname property
     * @param value Value to set for the surname property.
     */
    set surname(value: string | undefined);
    /**
     * Gets the title property value. The title property
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. The title property
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
    /**
     * Gets the yomiCompanyName property value. The yomiCompanyName property
     * @returns a string
     */
    get yomiCompanyName(): string | undefined;
    /**
     * Sets the yomiCompanyName property value. The yomiCompanyName property
     * @param value Value to set for the yomiCompanyName property.
     */
    set yomiCompanyName(value: string | undefined);
    /**
     * Gets the yomiGivenName property value. The yomiGivenName property
     * @returns a string
     */
    get yomiGivenName(): string | undefined;
    /**
     * Sets the yomiGivenName property value. The yomiGivenName property
     * @param value Value to set for the yomiGivenName property.
     */
    set yomiGivenName(value: string | undefined);
    /**
     * Gets the yomiSurname property value. The yomiSurname property
     * @returns a string
     */
    get yomiSurname(): string | undefined;
    /**
     * Sets the yomiSurname property value. The yomiSurname property
     * @param value Value to set for the yomiSurname property.
     */
    set yomiSurname(value: string | undefined);
}
