import { ColumnDefinition, ColumnLink, ContentTypeOrder, DocumentSet, DocumentSetContent, Entity, ItemReference } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class ContentType extends Entity implements Parsable {
    /** List of canonical URLs for hub sites with which this content type is associated to. This will contain all hubsites where this content type is queued to be enforced or is already enforced. Enforcing a content type means that the content type will be applied to the lists in the enforced sites. */
    private _associatedHubsUrls?;
    /** Parent contentType from which this content type is derived. */
    private _base?;
    /** The collection of content types that are ancestors of this content type. */
    private _baseTypes?;
    /** The collection of columns that are required by this content type */
    private _columnLinks?;
    /** Column order information in a content type. */
    private _columnPositions?;
    /** The collection of column definitions for this contentType. */
    private _columns?;
    /** The descriptive text for the item. */
    private _description?;
    /** Document Set metadata. */
    private _documentSet?;
    /** Document template metadata. To make sure that documents have consistent content across a site and its subsites, you can associate a Word, Excel, or PowerPoint template with a site content type. */
    private _documentTemplate?;
    /** The name of the group this content type belongs to. Helps organize related content types. */
    private _group?;
    /** Indicates whether the content type is hidden in the list's 'New' menu. */
    private _hidden?;
    /** If this content type is inherited from another scope (like a site), provides a reference to the item where the content type is defined. */
    private _inheritedFrom?;
    /** Specifies if a content type is a built-in content type. */
    private _isBuiltIn?;
    /** The name of the content type. */
    private _name?;
    /** Specifies the order in which the content type appears in the selection UI. */
    private _order?;
    /** The unique identifier of the content type. */
    private _parentId?;
    /** If true, any changes made to the content type will be pushed to inherited content types and lists that implement the content type. */
    private _propagateChanges?;
    /** If true, the content type cannot be modified unless this value is first set to false. */
    private _readOnly?;
    /** If true, the content type cannot be modified by users or through push-down operations. Only site collection administrators can seal or unseal content types. */
    private _sealed?;
    /**
     * Gets the associatedHubsUrls property value. List of canonical URLs for hub sites with which this content type is associated to. This will contain all hubsites where this content type is queued to be enforced or is already enforced. Enforcing a content type means that the content type will be applied to the lists in the enforced sites.
     * @returns a string
     */
    get associatedHubsUrls(): string[] | undefined;
    /**
     * Sets the associatedHubsUrls property value. List of canonical URLs for hub sites with which this content type is associated to. This will contain all hubsites where this content type is queued to be enforced or is already enforced. Enforcing a content type means that the content type will be applied to the lists in the enforced sites.
     * @param value Value to set for the associatedHubsUrls property.
     */
    set associatedHubsUrls(value: string[] | undefined);
    /**
     * Gets the base property value. Parent contentType from which this content type is derived.
     * @returns a contentType
     */
    get base(): ContentType | undefined;
    /**
     * Sets the base property value. Parent contentType from which this content type is derived.
     * @param value Value to set for the base property.
     */
    set base(value: ContentType | undefined);
    /**
     * Gets the baseTypes property value. The collection of content types that are ancestors of this content type.
     * @returns a contentType
     */
    get baseTypes(): ContentType[] | undefined;
    /**
     * Sets the baseTypes property value. The collection of content types that are ancestors of this content type.
     * @param value Value to set for the baseTypes property.
     */
    set baseTypes(value: ContentType[] | undefined);
    /**
     * Gets the columnLinks property value. The collection of columns that are required by this content type
     * @returns a columnLink
     */
    get columnLinks(): ColumnLink[] | undefined;
    /**
     * Sets the columnLinks property value. The collection of columns that are required by this content type
     * @param value Value to set for the columnLinks property.
     */
    set columnLinks(value: ColumnLink[] | undefined);
    /**
     * Gets the columnPositions property value. Column order information in a content type.
     * @returns a columnDefinition
     */
    get columnPositions(): ColumnDefinition[] | undefined;
    /**
     * Sets the columnPositions property value. Column order information in a content type.
     * @param value Value to set for the columnPositions property.
     */
    set columnPositions(value: ColumnDefinition[] | undefined);
    /**
     * Gets the columns property value. The collection of column definitions for this contentType.
     * @returns a columnDefinition
     */
    get columns(): ColumnDefinition[] | undefined;
    /**
     * Sets the columns property value. The collection of column definitions for this contentType.
     * @param value Value to set for the columns property.
     */
    set columns(value: ColumnDefinition[] | undefined);
    /**
     * Instantiates a new contentType and sets the default values.
     */
    constructor();
    /**
     * Gets the description property value. The descriptive text for the item.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. The descriptive text for the item.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the documentSet property value. Document Set metadata.
     * @returns a documentSet
     */
    get documentSet(): DocumentSet | undefined;
    /**
     * Sets the documentSet property value. Document Set metadata.
     * @param value Value to set for the documentSet property.
     */
    set documentSet(value: DocumentSet | undefined);
    /**
     * Gets the documentTemplate property value. Document template metadata. To make sure that documents have consistent content across a site and its subsites, you can associate a Word, Excel, or PowerPoint template with a site content type.
     * @returns a documentSetContent
     */
    get documentTemplate(): DocumentSetContent | undefined;
    /**
     * Sets the documentTemplate property value. Document template metadata. To make sure that documents have consistent content across a site and its subsites, you can associate a Word, Excel, or PowerPoint template with a site content type.
     * @param value Value to set for the documentTemplate property.
     */
    set documentTemplate(value: DocumentSetContent | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the group property value. The name of the group this content type belongs to. Helps organize related content types.
     * @returns a string
     */
    get group(): string | undefined;
    /**
     * Sets the group property value. The name of the group this content type belongs to. Helps organize related content types.
     * @param value Value to set for the group property.
     */
    set group(value: string | undefined);
    /**
     * Gets the hidden property value. Indicates whether the content type is hidden in the list's 'New' menu.
     * @returns a boolean
     */
    get hidden(): boolean | undefined;
    /**
     * Sets the hidden property value. Indicates whether the content type is hidden in the list's 'New' menu.
     * @param value Value to set for the hidden property.
     */
    set hidden(value: boolean | undefined);
    /**
     * Gets the inheritedFrom property value. If this content type is inherited from another scope (like a site), provides a reference to the item where the content type is defined.
     * @returns a itemReference
     */
    get inheritedFrom(): ItemReference | undefined;
    /**
     * Sets the inheritedFrom property value. If this content type is inherited from another scope (like a site), provides a reference to the item where the content type is defined.
     * @param value Value to set for the inheritedFrom property.
     */
    set inheritedFrom(value: ItemReference | undefined);
    /**
     * Gets the isBuiltIn property value. Specifies if a content type is a built-in content type.
     * @returns a boolean
     */
    get isBuiltIn(): boolean | undefined;
    /**
     * Sets the isBuiltIn property value. Specifies if a content type is a built-in content type.
     * @param value Value to set for the isBuiltIn property.
     */
    set isBuiltIn(value: boolean | undefined);
    /**
     * Gets the name property value. The name of the content type.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The name of the content type.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the order property value. Specifies the order in which the content type appears in the selection UI.
     * @returns a contentTypeOrder
     */
    get order(): ContentTypeOrder | undefined;
    /**
     * Sets the order property value. Specifies the order in which the content type appears in the selection UI.
     * @param value Value to set for the order property.
     */
    set order(value: ContentTypeOrder | undefined);
    /**
     * Gets the parentId property value. The unique identifier of the content type.
     * @returns a string
     */
    get parentId(): string | undefined;
    /**
     * Sets the parentId property value. The unique identifier of the content type.
     * @param value Value to set for the parentId property.
     */
    set parentId(value: string | undefined);
    /**
     * Gets the propagateChanges property value. If true, any changes made to the content type will be pushed to inherited content types and lists that implement the content type.
     * @returns a boolean
     */
    get propagateChanges(): boolean | undefined;
    /**
     * Sets the propagateChanges property value. If true, any changes made to the content type will be pushed to inherited content types and lists that implement the content type.
     * @param value Value to set for the propagateChanges property.
     */
    set propagateChanges(value: boolean | undefined);
    /**
     * Gets the readOnly property value. If true, the content type cannot be modified unless this value is first set to false.
     * @returns a boolean
     */
    get readOnly(): boolean | undefined;
    /**
     * Sets the readOnly property value. If true, the content type cannot be modified unless this value is first set to false.
     * @param value Value to set for the readOnly property.
     */
    set readOnly(value: boolean | undefined);
    /**
     * Gets the sealed property value. If true, the content type cannot be modified by users or through push-down operations. Only site collection administrators can seal or unseal content types.
     * @returns a boolean
     */
    get sealed(): boolean | undefined;
    /**
     * Sets the sealed property value. If true, the content type cannot be modified by users or through push-down operations. Only site collection administrators can seal or unseal content types.
     * @param value Value to set for the sealed property.
     */
    set sealed(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
