import { ConversationThread, Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Conversation extends Entity implements Parsable {
    /** Indicates whether any of the posts within this Conversation has at least one attachment. Supports $filter (eq, ne) and $search. */
    private _hasAttachments?;
    /** The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, le, ge). */
    private _lastDeliveredDateTime?;
    /** A short summary from the body of the latest post in this conversation. */
    private _preview?;
    /** A collection of all the conversation threads in the conversation. A navigation property. Read-only. Nullable. */
    private _threads?;
    /** The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated. */
    private _topic?;
    /** All the users that sent a message to this Conversation. */
    private _uniqueSenders?;
    /**
     * Instantiates a new conversation and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the hasAttachments property value. Indicates whether any of the posts within this Conversation has at least one attachment. Supports $filter (eq, ne) and $search.
     * @returns a boolean
     */
    get hasAttachments(): boolean | undefined;
    /**
     * Sets the hasAttachments property value. Indicates whether any of the posts within this Conversation has at least one attachment. Supports $filter (eq, ne) and $search.
     * @param value Value to set for the hasAttachments property.
     */
    set hasAttachments(value: boolean | undefined);
    /**
     * Gets the lastDeliveredDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, le, ge).
     * @returns a Date
     */
    get lastDeliveredDateTime(): Date | undefined;
    /**
     * Sets the lastDeliveredDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $filter (eq, ne, le, ge).
     * @param value Value to set for the lastDeliveredDateTime property.
     */
    set lastDeliveredDateTime(value: Date | undefined);
    /**
     * Gets the preview property value. A short summary from the body of the latest post in this conversation.
     * @returns a string
     */
    get preview(): string | undefined;
    /**
     * Sets the preview property value. A short summary from the body of the latest post in this conversation.
     * @param value Value to set for the preview property.
     */
    set preview(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the threads property value. A collection of all the conversation threads in the conversation. A navigation property. Read-only. Nullable.
     * @returns a conversationThread
     */
    get threads(): ConversationThread[] | undefined;
    /**
     * Sets the threads property value. A collection of all the conversation threads in the conversation. A navigation property. Read-only. Nullable.
     * @param value Value to set for the threads property.
     */
    set threads(value: ConversationThread[] | undefined);
    /**
     * Gets the topic property value. The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated.
     * @returns a string
     */
    get topic(): string | undefined;
    /**
     * Sets the topic property value. The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated.
     * @param value Value to set for the topic property.
     */
    set topic(value: string | undefined);
    /**
     * Gets the uniqueSenders property value. All the users that sent a message to this Conversation.
     * @returns a string
     */
    get uniqueSenders(): string[] | undefined;
    /**
     * Sets the uniqueSenders property value. All the users that sent a message to this Conversation.
     * @param value Value to set for the uniqueSenders property.
     */
    set uniqueSenders(value: string[] | undefined);
}
