import { Entity, Post, Recipient } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class ConversationThread extends Entity implements Parsable {
    /** The Cc: recipients for the thread. Returned only on $select. */
    private _ccRecipients?;
    /** Indicates whether any of the posts within this thread has at least one attachment. Returned by default. */
    private _hasAttachments?;
    /** Indicates if the thread is locked. Returned by default. */
    private _isLocked?;
    /** The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Returned by default. */
    private _lastDeliveredDateTime?;
    /** Read-only. Nullable. */
    private _posts?;
    /** A short summary from the body of the latest post in this conversation. Returned by default. */
    private _preview?;
    /** The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated. Returned by default. */
    private _topic?;
    /** The To: recipients for the thread. Returned only on $select. */
    private _toRecipients?;
    /** All the users that sent a message to this thread. Returned by default. */
    private _uniqueSenders?;
    /**
     * Gets the ccRecipients property value. The Cc: recipients for the thread. Returned only on $select.
     * @returns a recipient
     */
    get ccRecipients(): Recipient[] | undefined;
    /**
     * Sets the ccRecipients property value. The Cc: recipients for the thread. Returned only on $select.
     * @param value Value to set for the ccRecipients property.
     */
    set ccRecipients(value: Recipient[] | undefined);
    /**
     * Instantiates a new conversationThread and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the hasAttachments property value. Indicates whether any of the posts within this thread has at least one attachment. Returned by default.
     * @returns a boolean
     */
    get hasAttachments(): boolean | undefined;
    /**
     * Sets the hasAttachments property value. Indicates whether any of the posts within this thread has at least one attachment. Returned by default.
     * @param value Value to set for the hasAttachments property.
     */
    set hasAttachments(value: boolean | undefined);
    /**
     * Gets the isLocked property value. Indicates if the thread is locked. Returned by default.
     * @returns a boolean
     */
    get isLocked(): boolean | undefined;
    /**
     * Sets the isLocked property value. Indicates if the thread is locked. Returned by default.
     * @param value Value to set for the isLocked property.
     */
    set isLocked(value: boolean | undefined);
    /**
     * Gets the lastDeliveredDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Returned by default.
     * @returns a Date
     */
    get lastDeliveredDateTime(): Date | undefined;
    /**
     * Sets the lastDeliveredDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Returned by default.
     * @param value Value to set for the lastDeliveredDateTime property.
     */
    set lastDeliveredDateTime(value: Date | undefined);
    /**
     * Gets the posts property value. Read-only. Nullable.
     * @returns a post
     */
    get posts(): Post[] | undefined;
    /**
     * Sets the posts property value. Read-only. Nullable.
     * @param value Value to set for the posts property.
     */
    set posts(value: Post[] | undefined);
    /**
     * Gets the preview property value. A short summary from the body of the latest post in this conversation. Returned by default.
     * @returns a string
     */
    get preview(): string | undefined;
    /**
     * Sets the preview property value. A short summary from the body of the latest post in this conversation. Returned by default.
     * @param value Value to set for the preview property.
     */
    set preview(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the topic property value. The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated. Returned by default.
     * @returns a string
     */
    get topic(): string | undefined;
    /**
     * Sets the topic property value. The topic of the conversation. This property can be set when the conversation is created, but it cannot be updated. Returned by default.
     * @param value Value to set for the topic property.
     */
    set topic(value: string | undefined);
    /**
     * Gets the toRecipients property value. The To: recipients for the thread. Returned only on $select.
     * @returns a recipient
     */
    get toRecipients(): Recipient[] | undefined;
    /**
     * Sets the toRecipients property value. The To: recipients for the thread. Returned only on $select.
     * @param value Value to set for the toRecipients property.
     */
    set toRecipients(value: Recipient[] | undefined);
    /**
     * Gets the uniqueSenders property value. All the users that sent a message to this thread. Returned by default.
     * @returns a string
     */
    get uniqueSenders(): string[] | undefined;
    /**
     * Sets the uniqueSenders property value. All the users that sent a message to this thread. Returned by default.
     * @param value Value to set for the uniqueSenders property.
     */
    set uniqueSenders(value: string[] | undefined);
}
