"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultManagedAppProtection = void 0;
const createKeyValuePairFromDiscriminatorValue_1 = require("./createKeyValuePairFromDiscriminatorValue");
const createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue_1 = require("./createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue");
const createManagedMobileAppFromDiscriminatorValue_1 = require("./createManagedMobileAppFromDiscriminatorValue");
const index_1 = require("./index");
const managedAppDataEncryptionType_1 = require("./managedAppDataEncryptionType");
/** Policy used to configure detailed management settings for a specified set of apps for all users not targeted by a TargetedManagedAppProtection Policy */
class DefaultManagedAppProtection extends index_1.ManagedAppProtection {
    /**
     * Instantiates a new defaultManagedAppProtection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. (iOS Only). Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @returns a managedAppDataEncryptionType
     */
    get appDataEncryptionType() {
        return this._appDataEncryptionType;
    }
    ;
    /**
     * Sets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. (iOS Only). Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @param value Value to set for the appDataEncryptionType property.
     */
    set appDataEncryptionType(value) {
        this._appDataEncryptionType = value;
    }
    ;
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps() {
        return this._apps;
    }
    ;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value) {
        this._apps = value;
    }
    ;
    ;
    /**
     * Gets the customSettings property value. A set of string key and string value pairs to be sent to the affected users, unalterned by this service
     * @returns a keyValuePair
     */
    get customSettings() {
        return this._customSettings;
    }
    ;
    /**
     * Sets the customSettings property value. A set of string key and string value pairs to be sent to the affected users, unalterned by this service
     * @param value Value to set for the customSettings property.
     */
    set customSettings(value) {
        this._customSettings = value;
    }
    ;
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount() {
        return this._deployedAppCount;
    }
    ;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value) {
        this._deployedAppCount = value;
    }
    ;
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary() {
        return this._deploymentSummary;
    }
    ;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value) {
        this._deploymentSummary = value;
    }
    ;
    /**
     * Gets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled. (Android only)
     * @returns a boolean
     */
    get disableAppEncryptionIfDeviceEncryptionIsEnabled() {
        return this._disableAppEncryptionIfDeviceEncryptionIsEnabled;
    }
    ;
    /**
     * Sets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled. (Android only)
     * @param value Value to set for the disableAppEncryptionIfDeviceEncryptionIsEnabled property.
     */
    set disableAppEncryptionIfDeviceEncryptionIsEnabled(value) {
        this._disableAppEncryptionIfDeviceEncryptionIsEnabled = value;
    }
    ;
    /**
     * Gets the encryptAppData property value. Indicates whether managed-app data should be encrypted. (Android only)
     * @returns a boolean
     */
    get encryptAppData() {
        return this._encryptAppData;
    }
    ;
    /**
     * Sets the encryptAppData property value. Indicates whether managed-app data should be encrypted. (Android only)
     * @param value Value to set for the encryptAppData property.
     */
    set encryptAppData(value) {
        this._encryptAppData = value;
    }
    ;
    /**
     * Gets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. (iOS Only)
     * @returns a boolean
     */
    get faceIdBlocked() {
        return this._faceIdBlocked;
    }
    ;
    /**
     * Sets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. (iOS Only)
     * @param value Value to set for the faceIdBlocked property.
     */
    set faceIdBlocked(value) {
        this._faceIdBlocked = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appDataEncryptionType": n => { this.appDataEncryptionType = n.getEnumValue(managedAppDataEncryptionType_1.ManagedAppDataEncryptionType); }, "apps": n => { this.apps = n.getCollectionOfObjectValues(createManagedMobileAppFromDiscriminatorValue_1.createManagedMobileAppFromDiscriminatorValue); }, "customSettings": n => { this.customSettings = n.getCollectionOfObjectValues(createKeyValuePairFromDiscriminatorValue_1.createKeyValuePairFromDiscriminatorValue); }, "deployedAppCount": n => { this.deployedAppCount = n.getNumberValue(); }, "deploymentSummary": n => { this.deploymentSummary = n.getObjectValue(createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue_1.createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue); }, "disableAppEncryptionIfDeviceEncryptionIsEnabled": n => { this.disableAppEncryptionIfDeviceEncryptionIsEnabled = n.getBooleanValue(); }, "encryptAppData": n => { this.encryptAppData = n.getBooleanValue(); }, "faceIdBlocked": n => { this.faceIdBlocked = n.getBooleanValue(); }, "minimumRequiredPatchVersion": n => { this.minimumRequiredPatchVersion = n.getStringValue(); }, "minimumRequiredSdkVersion": n => { this.minimumRequiredSdkVersion = n.getStringValue(); }, "minimumWarningPatchVersion": n => { this.minimumWarningPatchVersion = n.getStringValue(); }, "screenCaptureBlocked": n => { this.screenCaptureBlocked = n.getBooleanValue(); } });
    }
    ;
    /**
     * Gets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app. (Android only)
     * @returns a string
     */
    get minimumRequiredPatchVersion() {
        return this._minimumRequiredPatchVersion;
    }
    ;
    /**
     * Sets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app. (Android only)
     * @param value Value to set for the minimumRequiredPatchVersion property.
     */
    set minimumRequiredPatchVersion(value) {
        this._minimumRequiredPatchVersion = value;
    }
    ;
    /**
     * Gets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data. (iOS Only)
     * @returns a string
     */
    get minimumRequiredSdkVersion() {
        return this._minimumRequiredSdkVersion;
    }
    ;
    /**
     * Sets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data. (iOS Only)
     * @param value Value to set for the minimumRequiredSdkVersion property.
     */
    set minimumRequiredSdkVersion(value) {
        this._minimumRequiredSdkVersion = value;
    }
    ;
    /**
     * Gets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app. (Android only)
     * @returns a string
     */
    get minimumWarningPatchVersion() {
        return this._minimumWarningPatchVersion;
    }
    ;
    /**
     * Sets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app. (Android only)
     * @param value Value to set for the minimumWarningPatchVersion property.
     */
    set minimumWarningPatchVersion(value) {
        this._minimumWarningPatchVersion = value;
    }
    ;
    /**
     * Gets the screenCaptureBlocked property value. Indicates whether screen capture is blocked. (Android only)
     * @returns a boolean
     */
    get screenCaptureBlocked() {
        return this._screenCaptureBlocked;
    }
    ;
    /**
     * Sets the screenCaptureBlocked property value. Indicates whether screen capture is blocked. (Android only)
     * @param value Value to set for the screenCaptureBlocked property.
     */
    set screenCaptureBlocked(value) {
        this._screenCaptureBlocked = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("appDataEncryptionType", this.appDataEncryptionType);
        writer.writeCollectionOfObjectValues("apps", this.apps);
        writer.writeCollectionOfObjectValues("customSettings", this.customSettings);
        writer.writeNumberValue("deployedAppCount", this.deployedAppCount);
        writer.writeObjectValue("deploymentSummary", this.deploymentSummary);
        writer.writeBooleanValue("disableAppEncryptionIfDeviceEncryptionIsEnabled", this.disableAppEncryptionIfDeviceEncryptionIsEnabled);
        writer.writeBooleanValue("encryptAppData", this.encryptAppData);
        writer.writeBooleanValue("faceIdBlocked", this.faceIdBlocked);
        writer.writeStringValue("minimumRequiredPatchVersion", this.minimumRequiredPatchVersion);
        writer.writeStringValue("minimumRequiredSdkVersion", this.minimumRequiredSdkVersion);
        writer.writeStringValue("minimumWarningPatchVersion", this.minimumWarningPatchVersion);
        writer.writeBooleanValue("screenCaptureBlocked", this.screenCaptureBlocked);
    }
    ;
}
exports.DefaultManagedAppProtection = DefaultManagedAppProtection;
