import { DeviceComplianceDeviceOverview, DeviceComplianceDeviceStatus, DeviceCompliancePolicyAssignment, DeviceComplianceScheduledActionForRule, DeviceComplianceUserOverview, DeviceComplianceUserStatus, Entity, SettingStateDeviceSummary } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** This is the base class for Compliance policy. Compliance policies are platform specific and individual per-platform compliance policies inherit from here.  */
export declare class DeviceCompliancePolicy extends Entity implements Parsable {
    /** The collection of assignments for this compliance policy. */
    private _assignments?;
    /** DateTime the object was created. */
    private _createdDateTime?;
    /** Admin provided description of the Device Configuration. */
    private _description?;
    /** Compliance Setting State Device Summary */
    private _deviceSettingStateSummaries?;
    /** List of DeviceComplianceDeviceStatus. */
    private _deviceStatuses?;
    /** Device compliance devices status overview */
    private _deviceStatusOverview?;
    /** Admin provided name of the device configuration. */
    private _displayName?;
    /** DateTime the object was last modified. */
    private _lastModifiedDateTime?;
    /** The list of scheduled action for this rule */
    private _scheduledActionsForRule?;
    /** List of DeviceComplianceUserStatus. */
    private _userStatuses?;
    /** Device compliance users status overview */
    private _userStatusOverview?;
    /** Version of the device configuration. */
    private _version?;
    /**
     * Gets the assignments property value. The collection of assignments for this compliance policy.
     * @returns a deviceCompliancePolicyAssignment
     */
    get assignments(): DeviceCompliancePolicyAssignment[] | undefined;
    /**
     * Sets the assignments property value. The collection of assignments for this compliance policy.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: DeviceCompliancePolicyAssignment[] | undefined);
    /**
     * Instantiates a new deviceCompliancePolicy and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. DateTime the object was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. DateTime the object was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. Admin provided description of the Device Configuration.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Admin provided description of the Device Configuration.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the deviceSettingStateSummaries property value. Compliance Setting State Device Summary
     * @returns a settingStateDeviceSummary
     */
    get deviceSettingStateSummaries(): SettingStateDeviceSummary[] | undefined;
    /**
     * Sets the deviceSettingStateSummaries property value. Compliance Setting State Device Summary
     * @param value Value to set for the deviceSettingStateSummaries property.
     */
    set deviceSettingStateSummaries(value: SettingStateDeviceSummary[] | undefined);
    /**
     * Gets the deviceStatuses property value. List of DeviceComplianceDeviceStatus.
     * @returns a deviceComplianceDeviceStatus
     */
    get deviceStatuses(): DeviceComplianceDeviceStatus[] | undefined;
    /**
     * Sets the deviceStatuses property value. List of DeviceComplianceDeviceStatus.
     * @param value Value to set for the deviceStatuses property.
     */
    set deviceStatuses(value: DeviceComplianceDeviceStatus[] | undefined);
    /**
     * Gets the deviceStatusOverview property value. Device compliance devices status overview
     * @returns a deviceComplianceDeviceOverview
     */
    get deviceStatusOverview(): DeviceComplianceDeviceOverview | undefined;
    /**
     * Sets the deviceStatusOverview property value. Device compliance devices status overview
     * @param value Value to set for the deviceStatusOverview property.
     */
    set deviceStatusOverview(value: DeviceComplianceDeviceOverview | undefined);
    /**
     * Gets the displayName property value. Admin provided name of the device configuration.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Admin provided name of the device configuration.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the scheduledActionsForRule property value. The list of scheduled action for this rule
     * @returns a deviceComplianceScheduledActionForRule
     */
    get scheduledActionsForRule(): DeviceComplianceScheduledActionForRule[] | undefined;
    /**
     * Sets the scheduledActionsForRule property value. The list of scheduled action for this rule
     * @param value Value to set for the scheduledActionsForRule property.
     */
    set scheduledActionsForRule(value: DeviceComplianceScheduledActionForRule[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the userStatuses property value. List of DeviceComplianceUserStatus.
     * @returns a deviceComplianceUserStatus
     */
    get userStatuses(): DeviceComplianceUserStatus[] | undefined;
    /**
     * Sets the userStatuses property value. List of DeviceComplianceUserStatus.
     * @param value Value to set for the userStatuses property.
     */
    set userStatuses(value: DeviceComplianceUserStatus[] | undefined);
    /**
     * Gets the userStatusOverview property value. Device compliance users status overview
     * @returns a deviceComplianceUserOverview
     */
    get userStatusOverview(): DeviceComplianceUserOverview | undefined;
    /**
     * Sets the userStatusOverview property value. Device compliance users status overview
     * @param value Value to set for the userStatusOverview property.
     */
    set userStatusOverview(value: DeviceComplianceUserOverview | undefined);
    /**
     * Gets the version property value. Version of the device configuration.
     * @returns a integer
     */
    get version(): number | undefined;
    /**
     * Sets the version property value. Version of the device configuration.
     * @param value Value to set for the version property.
     */
    set version(value: number | undefined);
}
