import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DeviceHealthAttestationState implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** TWhen an Attestation Identity Key (AIK) is present on a device, it indicates that the device has an endorsement key (EK) certificate. */
    private _attestationIdentityKey?;
    /** On or Off of BitLocker Drive Encryption */
    private _bitLockerStatus?;
    /** The security version number of the Boot Application */
    private _bootAppSecurityVersion?;
    /** When bootDebugging is enabled, the device is used in development and testing */
    private _bootDebugging?;
    /** The security version number of the Boot Application */
    private _bootManagerSecurityVersion?;
    /** The version of the Boot Manager */
    private _bootManagerVersion?;
    /** The Boot Revision List that was loaded during initial boot on the attested device */
    private _bootRevisionListInfo?;
    /** When code integrity is enabled, code execution is restricted to integrity verified code */
    private _codeIntegrity?;
    /** The version of the Boot Manager */
    private _codeIntegrityCheckVersion?;
    /** The Code Integrity policy that is controlling the security of the boot environment */
    private _codeIntegrityPolicy?;
    /** The DHA report version. (Namespace version) */
    private _contentNamespaceUrl?;
    /** The HealthAttestation state schema version */
    private _contentVersion?;
    /** DEP Policy defines a set of hardware and software technologies that perform additional checks on memory */
    private _dataExcutionPolicy?;
    /** The DHA report version. (Namespace version) */
    private _deviceHealthAttestationStatus?;
    /** ELAM provides protection for the computers in your network when they start up */
    private _earlyLaunchAntiMalwareDriverProtection?;
    /** This attribute indicates if DHA is supported for the device */
    private _healthAttestationSupportedStatus?;
    /** This attribute appears if DHA-Service detects an integrity issue */
    private _healthStatusMismatchInfo?;
    /** The DateTime when device was evaluated or issued to MDM */
    private _issuedDateTime?;
    /** The Timestamp of the last update. */
    private _lastUpdateDateTime?;
    /** When operatingSystemKernelDebugging is enabled, the device is used in development and testing */
    private _operatingSystemKernelDebugging?;
    /** The Operating System Revision List that was loaded during initial boot on the attested device */
    private _operatingSystemRevListInfo?;
    /** The measurement that is captured in PCR[0] */
    private _pcr0?;
    /** Informational attribute that identifies the HASH algorithm that was used by TPM */
    private _pcrHashAlgorithm?;
    /** The number of times a PC device has hibernated or resumed */
    private _resetCount?;
    /** The number of times a PC device has rebooted */
    private _restartCount?;
    /** Safe mode is a troubleshooting option for Windows that starts your computer in a limited state */
    private _safeMode?;
    /** When Secure Boot is enabled, the core components must have the correct cryptographic signatures */
    private _secureBoot?;
    /** Fingerprint of the Custom Secure Boot Configuration Policy */
    private _secureBootConfigurationPolicyFingerPrint?;
    /** When test signing is allowed, the device does not enforce signature validation during boot */
    private _testSigning?;
    /** The security version number of the Boot Application */
    private _tpmVersion?;
    /** VSM is a container that protects high value assets from a compromised kernel */
    private _virtualSecureMode?;
    /** Operating system running with limited services that is used to prepare a computer for Windows */
    private _windowsPE?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the attestationIdentityKey property value. TWhen an Attestation Identity Key (AIK) is present on a device, it indicates that the device has an endorsement key (EK) certificate.
     * @returns a string
     */
    get attestationIdentityKey(): string | undefined;
    /**
     * Sets the attestationIdentityKey property value. TWhen an Attestation Identity Key (AIK) is present on a device, it indicates that the device has an endorsement key (EK) certificate.
     * @param value Value to set for the attestationIdentityKey property.
     */
    set attestationIdentityKey(value: string | undefined);
    /**
     * Gets the bitLockerStatus property value. On or Off of BitLocker Drive Encryption
     * @returns a string
     */
    get bitLockerStatus(): string | undefined;
    /**
     * Sets the bitLockerStatus property value. On or Off of BitLocker Drive Encryption
     * @param value Value to set for the bitLockerStatus property.
     */
    set bitLockerStatus(value: string | undefined);
    /**
     * Gets the bootAppSecurityVersion property value. The security version number of the Boot Application
     * @returns a string
     */
    get bootAppSecurityVersion(): string | undefined;
    /**
     * Sets the bootAppSecurityVersion property value. The security version number of the Boot Application
     * @param value Value to set for the bootAppSecurityVersion property.
     */
    set bootAppSecurityVersion(value: string | undefined);
    /**
     * Gets the bootDebugging property value. When bootDebugging is enabled, the device is used in development and testing
     * @returns a string
     */
    get bootDebugging(): string | undefined;
    /**
     * Sets the bootDebugging property value. When bootDebugging is enabled, the device is used in development and testing
     * @param value Value to set for the bootDebugging property.
     */
    set bootDebugging(value: string | undefined);
    /**
     * Gets the bootManagerSecurityVersion property value. The security version number of the Boot Application
     * @returns a string
     */
    get bootManagerSecurityVersion(): string | undefined;
    /**
     * Sets the bootManagerSecurityVersion property value. The security version number of the Boot Application
     * @param value Value to set for the bootManagerSecurityVersion property.
     */
    set bootManagerSecurityVersion(value: string | undefined);
    /**
     * Gets the bootManagerVersion property value. The version of the Boot Manager
     * @returns a string
     */
    get bootManagerVersion(): string | undefined;
    /**
     * Sets the bootManagerVersion property value. The version of the Boot Manager
     * @param value Value to set for the bootManagerVersion property.
     */
    set bootManagerVersion(value: string | undefined);
    /**
     * Gets the bootRevisionListInfo property value. The Boot Revision List that was loaded during initial boot on the attested device
     * @returns a string
     */
    get bootRevisionListInfo(): string | undefined;
    /**
     * Sets the bootRevisionListInfo property value. The Boot Revision List that was loaded during initial boot on the attested device
     * @param value Value to set for the bootRevisionListInfo property.
     */
    set bootRevisionListInfo(value: string | undefined);
    /**
     * Gets the codeIntegrity property value. When code integrity is enabled, code execution is restricted to integrity verified code
     * @returns a string
     */
    get codeIntegrity(): string | undefined;
    /**
     * Sets the codeIntegrity property value. When code integrity is enabled, code execution is restricted to integrity verified code
     * @param value Value to set for the codeIntegrity property.
     */
    set codeIntegrity(value: string | undefined);
    /**
     * Gets the codeIntegrityCheckVersion property value. The version of the Boot Manager
     * @returns a string
     */
    get codeIntegrityCheckVersion(): string | undefined;
    /**
     * Sets the codeIntegrityCheckVersion property value. The version of the Boot Manager
     * @param value Value to set for the codeIntegrityCheckVersion property.
     */
    set codeIntegrityCheckVersion(value: string | undefined);
    /**
     * Gets the codeIntegrityPolicy property value. The Code Integrity policy that is controlling the security of the boot environment
     * @returns a string
     */
    get codeIntegrityPolicy(): string | undefined;
    /**
     * Sets the codeIntegrityPolicy property value. The Code Integrity policy that is controlling the security of the boot environment
     * @param value Value to set for the codeIntegrityPolicy property.
     */
    set codeIntegrityPolicy(value: string | undefined);
    /**
     * Instantiates a new deviceHealthAttestationState and sets the default values.
     */
    constructor();
    /**
     * Gets the contentNamespaceUrl property value. The DHA report version. (Namespace version)
     * @returns a string
     */
    get contentNamespaceUrl(): string | undefined;
    /**
     * Sets the contentNamespaceUrl property value. The DHA report version. (Namespace version)
     * @param value Value to set for the contentNamespaceUrl property.
     */
    set contentNamespaceUrl(value: string | undefined);
    /**
     * Gets the contentVersion property value. The HealthAttestation state schema version
     * @returns a string
     */
    get contentVersion(): string | undefined;
    /**
     * Sets the contentVersion property value. The HealthAttestation state schema version
     * @param value Value to set for the contentVersion property.
     */
    set contentVersion(value: string | undefined);
    /**
     * Gets the dataExcutionPolicy property value. DEP Policy defines a set of hardware and software technologies that perform additional checks on memory
     * @returns a string
     */
    get dataExcutionPolicy(): string | undefined;
    /**
     * Sets the dataExcutionPolicy property value. DEP Policy defines a set of hardware and software technologies that perform additional checks on memory
     * @param value Value to set for the dataExcutionPolicy property.
     */
    set dataExcutionPolicy(value: string | undefined);
    /**
     * Gets the deviceHealthAttestationStatus property value. The DHA report version. (Namespace version)
     * @returns a string
     */
    get deviceHealthAttestationStatus(): string | undefined;
    /**
     * Sets the deviceHealthAttestationStatus property value. The DHA report version. (Namespace version)
     * @param value Value to set for the deviceHealthAttestationStatus property.
     */
    set deviceHealthAttestationStatus(value: string | undefined);
    /**
     * Gets the earlyLaunchAntiMalwareDriverProtection property value. ELAM provides protection for the computers in your network when they start up
     * @returns a string
     */
    get earlyLaunchAntiMalwareDriverProtection(): string | undefined;
    /**
     * Sets the earlyLaunchAntiMalwareDriverProtection property value. ELAM provides protection for the computers in your network when they start up
     * @param value Value to set for the earlyLaunchAntiMalwareDriverProtection property.
     */
    set earlyLaunchAntiMalwareDriverProtection(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the healthAttestationSupportedStatus property value. This attribute indicates if DHA is supported for the device
     * @returns a string
     */
    get healthAttestationSupportedStatus(): string | undefined;
    /**
     * Sets the healthAttestationSupportedStatus property value. This attribute indicates if DHA is supported for the device
     * @param value Value to set for the healthAttestationSupportedStatus property.
     */
    set healthAttestationSupportedStatus(value: string | undefined);
    /**
     * Gets the healthStatusMismatchInfo property value. This attribute appears if DHA-Service detects an integrity issue
     * @returns a string
     */
    get healthStatusMismatchInfo(): string | undefined;
    /**
     * Sets the healthStatusMismatchInfo property value. This attribute appears if DHA-Service detects an integrity issue
     * @param value Value to set for the healthStatusMismatchInfo property.
     */
    set healthStatusMismatchInfo(value: string | undefined);
    /**
     * Gets the issuedDateTime property value. The DateTime when device was evaluated or issued to MDM
     * @returns a Date
     */
    get issuedDateTime(): Date | undefined;
    /**
     * Sets the issuedDateTime property value. The DateTime when device was evaluated or issued to MDM
     * @param value Value to set for the issuedDateTime property.
     */
    set issuedDateTime(value: Date | undefined);
    /**
     * Gets the lastUpdateDateTime property value. The Timestamp of the last update.
     * @returns a string
     */
    get lastUpdateDateTime(): string | undefined;
    /**
     * Sets the lastUpdateDateTime property value. The Timestamp of the last update.
     * @param value Value to set for the lastUpdateDateTime property.
     */
    set lastUpdateDateTime(value: string | undefined);
    /**
     * Gets the operatingSystemKernelDebugging property value. When operatingSystemKernelDebugging is enabled, the device is used in development and testing
     * @returns a string
     */
    get operatingSystemKernelDebugging(): string | undefined;
    /**
     * Sets the operatingSystemKernelDebugging property value. When operatingSystemKernelDebugging is enabled, the device is used in development and testing
     * @param value Value to set for the operatingSystemKernelDebugging property.
     */
    set operatingSystemKernelDebugging(value: string | undefined);
    /**
     * Gets the operatingSystemRevListInfo property value. The Operating System Revision List that was loaded during initial boot on the attested device
     * @returns a string
     */
    get operatingSystemRevListInfo(): string | undefined;
    /**
     * Sets the operatingSystemRevListInfo property value. The Operating System Revision List that was loaded during initial boot on the attested device
     * @param value Value to set for the operatingSystemRevListInfo property.
     */
    set operatingSystemRevListInfo(value: string | undefined);
    /**
     * Gets the pcr0 property value. The measurement that is captured in PCR[0]
     * @returns a string
     */
    get pcr0(): string | undefined;
    /**
     * Sets the pcr0 property value. The measurement that is captured in PCR[0]
     * @param value Value to set for the pcr0 property.
     */
    set pcr0(value: string | undefined);
    /**
     * Gets the pcrHashAlgorithm property value. Informational attribute that identifies the HASH algorithm that was used by TPM
     * @returns a string
     */
    get pcrHashAlgorithm(): string | undefined;
    /**
     * Sets the pcrHashAlgorithm property value. Informational attribute that identifies the HASH algorithm that was used by TPM
     * @param value Value to set for the pcrHashAlgorithm property.
     */
    set pcrHashAlgorithm(value: string | undefined);
    /**
     * Gets the resetCount property value. The number of times a PC device has hibernated or resumed
     * @returns a int64
     */
    get resetCount(): number | undefined;
    /**
     * Sets the resetCount property value. The number of times a PC device has hibernated or resumed
     * @param value Value to set for the resetCount property.
     */
    set resetCount(value: number | undefined);
    /**
     * Gets the restartCount property value. The number of times a PC device has rebooted
     * @returns a int64
     */
    get restartCount(): number | undefined;
    /**
     * Sets the restartCount property value. The number of times a PC device has rebooted
     * @param value Value to set for the restartCount property.
     */
    set restartCount(value: number | undefined);
    /**
     * Gets the safeMode property value. Safe mode is a troubleshooting option for Windows that starts your computer in a limited state
     * @returns a string
     */
    get safeMode(): string | undefined;
    /**
     * Sets the safeMode property value. Safe mode is a troubleshooting option for Windows that starts your computer in a limited state
     * @param value Value to set for the safeMode property.
     */
    set safeMode(value: string | undefined);
    /**
     * Gets the secureBoot property value. When Secure Boot is enabled, the core components must have the correct cryptographic signatures
     * @returns a string
     */
    get secureBoot(): string | undefined;
    /**
     * Sets the secureBoot property value. When Secure Boot is enabled, the core components must have the correct cryptographic signatures
     * @param value Value to set for the secureBoot property.
     */
    set secureBoot(value: string | undefined);
    /**
     * Gets the secureBootConfigurationPolicyFingerPrint property value. Fingerprint of the Custom Secure Boot Configuration Policy
     * @returns a string
     */
    get secureBootConfigurationPolicyFingerPrint(): string | undefined;
    /**
     * Sets the secureBootConfigurationPolicyFingerPrint property value. Fingerprint of the Custom Secure Boot Configuration Policy
     * @param value Value to set for the secureBootConfigurationPolicyFingerPrint property.
     */
    set secureBootConfigurationPolicyFingerPrint(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the testSigning property value. When test signing is allowed, the device does not enforce signature validation during boot
     * @returns a string
     */
    get testSigning(): string | undefined;
    /**
     * Sets the testSigning property value. When test signing is allowed, the device does not enforce signature validation during boot
     * @param value Value to set for the testSigning property.
     */
    set testSigning(value: string | undefined);
    /**
     * Gets the tpmVersion property value. The security version number of the Boot Application
     * @returns a string
     */
    get tpmVersion(): string | undefined;
    /**
     * Sets the tpmVersion property value. The security version number of the Boot Application
     * @param value Value to set for the tpmVersion property.
     */
    set tpmVersion(value: string | undefined);
    /**
     * Gets the virtualSecureMode property value. VSM is a container that protects high value assets from a compromised kernel
     * @returns a string
     */
    get virtualSecureMode(): string | undefined;
    /**
     * Sets the virtualSecureMode property value. VSM is a container that protects high value assets from a compromised kernel
     * @param value Value to set for the virtualSecureMode property.
     */
    set virtualSecureMode(value: string | undefined);
    /**
     * Gets the windowsPE property value. Operating system running with limited services that is used to prepare a computer for Windows
     * @returns a string
     */
    get windowsPE(): string | undefined;
    /**
     * Sets the windowsPE property value. Operating system running with limited services that is used to prepare a computer for Windows
     * @param value Value to set for the windowsPE property.
     */
    set windowsPE(value: string | undefined);
}
