import { DeviceManagementSubscriptionState } from './deviceManagementSubscriptionState';
import { ApplePushNotificationCertificate, ComplianceManagementPartner, DetectedApp, DeviceAndAppManagementRoleAssignment, DeviceCategory, DeviceCompliancePolicy, DeviceCompliancePolicyDeviceStateSummary, DeviceCompliancePolicySettingStateSummary, DeviceConfiguration, DeviceConfigurationDeviceStateSummary, DeviceEnrollmentConfiguration, DeviceManagementExchangeConnector, DeviceManagementPartner, DeviceManagementReports, DeviceManagementSettings, DeviceManagementTroubleshootingEvent, Entity, ImportedWindowsAutopilotDeviceIdentity, IntuneBrand, IosUpdateDeviceStatus, ManagedDevice, ManagedDeviceOverview, MobileThreatDefenseConnector, NotificationMessageTemplate, OnPremisesConditionalAccessSettings, RemoteAssistancePartner, ResourceOperation, RoleDefinition, SoftwareUpdateStatusSummary, TelecomExpenseManagementPartner, TermsAndConditions, WindowsAutopilotDeviceIdentity, WindowsInformationProtectionAppLearningSummary, WindowsInformationProtectionNetworkLearningSummary } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Singleton entity that acts as a container for all device management functionality. */
export declare class DeviceManagement extends Entity implements Parsable {
    /** Apple push notification certificate. */
    private _applePushNotificationCertificate?;
    /** The list of Compliance Management Partners configured by the tenant. */
    private _complianceManagementPartners?;
    /** The Exchange on premises conditional access settings. On premises conditional access will require devices to be both enrolled and compliant for mail access */
    private _conditionalAccessSettings?;
    /** The list of detected apps associated with a device. */
    private _detectedApps?;
    /** The list of device categories with the tenant. */
    private _deviceCategories?;
    /** The device compliance policies. */
    private _deviceCompliancePolicies?;
    /** The device compliance state summary for this account. */
    private _deviceCompliancePolicyDeviceStateSummary?;
    /** The summary states of compliance policy settings for this account. */
    private _deviceCompliancePolicySettingStateSummaries?;
    /** The device configuration device state summary for this account. */
    private _deviceConfigurationDeviceStateSummaries?;
    /** The device configurations. */
    private _deviceConfigurations?;
    /** The list of device enrollment configurations */
    private _deviceEnrollmentConfigurations?;
    /** The list of Device Management Partners configured by the tenant. */
    private _deviceManagementPartners?;
    /** The list of Exchange Connectors configured by the tenant. */
    private _exchangeConnectors?;
    /** Collection of imported Windows autopilot devices. */
    private _importedWindowsAutopilotDeviceIdentities?;
    /** Intune Account ID for given tenant */
    private _intuneAccountId?;
    /** intuneBrand contains data which is used in customizing the appearance of the Company Portal applications as well as the end user web portal. */
    private _intuneBrand?;
    /** The IOS software update installation statuses for this account. */
    private _iosUpdateStatuses?;
    /** Device overview */
    private _managedDeviceOverview?;
    /** The list of managed devices. */
    private _managedDevices?;
    /** The list of Mobile threat Defense connectors configured by the tenant. */
    private _mobileThreatDefenseConnectors?;
    /** The Notification Message Templates. */
    private _notificationMessageTemplates?;
    /** The remote assist partners. */
    private _remoteAssistancePartners?;
    /** Reports singleton */
    private _reports?;
    /** The Resource Operations. */
    private _resourceOperations?;
    /** The Role Assignments. */
    private _roleAssignments?;
    /** The Role Definitions. */
    private _roleDefinitions?;
    /** Account level settings. */
    private _settings?;
    /** The software update status summary. */
    private _softwareUpdateStatusSummary?;
    /** Tenant mobile device management subscription state. Possible values are: pending, active, warning, disabled, deleted, blocked, lockedOut. */
    private _subscriptionState?;
    /** The telecom expense management partners. */
    private _telecomExpenseManagementPartners?;
    /** The terms and conditions associated with device management of the company. */
    private _termsAndConditions?;
    /** The list of troubleshooting events for the tenant. */
    private _troubleshootingEvents?;
    /** The Windows autopilot device identities contained collection. */
    private _windowsAutopilotDeviceIdentities?;
    /** The windows information protection app learning summaries. */
    private _windowsInformationProtectionAppLearningSummaries?;
    /** The windows information protection network learning summaries. */
    private _windowsInformationProtectionNetworkLearningSummaries?;
    /**
     * Gets the applePushNotificationCertificate property value. Apple push notification certificate.
     * @returns a applePushNotificationCertificate
     */
    get applePushNotificationCertificate(): ApplePushNotificationCertificate | undefined;
    /**
     * Sets the applePushNotificationCertificate property value. Apple push notification certificate.
     * @param value Value to set for the applePushNotificationCertificate property.
     */
    set applePushNotificationCertificate(value: ApplePushNotificationCertificate | undefined);
    /**
     * Gets the complianceManagementPartners property value. The list of Compliance Management Partners configured by the tenant.
     * @returns a complianceManagementPartner
     */
    get complianceManagementPartners(): ComplianceManagementPartner[] | undefined;
    /**
     * Sets the complianceManagementPartners property value. The list of Compliance Management Partners configured by the tenant.
     * @param value Value to set for the complianceManagementPartners property.
     */
    set complianceManagementPartners(value: ComplianceManagementPartner[] | undefined);
    /**
     * Gets the conditionalAccessSettings property value. The Exchange on premises conditional access settings. On premises conditional access will require devices to be both enrolled and compliant for mail access
     * @returns a onPremisesConditionalAccessSettings
     */
    get conditionalAccessSettings(): OnPremisesConditionalAccessSettings | undefined;
    /**
     * Sets the conditionalAccessSettings property value. The Exchange on premises conditional access settings. On premises conditional access will require devices to be both enrolled and compliant for mail access
     * @param value Value to set for the conditionalAccessSettings property.
     */
    set conditionalAccessSettings(value: OnPremisesConditionalAccessSettings | undefined);
    /**
     * Instantiates a new deviceManagement and sets the default values.
     */
    constructor();
    /**
     * Gets the detectedApps property value. The list of detected apps associated with a device.
     * @returns a detectedApp
     */
    get detectedApps(): DetectedApp[] | undefined;
    /**
     * Sets the detectedApps property value. The list of detected apps associated with a device.
     * @param value Value to set for the detectedApps property.
     */
    set detectedApps(value: DetectedApp[] | undefined);
    /**
     * Gets the deviceCategories property value. The list of device categories with the tenant.
     * @returns a deviceCategory
     */
    get deviceCategories(): DeviceCategory[] | undefined;
    /**
     * Sets the deviceCategories property value. The list of device categories with the tenant.
     * @param value Value to set for the deviceCategories property.
     */
    set deviceCategories(value: DeviceCategory[] | undefined);
    /**
     * Gets the deviceCompliancePolicies property value. The device compliance policies.
     * @returns a deviceCompliancePolicy
     */
    get deviceCompliancePolicies(): DeviceCompliancePolicy[] | undefined;
    /**
     * Sets the deviceCompliancePolicies property value. The device compliance policies.
     * @param value Value to set for the deviceCompliancePolicies property.
     */
    set deviceCompliancePolicies(value: DeviceCompliancePolicy[] | undefined);
    /**
     * Gets the deviceCompliancePolicyDeviceStateSummary property value. The device compliance state summary for this account.
     * @returns a deviceCompliancePolicyDeviceStateSummary
     */
    get deviceCompliancePolicyDeviceStateSummary(): DeviceCompliancePolicyDeviceStateSummary | undefined;
    /**
     * Sets the deviceCompliancePolicyDeviceStateSummary property value. The device compliance state summary for this account.
     * @param value Value to set for the deviceCompliancePolicyDeviceStateSummary property.
     */
    set deviceCompliancePolicyDeviceStateSummary(value: DeviceCompliancePolicyDeviceStateSummary | undefined);
    /**
     * Gets the deviceCompliancePolicySettingStateSummaries property value. The summary states of compliance policy settings for this account.
     * @returns a deviceCompliancePolicySettingStateSummary
     */
    get deviceCompliancePolicySettingStateSummaries(): DeviceCompliancePolicySettingStateSummary[] | undefined;
    /**
     * Sets the deviceCompliancePolicySettingStateSummaries property value. The summary states of compliance policy settings for this account.
     * @param value Value to set for the deviceCompliancePolicySettingStateSummaries property.
     */
    set deviceCompliancePolicySettingStateSummaries(value: DeviceCompliancePolicySettingStateSummary[] | undefined);
    /**
     * Gets the deviceConfigurationDeviceStateSummaries property value. The device configuration device state summary for this account.
     * @returns a deviceConfigurationDeviceStateSummary
     */
    get deviceConfigurationDeviceStateSummaries(): DeviceConfigurationDeviceStateSummary | undefined;
    /**
     * Sets the deviceConfigurationDeviceStateSummaries property value. The device configuration device state summary for this account.
     * @param value Value to set for the deviceConfigurationDeviceStateSummaries property.
     */
    set deviceConfigurationDeviceStateSummaries(value: DeviceConfigurationDeviceStateSummary | undefined);
    /**
     * Gets the deviceConfigurations property value. The device configurations.
     * @returns a deviceConfiguration
     */
    get deviceConfigurations(): DeviceConfiguration[] | undefined;
    /**
     * Sets the deviceConfigurations property value. The device configurations.
     * @param value Value to set for the deviceConfigurations property.
     */
    set deviceConfigurations(value: DeviceConfiguration[] | undefined);
    /**
     * Gets the deviceEnrollmentConfigurations property value. The list of device enrollment configurations
     * @returns a deviceEnrollmentConfiguration
     */
    get deviceEnrollmentConfigurations(): DeviceEnrollmentConfiguration[] | undefined;
    /**
     * Sets the deviceEnrollmentConfigurations property value. The list of device enrollment configurations
     * @param value Value to set for the deviceEnrollmentConfigurations property.
     */
    set deviceEnrollmentConfigurations(value: DeviceEnrollmentConfiguration[] | undefined);
    /**
     * Gets the deviceManagementPartners property value. The list of Device Management Partners configured by the tenant.
     * @returns a deviceManagementPartner
     */
    get deviceManagementPartners(): DeviceManagementPartner[] | undefined;
    /**
     * Sets the deviceManagementPartners property value. The list of Device Management Partners configured by the tenant.
     * @param value Value to set for the deviceManagementPartners property.
     */
    set deviceManagementPartners(value: DeviceManagementPartner[] | undefined);
    /**
     * Gets the exchangeConnectors property value. The list of Exchange Connectors configured by the tenant.
     * @returns a deviceManagementExchangeConnector
     */
    get exchangeConnectors(): DeviceManagementExchangeConnector[] | undefined;
    /**
     * Sets the exchangeConnectors property value. The list of Exchange Connectors configured by the tenant.
     * @param value Value to set for the exchangeConnectors property.
     */
    set exchangeConnectors(value: DeviceManagementExchangeConnector[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the importedWindowsAutopilotDeviceIdentities property value. Collection of imported Windows autopilot devices.
     * @returns a importedWindowsAutopilotDeviceIdentity
     */
    get importedWindowsAutopilotDeviceIdentities(): ImportedWindowsAutopilotDeviceIdentity[] | undefined;
    /**
     * Sets the importedWindowsAutopilotDeviceIdentities property value. Collection of imported Windows autopilot devices.
     * @param value Value to set for the importedWindowsAutopilotDeviceIdentities property.
     */
    set importedWindowsAutopilotDeviceIdentities(value: ImportedWindowsAutopilotDeviceIdentity[] | undefined);
    /**
     * Gets the intuneAccountId property value. Intune Account ID for given tenant
     * @returns a string
     */
    get intuneAccountId(): string | undefined;
    /**
     * Sets the intuneAccountId property value. Intune Account ID for given tenant
     * @param value Value to set for the intuneAccountId property.
     */
    set intuneAccountId(value: string | undefined);
    /**
     * Gets the intuneBrand property value. intuneBrand contains data which is used in customizing the appearance of the Company Portal applications as well as the end user web portal.
     * @returns a intuneBrand
     */
    get intuneBrand(): IntuneBrand | undefined;
    /**
     * Sets the intuneBrand property value. intuneBrand contains data which is used in customizing the appearance of the Company Portal applications as well as the end user web portal.
     * @param value Value to set for the intuneBrand property.
     */
    set intuneBrand(value: IntuneBrand | undefined);
    /**
     * Gets the iosUpdateStatuses property value. The IOS software update installation statuses for this account.
     * @returns a iosUpdateDeviceStatus
     */
    get iosUpdateStatuses(): IosUpdateDeviceStatus[] | undefined;
    /**
     * Sets the iosUpdateStatuses property value. The IOS software update installation statuses for this account.
     * @param value Value to set for the iosUpdateStatuses property.
     */
    set iosUpdateStatuses(value: IosUpdateDeviceStatus[] | undefined);
    /**
     * Gets the managedDeviceOverview property value. Device overview
     * @returns a managedDeviceOverview
     */
    get managedDeviceOverview(): ManagedDeviceOverview | undefined;
    /**
     * Sets the managedDeviceOverview property value. Device overview
     * @param value Value to set for the managedDeviceOverview property.
     */
    set managedDeviceOverview(value: ManagedDeviceOverview | undefined);
    /**
     * Gets the managedDevices property value. The list of managed devices.
     * @returns a managedDevice
     */
    get managedDevices(): ManagedDevice[] | undefined;
    /**
     * Sets the managedDevices property value. The list of managed devices.
     * @param value Value to set for the managedDevices property.
     */
    set managedDevices(value: ManagedDevice[] | undefined);
    /**
     * Gets the mobileThreatDefenseConnectors property value. The list of Mobile threat Defense connectors configured by the tenant.
     * @returns a mobileThreatDefenseConnector
     */
    get mobileThreatDefenseConnectors(): MobileThreatDefenseConnector[] | undefined;
    /**
     * Sets the mobileThreatDefenseConnectors property value. The list of Mobile threat Defense connectors configured by the tenant.
     * @param value Value to set for the mobileThreatDefenseConnectors property.
     */
    set mobileThreatDefenseConnectors(value: MobileThreatDefenseConnector[] | undefined);
    /**
     * Gets the notificationMessageTemplates property value. The Notification Message Templates.
     * @returns a notificationMessageTemplate
     */
    get notificationMessageTemplates(): NotificationMessageTemplate[] | undefined;
    /**
     * Sets the notificationMessageTemplates property value. The Notification Message Templates.
     * @param value Value to set for the notificationMessageTemplates property.
     */
    set notificationMessageTemplates(value: NotificationMessageTemplate[] | undefined);
    /**
     * Gets the remoteAssistancePartners property value. The remote assist partners.
     * @returns a remoteAssistancePartner
     */
    get remoteAssistancePartners(): RemoteAssistancePartner[] | undefined;
    /**
     * Sets the remoteAssistancePartners property value. The remote assist partners.
     * @param value Value to set for the remoteAssistancePartners property.
     */
    set remoteAssistancePartners(value: RemoteAssistancePartner[] | undefined);
    /**
     * Gets the reports property value. Reports singleton
     * @returns a deviceManagementReports
     */
    get reports(): DeviceManagementReports | undefined;
    /**
     * Sets the reports property value. Reports singleton
     * @param value Value to set for the reports property.
     */
    set reports(value: DeviceManagementReports | undefined);
    /**
     * Gets the resourceOperations property value. The Resource Operations.
     * @returns a resourceOperation
     */
    get resourceOperations(): ResourceOperation[] | undefined;
    /**
     * Sets the resourceOperations property value. The Resource Operations.
     * @param value Value to set for the resourceOperations property.
     */
    set resourceOperations(value: ResourceOperation[] | undefined);
    /**
     * Gets the roleAssignments property value. The Role Assignments.
     * @returns a deviceAndAppManagementRoleAssignment
     */
    get roleAssignments(): DeviceAndAppManagementRoleAssignment[] | undefined;
    /**
     * Sets the roleAssignments property value. The Role Assignments.
     * @param value Value to set for the roleAssignments property.
     */
    set roleAssignments(value: DeviceAndAppManagementRoleAssignment[] | undefined);
    /**
     * Gets the roleDefinitions property value. The Role Definitions.
     * @returns a roleDefinition
     */
    get roleDefinitions(): RoleDefinition[] | undefined;
    /**
     * Sets the roleDefinitions property value. The Role Definitions.
     * @param value Value to set for the roleDefinitions property.
     */
    set roleDefinitions(value: RoleDefinition[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the settings property value. Account level settings.
     * @returns a deviceManagementSettings
     */
    get settings(): DeviceManagementSettings | undefined;
    /**
     * Sets the settings property value. Account level settings.
     * @param value Value to set for the settings property.
     */
    set settings(value: DeviceManagementSettings | undefined);
    /**
     * Gets the softwareUpdateStatusSummary property value. The software update status summary.
     * @returns a softwareUpdateStatusSummary
     */
    get softwareUpdateStatusSummary(): SoftwareUpdateStatusSummary | undefined;
    /**
     * Sets the softwareUpdateStatusSummary property value. The software update status summary.
     * @param value Value to set for the softwareUpdateStatusSummary property.
     */
    set softwareUpdateStatusSummary(value: SoftwareUpdateStatusSummary | undefined);
    /**
     * Gets the subscriptionState property value. Tenant mobile device management subscription state. Possible values are: pending, active, warning, disabled, deleted, blocked, lockedOut.
     * @returns a deviceManagementSubscriptionState
     */
    get subscriptionState(): DeviceManagementSubscriptionState | undefined;
    /**
     * Sets the subscriptionState property value. Tenant mobile device management subscription state. Possible values are: pending, active, warning, disabled, deleted, blocked, lockedOut.
     * @param value Value to set for the subscriptionState property.
     */
    set subscriptionState(value: DeviceManagementSubscriptionState | undefined);
    /**
     * Gets the telecomExpenseManagementPartners property value. The telecom expense management partners.
     * @returns a telecomExpenseManagementPartner
     */
    get telecomExpenseManagementPartners(): TelecomExpenseManagementPartner[] | undefined;
    /**
     * Sets the telecomExpenseManagementPartners property value. The telecom expense management partners.
     * @param value Value to set for the telecomExpenseManagementPartners property.
     */
    set telecomExpenseManagementPartners(value: TelecomExpenseManagementPartner[] | undefined);
    /**
     * Gets the termsAndConditions property value. The terms and conditions associated with device management of the company.
     * @returns a termsAndConditions
     */
    get termsAndConditions(): TermsAndConditions[] | undefined;
    /**
     * Sets the termsAndConditions property value. The terms and conditions associated with device management of the company.
     * @param value Value to set for the termsAndConditions property.
     */
    set termsAndConditions(value: TermsAndConditions[] | undefined);
    /**
     * Gets the troubleshootingEvents property value. The list of troubleshooting events for the tenant.
     * @returns a deviceManagementTroubleshootingEvent
     */
    get troubleshootingEvents(): DeviceManagementTroubleshootingEvent[] | undefined;
    /**
     * Sets the troubleshootingEvents property value. The list of troubleshooting events for the tenant.
     * @param value Value to set for the troubleshootingEvents property.
     */
    set troubleshootingEvents(value: DeviceManagementTroubleshootingEvent[] | undefined);
    /**
     * Gets the windowsAutopilotDeviceIdentities property value. The Windows autopilot device identities contained collection.
     * @returns a windowsAutopilotDeviceIdentity
     */
    get windowsAutopilotDeviceIdentities(): WindowsAutopilotDeviceIdentity[] | undefined;
    /**
     * Sets the windowsAutopilotDeviceIdentities property value. The Windows autopilot device identities contained collection.
     * @param value Value to set for the windowsAutopilotDeviceIdentities property.
     */
    set windowsAutopilotDeviceIdentities(value: WindowsAutopilotDeviceIdentity[] | undefined);
    /**
     * Gets the windowsInformationProtectionAppLearningSummaries property value. The windows information protection app learning summaries.
     * @returns a windowsInformationProtectionAppLearningSummary
     */
    get windowsInformationProtectionAppLearningSummaries(): WindowsInformationProtectionAppLearningSummary[] | undefined;
    /**
     * Sets the windowsInformationProtectionAppLearningSummaries property value. The windows information protection app learning summaries.
     * @param value Value to set for the windowsInformationProtectionAppLearningSummaries property.
     */
    set windowsInformationProtectionAppLearningSummaries(value: WindowsInformationProtectionAppLearningSummary[] | undefined);
    /**
     * Gets the windowsInformationProtectionNetworkLearningSummaries property value. The windows information protection network learning summaries.
     * @returns a windowsInformationProtectionNetworkLearningSummary
     */
    get windowsInformationProtectionNetworkLearningSummaries(): WindowsInformationProtectionNetworkLearningSummary[] | undefined;
    /**
     * Sets the windowsInformationProtectionNetworkLearningSummaries property value. The windows information protection network learning summaries.
     * @param value Value to set for the windowsInformationProtectionNetworkLearningSummaries property.
     */
    set windowsInformationProtectionNetworkLearningSummaries(value: WindowsInformationProtectionNetworkLearningSummary[] | undefined);
}
