"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeviceManagementExportJob = void 0;
const deviceManagementExportJobLocalizationType_1 = require("./deviceManagementExportJobLocalizationType");
const deviceManagementReportFileFormat_1 = require("./deviceManagementReportFileFormat");
const deviceManagementReportStatus_1 = require("./deviceManagementReportStatus");
const index_1 = require("./index");
/** Entity representing a job to export a report */
class DeviceManagementExportJob extends index_1.Entity {
    /**
     * Instantiates a new deviceManagementExportJob and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the expirationDateTime property value. Time that the exported report expires
     * @returns a Date
     */
    get expirationDateTime() {
        return this._expirationDateTime;
    }
    ;
    /**
     * Sets the expirationDateTime property value. Time that the exported report expires
     * @param value Value to set for the expirationDateTime property.
     */
    set expirationDateTime(value) {
        this._expirationDateTime = value;
    }
    ;
    /**
     * Gets the filter property value. Filters applied on the report
     * @returns a string
     */
    get filter() {
        return this._filter;
    }
    ;
    /**
     * Sets the filter property value. Filters applied on the report
     * @param value Value to set for the filter property.
     */
    set filter(value) {
        this._filter = value;
    }
    ;
    /**
     * Gets the format property value. Format of the exported report. Possible values are: csv, pdf.
     * @returns a deviceManagementReportFileFormat
     */
    get format() {
        return this._format;
    }
    ;
    /**
     * Sets the format property value. Format of the exported report. Possible values are: csv, pdf.
     * @param value Value to set for the format property.
     */
    set format(value) {
        this._format = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "expirationDateTime": n => { this.expirationDateTime = n.getDateValue(); }, "filter": n => { this.filter = n.getStringValue(); }, "format": n => { this.format = n.getEnumValue(deviceManagementReportFileFormat_1.DeviceManagementReportFileFormat); }, "localizationType": n => { this.localizationType = n.getEnumValue(deviceManagementExportJobLocalizationType_1.DeviceManagementExportJobLocalizationType); }, "reportName": n => { this.reportName = n.getStringValue(); }, "requestDateTime": n => { this.requestDateTime = n.getDateValue(); }, "select": n => { this.select = n.getCollectionOfPrimitiveValues(); }, "snapshotId": n => { this.snapshotId = n.getStringValue(); }, "status": n => { this.status = n.getEnumValue(deviceManagementReportStatus_1.DeviceManagementReportStatus); }, "url": n => { this.url = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the localizationType property value. Configures how the requested export job is localized. Possible values are: localizedValuesAsAdditionalColumn, replaceLocalizableValues.
     * @returns a deviceManagementExportJobLocalizationType
     */
    get localizationType() {
        return this._localizationType;
    }
    ;
    /**
     * Sets the localizationType property value. Configures how the requested export job is localized. Possible values are: localizedValuesAsAdditionalColumn, replaceLocalizableValues.
     * @param value Value to set for the localizationType property.
     */
    set localizationType(value) {
        this._localizationType = value;
    }
    ;
    /**
     * Gets the reportName property value. Name of the report
     * @returns a string
     */
    get reportName() {
        return this._reportName;
    }
    ;
    /**
     * Sets the reportName property value. Name of the report
     * @param value Value to set for the reportName property.
     */
    set reportName(value) {
        this._reportName = value;
    }
    ;
    /**
     * Gets the requestDateTime property value. Time that the exported report was requested
     * @returns a Date
     */
    get requestDateTime() {
        return this._requestDateTime;
    }
    ;
    /**
     * Sets the requestDateTime property value. Time that the exported report was requested
     * @param value Value to set for the requestDateTime property.
     */
    set requestDateTime(value) {
        this._requestDateTime = value;
    }
    ;
    /**
     * Gets the select property value. Columns selected from the report
     * @returns a string
     */
    get select() {
        return this._select;
    }
    ;
    /**
     * Sets the select property value. Columns selected from the report
     * @param value Value to set for the select property.
     */
    set select(value) {
        this._select = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeDateValue("expirationDateTime", this.expirationDateTime);
        writer.writeStringValue("filter", this.filter);
        writer.writeEnumValue("format", this.format);
        writer.writeEnumValue("localizationType", this.localizationType);
        writer.writeStringValue("reportName", this.reportName);
        writer.writeDateValue("requestDateTime", this.requestDateTime);
        writer.writeCollectionOfPrimitiveValues("select", this.select);
        writer.writeStringValue("snapshotId", this.snapshotId);
        writer.writeEnumValue("status", this.status);
        writer.writeStringValue("url", this.url);
    }
    ;
    /**
     * Gets the snapshotId property value. A snapshot is an identifiable subset of the dataset represented by the ReportName. A sessionId or CachedReportConfiguration id can be used here. If a sessionId is specified, Filter, Select, and OrderBy are applied to the data represented by the sessionId. Filter, Select, and OrderBy cannot be specified together with a CachedReportConfiguration id.
     * @returns a string
     */
    get snapshotId() {
        return this._snapshotId;
    }
    ;
    /**
     * Sets the snapshotId property value. A snapshot is an identifiable subset of the dataset represented by the ReportName. A sessionId or CachedReportConfiguration id can be used here. If a sessionId is specified, Filter, Select, and OrderBy are applied to the data represented by the sessionId. Filter, Select, and OrderBy cannot be specified together with a CachedReportConfiguration id.
     * @param value Value to set for the snapshotId property.
     */
    set snapshotId(value) {
        this._snapshotId = value;
    }
    ;
    /**
     * Gets the status property value. Status of the export job. Possible values are: unknown, notStarted, inProgress, completed, failed.
     * @returns a deviceManagementReportStatus
     */
    get status() {
        return this._status;
    }
    ;
    /**
     * Sets the status property value. Status of the export job. Possible values are: unknown, notStarted, inProgress, completed, failed.
     * @param value Value to set for the status property.
     */
    set status(value) {
        this._status = value;
    }
    ;
    /**
     * Gets the url property value. Temporary location of the exported report
     * @returns a string
     */
    get url() {
        return this._url;
    }
    ;
    /**
     * Sets the url property value. Temporary location of the exported report
     * @param value Value to set for the url property.
     */
    set url(value) {
        this._url = value;
    }
    ;
}
exports.DeviceManagementExportJob = DeviceManagementExportJob;
