import { AuditActivityInitiator, Entity, KeyValue, TargetResource } from './index';
import { OperationResult } from './operationResult';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the auditLogRoot singleton. */
export declare class DirectoryAudit extends Entity implements Parsable {
    /** Indicates the date and time the activity was performed. The Timestamp type is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _activityDateTime?;
    /** Indicates the activity name or the operation name (E.g. 'Create User', 'Add member to group'). For a list of activities logged, refer to Azure Ad activity list. */
    private _activityDisplayName?;
    /** Indicates additional details on the activity. */
    private _additionalDetails?;
    /** Indicates which resource category that's targeted by the activity. (For example: User Management, Group Management etc..) */
    private _category?;
    /** Indicates a unique ID that helps correlate activities that span across various services. Can be used to trace logs across services. */
    private _correlationId?;
    /** The initiatedBy property */
    private _initiatedBy?;
    /** Indicates information on which service initiated the activity (For example: Self-service Password Management, Core Directory, B2C, Invited Users, Microsoft Identity Manager, Privileged Identity Management. */
    private _loggedByService?;
    /** Indicates the type of operation that was performed. The possible values include but are not limited to the following: Add, Assign, Update, Unassign, and Delete. */
    private _operationType?;
    /** Indicates the result of the activity. Possible values are: success, failure, timeout, unknownFutureValue. */
    private _result?;
    /** Indicates the reason for failure if the result is failure or timeout. */
    private _resultReason?;
    /** Information about the resource that changed due to the activity. */
    private _targetResources?;
    /**
     * Gets the activityDateTime property value. Indicates the date and time the activity was performed. The Timestamp type is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get activityDateTime(): Date | undefined;
    /**
     * Sets the activityDateTime property value. Indicates the date and time the activity was performed. The Timestamp type is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the activityDateTime property.
     */
    set activityDateTime(value: Date | undefined);
    /**
     * Gets the activityDisplayName property value. Indicates the activity name or the operation name (E.g. 'Create User', 'Add member to group'). For a list of activities logged, refer to Azure Ad activity list.
     * @returns a string
     */
    get activityDisplayName(): string | undefined;
    /**
     * Sets the activityDisplayName property value. Indicates the activity name or the operation name (E.g. 'Create User', 'Add member to group'). For a list of activities logged, refer to Azure Ad activity list.
     * @param value Value to set for the activityDisplayName property.
     */
    set activityDisplayName(value: string | undefined);
    /**
     * Gets the additionalDetails property value. Indicates additional details on the activity.
     * @returns a keyValue
     */
    get additionalDetails(): KeyValue[] | undefined;
    /**
     * Sets the additionalDetails property value. Indicates additional details on the activity.
     * @param value Value to set for the additionalDetails property.
     */
    set additionalDetails(value: KeyValue[] | undefined);
    /**
     * Gets the category property value. Indicates which resource category that's targeted by the activity. (For example: User Management, Group Management etc..)
     * @returns a string
     */
    get category(): string | undefined;
    /**
     * Sets the category property value. Indicates which resource category that's targeted by the activity. (For example: User Management, Group Management etc..)
     * @param value Value to set for the category property.
     */
    set category(value: string | undefined);
    /**
     * Instantiates a new directoryAudit and sets the default values.
     */
    constructor();
    /**
     * Gets the correlationId property value. Indicates a unique ID that helps correlate activities that span across various services. Can be used to trace logs across services.
     * @returns a string
     */
    get correlationId(): string | undefined;
    /**
     * Sets the correlationId property value. Indicates a unique ID that helps correlate activities that span across various services. Can be used to trace logs across services.
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the initiatedBy property value. The initiatedBy property
     * @returns a auditActivityInitiator
     */
    get initiatedBy(): AuditActivityInitiator | undefined;
    /**
     * Sets the initiatedBy property value. The initiatedBy property
     * @param value Value to set for the initiatedBy property.
     */
    set initiatedBy(value: AuditActivityInitiator | undefined);
    /**
     * Gets the loggedByService property value. Indicates information on which service initiated the activity (For example: Self-service Password Management, Core Directory, B2C, Invited Users, Microsoft Identity Manager, Privileged Identity Management.
     * @returns a string
     */
    get loggedByService(): string | undefined;
    /**
     * Sets the loggedByService property value. Indicates information on which service initiated the activity (For example: Self-service Password Management, Core Directory, B2C, Invited Users, Microsoft Identity Manager, Privileged Identity Management.
     * @param value Value to set for the loggedByService property.
     */
    set loggedByService(value: string | undefined);
    /**
     * Gets the operationType property value. Indicates the type of operation that was performed. The possible values include but are not limited to the following: Add, Assign, Update, Unassign, and Delete.
     * @returns a string
     */
    get operationType(): string | undefined;
    /**
     * Sets the operationType property value. Indicates the type of operation that was performed. The possible values include but are not limited to the following: Add, Assign, Update, Unassign, and Delete.
     * @param value Value to set for the operationType property.
     */
    set operationType(value: string | undefined);
    /**
     * Gets the result property value. Indicates the result of the activity. Possible values are: success, failure, timeout, unknownFutureValue.
     * @returns a operationResult
     */
    get result(): OperationResult | undefined;
    /**
     * Sets the result property value. Indicates the result of the activity. Possible values are: success, failure, timeout, unknownFutureValue.
     * @param value Value to set for the result property.
     */
    set result(value: OperationResult | undefined);
    /**
     * Gets the resultReason property value. Indicates the reason for failure if the result is failure or timeout.
     * @returns a string
     */
    get resultReason(): string | undefined;
    /**
     * Sets the resultReason property value. Indicates the reason for failure if the result is failure or timeout.
     * @param value Value to set for the resultReason property.
     */
    set resultReason(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the targetResources property value. Information about the resource that changed due to the activity.
     * @returns a targetResource
     */
    get targetResources(): TargetResource[] | undefined;
    /**
     * Sets the targetResources property value. Information about the resource that changed due to the activity.
     * @param value Value to set for the targetResources property.
     */
    set targetResources(value: TargetResource[] | undefined);
}
