"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DocumentSet = void 0;
const createColumnDefinitionFromDiscriminatorValue_1 = require("./createColumnDefinitionFromDiscriminatorValue");
const createContentTypeInfoFromDiscriminatorValue_1 = require("./createContentTypeInfoFromDiscriminatorValue");
const createDocumentSetContentFromDiscriminatorValue_1 = require("./createDocumentSetContentFromDiscriminatorValue");
class DocumentSet {
    /**
     * Instantiates a new documentSet and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    /**
     * Gets the allowedContentTypes property value. Content types allowed in document set.
     * @returns a contentTypeInfo
     */
    get allowedContentTypes() {
        return this._allowedContentTypes;
    }
    ;
    /**
     * Sets the allowedContentTypes property value. Content types allowed in document set.
     * @param value Value to set for the allowedContentTypes property.
     */
    set allowedContentTypes(value) {
        this._allowedContentTypes = value;
    }
    ;
    ;
    /**
     * Gets the defaultContents property value. Default contents of document set.
     * @returns a documentSetContent
     */
    get defaultContents() {
        return this._defaultContents;
    }
    ;
    /**
     * Sets the defaultContents property value. Default contents of document set.
     * @param value Value to set for the defaultContents property.
     */
    set defaultContents(value) {
        this._defaultContents = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "allowedContentTypes": n => { this.allowedContentTypes = n.getCollectionOfObjectValues(createContentTypeInfoFromDiscriminatorValue_1.createContentTypeInfoFromDiscriminatorValue); },
            "defaultContents": n => { this.defaultContents = n.getCollectionOfObjectValues(createDocumentSetContentFromDiscriminatorValue_1.createDocumentSetContentFromDiscriminatorValue); },
            "propagateWelcomePageChanges": n => { this.propagateWelcomePageChanges = n.getBooleanValue(); },
            "sharedColumns": n => { this.sharedColumns = n.getCollectionOfObjectValues(createColumnDefinitionFromDiscriminatorValue_1.createColumnDefinitionFromDiscriminatorValue); },
            "shouldPrefixNameToFile": n => { this.shouldPrefixNameToFile = n.getBooleanValue(); },
            "welcomePageColumns": n => { this.welcomePageColumns = n.getCollectionOfObjectValues(createColumnDefinitionFromDiscriminatorValue_1.createColumnDefinitionFromDiscriminatorValue); },
            "welcomePageUrl": n => { this.welcomePageUrl = n.getStringValue(); },
        };
    }
    ;
    /**
     * Gets the propagateWelcomePageChanges property value. Indicates whether to add the name of the document set to each file name.
     * @returns a boolean
     */
    get propagateWelcomePageChanges() {
        return this._propagateWelcomePageChanges;
    }
    ;
    /**
     * Sets the propagateWelcomePageChanges property value. Indicates whether to add the name of the document set to each file name.
     * @param value Value to set for the propagateWelcomePageChanges property.
     */
    set propagateWelcomePageChanges(value) {
        this._propagateWelcomePageChanges = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeCollectionOfObjectValues("allowedContentTypes", this.allowedContentTypes);
        writer.writeCollectionOfObjectValues("defaultContents", this.defaultContents);
        writer.writeBooleanValue("propagateWelcomePageChanges", this.propagateWelcomePageChanges);
        writer.writeCollectionOfObjectValues("sharedColumns", this.sharedColumns);
        writer.writeBooleanValue("shouldPrefixNameToFile", this.shouldPrefixNameToFile);
        writer.writeCollectionOfObjectValues("welcomePageColumns", this.welcomePageColumns);
        writer.writeStringValue("welcomePageUrl", this.welcomePageUrl);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the sharedColumns property value. The sharedColumns property
     * @returns a columnDefinition
     */
    get sharedColumns() {
        return this._sharedColumns;
    }
    ;
    /**
     * Sets the sharedColumns property value. The sharedColumns property
     * @param value Value to set for the sharedColumns property.
     */
    set sharedColumns(value) {
        this._sharedColumns = value;
    }
    ;
    /**
     * Gets the shouldPrefixNameToFile property value. Add the name of the Document Set to each file name.
     * @returns a boolean
     */
    get shouldPrefixNameToFile() {
        return this._shouldPrefixNameToFile;
    }
    ;
    /**
     * Sets the shouldPrefixNameToFile property value. Add the name of the Document Set to each file name.
     * @param value Value to set for the shouldPrefixNameToFile property.
     */
    set shouldPrefixNameToFile(value) {
        this._shouldPrefixNameToFile = value;
    }
    ;
    /**
     * Gets the welcomePageColumns property value. The welcomePageColumns property
     * @returns a columnDefinition
     */
    get welcomePageColumns() {
        return this._welcomePageColumns;
    }
    ;
    /**
     * Sets the welcomePageColumns property value. The welcomePageColumns property
     * @param value Value to set for the welcomePageColumns property.
     */
    set welcomePageColumns(value) {
        this._welcomePageColumns = value;
    }
    ;
    /**
     * Gets the welcomePageUrl property value. Welcome page absolute URL.
     * @returns a string
     */
    get welcomePageUrl() {
        return this._welcomePageUrl;
    }
    ;
    /**
     * Sets the welcomePageUrl property value. Welcome page absolute URL.
     * @param value Value to set for the welcomePageUrl property.
     */
    set welcomePageUrl(value) {
        this._welcomePageUrl = value;
    }
    ;
}
exports.DocumentSet = DocumentSet;
