import { Audio, BaseItem, Bundle, Deleted, DriveItemVersion, File, FileSystemInfo, Folder, GeoCoordinates, Image, ItemAnalytics, ListItem, Malware, Package, PendingOperations, Permission, Photo, PublicationFacet, RemoteItem, Root, SearchResult, Shared, SharepointIds, SpecialFolder, Subscription, ThumbnailSet, Video, Workbook } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class DriveItem extends BaseItem implements Parsable {
    /** Analytics about the view activities that took place on this item. */
    private _analytics?;
    /** Audio metadata, if the item is an audio file. Read-only. Only on OneDrive Personal. */
    private _audio?;
    /** Bundle metadata, if the item is a bundle. Read-only. */
    private _bundle?;
    /** Collection containing Item objects for the immediate children of Item. Only items representing folders have children. Read-only. Nullable. */
    private _children?;
    /** The content stream, if the item represents a file. */
    private _content?;
    /** An eTag for the content of the item. This eTag is not changed if only the metadata is changed. Note This property is not returned if the item is a folder. Read-only. */
    private _cTag?;
    /** Information about the deleted state of the item. Read-only. */
    private _deleted?;
    /** File metadata, if the item is a file. Read-only. */
    private _file?;
    /** File system information on client. Read-write. */
    private _fileSystemInfo?;
    /** Folder metadata, if the item is a folder. Read-only. */
    private _folder?;
    /** Image metadata, if the item is an image. Read-only. */
    private _image?;
    /** For drives in SharePoint, the associated document library list item. Read-only. Nullable. */
    private _listItem?;
    /** Location metadata, if the item has location data. Read-only. */
    private _location?;
    /** Malware metadata, if the item was detected to contain malware. Read-only. */
    private _malware?;
    /** If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only. */
    private _package?;
    /** If present, indicates that indicates that one or more operations that may affect the state of the driveItem are pending completion. Read-only. */
    private _pendingOperations?;
    /** The set of permissions for the item. Read-only. Nullable. */
    private _permissions?;
    /** Photo metadata, if the item is a photo. Read-only. */
    private _photo?;
    /** Provides information about the published or checked-out state of an item, in locations that support such actions. This property is not returned by default. Read-only. */
    private _publication?;
    /** Remote item data, if the item is shared from a drive other than the one being accessed. Read-only. */
    private _remoteItem?;
    /** If this property is non-null, it indicates that the driveItem is the top-most driveItem in the drive. */
    private _root?;
    /** Search metadata, if the item is from a search result. Read-only. */
    private _searchResult?;
    /** Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only. */
    private _shared?;
    /** Returns identifiers useful for SharePoint REST compatibility. Read-only. */
    private _sharepointIds?;
    /** Size of the item in bytes. Read-only. */
    private _size?;
    /** If the current item is also available as a special folder, this facet is returned. Read-only. */
    private _specialFolder?;
    /** The set of subscriptions on the item. Only supported on the root of a drive. */
    private _subscriptions?;
    /** Collection containing [ThumbnailSet][] objects associated with the item. For more info, see [getting thumbnails][]. Read-only. Nullable. */
    private _thumbnails?;
    /** The list of previous versions of the item. For more info, see [getting previous versions][]. Read-only. Nullable. */
    private _versions?;
    /** Video metadata, if the item is a video. Read-only. */
    private _video?;
    /** WebDAV compatible URL for the item. */
    private _webDavUrl?;
    /** For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. Nullable. */
    private _workbook?;
    /**
     * Gets the analytics property value. Analytics about the view activities that took place on this item.
     * @returns a itemAnalytics
     */
    get analytics(): ItemAnalytics | undefined;
    /**
     * Sets the analytics property value. Analytics about the view activities that took place on this item.
     * @param value Value to set for the analytics property.
     */
    set analytics(value: ItemAnalytics | undefined);
    /**
     * Gets the audio property value. Audio metadata, if the item is an audio file. Read-only. Only on OneDrive Personal.
     * @returns a audio
     */
    get audio(): Audio | undefined;
    /**
     * Sets the audio property value. Audio metadata, if the item is an audio file. Read-only. Only on OneDrive Personal.
     * @param value Value to set for the audio property.
     */
    set audio(value: Audio | undefined);
    /**
     * Gets the bundle property value. Bundle metadata, if the item is a bundle. Read-only.
     * @returns a bundle
     */
    get bundle(): Bundle | undefined;
    /**
     * Sets the bundle property value. Bundle metadata, if the item is a bundle. Read-only.
     * @param value Value to set for the bundle property.
     */
    set bundle(value: Bundle | undefined);
    /**
     * Gets the children property value. Collection containing Item objects for the immediate children of Item. Only items representing folders have children. Read-only. Nullable.
     * @returns a driveItem
     */
    get children(): DriveItem[] | undefined;
    /**
     * Sets the children property value. Collection containing Item objects for the immediate children of Item. Only items representing folders have children. Read-only. Nullable.
     * @param value Value to set for the children property.
     */
    set children(value: DriveItem[] | undefined);
    /**
     * Instantiates a new driveItem and sets the default values.
     */
    constructor();
    /**
     * Gets the content property value. The content stream, if the item represents a file.
     * @returns a binary
     */
    get content(): string | undefined;
    /**
     * Sets the content property value. The content stream, if the item represents a file.
     * @param value Value to set for the content property.
     */
    set content(value: string | undefined);
    /**
     * Gets the cTag property value. An eTag for the content of the item. This eTag is not changed if only the metadata is changed. Note This property is not returned if the item is a folder. Read-only.
     * @returns a string
     */
    get cTag(): string | undefined;
    /**
     * Sets the cTag property value. An eTag for the content of the item. This eTag is not changed if only the metadata is changed. Note This property is not returned if the item is a folder. Read-only.
     * @param value Value to set for the cTag property.
     */
    set cTag(value: string | undefined);
    /**
     * Gets the deleted property value. Information about the deleted state of the item. Read-only.
     * @returns a deleted
     */
    get deleted(): Deleted | undefined;
    /**
     * Sets the deleted property value. Information about the deleted state of the item. Read-only.
     * @param value Value to set for the deleted property.
     */
    set deleted(value: Deleted | undefined);
    /**
     * Gets the file property value. File metadata, if the item is a file. Read-only.
     * @returns a file
     */
    get file(): File | undefined;
    /**
     * Sets the file property value. File metadata, if the item is a file. Read-only.
     * @param value Value to set for the file property.
     */
    set file(value: File | undefined);
    /**
     * Gets the fileSystemInfo property value. File system information on client. Read-write.
     * @returns a fileSystemInfo
     */
    get fileSystemInfo(): FileSystemInfo | undefined;
    /**
     * Sets the fileSystemInfo property value. File system information on client. Read-write.
     * @param value Value to set for the fileSystemInfo property.
     */
    set fileSystemInfo(value: FileSystemInfo | undefined);
    /**
     * Gets the folder property value. Folder metadata, if the item is a folder. Read-only.
     * @returns a folder
     */
    get folder(): Folder | undefined;
    /**
     * Sets the folder property value. Folder metadata, if the item is a folder. Read-only.
     * @param value Value to set for the folder property.
     */
    set folder(value: Folder | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the image property value. Image metadata, if the item is an image. Read-only.
     * @returns a image
     */
    get image(): Image | undefined;
    /**
     * Sets the image property value. Image metadata, if the item is an image. Read-only.
     * @param value Value to set for the image property.
     */
    set image(value: Image | undefined);
    /**
     * Gets the listItem property value. For drives in SharePoint, the associated document library list item. Read-only. Nullable.
     * @returns a listItem
     */
    get listItem(): ListItem | undefined;
    /**
     * Sets the listItem property value. For drives in SharePoint, the associated document library list item. Read-only. Nullable.
     * @param value Value to set for the listItem property.
     */
    set listItem(value: ListItem | undefined);
    /**
     * Gets the location property value. Location metadata, if the item has location data. Read-only.
     * @returns a geoCoordinates
     */
    get location(): GeoCoordinates | undefined;
    /**
     * Sets the location property value. Location metadata, if the item has location data. Read-only.
     * @param value Value to set for the location property.
     */
    set location(value: GeoCoordinates | undefined);
    /**
     * Gets the malware property value. Malware metadata, if the item was detected to contain malware. Read-only.
     * @returns a malware
     */
    get malware(): Malware | undefined;
    /**
     * Sets the malware property value. Malware metadata, if the item was detected to contain malware. Read-only.
     * @param value Value to set for the malware property.
     */
    set malware(value: Malware | undefined);
    /**
     * Gets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
     * @returns a package
     */
    get package(): Package | undefined;
    /**
     * Sets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
     * @param value Value to set for the package property.
     */
    set package(value: Package | undefined);
    /**
     * Gets the pendingOperations property value. If present, indicates that indicates that one or more operations that may affect the state of the driveItem are pending completion. Read-only.
     * @returns a pendingOperations
     */
    get pendingOperations(): PendingOperations | undefined;
    /**
     * Sets the pendingOperations property value. If present, indicates that indicates that one or more operations that may affect the state of the driveItem are pending completion. Read-only.
     * @param value Value to set for the pendingOperations property.
     */
    set pendingOperations(value: PendingOperations | undefined);
    /**
     * Gets the permissions property value. The set of permissions for the item. Read-only. Nullable.
     * @returns a permission
     */
    get permissions(): Permission[] | undefined;
    /**
     * Sets the permissions property value. The set of permissions for the item. Read-only. Nullable.
     * @param value Value to set for the permissions property.
     */
    set permissions(value: Permission[] | undefined);
    /**
     * Gets the photo property value. Photo metadata, if the item is a photo. Read-only.
     * @returns a photo
     */
    get photo(): Photo | undefined;
    /**
     * Sets the photo property value. Photo metadata, if the item is a photo. Read-only.
     * @param value Value to set for the photo property.
     */
    set photo(value: Photo | undefined);
    /**
     * Gets the publication property value. Provides information about the published or checked-out state of an item, in locations that support such actions. This property is not returned by default. Read-only.
     * @returns a publicationFacet
     */
    get publication(): PublicationFacet | undefined;
    /**
     * Sets the publication property value. Provides information about the published or checked-out state of an item, in locations that support such actions. This property is not returned by default. Read-only.
     * @param value Value to set for the publication property.
     */
    set publication(value: PublicationFacet | undefined);
    /**
     * Gets the remoteItem property value. Remote item data, if the item is shared from a drive other than the one being accessed. Read-only.
     * @returns a remoteItem
     */
    get remoteItem(): RemoteItem | undefined;
    /**
     * Sets the remoteItem property value. Remote item data, if the item is shared from a drive other than the one being accessed. Read-only.
     * @param value Value to set for the remoteItem property.
     */
    set remoteItem(value: RemoteItem | undefined);
    /**
     * Gets the root property value. If this property is non-null, it indicates that the driveItem is the top-most driveItem in the drive.
     * @returns a root
     */
    get root(): Root | undefined;
    /**
     * Sets the root property value. If this property is non-null, it indicates that the driveItem is the top-most driveItem in the drive.
     * @param value Value to set for the root property.
     */
    set root(value: Root | undefined);
    /**
     * Gets the searchResult property value. Search metadata, if the item is from a search result. Read-only.
     * @returns a searchResult
     */
    get searchResult(): SearchResult | undefined;
    /**
     * Sets the searchResult property value. Search metadata, if the item is from a search result. Read-only.
     * @param value Value to set for the searchResult property.
     */
    set searchResult(value: SearchResult | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
     * @returns a shared
     */
    get shared(): Shared | undefined;
    /**
     * Sets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
     * @param value Value to set for the shared property.
     */
    set shared(value: Shared | undefined);
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the size property value. Size of the item in bytes. Read-only.
     * @returns a int64
     */
    get size(): number | undefined;
    /**
     * Sets the size property value. Size of the item in bytes. Read-only.
     * @param value Value to set for the size property.
     */
    set size(value: number | undefined);
    /**
     * Gets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
     * @returns a specialFolder
     */
    get specialFolder(): SpecialFolder | undefined;
    /**
     * Sets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
     * @param value Value to set for the specialFolder property.
     */
    set specialFolder(value: SpecialFolder | undefined);
    /**
     * Gets the subscriptions property value. The set of subscriptions on the item. Only supported on the root of a drive.
     * @returns a subscription
     */
    get subscriptions(): Subscription[] | undefined;
    /**
     * Sets the subscriptions property value. The set of subscriptions on the item. Only supported on the root of a drive.
     * @param value Value to set for the subscriptions property.
     */
    set subscriptions(value: Subscription[] | undefined);
    /**
     * Gets the thumbnails property value. Collection containing [ThumbnailSet][] objects associated with the item. For more info, see [getting thumbnails][]. Read-only. Nullable.
     * @returns a thumbnailSet
     */
    get thumbnails(): ThumbnailSet[] | undefined;
    /**
     * Sets the thumbnails property value. Collection containing [ThumbnailSet][] objects associated with the item. For more info, see [getting thumbnails][]. Read-only. Nullable.
     * @param value Value to set for the thumbnails property.
     */
    set thumbnails(value: ThumbnailSet[] | undefined);
    /**
     * Gets the versions property value. The list of previous versions of the item. For more info, see [getting previous versions][]. Read-only. Nullable.
     * @returns a driveItemVersion
     */
    get versions(): DriveItemVersion[] | undefined;
    /**
     * Sets the versions property value. The list of previous versions of the item. For more info, see [getting previous versions][]. Read-only. Nullable.
     * @param value Value to set for the versions property.
     */
    set versions(value: DriveItemVersion[] | undefined);
    /**
     * Gets the video property value. Video metadata, if the item is a video. Read-only.
     * @returns a video
     */
    get video(): Video | undefined;
    /**
     * Sets the video property value. Video metadata, if the item is a video. Read-only.
     * @param value Value to set for the video property.
     */
    set video(value: Video | undefined);
    /**
     * Gets the webDavUrl property value. WebDAV compatible URL for the item.
     * @returns a string
     */
    get webDavUrl(): string | undefined;
    /**
     * Sets the webDavUrl property value. WebDAV compatible URL for the item.
     * @param value Value to set for the webDavUrl property.
     */
    set webDavUrl(value: string | undefined);
    /**
     * Gets the workbook property value. For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. Nullable.
     * @returns a workbook
     */
    get workbook(): Workbook | undefined;
    /**
     * Sets the workbook property value. For files that are Excel spreadsheets, accesses the workbook API to work with the spreadsheet's contents. Nullable.
     * @param value Value to set for the workbook property.
     */
    set workbook(value: Workbook | undefined);
}
