import { EducationExternalSource } from './educationExternalSource';
import { EducationUserRole } from './educationUserRole';
import { AssignedLicense, AssignedPlan, EducationAssignment, EducationClass, EducationOnPremisesInfo, EducationRubric, EducationSchool, EducationStudent, EducationTeacher, Entity, IdentitySet, PasswordProfile, PhysicalAddress, ProvisionedPlan, RelatedContact, User } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the educationRoot singleton. */
export declare class EducationUser extends Entity implements Parsable {
    /** True if the account is enabled; otherwise, false. This property is required when a user is created. Supports /$filter. */
    private _accountEnabled?;
    /** The licenses that are assigned to the user. Not nullable. */
    private _assignedLicenses?;
    /** The plans that are assigned to the user. Read-only. Not nullable. */
    private _assignedPlans?;
    /** List of assignments for the user. Nullable. */
    private _assignments?;
    /** The telephone numbers for the user. Note: Although this is a string collection, only one number can be set for this property. */
    private _businessPhones?;
    /** Classes to which the user belongs. Nullable. */
    private _classes?;
    /** Entity who created the user. */
    private _createdBy?;
    /** The name for the department in which the user works. Supports /$filter. */
    private _department?;
    /** The name displayed in the address book for the user. Supports $filter and $orderby. */
    private _displayName?;
    /** The type of external source this resource was generated from (automatically determined from externalSourceDetail). Possible values are: sis, lms, or manual. */
    private _externalSource?;
    /** The name of the external source this resources was generated from. */
    private _externalSourceDetail?;
    /** The given name (first name) of the user. Supports /$filter. */
    private _givenName?;
    /** The SMTP address for the user; for example, 'jeff@contoso.onmicrosoft.com'. Read-Only. Supports /$filter. */
    private _mail?;
    /** Mail address of user. Note: type and postOfficeBox are not supported for educationUser resources. */
    private _mailingAddress?;
    /** The mail alias for the user. This property must be specified when a user is created. Supports /$filter. */
    private _mailNickname?;
    /** The middle name of user. */
    private _middleName?;
    /** The primary cellular telephone number for the user. */
    private _mobilePhone?;
    /** The officeLocation property */
    private _officeLocation?;
    /** Additional information used to associate the AAD user with it's Active Directory counterpart. */
    private _onPremisesInfo?;
    /** Specifies password policies for the user. See standard [user] resource for additional details. */
    private _passwordPolicies?;
    /** Specifies the password profile for the user. The profile contains the user's password. This property is required when a user is created. See standard [user] resource for additional details. */
    private _passwordProfile?;
    /** The preferred language for the user. Should follow ISO 639-1 Code; for example, 'en-US'. */
    private _preferredLanguage?;
    /** Default role for a user. The user's role might be different in an individual class. Possible values are: student, teacher, faculty. Supports /$filter. */
    private _primaryRole?;
    /** The plans that are provisioned for the user. Read-only. Not nullable. */
    private _provisionedPlans?;
    /** The refreshTokensValidFromDateTime property */
    private _refreshTokensValidFromDateTime?;
    /** Related records related to the user. Possible relationships are parent, relative, aide, doctor, guardian, child, other, unknownFutureValue */
    private _relatedContacts?;
    /** Address where user lives. Note: type and postOfficeBox are not supported for educationUser resources. */
    private _residenceAddress?;
    /** When set, the grading rubric attached to the assignment. */
    private _rubrics?;
    /** Schools to which the user belongs. Nullable. */
    private _schools?;
    /** True if the Outlook Global Address List should contain this user; otherwise, false. If not set, this will be treated as true. For users invited through the invitation manager, this property will be set to false. */
    private _showInAddressList?;
    /** If the primary role is student, this block will contain student specific data. */
    private _student?;
    /** The user's surname (family name or last name). Supports /$filter. */
    private _surname?;
    /** Classes for which the user is a teacher. */
    private _taughtClasses?;
    /** If the primary role is teacher, this block will contain teacher specific data. */
    private _teacher?;
    /** A two-letter country code ([ISO 3166 Alpha-2]). Required for users who will be assigned licenses. Not nullable. Supports /$filter. */
    private _usageLocation?;
    /** The directory user that corresponds to this user. */
    private _user?;
    /** The user principal name (UPN) for the user. Supports $filter and $orderby. See standard [user] resource for additional details. */
    private _userPrincipalName?;
    /** A string value that can be used to classify user types in your directory, such as 'Member' and 'Guest'. Supports /$filter. */
    private _userType?;
    /**
     * Gets the accountEnabled property value. True if the account is enabled; otherwise, false. This property is required when a user is created. Supports /$filter.
     * @returns a boolean
     */
    get accountEnabled(): boolean | undefined;
    /**
     * Sets the accountEnabled property value. True if the account is enabled; otherwise, false. This property is required when a user is created. Supports /$filter.
     * @param value Value to set for the accountEnabled property.
     */
    set accountEnabled(value: boolean | undefined);
    /**
     * Gets the assignedLicenses property value. The licenses that are assigned to the user. Not nullable.
     * @returns a assignedLicense
     */
    get assignedLicenses(): AssignedLicense[] | undefined;
    /**
     * Sets the assignedLicenses property value. The licenses that are assigned to the user. Not nullable.
     * @param value Value to set for the assignedLicenses property.
     */
    set assignedLicenses(value: AssignedLicense[] | undefined);
    /**
     * Gets the assignedPlans property value. The plans that are assigned to the user. Read-only. Not nullable.
     * @returns a assignedPlan
     */
    get assignedPlans(): AssignedPlan[] | undefined;
    /**
     * Sets the assignedPlans property value. The plans that are assigned to the user. Read-only. Not nullable.
     * @param value Value to set for the assignedPlans property.
     */
    set assignedPlans(value: AssignedPlan[] | undefined);
    /**
     * Gets the assignments property value. List of assignments for the user. Nullable.
     * @returns a educationAssignment
     */
    get assignments(): EducationAssignment[] | undefined;
    /**
     * Sets the assignments property value. List of assignments for the user. Nullable.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: EducationAssignment[] | undefined);
    /**
     * Gets the businessPhones property value. The telephone numbers for the user. Note: Although this is a string collection, only one number can be set for this property.
     * @returns a string
     */
    get businessPhones(): string[] | undefined;
    /**
     * Sets the businessPhones property value. The telephone numbers for the user. Note: Although this is a string collection, only one number can be set for this property.
     * @param value Value to set for the businessPhones property.
     */
    set businessPhones(value: string[] | undefined);
    /**
     * Gets the classes property value. Classes to which the user belongs. Nullable.
     * @returns a educationClass
     */
    get classes(): EducationClass[] | undefined;
    /**
     * Sets the classes property value. Classes to which the user belongs. Nullable.
     * @param value Value to set for the classes property.
     */
    set classes(value: EducationClass[] | undefined);
    /**
     * Instantiates a new educationUser and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Entity who created the user.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Entity who created the user.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the department property value. The name for the department in which the user works. Supports /$filter.
     * @returns a string
     */
    get department(): string | undefined;
    /**
     * Sets the department property value. The name for the department in which the user works. Supports /$filter.
     * @param value Value to set for the department property.
     */
    set department(value: string | undefined);
    /**
     * Gets the displayName property value. The name displayed in the address book for the user. Supports $filter and $orderby.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name displayed in the address book for the user. Supports $filter and $orderby.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the externalSource property value. The type of external source this resource was generated from (automatically determined from externalSourceDetail). Possible values are: sis, lms, or manual.
     * @returns a educationExternalSource
     */
    get externalSource(): EducationExternalSource | undefined;
    /**
     * Sets the externalSource property value. The type of external source this resource was generated from (automatically determined from externalSourceDetail). Possible values are: sis, lms, or manual.
     * @param value Value to set for the externalSource property.
     */
    set externalSource(value: EducationExternalSource | undefined);
    /**
     * Gets the externalSourceDetail property value. The name of the external source this resources was generated from.
     * @returns a string
     */
    get externalSourceDetail(): string | undefined;
    /**
     * Sets the externalSourceDetail property value. The name of the external source this resources was generated from.
     * @param value Value to set for the externalSourceDetail property.
     */
    set externalSourceDetail(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the givenName property value. The given name (first name) of the user. Supports /$filter.
     * @returns a string
     */
    get givenName(): string | undefined;
    /**
     * Sets the givenName property value. The given name (first name) of the user. Supports /$filter.
     * @param value Value to set for the givenName property.
     */
    set givenName(value: string | undefined);
    /**
     * Gets the mail property value. The SMTP address for the user; for example, 'jeff@contoso.onmicrosoft.com'. Read-Only. Supports /$filter.
     * @returns a string
     */
    get mail(): string | undefined;
    /**
     * Sets the mail property value. The SMTP address for the user; for example, 'jeff@contoso.onmicrosoft.com'. Read-Only. Supports /$filter.
     * @param value Value to set for the mail property.
     */
    set mail(value: string | undefined);
    /**
     * Gets the mailingAddress property value. Mail address of user. Note: type and postOfficeBox are not supported for educationUser resources.
     * @returns a physicalAddress
     */
    get mailingAddress(): PhysicalAddress | undefined;
    /**
     * Sets the mailingAddress property value. Mail address of user. Note: type and postOfficeBox are not supported for educationUser resources.
     * @param value Value to set for the mailingAddress property.
     */
    set mailingAddress(value: PhysicalAddress | undefined);
    /**
     * Gets the mailNickname property value. The mail alias for the user. This property must be specified when a user is created. Supports /$filter.
     * @returns a string
     */
    get mailNickname(): string | undefined;
    /**
     * Sets the mailNickname property value. The mail alias for the user. This property must be specified when a user is created. Supports /$filter.
     * @param value Value to set for the mailNickname property.
     */
    set mailNickname(value: string | undefined);
    /**
     * Gets the middleName property value. The middle name of user.
     * @returns a string
     */
    get middleName(): string | undefined;
    /**
     * Sets the middleName property value. The middle name of user.
     * @param value Value to set for the middleName property.
     */
    set middleName(value: string | undefined);
    /**
     * Gets the mobilePhone property value. The primary cellular telephone number for the user.
     * @returns a string
     */
    get mobilePhone(): string | undefined;
    /**
     * Sets the mobilePhone property value. The primary cellular telephone number for the user.
     * @param value Value to set for the mobilePhone property.
     */
    set mobilePhone(value: string | undefined);
    /**
     * Gets the officeLocation property value. The officeLocation property
     * @returns a string
     */
    get officeLocation(): string | undefined;
    /**
     * Sets the officeLocation property value. The officeLocation property
     * @param value Value to set for the officeLocation property.
     */
    set officeLocation(value: string | undefined);
    /**
     * Gets the onPremisesInfo property value. Additional information used to associate the AAD user with it's Active Directory counterpart.
     * @returns a educationOnPremisesInfo
     */
    get onPremisesInfo(): EducationOnPremisesInfo | undefined;
    /**
     * Sets the onPremisesInfo property value. Additional information used to associate the AAD user with it's Active Directory counterpart.
     * @param value Value to set for the onPremisesInfo property.
     */
    set onPremisesInfo(value: EducationOnPremisesInfo | undefined);
    /**
     * Gets the passwordPolicies property value. Specifies password policies for the user. See standard [user] resource for additional details.
     * @returns a string
     */
    get passwordPolicies(): string | undefined;
    /**
     * Sets the passwordPolicies property value. Specifies password policies for the user. See standard [user] resource for additional details.
     * @param value Value to set for the passwordPolicies property.
     */
    set passwordPolicies(value: string | undefined);
    /**
     * Gets the passwordProfile property value. Specifies the password profile for the user. The profile contains the user's password. This property is required when a user is created. See standard [user] resource for additional details.
     * @returns a passwordProfile
     */
    get passwordProfile(): PasswordProfile | undefined;
    /**
     * Sets the passwordProfile property value. Specifies the password profile for the user. The profile contains the user's password. This property is required when a user is created. See standard [user] resource for additional details.
     * @param value Value to set for the passwordProfile property.
     */
    set passwordProfile(value: PasswordProfile | undefined);
    /**
     * Gets the preferredLanguage property value. The preferred language for the user. Should follow ISO 639-1 Code; for example, 'en-US'.
     * @returns a string
     */
    get preferredLanguage(): string | undefined;
    /**
     * Sets the preferredLanguage property value. The preferred language for the user. Should follow ISO 639-1 Code; for example, 'en-US'.
     * @param value Value to set for the preferredLanguage property.
     */
    set preferredLanguage(value: string | undefined);
    /**
     * Gets the primaryRole property value. Default role for a user. The user's role might be different in an individual class. Possible values are: student, teacher, faculty. Supports /$filter.
     * @returns a educationUserRole
     */
    get primaryRole(): EducationUserRole | undefined;
    /**
     * Sets the primaryRole property value. Default role for a user. The user's role might be different in an individual class. Possible values are: student, teacher, faculty. Supports /$filter.
     * @param value Value to set for the primaryRole property.
     */
    set primaryRole(value: EducationUserRole | undefined);
    /**
     * Gets the provisionedPlans property value. The plans that are provisioned for the user. Read-only. Not nullable.
     * @returns a provisionedPlan
     */
    get provisionedPlans(): ProvisionedPlan[] | undefined;
    /**
     * Sets the provisionedPlans property value. The plans that are provisioned for the user. Read-only. Not nullable.
     * @param value Value to set for the provisionedPlans property.
     */
    set provisionedPlans(value: ProvisionedPlan[] | undefined);
    /**
     * Gets the refreshTokensValidFromDateTime property value. The refreshTokensValidFromDateTime property
     * @returns a Date
     */
    get refreshTokensValidFromDateTime(): Date | undefined;
    /**
     * Sets the refreshTokensValidFromDateTime property value. The refreshTokensValidFromDateTime property
     * @param value Value to set for the refreshTokensValidFromDateTime property.
     */
    set refreshTokensValidFromDateTime(value: Date | undefined);
    /**
     * Gets the relatedContacts property value. Related records related to the user. Possible relationships are parent, relative, aide, doctor, guardian, child, other, unknownFutureValue
     * @returns a relatedContact
     */
    get relatedContacts(): RelatedContact[] | undefined;
    /**
     * Sets the relatedContacts property value. Related records related to the user. Possible relationships are parent, relative, aide, doctor, guardian, child, other, unknownFutureValue
     * @param value Value to set for the relatedContacts property.
     */
    set relatedContacts(value: RelatedContact[] | undefined);
    /**
     * Gets the residenceAddress property value. Address where user lives. Note: type and postOfficeBox are not supported for educationUser resources.
     * @returns a physicalAddress
     */
    get residenceAddress(): PhysicalAddress | undefined;
    /**
     * Sets the residenceAddress property value. Address where user lives. Note: type and postOfficeBox are not supported for educationUser resources.
     * @param value Value to set for the residenceAddress property.
     */
    set residenceAddress(value: PhysicalAddress | undefined);
    /**
     * Gets the rubrics property value. When set, the grading rubric attached to the assignment.
     * @returns a educationRubric
     */
    get rubrics(): EducationRubric[] | undefined;
    /**
     * Sets the rubrics property value. When set, the grading rubric attached to the assignment.
     * @param value Value to set for the rubrics property.
     */
    set rubrics(value: EducationRubric[] | undefined);
    /**
     * Gets the schools property value. Schools to which the user belongs. Nullable.
     * @returns a educationSchool
     */
    get schools(): EducationSchool[] | undefined;
    /**
     * Sets the schools property value. Schools to which the user belongs. Nullable.
     * @param value Value to set for the schools property.
     */
    set schools(value: EducationSchool[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the showInAddressList property value. True if the Outlook Global Address List should contain this user; otherwise, false. If not set, this will be treated as true. For users invited through the invitation manager, this property will be set to false.
     * @returns a boolean
     */
    get showInAddressList(): boolean | undefined;
    /**
     * Sets the showInAddressList property value. True if the Outlook Global Address List should contain this user; otherwise, false. If not set, this will be treated as true. For users invited through the invitation manager, this property will be set to false.
     * @param value Value to set for the showInAddressList property.
     */
    set showInAddressList(value: boolean | undefined);
    /**
     * Gets the student property value. If the primary role is student, this block will contain student specific data.
     * @returns a educationStudent
     */
    get student(): EducationStudent | undefined;
    /**
     * Sets the student property value. If the primary role is student, this block will contain student specific data.
     * @param value Value to set for the student property.
     */
    set student(value: EducationStudent | undefined);
    /**
     * Gets the surname property value. The user's surname (family name or last name). Supports /$filter.
     * @returns a string
     */
    get surname(): string | undefined;
    /**
     * Sets the surname property value. The user's surname (family name or last name). Supports /$filter.
     * @param value Value to set for the surname property.
     */
    set surname(value: string | undefined);
    /**
     * Gets the taughtClasses property value. Classes for which the user is a teacher.
     * @returns a educationClass
     */
    get taughtClasses(): EducationClass[] | undefined;
    /**
     * Sets the taughtClasses property value. Classes for which the user is a teacher.
     * @param value Value to set for the taughtClasses property.
     */
    set taughtClasses(value: EducationClass[] | undefined);
    /**
     * Gets the teacher property value. If the primary role is teacher, this block will contain teacher specific data.
     * @returns a educationTeacher
     */
    get teacher(): EducationTeacher | undefined;
    /**
     * Sets the teacher property value. If the primary role is teacher, this block will contain teacher specific data.
     * @param value Value to set for the teacher property.
     */
    set teacher(value: EducationTeacher | undefined);
    /**
     * Gets the usageLocation property value. A two-letter country code ([ISO 3166 Alpha-2]). Required for users who will be assigned licenses. Not nullable. Supports /$filter.
     * @returns a string
     */
    get usageLocation(): string | undefined;
    /**
     * Sets the usageLocation property value. A two-letter country code ([ISO 3166 Alpha-2]). Required for users who will be assigned licenses. Not nullable. Supports /$filter.
     * @param value Value to set for the usageLocation property.
     */
    set usageLocation(value: string | undefined);
    /**
     * Gets the user property value. The directory user that corresponds to this user.
     * @returns a user
     */
    get user(): User | undefined;
    /**
     * Sets the user property value. The directory user that corresponds to this user.
     * @param value Value to set for the user property.
     */
    set user(value: User | undefined);
    /**
     * Gets the userPrincipalName property value. The user principal name (UPN) for the user. Supports $filter and $orderby. See standard [user] resource for additional details.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. The user principal name (UPN) for the user. Supports $filter and $orderby. See standard [user] resource for additional details.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
    /**
     * Gets the userType property value. A string value that can be used to classify user types in your directory, such as 'Member' and 'Guest'. Supports /$filter.
     * @returns a string
     */
    get userType(): string | undefined;
    /**
     * Sets the userType property value. A string value that can be used to classify user types in your directory, such as 'Member' and 'Guest'. Supports /$filter.
     * @param value Value to set for the userType property.
     */
    set userType(value: string | undefined);
}
