import { AccessPackage, AccessPackageAssignment, AccessPackageAssignmentPolicy, AccessPackageAssignmentRequest, AccessPackageCatalog, Approval, ConnectedOrganization, EntitlementManagementSettings, Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityGovernance singleton. */
export declare class EntitlementManagement extends Entity implements Parsable {
    /** Approval stages for assignment requests. */
    private _accessPackageAssignmentApprovals?;
    /** Represents access package objects. */
    private _accessPackages?;
    /** Access package assignment policies. */
    private _assignmentPolicies?;
    /** Represents access package assignment requests created by or on behalf of a user. */
    private _assignmentRequests?;
    /** Represents the grant of an access package to a subject (user or group). */
    private _assignments?;
    /** Represents a collection of access packages. */
    private _catalogs?;
    /** Represents references to a directory or domain of another organization whose users can request access. */
    private _connectedOrganizations?;
    /** Represents the settings that control the behavior of Azure AD entitlement management. */
    private _settings?;
    /**
     * Gets the accessPackageAssignmentApprovals property value. Approval stages for assignment requests.
     * @returns a approval
     */
    get accessPackageAssignmentApprovals(): Approval[] | undefined;
    /**
     * Sets the accessPackageAssignmentApprovals property value. Approval stages for assignment requests.
     * @param value Value to set for the accessPackageAssignmentApprovals property.
     */
    set accessPackageAssignmentApprovals(value: Approval[] | undefined);
    /**
     * Gets the accessPackages property value. Represents access package objects.
     * @returns a accessPackage
     */
    get accessPackages(): AccessPackage[] | undefined;
    /**
     * Sets the accessPackages property value. Represents access package objects.
     * @param value Value to set for the accessPackages property.
     */
    set accessPackages(value: AccessPackage[] | undefined);
    /**
     * Gets the assignmentPolicies property value. Access package assignment policies.
     * @returns a accessPackageAssignmentPolicy
     */
    get assignmentPolicies(): AccessPackageAssignmentPolicy[] | undefined;
    /**
     * Sets the assignmentPolicies property value. Access package assignment policies.
     * @param value Value to set for the assignmentPolicies property.
     */
    set assignmentPolicies(value: AccessPackageAssignmentPolicy[] | undefined);
    /**
     * Gets the assignmentRequests property value. Represents access package assignment requests created by or on behalf of a user.
     * @returns a accessPackageAssignmentRequest
     */
    get assignmentRequests(): AccessPackageAssignmentRequest[] | undefined;
    /**
     * Sets the assignmentRequests property value. Represents access package assignment requests created by or on behalf of a user.
     * @param value Value to set for the assignmentRequests property.
     */
    set assignmentRequests(value: AccessPackageAssignmentRequest[] | undefined);
    /**
     * Gets the assignments property value. Represents the grant of an access package to a subject (user or group).
     * @returns a accessPackageAssignment
     */
    get assignments(): AccessPackageAssignment[] | undefined;
    /**
     * Sets the assignments property value. Represents the grant of an access package to a subject (user or group).
     * @param value Value to set for the assignments property.
     */
    set assignments(value: AccessPackageAssignment[] | undefined);
    /**
     * Gets the catalogs property value. Represents a collection of access packages.
     * @returns a accessPackageCatalog
     */
    get catalogs(): AccessPackageCatalog[] | undefined;
    /**
     * Sets the catalogs property value. Represents a collection of access packages.
     * @param value Value to set for the catalogs property.
     */
    set catalogs(value: AccessPackageCatalog[] | undefined);
    /**
     * Gets the connectedOrganizations property value. Represents references to a directory or domain of another organization whose users can request access.
     * @returns a connectedOrganization
     */
    get connectedOrganizations(): ConnectedOrganization[] | undefined;
    /**
     * Sets the connectedOrganizations property value. Represents references to a directory or domain of another organization whose users can request access.
     * @param value Value to set for the connectedOrganizations property.
     */
    set connectedOrganizations(value: ConnectedOrganization[] | undefined);
    /**
     * Instantiates a new entitlementManagement and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the settings property value. Represents the settings that control the behavior of Azure AD entitlement management.
     * @returns a entitlementManagementSettings
     */
    get settings(): EntitlementManagementSettings | undefined;
    /**
     * Sets the settings property value. Represents the settings that control the behavior of Azure AD entitlement management.
     * @param value Value to set for the settings property.
     */
    set settings(value: EntitlementManagementSettings | undefined);
}
