import { Entity } from '../';
import { ConnectionState } from './connectionState';
import { Configuration, ConnectionOperation, ExternalGroup, ExternalItem, Schema } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of externalConnection entities. */
export declare class ExternalConnection extends Entity implements Parsable {
    /** Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional. */
    private _configuration?;
    /** Description of the connection displayed in the Microsoft 365 admin center. Optional. */
    private _description?;
    /** Read-only. Nullable. */
    private _groups?;
    /** Read-only. Nullable. */
    private _items?;
    /** The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required. */
    private _name?;
    /** Read-only. Nullable. */
    private _operations?;
    /** Read-only. Nullable. */
    private _schema?;
    /** Indicates the current state of the connection. Possible values are draft, ready, obsolete, and limitExceeded. Required. */
    private _state?;
    /**
     * Gets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
     * @returns a configuration
     */
    get configuration(): Configuration | undefined;
    /**
     * Sets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
     * @param value Value to set for the configuration property.
     */
    set configuration(value: Configuration | undefined);
    /**
     * Instantiates a new externalConnection and sets the default values.
     */
    constructor();
    /**
     * Gets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the groups property value. Read-only. Nullable.
     * @returns a externalGroup
     */
    get groups(): ExternalGroup[] | undefined;
    /**
     * Sets the groups property value. Read-only. Nullable.
     * @param value Value to set for the groups property.
     */
    set groups(value: ExternalGroup[] | undefined);
    /**
     * Gets the items property value. Read-only. Nullable.
     * @returns a externalItem
     */
    get items(): ExternalItem[] | undefined;
    /**
     * Sets the items property value. Read-only. Nullable.
     * @param value Value to set for the items property.
     */
    set items(value: ExternalItem[] | undefined);
    /**
     * Gets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the operations property value. Read-only. Nullable.
     * @returns a connectionOperation
     */
    get operations(): ConnectionOperation[] | undefined;
    /**
     * Sets the operations property value. Read-only. Nullable.
     * @param value Value to set for the operations property.
     */
    set operations(value: ConnectionOperation[] | undefined);
    /**
     * Gets the schema property value. Read-only. Nullable.
     * @returns a schema
     */
    get schema(): Schema | undefined;
    /**
     * Sets the schema property value. Read-only. Nullable.
     * @param value Value to set for the schema property.
     */
    set schema(value: Schema | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the state property value. Indicates the current state of the connection. Possible values are draft, ready, obsolete, and limitExceeded. Required.
     * @returns a connectionState
     */
    get state(): ConnectionState | undefined;
    /**
     * Sets the state property value. Indicates the current state of the connection. Possible values are draft, ready, obsolete, and limitExceeded. Required.
     * @param value Value to set for the state property.
     */
    set state(value: ConnectionState | undefined);
}
