"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExternalConnection = void 0;
const __1 = require("../");
const connectionState_1 = require("./connectionState");
const createConfigurationFromDiscriminatorValue_1 = require("./createConfigurationFromDiscriminatorValue");
const createConnectionOperationFromDiscriminatorValue_1 = require("./createConnectionOperationFromDiscriminatorValue");
const createExternalGroupFromDiscriminatorValue_1 = require("./createExternalGroupFromDiscriminatorValue");
const createExternalItemFromDiscriminatorValue_1 = require("./createExternalItemFromDiscriminatorValue");
const createSchemaFromDiscriminatorValue_1 = require("./createSchemaFromDiscriminatorValue");
/** Provides operations to manage the collection of externalConnection entities. */
class ExternalConnection extends __1.Entity {
    /**
     * Instantiates a new externalConnection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
     * @returns a configuration
     */
    get configuration() {
        return this._configuration;
    }
    ;
    /**
     * Sets the configuration property value. Specifies additional application IDs that are allowed to manage the connection and to index content in the connection. Optional.
     * @param value Value to set for the configuration property.
     */
    set configuration(value) {
        this._configuration = value;
    }
    ;
    ;
    /**
     * Gets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Description of the connection displayed in the Microsoft 365 admin center. Optional.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "configuration": n => { this.configuration = n.getObjectValue(createConfigurationFromDiscriminatorValue_1.createConfigurationFromDiscriminatorValue); }, "description": n => { this.description = n.getStringValue(); }, "groups": n => { this.groups = n.getCollectionOfObjectValues(createExternalGroupFromDiscriminatorValue_1.createExternalGroupFromDiscriminatorValue); }, "items": n => { this.items = n.getCollectionOfObjectValues(createExternalItemFromDiscriminatorValue_1.createExternalItemFromDiscriminatorValue); }, "name": n => { this.name = n.getStringValue(); }, "operations": n => { this.operations = n.getCollectionOfObjectValues(createConnectionOperationFromDiscriminatorValue_1.createConnectionOperationFromDiscriminatorValue); }, "schema": n => { this.schema = n.getObjectValue(createSchemaFromDiscriminatorValue_1.createSchemaFromDiscriminatorValue); }, "state": n => { this.state = n.getEnumValue(connectionState_1.ConnectionState); } });
    }
    ;
    /**
     * Gets the groups property value. Read-only. Nullable.
     * @returns a externalGroup
     */
    get groups() {
        return this._groups;
    }
    ;
    /**
     * Sets the groups property value. Read-only. Nullable.
     * @param value Value to set for the groups property.
     */
    set groups(value) {
        this._groups = value;
    }
    ;
    /**
     * Gets the items property value. Read-only. Nullable.
     * @returns a externalItem
     */
    get items() {
        return this._items;
    }
    ;
    /**
     * Sets the items property value. Read-only. Nullable.
     * @param value Value to set for the items property.
     */
    set items(value) {
        this._items = value;
    }
    ;
    /**
     * Gets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
     * @returns a string
     */
    get name() {
        return this._name;
    }
    ;
    /**
     * Sets the name property value. The display name of the connection to be displayed in the Microsoft 365 admin center. Maximum length of 128 characters. Required.
     * @param value Value to set for the name property.
     */
    set name(value) {
        this._name = value;
    }
    ;
    /**
     * Gets the operations property value. Read-only. Nullable.
     * @returns a connectionOperation
     */
    get operations() {
        return this._operations;
    }
    ;
    /**
     * Sets the operations property value. Read-only. Nullable.
     * @param value Value to set for the operations property.
     */
    set operations(value) {
        this._operations = value;
    }
    ;
    /**
     * Gets the schema property value. Read-only. Nullable.
     * @returns a schema
     */
    get schema() {
        return this._schema;
    }
    ;
    /**
     * Sets the schema property value. Read-only. Nullable.
     * @param value Value to set for the schema property.
     */
    set schema(value) {
        this._schema = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("configuration", this.configuration);
        writer.writeStringValue("description", this.description);
        writer.writeCollectionOfObjectValues("groups", this.groups);
        writer.writeCollectionOfObjectValues("items", this.items);
        writer.writeStringValue("name", this.name);
        writer.writeCollectionOfObjectValues("operations", this.operations);
        writer.writeObjectValue("schema", this.schema);
        writer.writeEnumValue("state", this.state);
    }
    ;
    /**
     * Gets the state property value. Indicates the current state of the connection. Possible values are draft, ready, obsolete, and limitExceeded. Required.
     * @returns a connectionState
     */
    get state() {
        return this._state;
    }
    ;
    /**
     * Sets the state property value. Indicates the current state of the connection. Possible values are draft, ready, obsolete, and limitExceeded. Required.
     * @param value Value to set for the state property.
     */
    set state(value) {
        this._state = value;
    }
    ;
}
exports.ExternalConnection = ExternalConnection;
