import { AttestationLevel } from './attestationLevel';
import { AuthenticationMethod } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Fido2AuthenticationMethod extends AuthenticationMethod implements Parsable {
    /** Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator. */
    private _aaGuid?;
    /** The attestation certificate(s) attached to this security key. */
    private _attestationCertificates?;
    /** The attestation level of this FIDO2 security key. Possible values are: attested, notAttested, unknownFutureValue. */
    private _attestationLevel?;
    /** The timestamp when this key was registered to the user. */
    private _createdDateTime?;
    /** The display name of the key as given by the user. */
    private _displayName?;
    /** The manufacturer-assigned model of the FIDO2 security key. */
    private _model?;
    /**
     * Gets the aaGuid property value. Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator.
     * @returns a string
     */
    get aaGuid(): string | undefined;
    /**
     * Sets the aaGuid property value. Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator.
     * @param value Value to set for the aaGuid property.
     */
    set aaGuid(value: string | undefined);
    /**
     * Gets the attestationCertificates property value. The attestation certificate(s) attached to this security key.
     * @returns a string
     */
    get attestationCertificates(): string[] | undefined;
    /**
     * Sets the attestationCertificates property value. The attestation certificate(s) attached to this security key.
     * @param value Value to set for the attestationCertificates property.
     */
    set attestationCertificates(value: string[] | undefined);
    /**
     * Gets the attestationLevel property value. The attestation level of this FIDO2 security key. Possible values are: attested, notAttested, unknownFutureValue.
     * @returns a attestationLevel
     */
    get attestationLevel(): AttestationLevel | undefined;
    /**
     * Sets the attestationLevel property value. The attestation level of this FIDO2 security key. Possible values are: attested, notAttested, unknownFutureValue.
     * @param value Value to set for the attestationLevel property.
     */
    set attestationLevel(value: AttestationLevel | undefined);
    /**
     * Instantiates a new fido2AuthenticationMethod and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. The timestamp when this key was registered to the user.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The timestamp when this key was registered to the user.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the displayName property value. The display name of the key as given by the user.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The display name of the key as given by the user.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the model property value. The manufacturer-assigned model of the FIDO2 security key.
     * @returns a string
     */
    get model(): string | undefined;
    /**
     * Sets the model property value. The manufacturer-assigned model of the FIDO2 security key.
     * @param value Value to set for the model property.
     */
    set model(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
