"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InternalDomainFederation = void 0;
const createSigningCertificateUpdateStatusFromDiscriminatorValue_1 = require("./createSigningCertificateUpdateStatusFromDiscriminatorValue");
const federatedIdpMfaBehavior_1 = require("./federatedIdpMfaBehavior");
const index_1 = require("./index");
const promptLoginBehavior_1 = require("./promptLoginBehavior");
/** Provides operations to manage the collection of domain entities. */
class InternalDomainFederation extends index_1.SamlOrWsFedProvider {
    /**
     * Instantiates a new internalDomainFederation and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the activeSignInUri property value. URL of the endpoint used by active clients when authenticating with federated domains set up for single sign-on in Azure Active Directory (Azure AD). Corresponds to the ActiveLogOnUri property of the Set-MsolDomainFederationSettings MSOnline v1 PowerShell cmdlet.
     * @returns a string
     */
    get activeSignInUri() {
        return this._activeSignInUri;
    }
    ;
    /**
     * Sets the activeSignInUri property value. URL of the endpoint used by active clients when authenticating with federated domains set up for single sign-on in Azure Active Directory (Azure AD). Corresponds to the ActiveLogOnUri property of the Set-MsolDomainFederationSettings MSOnline v1 PowerShell cmdlet.
     * @param value Value to set for the activeSignInUri property.
     */
    set activeSignInUri(value) {
        this._activeSignInUri = value;
    }
    ;
    ;
    /**
     * Gets the federatedIdpMfaBehavior property value. Determines whether Azure AD accepts the MFA performed by the federated IdP when a federated user accesses an application that is governed by a conditional access policy that requires MFA. The possible values are: acceptIfMfaDoneByFederatedIdp, enforceMfaByFederatedIdp, rejectMfaByFederatedIdp, unknownFutureValue. For more information, see federatedIdpMfaBehavior values.
     * @returns a federatedIdpMfaBehavior
     */
    get federatedIdpMfaBehavior() {
        return this._federatedIdpMfaBehavior;
    }
    ;
    /**
     * Sets the federatedIdpMfaBehavior property value. Determines whether Azure AD accepts the MFA performed by the federated IdP when a federated user accesses an application that is governed by a conditional access policy that requires MFA. The possible values are: acceptIfMfaDoneByFederatedIdp, enforceMfaByFederatedIdp, rejectMfaByFederatedIdp, unknownFutureValue. For more information, see federatedIdpMfaBehavior values.
     * @param value Value to set for the federatedIdpMfaBehavior property.
     */
    set federatedIdpMfaBehavior(value) {
        this._federatedIdpMfaBehavior = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "activeSignInUri": n => { this.activeSignInUri = n.getStringValue(); }, "federatedIdpMfaBehavior": n => { this.federatedIdpMfaBehavior = n.getEnumValue(federatedIdpMfaBehavior_1.FederatedIdpMfaBehavior); }, "isSignedAuthenticationRequestRequired": n => { this.isSignedAuthenticationRequestRequired = n.getBooleanValue(); }, "nextSigningCertificate": n => { this.nextSigningCertificate = n.getStringValue(); }, "promptLoginBehavior": n => { this.promptLoginBehavior = n.getEnumValue(promptLoginBehavior_1.PromptLoginBehavior); }, "signingCertificateUpdateStatus": n => { this.signingCertificateUpdateStatus = n.getObjectValue(createSigningCertificateUpdateStatusFromDiscriminatorValue_1.createSigningCertificateUpdateStatusFromDiscriminatorValue); }, "signOutUri": n => { this.signOutUri = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the isSignedAuthenticationRequestRequired property value. If true, when SAML authentication requests are sent to the federated SAML IdP, Azure AD will sign those requests using the OrgID signing key. If false (default), the SAML authentication requests sent to the federated IdP are not signed.
     * @returns a boolean
     */
    get isSignedAuthenticationRequestRequired() {
        return this._isSignedAuthenticationRequestRequired;
    }
    ;
    /**
     * Sets the isSignedAuthenticationRequestRequired property value. If true, when SAML authentication requests are sent to the federated SAML IdP, Azure AD will sign those requests using the OrgID signing key. If false (default), the SAML authentication requests sent to the federated IdP are not signed.
     * @param value Value to set for the isSignedAuthenticationRequestRequired property.
     */
    set isSignedAuthenticationRequestRequired(value) {
        this._isSignedAuthenticationRequestRequired = value;
    }
    ;
    /**
     * Gets the nextSigningCertificate property value. Fallback token signing certificate that is used to sign tokens when the primary signing certificate expires. Formatted as Base64 encoded strings of the public portion of the federated IdP's token signing certificate. Needs to be compatible with the X509Certificate2 class. Much like the signingCertificate, the nextSigningCertificate property is used if a rollover is required outside of the auto-rollover update, a new federation service is being set up, or if the new token signing certificate is not present in the federation properties after the federation service certificate has been updated.
     * @returns a string
     */
    get nextSigningCertificate() {
        return this._nextSigningCertificate;
    }
    ;
    /**
     * Sets the nextSigningCertificate property value. Fallback token signing certificate that is used to sign tokens when the primary signing certificate expires. Formatted as Base64 encoded strings of the public portion of the federated IdP's token signing certificate. Needs to be compatible with the X509Certificate2 class. Much like the signingCertificate, the nextSigningCertificate property is used if a rollover is required outside of the auto-rollover update, a new federation service is being set up, or if the new token signing certificate is not present in the federation properties after the federation service certificate has been updated.
     * @param value Value to set for the nextSigningCertificate property.
     */
    set nextSigningCertificate(value) {
        this._nextSigningCertificate = value;
    }
    ;
    /**
     * Gets the promptLoginBehavior property value. Sets the preferred behavior for the sign-in prompt. The possible values are: translateToFreshPasswordAuthentication, nativeSupport, disabled, unknownFutureValue.
     * @returns a promptLoginBehavior
     */
    get promptLoginBehavior() {
        return this._promptLoginBehavior;
    }
    ;
    /**
     * Sets the promptLoginBehavior property value. Sets the preferred behavior for the sign-in prompt. The possible values are: translateToFreshPasswordAuthentication, nativeSupport, disabled, unknownFutureValue.
     * @param value Value to set for the promptLoginBehavior property.
     */
    set promptLoginBehavior(value) {
        this._promptLoginBehavior = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("activeSignInUri", this.activeSignInUri);
        writer.writeEnumValue("federatedIdpMfaBehavior", this.federatedIdpMfaBehavior);
        writer.writeBooleanValue("isSignedAuthenticationRequestRequired", this.isSignedAuthenticationRequestRequired);
        writer.writeStringValue("nextSigningCertificate", this.nextSigningCertificate);
        writer.writeEnumValue("promptLoginBehavior", this.promptLoginBehavior);
        writer.writeObjectValue("signingCertificateUpdateStatus", this.signingCertificateUpdateStatus);
        writer.writeStringValue("signOutUri", this.signOutUri);
    }
    ;
    /**
     * Gets the signingCertificateUpdateStatus property value. Provides status and timestamp of the last update of the signing certificate.
     * @returns a signingCertificateUpdateStatus
     */
    get signingCertificateUpdateStatus() {
        return this._signingCertificateUpdateStatus;
    }
    ;
    /**
     * Sets the signingCertificateUpdateStatus property value. Provides status and timestamp of the last update of the signing certificate.
     * @param value Value to set for the signingCertificateUpdateStatus property.
     */
    set signingCertificateUpdateStatus(value) {
        this._signingCertificateUpdateStatus = value;
    }
    ;
    /**
     * Gets the signOutUri property value. URI that clients are redirected to when they sign out of Azure AD services. Corresponds to the LogOffUri property of the Set-MsolDomainFederationSettings MSOnline v1 PowerShell cmdlet.
     * @returns a string
     */
    get signOutUri() {
        return this._signOutUri;
    }
    ;
    /**
     * Sets the signOutUri property value. URI that clients are redirected to when they sign out of Azure AD services. Corresponds to the LogOffUri property of the Set-MsolDomainFederationSettings MSOnline v1 PowerShell cmdlet.
     * @param value Value to set for the signOutUri property.
     */
    set signOutUri(value) {
        this._signOutUri = value;
    }
    ;
}
exports.InternalDomainFederation = InternalDomainFederation;
