import { MimeContent, RgbColor } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** intuneBrand contains data which is used in customizing the appearance of the Company Portal applications as well as the end user web portal. */
export declare class IntuneBrand implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Email address of the person/organization responsible for IT support. */
    private _contactITEmailAddress?;
    /** Name of the person/organization responsible for IT support. */
    private _contactITName?;
    /** Text comments regarding the person/organization responsible for IT support. */
    private _contactITNotes?;
    /** Phone number of the person/organization responsible for IT support. */
    private _contactITPhoneNumber?;
    /** Logo image displayed in Company Portal apps which have a dark background behind the logo. */
    private _darkBackgroundLogo?;
    /** Company/organization name that is displayed to end users. */
    private _displayName?;
    /** Logo image displayed in Company Portal apps which have a light background behind the logo. */
    private _lightBackgroundLogo?;
    /** Display name of the company/organization’s IT helpdesk site. */
    private _onlineSupportSiteName?;
    /** URL to the company/organization’s IT helpdesk site. */
    private _onlineSupportSiteUrl?;
    /** URL to the company/organization’s privacy policy. */
    private _privacyUrl?;
    /** Boolean that represents whether the administrator-supplied display name will be shown next to the logo image. */
    private _showDisplayNameNextToLogo?;
    /** Boolean that represents whether the administrator-supplied logo images are shown or not shown. */
    private _showLogo?;
    /** Boolean that represents whether the administrator-supplied display name will be shown next to the logo image. */
    private _showNameNextToLogo?;
    /** Primary theme color used in the Company Portal applications and web portal. */
    private _themeColor?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new intuneBrand and sets the default values.
     */
    constructor();
    /**
     * Gets the contactITEmailAddress property value. Email address of the person/organization responsible for IT support.
     * @returns a string
     */
    get contactITEmailAddress(): string | undefined;
    /**
     * Sets the contactITEmailAddress property value. Email address of the person/organization responsible for IT support.
     * @param value Value to set for the contactITEmailAddress property.
     */
    set contactITEmailAddress(value: string | undefined);
    /**
     * Gets the contactITName property value. Name of the person/organization responsible for IT support.
     * @returns a string
     */
    get contactITName(): string | undefined;
    /**
     * Sets the contactITName property value. Name of the person/organization responsible for IT support.
     * @param value Value to set for the contactITName property.
     */
    set contactITName(value: string | undefined);
    /**
     * Gets the contactITNotes property value. Text comments regarding the person/organization responsible for IT support.
     * @returns a string
     */
    get contactITNotes(): string | undefined;
    /**
     * Sets the contactITNotes property value. Text comments regarding the person/organization responsible for IT support.
     * @param value Value to set for the contactITNotes property.
     */
    set contactITNotes(value: string | undefined);
    /**
     * Gets the contactITPhoneNumber property value. Phone number of the person/organization responsible for IT support.
     * @returns a string
     */
    get contactITPhoneNumber(): string | undefined;
    /**
     * Sets the contactITPhoneNumber property value. Phone number of the person/organization responsible for IT support.
     * @param value Value to set for the contactITPhoneNumber property.
     */
    set contactITPhoneNumber(value: string | undefined);
    /**
     * Gets the darkBackgroundLogo property value. Logo image displayed in Company Portal apps which have a dark background behind the logo.
     * @returns a mimeContent
     */
    get darkBackgroundLogo(): MimeContent | undefined;
    /**
     * Sets the darkBackgroundLogo property value. Logo image displayed in Company Portal apps which have a dark background behind the logo.
     * @param value Value to set for the darkBackgroundLogo property.
     */
    set darkBackgroundLogo(value: MimeContent | undefined);
    /**
     * Gets the displayName property value. Company/organization name that is displayed to end users.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Company/organization name that is displayed to end users.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the lightBackgroundLogo property value. Logo image displayed in Company Portal apps which have a light background behind the logo.
     * @returns a mimeContent
     */
    get lightBackgroundLogo(): MimeContent | undefined;
    /**
     * Sets the lightBackgroundLogo property value. Logo image displayed in Company Portal apps which have a light background behind the logo.
     * @param value Value to set for the lightBackgroundLogo property.
     */
    set lightBackgroundLogo(value: MimeContent | undefined);
    /**
     * Gets the onlineSupportSiteName property value. Display name of the company/organization’s IT helpdesk site.
     * @returns a string
     */
    get onlineSupportSiteName(): string | undefined;
    /**
     * Sets the onlineSupportSiteName property value. Display name of the company/organization’s IT helpdesk site.
     * @param value Value to set for the onlineSupportSiteName property.
     */
    set onlineSupportSiteName(value: string | undefined);
    /**
     * Gets the onlineSupportSiteUrl property value. URL to the company/organization’s IT helpdesk site.
     * @returns a string
     */
    get onlineSupportSiteUrl(): string | undefined;
    /**
     * Sets the onlineSupportSiteUrl property value. URL to the company/organization’s IT helpdesk site.
     * @param value Value to set for the onlineSupportSiteUrl property.
     */
    set onlineSupportSiteUrl(value: string | undefined);
    /**
     * Gets the privacyUrl property value. URL to the company/organization’s privacy policy.
     * @returns a string
     */
    get privacyUrl(): string | undefined;
    /**
     * Sets the privacyUrl property value. URL to the company/organization’s privacy policy.
     * @param value Value to set for the privacyUrl property.
     */
    set privacyUrl(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the showDisplayNameNextToLogo property value. Boolean that represents whether the administrator-supplied display name will be shown next to the logo image.
     * @returns a boolean
     */
    get showDisplayNameNextToLogo(): boolean | undefined;
    /**
     * Sets the showDisplayNameNextToLogo property value. Boolean that represents whether the administrator-supplied display name will be shown next to the logo image.
     * @param value Value to set for the showDisplayNameNextToLogo property.
     */
    set showDisplayNameNextToLogo(value: boolean | undefined);
    /**
     * Gets the showLogo property value. Boolean that represents whether the administrator-supplied logo images are shown or not shown.
     * @returns a boolean
     */
    get showLogo(): boolean | undefined;
    /**
     * Sets the showLogo property value. Boolean that represents whether the administrator-supplied logo images are shown or not shown.
     * @param value Value to set for the showLogo property.
     */
    set showLogo(value: boolean | undefined);
    /**
     * Gets the showNameNextToLogo property value. Boolean that represents whether the administrator-supplied display name will be shown next to the logo image.
     * @returns a boolean
     */
    get showNameNextToLogo(): boolean | undefined;
    /**
     * Sets the showNameNextToLogo property value. Boolean that represents whether the administrator-supplied display name will be shown next to the logo image.
     * @param value Value to set for the showNameNextToLogo property.
     */
    set showNameNextToLogo(value: boolean | undefined);
    /**
     * Gets the themeColor property value. Primary theme color used in the Company Portal applications and web portal.
     * @returns a rgbColor
     */
    get themeColor(): RgbColor | undefined;
    /**
     * Sets the themeColor property value. Primary theme color used in the Company Portal applications and web portal.
     * @param value Value to set for the themeColor property.
     */
    set themeColor(value: RgbColor | undefined);
}
