import { ManagedAppPolicyDeploymentSummary, ManagedMobileApp, TargetedManagedAppProtection } from './index';
import { ManagedAppDataEncryptionType } from './managedAppDataEncryptionType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Policy used to configure detailed management settings targeted to specific security groups and for a specified set of apps on an iOS device */
export declare class IosManagedAppProtection extends TargetedManagedAppProtection implements Parsable {
    /** Type of encryption which should be used for data in a managed app. Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked. */
    private _appDataEncryptionType?;
    /** List of apps to which the policy is deployed. */
    private _apps?;
    /** A custom browser protocol to open weblink on iOS. */
    private _customBrowserProtocol?;
    /** Count of apps to which the current policy is deployed. */
    private _deployedAppCount?;
    /** Navigation property to deployment summary of the configuration. */
    private _deploymentSummary?;
    /** Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. */
    private _faceIdBlocked?;
    /** Versions less than the specified version will block the managed app from accessing company data. */
    private _minimumRequiredSdkVersion?;
    /**
     * Gets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @returns a managedAppDataEncryptionType
     */
    get appDataEncryptionType(): ManagedAppDataEncryptionType | undefined;
    /**
     * Sets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @param value Value to set for the appDataEncryptionType property.
     */
    set appDataEncryptionType(value: ManagedAppDataEncryptionType | undefined);
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps(): ManagedMobileApp[] | undefined;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value: ManagedMobileApp[] | undefined);
    /**
     * Instantiates a new iosManagedAppProtection and sets the default values.
     */
    constructor();
    /**
     * Gets the customBrowserProtocol property value. A custom browser protocol to open weblink on iOS.
     * @returns a string
     */
    get customBrowserProtocol(): string | undefined;
    /**
     * Sets the customBrowserProtocol property value. A custom browser protocol to open weblink on iOS.
     * @param value Value to set for the customBrowserProtocol property.
     */
    set customBrowserProtocol(value: string | undefined);
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount(): number | undefined;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value: number | undefined);
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary(): ManagedAppPolicyDeploymentSummary | undefined;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value: ManagedAppPolicyDeploymentSummary | undefined);
    /**
     * Gets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True.
     * @returns a boolean
     */
    get faceIdBlocked(): boolean | undefined;
    /**
     * Sets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True.
     * @param value Value to set for the faceIdBlocked property.
     */
    set faceIdBlocked(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredSdkVersion(): string | undefined;
    /**
     * Sets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredSdkVersion property.
     */
    set minimumRequiredSdkVersion(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
