"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IosManagedAppProtection = void 0;
const createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue_1 = require("./createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue");
const createManagedMobileAppFromDiscriminatorValue_1 = require("./createManagedMobileAppFromDiscriminatorValue");
const index_1 = require("./index");
const managedAppDataEncryptionType_1 = require("./managedAppDataEncryptionType");
/** Policy used to configure detailed management settings targeted to specific security groups and for a specified set of apps on an iOS device */
class IosManagedAppProtection extends index_1.TargetedManagedAppProtection {
    /**
     * Instantiates a new iosManagedAppProtection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @returns a managedAppDataEncryptionType
     */
    get appDataEncryptionType() {
        return this._appDataEncryptionType;
    }
    ;
    /**
     * Sets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @param value Value to set for the appDataEncryptionType property.
     */
    set appDataEncryptionType(value) {
        this._appDataEncryptionType = value;
    }
    ;
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps() {
        return this._apps;
    }
    ;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value) {
        this._apps = value;
    }
    ;
    ;
    /**
     * Gets the customBrowserProtocol property value. A custom browser protocol to open weblink on iOS.
     * @returns a string
     */
    get customBrowserProtocol() {
        return this._customBrowserProtocol;
    }
    ;
    /**
     * Sets the customBrowserProtocol property value. A custom browser protocol to open weblink on iOS.
     * @param value Value to set for the customBrowserProtocol property.
     */
    set customBrowserProtocol(value) {
        this._customBrowserProtocol = value;
    }
    ;
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount() {
        return this._deployedAppCount;
    }
    ;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value) {
        this._deployedAppCount = value;
    }
    ;
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary() {
        return this._deploymentSummary;
    }
    ;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value) {
        this._deploymentSummary = value;
    }
    ;
    /**
     * Gets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True.
     * @returns a boolean
     */
    get faceIdBlocked() {
        return this._faceIdBlocked;
    }
    ;
    /**
     * Sets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True.
     * @param value Value to set for the faceIdBlocked property.
     */
    set faceIdBlocked(value) {
        this._faceIdBlocked = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appDataEncryptionType": n => { this.appDataEncryptionType = n.getEnumValue(managedAppDataEncryptionType_1.ManagedAppDataEncryptionType); }, "apps": n => { this.apps = n.getCollectionOfObjectValues(createManagedMobileAppFromDiscriminatorValue_1.createManagedMobileAppFromDiscriminatorValue); }, "customBrowserProtocol": n => { this.customBrowserProtocol = n.getStringValue(); }, "deployedAppCount": n => { this.deployedAppCount = n.getNumberValue(); }, "deploymentSummary": n => { this.deploymentSummary = n.getObjectValue(createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue_1.createManagedAppPolicyDeploymentSummaryFromDiscriminatorValue); }, "faceIdBlocked": n => { this.faceIdBlocked = n.getBooleanValue(); }, "minimumRequiredSdkVersion": n => { this.minimumRequiredSdkVersion = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredSdkVersion() {
        return this._minimumRequiredSdkVersion;
    }
    ;
    /**
     * Sets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredSdkVersion property.
     */
    set minimumRequiredSdkVersion(value) {
        this._minimumRequiredSdkVersion = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("appDataEncryptionType", this.appDataEncryptionType);
        writer.writeCollectionOfObjectValues("apps", this.apps);
        writer.writeStringValue("customBrowserProtocol", this.customBrowserProtocol);
        writer.writeNumberValue("deployedAppCount", this.deployedAppCount);
        writer.writeObjectValue("deploymentSummary", this.deploymentSummary);
        writer.writeBooleanValue("faceIdBlocked", this.faceIdBlocked);
        writer.writeStringValue("minimumRequiredSdkVersion", this.minimumRequiredSdkVersion);
    }
    ;
}
exports.IosManagedAppProtection = IosManagedAppProtection;
