import { BaseItem, ColumnDefinition, ContentType, Drive, ListInfo, ListItem, RichLongRunningOperation, SharepointIds, Subscription, SystemFacet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class List extends BaseItem implements Parsable {
    /** The collection of field definitions for this list. */
    private _columns?;
    /** The collection of content types present in this list. */
    private _contentTypes?;
    /** The displayable title of the list. */
    private _displayName?;
    /** Only present on document libraries. Allows access to the list as a [drive][] resource with [driveItems][driveItem]. */
    private _drive?;
    /** All items contained in the list. */
    private _items?;
    /** Provides additional details about the list. */
    private _list?;
    /** The collection of long running operations for the list. */
    private _operations?;
    /** Returns identifiers useful for SharePoint REST compatibility. Read-only. */
    private _sharepointIds?;
    /** The set of subscriptions on the list. */
    private _subscriptions?;
    /** If present, indicates that this is a system-managed list. Read-only. */
    private _system?;
    /**
     * Gets the columns property value. The collection of field definitions for this list.
     * @returns a columnDefinition
     */
    get columns(): ColumnDefinition[] | undefined;
    /**
     * Sets the columns property value. The collection of field definitions for this list.
     * @param value Value to set for the columns property.
     */
    set columns(value: ColumnDefinition[] | undefined);
    /**
     * Instantiates a new list and sets the default values.
     */
    constructor();
    /**
     * Gets the contentTypes property value. The collection of content types present in this list.
     * @returns a contentType
     */
    get contentTypes(): ContentType[] | undefined;
    /**
     * Sets the contentTypes property value. The collection of content types present in this list.
     * @param value Value to set for the contentTypes property.
     */
    set contentTypes(value: ContentType[] | undefined);
    /**
     * Gets the displayName property value. The displayable title of the list.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The displayable title of the list.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the drive property value. Only present on document libraries. Allows access to the list as a [drive][] resource with [driveItems][driveItem].
     * @returns a drive
     */
    get drive(): Drive | undefined;
    /**
     * Sets the drive property value. Only present on document libraries. Allows access to the list as a [drive][] resource with [driveItems][driveItem].
     * @param value Value to set for the drive property.
     */
    set drive(value: Drive | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the items property value. All items contained in the list.
     * @returns a listItem
     */
    get items(): ListItem[] | undefined;
    /**
     * Sets the items property value. All items contained in the list.
     * @param value Value to set for the items property.
     */
    set items(value: ListItem[] | undefined);
    /**
     * Gets the list property value. Provides additional details about the list.
     * @returns a listInfo
     */
    get list(): ListInfo | undefined;
    /**
     * Sets the list property value. Provides additional details about the list.
     * @param value Value to set for the list property.
     */
    set list(value: ListInfo | undefined);
    /**
     * Gets the operations property value. The collection of long running operations for the list.
     * @returns a richLongRunningOperation
     */
    get operations(): RichLongRunningOperation[] | undefined;
    /**
     * Sets the operations property value. The collection of long running operations for the list.
     * @param value Value to set for the operations property.
     */
    set operations(value: RichLongRunningOperation[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the subscriptions property value. The set of subscriptions on the list.
     * @returns a subscription
     */
    get subscriptions(): Subscription[] | undefined;
    /**
     * Sets the subscriptions property value. The set of subscriptions on the list.
     * @param value Value to set for the subscriptions property.
     */
    set subscriptions(value: Subscription[] | undefined);
    /**
     * Gets the system property value. If present, indicates that this is a system-managed list. Read-only.
     * @returns a systemFacet
     */
    get system(): SystemFacet | undefined;
    /**
     * Sets the system property value. If present, indicates that this is a system-managed list. Read-only.
     * @param value Value to set for the system property.
     */
    set system(value: SystemFacet | undefined);
}
