import { OutlookGeoCoordinates, PhysicalAddress } from './index';
import { LocationType } from './locationType';
import { LocationUniqueIdType } from './locationUniqueIdType';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Location implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** The street address of the location. */
    private _address?;
    /** The geographic coordinates and elevation of the location. */
    private _coordinates?;
    /** The name associated with the location. */
    private _displayName?;
    /** Optional email address of the location. */
    private _locationEmailAddress?;
    /** The type of location. Possible values are: default, conferenceRoom, homeAddress, businessAddress,geoCoordinates, streetAddress, hotel, restaurant, localBusiness, postalAddress. Read-only. */
    private _locationType?;
    /** Optional URI representing the location. */
    private _locationUri?;
    /** For internal use only. */
    private _uniqueId?;
    /** For internal use only. */
    private _uniqueIdType?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the address property value. The street address of the location.
     * @returns a physicalAddress
     */
    get address(): PhysicalAddress | undefined;
    /**
     * Sets the address property value. The street address of the location.
     * @param value Value to set for the address property.
     */
    set address(value: PhysicalAddress | undefined);
    /**
     * Instantiates a new location and sets the default values.
     */
    constructor();
    /**
     * Gets the coordinates property value. The geographic coordinates and elevation of the location.
     * @returns a outlookGeoCoordinates
     */
    get coordinates(): OutlookGeoCoordinates | undefined;
    /**
     * Sets the coordinates property value. The geographic coordinates and elevation of the location.
     * @param value Value to set for the coordinates property.
     */
    set coordinates(value: OutlookGeoCoordinates | undefined);
    /**
     * Gets the displayName property value. The name associated with the location.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name associated with the location.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the locationEmailAddress property value. Optional email address of the location.
     * @returns a string
     */
    get locationEmailAddress(): string | undefined;
    /**
     * Sets the locationEmailAddress property value. Optional email address of the location.
     * @param value Value to set for the locationEmailAddress property.
     */
    set locationEmailAddress(value: string | undefined);
    /**
     * Gets the locationType property value. The type of location. Possible values are: default, conferenceRoom, homeAddress, businessAddress,geoCoordinates, streetAddress, hotel, restaurant, localBusiness, postalAddress. Read-only.
     * @returns a locationType
     */
    get locationType(): LocationType | undefined;
    /**
     * Sets the locationType property value. The type of location. Possible values are: default, conferenceRoom, homeAddress, businessAddress,geoCoordinates, streetAddress, hotel, restaurant, localBusiness, postalAddress. Read-only.
     * @param value Value to set for the locationType property.
     */
    set locationType(value: LocationType | undefined);
    /**
     * Gets the locationUri property value. Optional URI representing the location.
     * @returns a string
     */
    get locationUri(): string | undefined;
    /**
     * Sets the locationUri property value. Optional URI representing the location.
     * @param value Value to set for the locationUri property.
     */
    set locationUri(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the uniqueId property value. For internal use only.
     * @returns a string
     */
    get uniqueId(): string | undefined;
    /**
     * Sets the uniqueId property value. For internal use only.
     * @param value Value to set for the uniqueId property.
     */
    set uniqueId(value: string | undefined);
    /**
     * Gets the uniqueIdType property value. For internal use only.
     * @returns a locationUniqueIdType
     */
    get uniqueIdType(): LocationUniqueIdType | undefined;
    /**
     * Sets the uniqueIdType property value. For internal use only.
     * @param value Value to set for the uniqueIdType property.
     */
    set uniqueIdType(value: LocationUniqueIdType | undefined);
}
