"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Location = void 0;
const createOutlookGeoCoordinatesFromDiscriminatorValue_1 = require("./createOutlookGeoCoordinatesFromDiscriminatorValue");
const createPhysicalAddressFromDiscriminatorValue_1 = require("./createPhysicalAddressFromDiscriminatorValue");
const locationType_1 = require("./locationType");
const locationUniqueIdType_1 = require("./locationUniqueIdType");
class Location {
    /**
     * Instantiates a new location and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    /**
     * Gets the address property value. The street address of the location.
     * @returns a physicalAddress
     */
    get address() {
        return this._address;
    }
    ;
    /**
     * Sets the address property value. The street address of the location.
     * @param value Value to set for the address property.
     */
    set address(value) {
        this._address = value;
    }
    ;
    ;
    /**
     * Gets the coordinates property value. The geographic coordinates and elevation of the location.
     * @returns a outlookGeoCoordinates
     */
    get coordinates() {
        return this._coordinates;
    }
    ;
    /**
     * Sets the coordinates property value. The geographic coordinates and elevation of the location.
     * @param value Value to set for the coordinates property.
     */
    set coordinates(value) {
        this._coordinates = value;
    }
    ;
    /**
     * Gets the displayName property value. The name associated with the location.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The name associated with the location.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "address": n => { this.address = n.getObjectValue(createPhysicalAddressFromDiscriminatorValue_1.createPhysicalAddressFromDiscriminatorValue); },
            "coordinates": n => { this.coordinates = n.getObjectValue(createOutlookGeoCoordinatesFromDiscriminatorValue_1.createOutlookGeoCoordinatesFromDiscriminatorValue); },
            "displayName": n => { this.displayName = n.getStringValue(); },
            "locationEmailAddress": n => { this.locationEmailAddress = n.getStringValue(); },
            "locationType": n => { this.locationType = n.getEnumValue(locationType_1.LocationType); },
            "locationUri": n => { this.locationUri = n.getStringValue(); },
            "uniqueId": n => { this.uniqueId = n.getStringValue(); },
            "uniqueIdType": n => { this.uniqueIdType = n.getEnumValue(locationUniqueIdType_1.LocationUniqueIdType); },
        };
    }
    ;
    /**
     * Gets the locationEmailAddress property value. Optional email address of the location.
     * @returns a string
     */
    get locationEmailAddress() {
        return this._locationEmailAddress;
    }
    ;
    /**
     * Sets the locationEmailAddress property value. Optional email address of the location.
     * @param value Value to set for the locationEmailAddress property.
     */
    set locationEmailAddress(value) {
        this._locationEmailAddress = value;
    }
    ;
    /**
     * Gets the locationType property value. The type of location. Possible values are: default, conferenceRoom, homeAddress, businessAddress,geoCoordinates, streetAddress, hotel, restaurant, localBusiness, postalAddress. Read-only.
     * @returns a locationType
     */
    get locationType() {
        return this._locationType;
    }
    ;
    /**
     * Sets the locationType property value. The type of location. Possible values are: default, conferenceRoom, homeAddress, businessAddress,geoCoordinates, streetAddress, hotel, restaurant, localBusiness, postalAddress. Read-only.
     * @param value Value to set for the locationType property.
     */
    set locationType(value) {
        this._locationType = value;
    }
    ;
    /**
     * Gets the locationUri property value. Optional URI representing the location.
     * @returns a string
     */
    get locationUri() {
        return this._locationUri;
    }
    ;
    /**
     * Sets the locationUri property value. Optional URI representing the location.
     * @param value Value to set for the locationUri property.
     */
    set locationUri(value) {
        this._locationUri = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeObjectValue("address", this.address);
        writer.writeObjectValue("coordinates", this.coordinates);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeStringValue("locationEmailAddress", this.locationEmailAddress);
        writer.writeEnumValue("locationType", this.locationType);
        writer.writeStringValue("locationUri", this.locationUri);
        writer.writeStringValue("uniqueId", this.uniqueId);
        writer.writeEnumValue("uniqueIdType", this.uniqueIdType);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the uniqueId property value. For internal use only.
     * @returns a string
     */
    get uniqueId() {
        return this._uniqueId;
    }
    ;
    /**
     * Sets the uniqueId property value. For internal use only.
     * @param value Value to set for the uniqueId property.
     */
    set uniqueId(value) {
        this._uniqueId = value;
    }
    ;
    /**
     * Gets the uniqueIdType property value. For internal use only.
     * @returns a locationUniqueIdType
     */
    get uniqueIdType() {
        return this._uniqueIdType;
    }
    ;
    /**
     * Sets the uniqueIdType property value. For internal use only.
     * @param value Value to set for the uniqueIdType property.
     */
    set uniqueIdType(value) {
        this._uniqueIdType = value;
    }
    ;
}
exports.Location = Location;
