"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagedAppProtection = void 0;
const index_1 = require("./index");
const managedAppClipboardSharingLevel_1 = require("./managedAppClipboardSharingLevel");
const managedAppDataTransferLevel_1 = require("./managedAppDataTransferLevel");
const managedAppPinCharacterSet_1 = require("./managedAppPinCharacterSet");
const managedBrowserType_1 = require("./managedBrowserType");
/** Policy used to configure detailed management settings for a specified set of apps */
class ManagedAppProtection extends index_1.ManagedAppPolicy {
    /**
     * Instantiates a new managedAppProtection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the allowedDataStorageLocations property value. Data storage locations where a user may store managed data.
     * @returns a string
     */
    get allowedDataStorageLocations() {
        return this._allowedDataStorageLocations;
    }
    ;
    /**
     * Sets the allowedDataStorageLocations property value. Data storage locations where a user may store managed data.
     * @param value Value to set for the allowedDataStorageLocations property.
     */
    set allowedDataStorageLocations(value) {
        this._allowedDataStorageLocations = value;
    }
    ;
    /**
     * Gets the allowedInboundDataTransferSources property value. Sources from which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @returns a managedAppDataTransferLevel
     */
    get allowedInboundDataTransferSources() {
        return this._allowedInboundDataTransferSources;
    }
    ;
    /**
     * Sets the allowedInboundDataTransferSources property value. Sources from which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @param value Value to set for the allowedInboundDataTransferSources property.
     */
    set allowedInboundDataTransferSources(value) {
        this._allowedInboundDataTransferSources = value;
    }
    ;
    /**
     * Gets the allowedOutboundClipboardSharingLevel property value. The level to which the clipboard may be shared between apps on the managed device. Possible values are: allApps, managedAppsWithPasteIn, managedApps, blocked.
     * @returns a managedAppClipboardSharingLevel
     */
    get allowedOutboundClipboardSharingLevel() {
        return this._allowedOutboundClipboardSharingLevel;
    }
    ;
    /**
     * Sets the allowedOutboundClipboardSharingLevel property value. The level to which the clipboard may be shared between apps on the managed device. Possible values are: allApps, managedAppsWithPasteIn, managedApps, blocked.
     * @param value Value to set for the allowedOutboundClipboardSharingLevel property.
     */
    set allowedOutboundClipboardSharingLevel(value) {
        this._allowedOutboundClipboardSharingLevel = value;
    }
    ;
    /**
     * Gets the allowedOutboundDataTransferDestinations property value. Destinations to which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @returns a managedAppDataTransferLevel
     */
    get allowedOutboundDataTransferDestinations() {
        return this._allowedOutboundDataTransferDestinations;
    }
    ;
    /**
     * Sets the allowedOutboundDataTransferDestinations property value. Destinations to which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @param value Value to set for the allowedOutboundDataTransferDestinations property.
     */
    set allowedOutboundDataTransferDestinations(value) {
        this._allowedOutboundDataTransferDestinations = value;
    }
    ;
    ;
    /**
     * Gets the contactSyncBlocked property value. Indicates whether contacts can be synced to the user's device.
     * @returns a boolean
     */
    get contactSyncBlocked() {
        return this._contactSyncBlocked;
    }
    ;
    /**
     * Sets the contactSyncBlocked property value. Indicates whether contacts can be synced to the user's device.
     * @param value Value to set for the contactSyncBlocked property.
     */
    set contactSyncBlocked(value) {
        this._contactSyncBlocked = value;
    }
    ;
    /**
     * Gets the dataBackupBlocked property value. Indicates whether the backup of a managed app's data is blocked.
     * @returns a boolean
     */
    get dataBackupBlocked() {
        return this._dataBackupBlocked;
    }
    ;
    /**
     * Sets the dataBackupBlocked property value. Indicates whether the backup of a managed app's data is blocked.
     * @param value Value to set for the dataBackupBlocked property.
     */
    set dataBackupBlocked(value) {
        this._dataBackupBlocked = value;
    }
    ;
    /**
     * Gets the deviceComplianceRequired property value. Indicates whether device compliance is required.
     * @returns a boolean
     */
    get deviceComplianceRequired() {
        return this._deviceComplianceRequired;
    }
    ;
    /**
     * Sets the deviceComplianceRequired property value. Indicates whether device compliance is required.
     * @param value Value to set for the deviceComplianceRequired property.
     */
    set deviceComplianceRequired(value) {
        this._deviceComplianceRequired = value;
    }
    ;
    /**
     * Gets the disableAppPinIfDevicePinIsSet property value. Indicates whether use of the app pin is required if the device pin is set.
     * @returns a boolean
     */
    get disableAppPinIfDevicePinIsSet() {
        return this._disableAppPinIfDevicePinIsSet;
    }
    ;
    /**
     * Sets the disableAppPinIfDevicePinIsSet property value. Indicates whether use of the app pin is required if the device pin is set.
     * @param value Value to set for the disableAppPinIfDevicePinIsSet property.
     */
    set disableAppPinIfDevicePinIsSet(value) {
        this._disableAppPinIfDevicePinIsSet = value;
    }
    ;
    /**
     * Gets the fingerprintBlocked property value. Indicates whether use of the fingerprint reader is allowed in place of a pin if PinRequired is set to True.
     * @returns a boolean
     */
    get fingerprintBlocked() {
        return this._fingerprintBlocked;
    }
    ;
    /**
     * Sets the fingerprintBlocked property value. Indicates whether use of the fingerprint reader is allowed in place of a pin if PinRequired is set to True.
     * @param value Value to set for the fingerprintBlocked property.
     */
    set fingerprintBlocked(value) {
        this._fingerprintBlocked = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "allowedDataStorageLocations": n => { this.allowedDataStorageLocations = n.getCollectionOfPrimitiveValues(); }, "allowedInboundDataTransferSources": n => { this.allowedInboundDataTransferSources = n.getEnumValue(managedAppDataTransferLevel_1.ManagedAppDataTransferLevel); }, "allowedOutboundClipboardSharingLevel": n => { this.allowedOutboundClipboardSharingLevel = n.getEnumValue(managedAppClipboardSharingLevel_1.ManagedAppClipboardSharingLevel); }, "allowedOutboundDataTransferDestinations": n => { this.allowedOutboundDataTransferDestinations = n.getEnumValue(managedAppDataTransferLevel_1.ManagedAppDataTransferLevel); }, "contactSyncBlocked": n => { this.contactSyncBlocked = n.getBooleanValue(); }, "dataBackupBlocked": n => { this.dataBackupBlocked = n.getBooleanValue(); }, "deviceComplianceRequired": n => { this.deviceComplianceRequired = n.getBooleanValue(); }, "disableAppPinIfDevicePinIsSet": n => { this.disableAppPinIfDevicePinIsSet = n.getBooleanValue(); }, "fingerprintBlocked": n => { this.fingerprintBlocked = n.getBooleanValue(); }, "managedBrowser": n => { this.managedBrowser = n.getEnumValue(managedBrowserType_1.ManagedBrowserType); }, "managedBrowserToOpenLinksRequired": n => { this.managedBrowserToOpenLinksRequired = n.getBooleanValue(); }, "maximumPinRetries": n => { this.maximumPinRetries = n.getNumberValue(); }, "minimumPinLength": n => { this.minimumPinLength = n.getNumberValue(); }, "minimumRequiredAppVersion": n => { this.minimumRequiredAppVersion = n.getStringValue(); }, "minimumRequiredOsVersion": n => { this.minimumRequiredOsVersion = n.getStringValue(); }, "minimumWarningAppVersion": n => { this.minimumWarningAppVersion = n.getStringValue(); }, "minimumWarningOsVersion": n => { this.minimumWarningOsVersion = n.getStringValue(); }, "organizationalCredentialsRequired": n => { this.organizationalCredentialsRequired = n.getBooleanValue(); }, "periodBeforePinReset": n => { this.periodBeforePinReset = n.getDurationValue(); }, "periodOfflineBeforeAccessCheck": n => { this.periodOfflineBeforeAccessCheck = n.getDurationValue(); }, "periodOfflineBeforeWipeIsEnforced": n => { this.periodOfflineBeforeWipeIsEnforced = n.getDurationValue(); }, "periodOnlineBeforeAccessCheck": n => { this.periodOnlineBeforeAccessCheck = n.getDurationValue(); }, "pinCharacterSet": n => { this.pinCharacterSet = n.getEnumValue(managedAppPinCharacterSet_1.ManagedAppPinCharacterSet); }, "pinRequired": n => { this.pinRequired = n.getBooleanValue(); }, "printBlocked": n => { this.printBlocked = n.getBooleanValue(); }, "saveAsBlocked": n => { this.saveAsBlocked = n.getBooleanValue(); }, "simplePinBlocked": n => { this.simplePinBlocked = n.getBooleanValue(); } });
    }
    ;
    /**
     * Gets the managedBrowser property value. Indicates in which managed browser(s) that internet links should be opened. When this property is configured, ManagedBrowserToOpenLinksRequired should be true. Possible values are: notConfigured, microsoftEdge.
     * @returns a managedBrowserType
     */
    get managedBrowser() {
        return this._managedBrowser;
    }
    ;
    /**
     * Sets the managedBrowser property value. Indicates in which managed browser(s) that internet links should be opened. When this property is configured, ManagedBrowserToOpenLinksRequired should be true. Possible values are: notConfigured, microsoftEdge.
     * @param value Value to set for the managedBrowser property.
     */
    set managedBrowser(value) {
        this._managedBrowser = value;
    }
    ;
    /**
     * Gets the managedBrowserToOpenLinksRequired property value. Indicates whether internet links should be opened in the managed browser app, or any custom browser specified by CustomBrowserProtocol (for iOS) or CustomBrowserPackageId/CustomBrowserDisplayName (for Android)
     * @returns a boolean
     */
    get managedBrowserToOpenLinksRequired() {
        return this._managedBrowserToOpenLinksRequired;
    }
    ;
    /**
     * Sets the managedBrowserToOpenLinksRequired property value. Indicates whether internet links should be opened in the managed browser app, or any custom browser specified by CustomBrowserProtocol (for iOS) or CustomBrowserPackageId/CustomBrowserDisplayName (for Android)
     * @param value Value to set for the managedBrowserToOpenLinksRequired property.
     */
    set managedBrowserToOpenLinksRequired(value) {
        this._managedBrowserToOpenLinksRequired = value;
    }
    ;
    /**
     * Gets the maximumPinRetries property value. Maximum number of incorrect pin retry attempts before the managed app is either blocked or wiped.
     * @returns a integer
     */
    get maximumPinRetries() {
        return this._maximumPinRetries;
    }
    ;
    /**
     * Sets the maximumPinRetries property value. Maximum number of incorrect pin retry attempts before the managed app is either blocked or wiped.
     * @param value Value to set for the maximumPinRetries property.
     */
    set maximumPinRetries(value) {
        this._maximumPinRetries = value;
    }
    ;
    /**
     * Gets the minimumPinLength property value. Minimum pin length required for an app-level pin if PinRequired is set to True
     * @returns a integer
     */
    get minimumPinLength() {
        return this._minimumPinLength;
    }
    ;
    /**
     * Sets the minimumPinLength property value. Minimum pin length required for an app-level pin if PinRequired is set to True
     * @param value Value to set for the minimumPinLength property.
     */
    set minimumPinLength(value) {
        this._minimumPinLength = value;
    }
    ;
    /**
     * Gets the minimumRequiredAppVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredAppVersion() {
        return this._minimumRequiredAppVersion;
    }
    ;
    /**
     * Sets the minimumRequiredAppVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredAppVersion property.
     */
    set minimumRequiredAppVersion(value) {
        this._minimumRequiredAppVersion = value;
    }
    ;
    /**
     * Gets the minimumRequiredOsVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredOsVersion() {
        return this._minimumRequiredOsVersion;
    }
    ;
    /**
     * Sets the minimumRequiredOsVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredOsVersion property.
     */
    set minimumRequiredOsVersion(value) {
        this._minimumRequiredOsVersion = value;
    }
    ;
    /**
     * Gets the minimumWarningAppVersion property value. Versions less than the specified version will result in warning message on the managed app.
     * @returns a string
     */
    get minimumWarningAppVersion() {
        return this._minimumWarningAppVersion;
    }
    ;
    /**
     * Sets the minimumWarningAppVersion property value. Versions less than the specified version will result in warning message on the managed app.
     * @param value Value to set for the minimumWarningAppVersion property.
     */
    set minimumWarningAppVersion(value) {
        this._minimumWarningAppVersion = value;
    }
    ;
    /**
     * Gets the minimumWarningOsVersion property value. Versions less than the specified version will result in warning message on the managed app from accessing company data.
     * @returns a string
     */
    get minimumWarningOsVersion() {
        return this._minimumWarningOsVersion;
    }
    ;
    /**
     * Sets the minimumWarningOsVersion property value. Versions less than the specified version will result in warning message on the managed app from accessing company data.
     * @param value Value to set for the minimumWarningOsVersion property.
     */
    set minimumWarningOsVersion(value) {
        this._minimumWarningOsVersion = value;
    }
    ;
    /**
     * Gets the organizationalCredentialsRequired property value. Indicates whether organizational credentials are required for app use.
     * @returns a boolean
     */
    get organizationalCredentialsRequired() {
        return this._organizationalCredentialsRequired;
    }
    ;
    /**
     * Sets the organizationalCredentialsRequired property value. Indicates whether organizational credentials are required for app use.
     * @param value Value to set for the organizationalCredentialsRequired property.
     */
    set organizationalCredentialsRequired(value) {
        this._organizationalCredentialsRequired = value;
    }
    ;
    /**
     * Gets the periodBeforePinReset property value. TimePeriod before the all-level pin must be reset if PinRequired is set to True.
     * @returns a Duration
     */
    get periodBeforePinReset() {
        return this._periodBeforePinReset;
    }
    ;
    /**
     * Sets the periodBeforePinReset property value. TimePeriod before the all-level pin must be reset if PinRequired is set to True.
     * @param value Value to set for the periodBeforePinReset property.
     */
    set periodBeforePinReset(value) {
        this._periodBeforePinReset = value;
    }
    ;
    /**
     * Gets the periodOfflineBeforeAccessCheck property value. The period after which access is checked when the device is not connected to the internet.
     * @returns a Duration
     */
    get periodOfflineBeforeAccessCheck() {
        return this._periodOfflineBeforeAccessCheck;
    }
    ;
    /**
     * Sets the periodOfflineBeforeAccessCheck property value. The period after which access is checked when the device is not connected to the internet.
     * @param value Value to set for the periodOfflineBeforeAccessCheck property.
     */
    set periodOfflineBeforeAccessCheck(value) {
        this._periodOfflineBeforeAccessCheck = value;
    }
    ;
    /**
     * Gets the periodOfflineBeforeWipeIsEnforced property value. The amount of time an app is allowed to remain disconnected from the internet before all managed data it is wiped.
     * @returns a Duration
     */
    get periodOfflineBeforeWipeIsEnforced() {
        return this._periodOfflineBeforeWipeIsEnforced;
    }
    ;
    /**
     * Sets the periodOfflineBeforeWipeIsEnforced property value. The amount of time an app is allowed to remain disconnected from the internet before all managed data it is wiped.
     * @param value Value to set for the periodOfflineBeforeWipeIsEnforced property.
     */
    set periodOfflineBeforeWipeIsEnforced(value) {
        this._periodOfflineBeforeWipeIsEnforced = value;
    }
    ;
    /**
     * Gets the periodOnlineBeforeAccessCheck property value. The period after which access is checked when the device is connected to the internet.
     * @returns a Duration
     */
    get periodOnlineBeforeAccessCheck() {
        return this._periodOnlineBeforeAccessCheck;
    }
    ;
    /**
     * Sets the periodOnlineBeforeAccessCheck property value. The period after which access is checked when the device is connected to the internet.
     * @param value Value to set for the periodOnlineBeforeAccessCheck property.
     */
    set periodOnlineBeforeAccessCheck(value) {
        this._periodOnlineBeforeAccessCheck = value;
    }
    ;
    /**
     * Gets the pinCharacterSet property value. Character set which may be used for an app-level pin if PinRequired is set to True. Possible values are: numeric, alphanumericAndSymbol.
     * @returns a managedAppPinCharacterSet
     */
    get pinCharacterSet() {
        return this._pinCharacterSet;
    }
    ;
    /**
     * Sets the pinCharacterSet property value. Character set which may be used for an app-level pin if PinRequired is set to True. Possible values are: numeric, alphanumericAndSymbol.
     * @param value Value to set for the pinCharacterSet property.
     */
    set pinCharacterSet(value) {
        this._pinCharacterSet = value;
    }
    ;
    /**
     * Gets the pinRequired property value. Indicates whether an app-level pin is required.
     * @returns a boolean
     */
    get pinRequired() {
        return this._pinRequired;
    }
    ;
    /**
     * Sets the pinRequired property value. Indicates whether an app-level pin is required.
     * @param value Value to set for the pinRequired property.
     */
    set pinRequired(value) {
        this._pinRequired = value;
    }
    ;
    /**
     * Gets the printBlocked property value. Indicates whether printing is allowed from managed apps.
     * @returns a boolean
     */
    get printBlocked() {
        return this._printBlocked;
    }
    ;
    /**
     * Sets the printBlocked property value. Indicates whether printing is allowed from managed apps.
     * @param value Value to set for the printBlocked property.
     */
    set printBlocked(value) {
        this._printBlocked = value;
    }
    ;
    /**
     * Gets the saveAsBlocked property value. Indicates whether users may use the 'Save As' menu item to save a copy of protected files.
     * @returns a boolean
     */
    get saveAsBlocked() {
        return this._saveAsBlocked;
    }
    ;
    /**
     * Sets the saveAsBlocked property value. Indicates whether users may use the 'Save As' menu item to save a copy of protected files.
     * @param value Value to set for the saveAsBlocked property.
     */
    set saveAsBlocked(value) {
        this._saveAsBlocked = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfPrimitiveValues("allowedDataStorageLocations", this.allowedDataStorageLocations);
        writer.writeEnumValue("allowedInboundDataTransferSources", this.allowedInboundDataTransferSources);
        writer.writeEnumValue("allowedOutboundClipboardSharingLevel", this.allowedOutboundClipboardSharingLevel);
        writer.writeEnumValue("allowedOutboundDataTransferDestinations", this.allowedOutboundDataTransferDestinations);
        writer.writeBooleanValue("contactSyncBlocked", this.contactSyncBlocked);
        writer.writeBooleanValue("dataBackupBlocked", this.dataBackupBlocked);
        writer.writeBooleanValue("deviceComplianceRequired", this.deviceComplianceRequired);
        writer.writeBooleanValue("disableAppPinIfDevicePinIsSet", this.disableAppPinIfDevicePinIsSet);
        writer.writeBooleanValue("fingerprintBlocked", this.fingerprintBlocked);
        writer.writeEnumValue("managedBrowser", this.managedBrowser);
        writer.writeBooleanValue("managedBrowserToOpenLinksRequired", this.managedBrowserToOpenLinksRequired);
        writer.writeNumberValue("maximumPinRetries", this.maximumPinRetries);
        writer.writeNumberValue("minimumPinLength", this.minimumPinLength);
        writer.writeStringValue("minimumRequiredAppVersion", this.minimumRequiredAppVersion);
        writer.writeStringValue("minimumRequiredOsVersion", this.minimumRequiredOsVersion);
        writer.writeStringValue("minimumWarningAppVersion", this.minimumWarningAppVersion);
        writer.writeStringValue("minimumWarningOsVersion", this.minimumWarningOsVersion);
        writer.writeBooleanValue("organizationalCredentialsRequired", this.organizationalCredentialsRequired);
        writer.writeDurationValue("periodBeforePinReset", this.periodBeforePinReset);
        writer.writeDurationValue("periodOfflineBeforeAccessCheck", this.periodOfflineBeforeAccessCheck);
        writer.writeDurationValue("periodOfflineBeforeWipeIsEnforced", this.periodOfflineBeforeWipeIsEnforced);
        writer.writeDurationValue("periodOnlineBeforeAccessCheck", this.periodOnlineBeforeAccessCheck);
        writer.writeEnumValue("pinCharacterSet", this.pinCharacterSet);
        writer.writeBooleanValue("pinRequired", this.pinRequired);
        writer.writeBooleanValue("printBlocked", this.printBlocked);
        writer.writeBooleanValue("saveAsBlocked", this.saveAsBlocked);
        writer.writeBooleanValue("simplePinBlocked", this.simplePinBlocked);
    }
    ;
    /**
     * Gets the simplePinBlocked property value. Indicates whether simplePin is blocked.
     * @returns a boolean
     */
    get simplePinBlocked() {
        return this._simplePinBlocked;
    }
    ;
    /**
     * Sets the simplePinBlocked property value. Indicates whether simplePin is blocked.
     * @param value Value to set for the simplePinBlocked property.
     */
    set simplePinBlocked(value) {
        this._simplePinBlocked = value;
    }
    ;
}
exports.ManagedAppProtection = ManagedAppProtection;
