import { Entity, ManagedAppOperation, ManagedAppPolicy, MobileAppIdentifier } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** The ManagedAppEntity is the base entity type for all other entity types under app management workflow. */
export declare class ManagedAppRegistration extends Entity implements Parsable {
    /** The app package Identifier */
    private _appIdentifier?;
    /** App version */
    private _applicationVersion?;
    /** Zero or more policys already applied on the registered app when it last synchronized with managment service. */
    private _appliedPolicies?;
    /** Date and time of creation */
    private _createdDateTime?;
    /** Host device name */
    private _deviceName?;
    /** App management SDK generated tag, which helps relate apps hosted on the same device. Not guaranteed to relate apps in all conditions. */
    private _deviceTag?;
    /** Host device type */
    private _deviceType?;
    /** Zero or more reasons an app registration is flagged. E.g. app running on rooted device */
    private _flaggedReasons?;
    /** Zero or more policies admin intended for the app as of now. */
    private _intendedPolicies?;
    /** Date and time of last the app synced with management service. */
    private _lastSyncDateTime?;
    /** App management SDK version */
    private _managementSdkVersion?;
    /** Zero or more long running operations triggered on the app registration. */
    private _operations?;
    /** Operating System version */
    private _platformVersion?;
    /** The user Id to who this app registration belongs. */
    private _userId?;
    /** Version of the entity. */
    private _version?;
    /**
     * Gets the appIdentifier property value. The app package Identifier
     * @returns a mobileAppIdentifier
     */
    get appIdentifier(): MobileAppIdentifier | undefined;
    /**
     * Sets the appIdentifier property value. The app package Identifier
     * @param value Value to set for the appIdentifier property.
     */
    set appIdentifier(value: MobileAppIdentifier | undefined);
    /**
     * Gets the applicationVersion property value. App version
     * @returns a string
     */
    get applicationVersion(): string | undefined;
    /**
     * Sets the applicationVersion property value. App version
     * @param value Value to set for the applicationVersion property.
     */
    set applicationVersion(value: string | undefined);
    /**
     * Gets the appliedPolicies property value. Zero or more policys already applied on the registered app when it last synchronized with managment service.
     * @returns a managedAppPolicy
     */
    get appliedPolicies(): ManagedAppPolicy[] | undefined;
    /**
     * Sets the appliedPolicies property value. Zero or more policys already applied on the registered app when it last synchronized with managment service.
     * @param value Value to set for the appliedPolicies property.
     */
    set appliedPolicies(value: ManagedAppPolicy[] | undefined);
    /**
     * Instantiates a new managedAppRegistration and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Date and time of creation
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Date and time of creation
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the deviceName property value. Host device name
     * @returns a string
     */
    get deviceName(): string | undefined;
    /**
     * Sets the deviceName property value. Host device name
     * @param value Value to set for the deviceName property.
     */
    set deviceName(value: string | undefined);
    /**
     * Gets the deviceTag property value. App management SDK generated tag, which helps relate apps hosted on the same device. Not guaranteed to relate apps in all conditions.
     * @returns a string
     */
    get deviceTag(): string | undefined;
    /**
     * Sets the deviceTag property value. App management SDK generated tag, which helps relate apps hosted on the same device. Not guaranteed to relate apps in all conditions.
     * @param value Value to set for the deviceTag property.
     */
    set deviceTag(value: string | undefined);
    /**
     * Gets the deviceType property value. Host device type
     * @returns a string
     */
    get deviceType(): string | undefined;
    /**
     * Sets the deviceType property value. Host device type
     * @param value Value to set for the deviceType property.
     */
    set deviceType(value: string | undefined);
    /**
     * Gets the flaggedReasons property value. Zero or more reasons an app registration is flagged. E.g. app running on rooted device
     * @returns a string
     */
    get flaggedReasons(): string[] | undefined;
    /**
     * Sets the flaggedReasons property value. Zero or more reasons an app registration is flagged. E.g. app running on rooted device
     * @param value Value to set for the flaggedReasons property.
     */
    set flaggedReasons(value: string[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the intendedPolicies property value. Zero or more policies admin intended for the app as of now.
     * @returns a managedAppPolicy
     */
    get intendedPolicies(): ManagedAppPolicy[] | undefined;
    /**
     * Sets the intendedPolicies property value. Zero or more policies admin intended for the app as of now.
     * @param value Value to set for the intendedPolicies property.
     */
    set intendedPolicies(value: ManagedAppPolicy[] | undefined);
    /**
     * Gets the lastSyncDateTime property value. Date and time of last the app synced with management service.
     * @returns a Date
     */
    get lastSyncDateTime(): Date | undefined;
    /**
     * Sets the lastSyncDateTime property value. Date and time of last the app synced with management service.
     * @param value Value to set for the lastSyncDateTime property.
     */
    set lastSyncDateTime(value: Date | undefined);
    /**
     * Gets the managementSdkVersion property value. App management SDK version
     * @returns a string
     */
    get managementSdkVersion(): string | undefined;
    /**
     * Sets the managementSdkVersion property value. App management SDK version
     * @param value Value to set for the managementSdkVersion property.
     */
    set managementSdkVersion(value: string | undefined);
    /**
     * Gets the operations property value. Zero or more long running operations triggered on the app registration.
     * @returns a managedAppOperation
     */
    get operations(): ManagedAppOperation[] | undefined;
    /**
     * Sets the operations property value. Zero or more long running operations triggered on the app registration.
     * @param value Value to set for the operations property.
     */
    set operations(value: ManagedAppOperation[] | undefined);
    /**
     * Gets the platformVersion property value. Operating System version
     * @returns a string
     */
    get platformVersion(): string | undefined;
    /**
     * Sets the platformVersion property value. Operating System version
     * @param value Value to set for the platformVersion property.
     */
    set platformVersion(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the userId property value. The user Id to who this app registration belongs.
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. The user Id to who this app registration belongs.
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
    /**
     * Gets the version property value. Version of the entity.
     * @returns a string
     */
    get version(): string | undefined;
    /**
     * Sets the version property value. Version of the entity.
     * @param value Value to set for the version property.
     */
    set version(value: string | undefined);
}
