import { ComplianceState } from './complianceState';
import { DeviceEnrollmentType } from './deviceEnrollmentType';
import { DeviceManagementExchangeAccessState } from './deviceManagementExchangeAccessState';
import { DeviceManagementExchangeAccessStateReason } from './deviceManagementExchangeAccessStateReason';
import { DeviceRegistrationState } from './deviceRegistrationState';
import { ConfigurationManagerClientEnabledFeatures, DeviceActionResult, DeviceCategory, DeviceCompliancePolicyState, DeviceConfigurationState, DeviceHealthAttestationState, Entity } from './index';
import { ManagedDeviceOwnerType } from './managedDeviceOwnerType';
import { ManagedDevicePartnerReportedHealthState } from './managedDevicePartnerReportedHealthState';
import { ManagementAgentType } from './managementAgentType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Devices that are managed or pre-enrolled through Intune */
export declare class ManagedDevice extends Entity implements Parsable {
    /** Code that allows the Activation Lock on a device to be bypassed. This property is read-only. */
    private _activationLockBypassCode?;
    /** Android security patch level. This property is read-only. */
    private _androidSecurityPatchLevel?;
    /** The unique identifier for the Azure Active Directory device. Read only. This property is read-only. */
    private _azureADDeviceId?;
    /** Whether the device is Azure Active Directory registered. This property is read-only. */
    private _azureADRegistered?;
    /** The DateTime when device compliance grace period expires. This property is read-only. */
    private _complianceGracePeriodExpirationDateTime?;
    /** Compliance state of the device. This property is read-only. Possible values are: unknown, compliant, noncompliant, conflict, error, inGracePeriod, configManager. */
    private _complianceState?;
    /** ConfigrMgr client enabled features. This property is read-only. */
    private _configurationManagerClientEnabledFeatures?;
    /** List of ComplexType deviceActionResult objects. This property is read-only. */
    private _deviceActionResults?;
    /** Device category */
    private _deviceCategory?;
    /** Device category display name. This property is read-only. */
    private _deviceCategoryDisplayName?;
    /** Device compliance policy states for this device. */
    private _deviceCompliancePolicyStates?;
    /** Device configuration states for this device. */
    private _deviceConfigurationStates?;
    /** Enrollment type of the device. This property is read-only. Possible values are: unknown, userEnrollment, deviceEnrollmentManager, appleBulkWithUser, appleBulkWithoutUser, windowsAzureADJoin, windowsBulkUserless, windowsAutoEnrollment, windowsBulkAzureDomainJoin, windowsCoManagement, windowsAzureADJoinUsingDeviceAuth, appleUserEnrollment, appleUserEnrollmentWithServiceAccount, azureAdJoinUsingAzureVmExtension, androidEnterpriseDedicatedDevice, androidEnterpriseFullyManaged, androidEnterpriseCorporateWorkProfile. */
    private _deviceEnrollmentType?;
    /** The device health attestation state. This property is read-only. */
    private _deviceHealthAttestationState?;
    /** Name of the device. This property is read-only. */
    private _deviceName?;
    /** Device registration state. This property is read-only. Possible values are: notRegistered, registered, revoked, keyConflict, approvalPending, certificateReset, notRegisteredPendingEnrollment, unknown. */
    private _deviceRegistrationState?;
    /** Whether the device is Exchange ActiveSync activated. This property is read-only. */
    private _easActivated?;
    /** Exchange ActivationSync activation time of the device. This property is read-only. */
    private _easActivationDateTime?;
    /** Exchange ActiveSync Id of the device. This property is read-only. */
    private _easDeviceId?;
    /** Email(s) for the user associated with the device. This property is read-only. */
    private _emailAddress?;
    /** Enrollment time of the device. This property is read-only. */
    private _enrolledDateTime?;
    /** Ethernet MAC. This property is read-only. */
    private _ethernetMacAddress?;
    /** The Access State of the device in Exchange. This property is read-only. Possible values are: none, unknown, allowed, blocked, quarantined. */
    private _exchangeAccessState?;
    /** The reason for the device's access state in Exchange. This property is read-only. Possible values are: none, unknown, exchangeGlobalRule, exchangeIndividualRule, exchangeDeviceRule, exchangeUpgrade, exchangeMailboxPolicy, other, compliant, notCompliant, notEnrolled, unknownLocation, mfaRequired, azureADBlockDueToAccessPolicy, compromisedPassword, deviceNotKnownWithManagedApp. */
    private _exchangeAccessStateReason?;
    /** Last time the device contacted Exchange. This property is read-only. */
    private _exchangeLastSuccessfulSyncDateTime?;
    /** Free Storage in Bytes. This property is read-only. */
    private _freeStorageSpaceInBytes?;
    /** Integrated Circuit Card Identifier, it is A SIM card's unique identification number. This property is read-only. */
    private _iccid?;
    /** IMEI. This property is read-only. */
    private _imei?;
    /** Device encryption status. This property is read-only. */
    private _isEncrypted?;
    /** Device supervised status. This property is read-only. */
    private _isSupervised?;
    /** whether the device is jail broken or rooted. This property is read-only. */
    private _jailBroken?;
    /** The date and time that the device last completed a successful sync with Intune. This property is read-only. */
    private _lastSyncDateTime?;
    /** Automatically generated name to identify a device. Can be overwritten to a user friendly name. */
    private _managedDeviceName?;
    /** Ownership of the device. Can be 'company' or 'personal'. Possible values are: unknown, company, personal. */
    private _managedDeviceOwnerType?;
    /** Management channel of the device. Intune, EAS, etc. This property is read-only. Possible values are: eas, mdm, easMdm, intuneClient, easIntuneClient, configurationManagerClient, configurationManagerClientMdm, configurationManagerClientMdmEas, unknown, jamf, googleCloudDevicePolicyController, microsoft365ManagedMdm, msSense, intuneAosp. */
    private _managementAgent?;
    /** Manufacturer of the device. This property is read-only. */
    private _manufacturer?;
    /** MEID. This property is read-only. */
    private _meid?;
    /** Model of the device. This property is read-only. */
    private _model?;
    /** Notes on the device created by IT Admin */
    private _notes?;
    /** Operating system of the device. Windows, iOS, etc. This property is read-only. */
    private _operatingSystem?;
    /** Operating system version of the device. This property is read-only. */
    private _osVersion?;
    /** Indicates the threat state of a device when a Mobile Threat Defense partner is in use by the account and device. Read Only. This property is read-only. Possible values are: unknown, activated, deactivated, secured, lowSeverity, mediumSeverity, highSeverity, unresponsive, compromised, misconfigured. */
    private _partnerReportedThreatState?;
    /** Phone number of the device. This property is read-only. */
    private _phoneNumber?;
    /** Total Memory in Bytes. This property is read-only. */
    private _physicalMemoryInBytes?;
    /** An error string that identifies issues when creating Remote Assistance session objects. This property is read-only. */
    private _remoteAssistanceSessionErrorDetails?;
    /** Url that allows a Remote Assistance session to be established with the device. This property is read-only. */
    private _remoteAssistanceSessionUrl?;
    /** SerialNumber. This property is read-only. */
    private _serialNumber?;
    /** Subscriber Carrier. This property is read-only. */
    private _subscriberCarrier?;
    /** Total Storage in Bytes. This property is read-only. */
    private _totalStorageSpaceInBytes?;
    /** Unique Device Identifier for iOS and macOS devices. This property is read-only. */
    private _udid?;
    /** User display name. This property is read-only. */
    private _userDisplayName?;
    /** Unique Identifier for the user associated with the device. This property is read-only. */
    private _userId?;
    /** Device user principal name. This property is read-only. */
    private _userPrincipalName?;
    /** Wi-Fi MAC. This property is read-only. */
    private _wiFiMacAddress?;
    /**
     * Gets the activationLockBypassCode property value. Code that allows the Activation Lock on a device to be bypassed. This property is read-only.
     * @returns a string
     */
    get activationLockBypassCode(): string | undefined;
    /**
     * Sets the activationLockBypassCode property value. Code that allows the Activation Lock on a device to be bypassed. This property is read-only.
     * @param value Value to set for the activationLockBypassCode property.
     */
    set activationLockBypassCode(value: string | undefined);
    /**
     * Gets the androidSecurityPatchLevel property value. Android security patch level. This property is read-only.
     * @returns a string
     */
    get androidSecurityPatchLevel(): string | undefined;
    /**
     * Sets the androidSecurityPatchLevel property value. Android security patch level. This property is read-only.
     * @param value Value to set for the androidSecurityPatchLevel property.
     */
    set androidSecurityPatchLevel(value: string | undefined);
    /**
     * Gets the azureADDeviceId property value. The unique identifier for the Azure Active Directory device. Read only. This property is read-only.
     * @returns a string
     */
    get azureADDeviceId(): string | undefined;
    /**
     * Sets the azureADDeviceId property value. The unique identifier for the Azure Active Directory device. Read only. This property is read-only.
     * @param value Value to set for the azureADDeviceId property.
     */
    set azureADDeviceId(value: string | undefined);
    /**
     * Gets the azureADRegistered property value. Whether the device is Azure Active Directory registered. This property is read-only.
     * @returns a boolean
     */
    get azureADRegistered(): boolean | undefined;
    /**
     * Sets the azureADRegistered property value. Whether the device is Azure Active Directory registered. This property is read-only.
     * @param value Value to set for the azureADRegistered property.
     */
    set azureADRegistered(value: boolean | undefined);
    /**
     * Gets the complianceGracePeriodExpirationDateTime property value. The DateTime when device compliance grace period expires. This property is read-only.
     * @returns a Date
     */
    get complianceGracePeriodExpirationDateTime(): Date | undefined;
    /**
     * Sets the complianceGracePeriodExpirationDateTime property value. The DateTime when device compliance grace period expires. This property is read-only.
     * @param value Value to set for the complianceGracePeriodExpirationDateTime property.
     */
    set complianceGracePeriodExpirationDateTime(value: Date | undefined);
    /**
     * Gets the complianceState property value. Compliance state of the device. This property is read-only. Possible values are: unknown, compliant, noncompliant, conflict, error, inGracePeriod, configManager.
     * @returns a complianceState
     */
    get complianceState(): ComplianceState | undefined;
    /**
     * Sets the complianceState property value. Compliance state of the device. This property is read-only. Possible values are: unknown, compliant, noncompliant, conflict, error, inGracePeriod, configManager.
     * @param value Value to set for the complianceState property.
     */
    set complianceState(value: ComplianceState | undefined);
    /**
     * Gets the configurationManagerClientEnabledFeatures property value. ConfigrMgr client enabled features. This property is read-only.
     * @returns a configurationManagerClientEnabledFeatures
     */
    get configurationManagerClientEnabledFeatures(): ConfigurationManagerClientEnabledFeatures | undefined;
    /**
     * Sets the configurationManagerClientEnabledFeatures property value. ConfigrMgr client enabled features. This property is read-only.
     * @param value Value to set for the configurationManagerClientEnabledFeatures property.
     */
    set configurationManagerClientEnabledFeatures(value: ConfigurationManagerClientEnabledFeatures | undefined);
    /**
     * Instantiates a new managedDevice and sets the default values.
     */
    constructor();
    /**
     * Gets the deviceActionResults property value. List of ComplexType deviceActionResult objects. This property is read-only.
     * @returns a deviceActionResult
     */
    get deviceActionResults(): DeviceActionResult[] | undefined;
    /**
     * Sets the deviceActionResults property value. List of ComplexType deviceActionResult objects. This property is read-only.
     * @param value Value to set for the deviceActionResults property.
     */
    set deviceActionResults(value: DeviceActionResult[] | undefined);
    /**
     * Gets the deviceCategory property value. Device category
     * @returns a deviceCategory
     */
    get deviceCategory(): DeviceCategory | undefined;
    /**
     * Sets the deviceCategory property value. Device category
     * @param value Value to set for the deviceCategory property.
     */
    set deviceCategory(value: DeviceCategory | undefined);
    /**
     * Gets the deviceCategoryDisplayName property value. Device category display name. This property is read-only.
     * @returns a string
     */
    get deviceCategoryDisplayName(): string | undefined;
    /**
     * Sets the deviceCategoryDisplayName property value. Device category display name. This property is read-only.
     * @param value Value to set for the deviceCategoryDisplayName property.
     */
    set deviceCategoryDisplayName(value: string | undefined);
    /**
     * Gets the deviceCompliancePolicyStates property value. Device compliance policy states for this device.
     * @returns a deviceCompliancePolicyState
     */
    get deviceCompliancePolicyStates(): DeviceCompliancePolicyState[] | undefined;
    /**
     * Sets the deviceCompliancePolicyStates property value. Device compliance policy states for this device.
     * @param value Value to set for the deviceCompliancePolicyStates property.
     */
    set deviceCompliancePolicyStates(value: DeviceCompliancePolicyState[] | undefined);
    /**
     * Gets the deviceConfigurationStates property value. Device configuration states for this device.
     * @returns a deviceConfigurationState
     */
    get deviceConfigurationStates(): DeviceConfigurationState[] | undefined;
    /**
     * Sets the deviceConfigurationStates property value. Device configuration states for this device.
     * @param value Value to set for the deviceConfigurationStates property.
     */
    set deviceConfigurationStates(value: DeviceConfigurationState[] | undefined);
    /**
     * Gets the deviceEnrollmentType property value. Enrollment type of the device. This property is read-only. Possible values are: unknown, userEnrollment, deviceEnrollmentManager, appleBulkWithUser, appleBulkWithoutUser, windowsAzureADJoin, windowsBulkUserless, windowsAutoEnrollment, windowsBulkAzureDomainJoin, windowsCoManagement, windowsAzureADJoinUsingDeviceAuth, appleUserEnrollment, appleUserEnrollmentWithServiceAccount, azureAdJoinUsingAzureVmExtension, androidEnterpriseDedicatedDevice, androidEnterpriseFullyManaged, androidEnterpriseCorporateWorkProfile.
     * @returns a deviceEnrollmentType
     */
    get deviceEnrollmentType(): DeviceEnrollmentType | undefined;
    /**
     * Sets the deviceEnrollmentType property value. Enrollment type of the device. This property is read-only. Possible values are: unknown, userEnrollment, deviceEnrollmentManager, appleBulkWithUser, appleBulkWithoutUser, windowsAzureADJoin, windowsBulkUserless, windowsAutoEnrollment, windowsBulkAzureDomainJoin, windowsCoManagement, windowsAzureADJoinUsingDeviceAuth, appleUserEnrollment, appleUserEnrollmentWithServiceAccount, azureAdJoinUsingAzureVmExtension, androidEnterpriseDedicatedDevice, androidEnterpriseFullyManaged, androidEnterpriseCorporateWorkProfile.
     * @param value Value to set for the deviceEnrollmentType property.
     */
    set deviceEnrollmentType(value: DeviceEnrollmentType | undefined);
    /**
     * Gets the deviceHealthAttestationState property value. The device health attestation state. This property is read-only.
     * @returns a deviceHealthAttestationState
     */
    get deviceHealthAttestationState(): DeviceHealthAttestationState | undefined;
    /**
     * Sets the deviceHealthAttestationState property value. The device health attestation state. This property is read-only.
     * @param value Value to set for the deviceHealthAttestationState property.
     */
    set deviceHealthAttestationState(value: DeviceHealthAttestationState | undefined);
    /**
     * Gets the deviceName property value. Name of the device. This property is read-only.
     * @returns a string
     */
    get deviceName(): string | undefined;
    /**
     * Sets the deviceName property value. Name of the device. This property is read-only.
     * @param value Value to set for the deviceName property.
     */
    set deviceName(value: string | undefined);
    /**
     * Gets the deviceRegistrationState property value. Device registration state. This property is read-only. Possible values are: notRegistered, registered, revoked, keyConflict, approvalPending, certificateReset, notRegisteredPendingEnrollment, unknown.
     * @returns a deviceRegistrationState
     */
    get deviceRegistrationState(): DeviceRegistrationState | undefined;
    /**
     * Sets the deviceRegistrationState property value. Device registration state. This property is read-only. Possible values are: notRegistered, registered, revoked, keyConflict, approvalPending, certificateReset, notRegisteredPendingEnrollment, unknown.
     * @param value Value to set for the deviceRegistrationState property.
     */
    set deviceRegistrationState(value: DeviceRegistrationState | undefined);
    /**
     * Gets the easActivated property value. Whether the device is Exchange ActiveSync activated. This property is read-only.
     * @returns a boolean
     */
    get easActivated(): boolean | undefined;
    /**
     * Sets the easActivated property value. Whether the device is Exchange ActiveSync activated. This property is read-only.
     * @param value Value to set for the easActivated property.
     */
    set easActivated(value: boolean | undefined);
    /**
     * Gets the easActivationDateTime property value. Exchange ActivationSync activation time of the device. This property is read-only.
     * @returns a Date
     */
    get easActivationDateTime(): Date | undefined;
    /**
     * Sets the easActivationDateTime property value. Exchange ActivationSync activation time of the device. This property is read-only.
     * @param value Value to set for the easActivationDateTime property.
     */
    set easActivationDateTime(value: Date | undefined);
    /**
     * Gets the easDeviceId property value. Exchange ActiveSync Id of the device. This property is read-only.
     * @returns a string
     */
    get easDeviceId(): string | undefined;
    /**
     * Sets the easDeviceId property value. Exchange ActiveSync Id of the device. This property is read-only.
     * @param value Value to set for the easDeviceId property.
     */
    set easDeviceId(value: string | undefined);
    /**
     * Gets the emailAddress property value. Email(s) for the user associated with the device. This property is read-only.
     * @returns a string
     */
    get emailAddress(): string | undefined;
    /**
     * Sets the emailAddress property value. Email(s) for the user associated with the device. This property is read-only.
     * @param value Value to set for the emailAddress property.
     */
    set emailAddress(value: string | undefined);
    /**
     * Gets the enrolledDateTime property value. Enrollment time of the device. This property is read-only.
     * @returns a Date
     */
    get enrolledDateTime(): Date | undefined;
    /**
     * Sets the enrolledDateTime property value. Enrollment time of the device. This property is read-only.
     * @param value Value to set for the enrolledDateTime property.
     */
    set enrolledDateTime(value: Date | undefined);
    /**
     * Gets the ethernetMacAddress property value. Ethernet MAC. This property is read-only.
     * @returns a string
     */
    get ethernetMacAddress(): string | undefined;
    /**
     * Sets the ethernetMacAddress property value. Ethernet MAC. This property is read-only.
     * @param value Value to set for the ethernetMacAddress property.
     */
    set ethernetMacAddress(value: string | undefined);
    /**
     * Gets the exchangeAccessState property value. The Access State of the device in Exchange. This property is read-only. Possible values are: none, unknown, allowed, blocked, quarantined.
     * @returns a deviceManagementExchangeAccessState
     */
    get exchangeAccessState(): DeviceManagementExchangeAccessState | undefined;
    /**
     * Sets the exchangeAccessState property value. The Access State of the device in Exchange. This property is read-only. Possible values are: none, unknown, allowed, blocked, quarantined.
     * @param value Value to set for the exchangeAccessState property.
     */
    set exchangeAccessState(value: DeviceManagementExchangeAccessState | undefined);
    /**
     * Gets the exchangeAccessStateReason property value. The reason for the device's access state in Exchange. This property is read-only. Possible values are: none, unknown, exchangeGlobalRule, exchangeIndividualRule, exchangeDeviceRule, exchangeUpgrade, exchangeMailboxPolicy, other, compliant, notCompliant, notEnrolled, unknownLocation, mfaRequired, azureADBlockDueToAccessPolicy, compromisedPassword, deviceNotKnownWithManagedApp.
     * @returns a deviceManagementExchangeAccessStateReason
     */
    get exchangeAccessStateReason(): DeviceManagementExchangeAccessStateReason | undefined;
    /**
     * Sets the exchangeAccessStateReason property value. The reason for the device's access state in Exchange. This property is read-only. Possible values are: none, unknown, exchangeGlobalRule, exchangeIndividualRule, exchangeDeviceRule, exchangeUpgrade, exchangeMailboxPolicy, other, compliant, notCompliant, notEnrolled, unknownLocation, mfaRequired, azureADBlockDueToAccessPolicy, compromisedPassword, deviceNotKnownWithManagedApp.
     * @param value Value to set for the exchangeAccessStateReason property.
     */
    set exchangeAccessStateReason(value: DeviceManagementExchangeAccessStateReason | undefined);
    /**
     * Gets the exchangeLastSuccessfulSyncDateTime property value. Last time the device contacted Exchange. This property is read-only.
     * @returns a Date
     */
    get exchangeLastSuccessfulSyncDateTime(): Date | undefined;
    /**
     * Sets the exchangeLastSuccessfulSyncDateTime property value. Last time the device contacted Exchange. This property is read-only.
     * @param value Value to set for the exchangeLastSuccessfulSyncDateTime property.
     */
    set exchangeLastSuccessfulSyncDateTime(value: Date | undefined);
    /**
     * Gets the freeStorageSpaceInBytes property value. Free Storage in Bytes. This property is read-only.
     * @returns a int64
     */
    get freeStorageSpaceInBytes(): number | undefined;
    /**
     * Sets the freeStorageSpaceInBytes property value. Free Storage in Bytes. This property is read-only.
     * @param value Value to set for the freeStorageSpaceInBytes property.
     */
    set freeStorageSpaceInBytes(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the iccid property value. Integrated Circuit Card Identifier, it is A SIM card's unique identification number. This property is read-only.
     * @returns a string
     */
    get iccid(): string | undefined;
    /**
     * Sets the iccid property value. Integrated Circuit Card Identifier, it is A SIM card's unique identification number. This property is read-only.
     * @param value Value to set for the iccid property.
     */
    set iccid(value: string | undefined);
    /**
     * Gets the imei property value. IMEI. This property is read-only.
     * @returns a string
     */
    get imei(): string | undefined;
    /**
     * Sets the imei property value. IMEI. This property is read-only.
     * @param value Value to set for the imei property.
     */
    set imei(value: string | undefined);
    /**
     * Gets the isEncrypted property value. Device encryption status. This property is read-only.
     * @returns a boolean
     */
    get isEncrypted(): boolean | undefined;
    /**
     * Sets the isEncrypted property value. Device encryption status. This property is read-only.
     * @param value Value to set for the isEncrypted property.
     */
    set isEncrypted(value: boolean | undefined);
    /**
     * Gets the isSupervised property value. Device supervised status. This property is read-only.
     * @returns a boolean
     */
    get isSupervised(): boolean | undefined;
    /**
     * Sets the isSupervised property value. Device supervised status. This property is read-only.
     * @param value Value to set for the isSupervised property.
     */
    set isSupervised(value: boolean | undefined);
    /**
     * Gets the jailBroken property value. whether the device is jail broken or rooted. This property is read-only.
     * @returns a string
     */
    get jailBroken(): string | undefined;
    /**
     * Sets the jailBroken property value. whether the device is jail broken or rooted. This property is read-only.
     * @param value Value to set for the jailBroken property.
     */
    set jailBroken(value: string | undefined);
    /**
     * Gets the lastSyncDateTime property value. The date and time that the device last completed a successful sync with Intune. This property is read-only.
     * @returns a Date
     */
    get lastSyncDateTime(): Date | undefined;
    /**
     * Sets the lastSyncDateTime property value. The date and time that the device last completed a successful sync with Intune. This property is read-only.
     * @param value Value to set for the lastSyncDateTime property.
     */
    set lastSyncDateTime(value: Date | undefined);
    /**
     * Gets the managedDeviceName property value. Automatically generated name to identify a device. Can be overwritten to a user friendly name.
     * @returns a string
     */
    get managedDeviceName(): string | undefined;
    /**
     * Sets the managedDeviceName property value. Automatically generated name to identify a device. Can be overwritten to a user friendly name.
     * @param value Value to set for the managedDeviceName property.
     */
    set managedDeviceName(value: string | undefined);
    /**
     * Gets the managedDeviceOwnerType property value. Ownership of the device. Can be 'company' or 'personal'. Possible values are: unknown, company, personal.
     * @returns a managedDeviceOwnerType
     */
    get managedDeviceOwnerType(): ManagedDeviceOwnerType | undefined;
    /**
     * Sets the managedDeviceOwnerType property value. Ownership of the device. Can be 'company' or 'personal'. Possible values are: unknown, company, personal.
     * @param value Value to set for the managedDeviceOwnerType property.
     */
    set managedDeviceOwnerType(value: ManagedDeviceOwnerType | undefined);
    /**
     * Gets the managementAgent property value. Management channel of the device. Intune, EAS, etc. This property is read-only. Possible values are: eas, mdm, easMdm, intuneClient, easIntuneClient, configurationManagerClient, configurationManagerClientMdm, configurationManagerClientMdmEas, unknown, jamf, googleCloudDevicePolicyController, microsoft365ManagedMdm, msSense, intuneAosp.
     * @returns a managementAgentType
     */
    get managementAgent(): ManagementAgentType | undefined;
    /**
     * Sets the managementAgent property value. Management channel of the device. Intune, EAS, etc. This property is read-only. Possible values are: eas, mdm, easMdm, intuneClient, easIntuneClient, configurationManagerClient, configurationManagerClientMdm, configurationManagerClientMdmEas, unknown, jamf, googleCloudDevicePolicyController, microsoft365ManagedMdm, msSense, intuneAosp.
     * @param value Value to set for the managementAgent property.
     */
    set managementAgent(value: ManagementAgentType | undefined);
    /**
     * Gets the manufacturer property value. Manufacturer of the device. This property is read-only.
     * @returns a string
     */
    get manufacturer(): string | undefined;
    /**
     * Sets the manufacturer property value. Manufacturer of the device. This property is read-only.
     * @param value Value to set for the manufacturer property.
     */
    set manufacturer(value: string | undefined);
    /**
     * Gets the meid property value. MEID. This property is read-only.
     * @returns a string
     */
    get meid(): string | undefined;
    /**
     * Sets the meid property value. MEID. This property is read-only.
     * @param value Value to set for the meid property.
     */
    set meid(value: string | undefined);
    /**
     * Gets the model property value. Model of the device. This property is read-only.
     * @returns a string
     */
    get model(): string | undefined;
    /**
     * Sets the model property value. Model of the device. This property is read-only.
     * @param value Value to set for the model property.
     */
    set model(value: string | undefined);
    /**
     * Gets the notes property value. Notes on the device created by IT Admin
     * @returns a string
     */
    get notes(): string | undefined;
    /**
     * Sets the notes property value. Notes on the device created by IT Admin
     * @param value Value to set for the notes property.
     */
    set notes(value: string | undefined);
    /**
     * Gets the operatingSystem property value. Operating system of the device. Windows, iOS, etc. This property is read-only.
     * @returns a string
     */
    get operatingSystem(): string | undefined;
    /**
     * Sets the operatingSystem property value. Operating system of the device. Windows, iOS, etc. This property is read-only.
     * @param value Value to set for the operatingSystem property.
     */
    set operatingSystem(value: string | undefined);
    /**
     * Gets the osVersion property value. Operating system version of the device. This property is read-only.
     * @returns a string
     */
    get osVersion(): string | undefined;
    /**
     * Sets the osVersion property value. Operating system version of the device. This property is read-only.
     * @param value Value to set for the osVersion property.
     */
    set osVersion(value: string | undefined);
    /**
     * Gets the partnerReportedThreatState property value. Indicates the threat state of a device when a Mobile Threat Defense partner is in use by the account and device. Read Only. This property is read-only. Possible values are: unknown, activated, deactivated, secured, lowSeverity, mediumSeverity, highSeverity, unresponsive, compromised, misconfigured.
     * @returns a managedDevicePartnerReportedHealthState
     */
    get partnerReportedThreatState(): ManagedDevicePartnerReportedHealthState | undefined;
    /**
     * Sets the partnerReportedThreatState property value. Indicates the threat state of a device when a Mobile Threat Defense partner is in use by the account and device. Read Only. This property is read-only. Possible values are: unknown, activated, deactivated, secured, lowSeverity, mediumSeverity, highSeverity, unresponsive, compromised, misconfigured.
     * @param value Value to set for the partnerReportedThreatState property.
     */
    set partnerReportedThreatState(value: ManagedDevicePartnerReportedHealthState | undefined);
    /**
     * Gets the phoneNumber property value. Phone number of the device. This property is read-only.
     * @returns a string
     */
    get phoneNumber(): string | undefined;
    /**
     * Sets the phoneNumber property value. Phone number of the device. This property is read-only.
     * @param value Value to set for the phoneNumber property.
     */
    set phoneNumber(value: string | undefined);
    /**
     * Gets the physicalMemoryInBytes property value. Total Memory in Bytes. This property is read-only.
     * @returns a int64
     */
    get physicalMemoryInBytes(): number | undefined;
    /**
     * Sets the physicalMemoryInBytes property value. Total Memory in Bytes. This property is read-only.
     * @param value Value to set for the physicalMemoryInBytes property.
     */
    set physicalMemoryInBytes(value: number | undefined);
    /**
     * Gets the remoteAssistanceSessionErrorDetails property value. An error string that identifies issues when creating Remote Assistance session objects. This property is read-only.
     * @returns a string
     */
    get remoteAssistanceSessionErrorDetails(): string | undefined;
    /**
     * Sets the remoteAssistanceSessionErrorDetails property value. An error string that identifies issues when creating Remote Assistance session objects. This property is read-only.
     * @param value Value to set for the remoteAssistanceSessionErrorDetails property.
     */
    set remoteAssistanceSessionErrorDetails(value: string | undefined);
    /**
     * Gets the remoteAssistanceSessionUrl property value. Url that allows a Remote Assistance session to be established with the device. This property is read-only.
     * @returns a string
     */
    get remoteAssistanceSessionUrl(): string | undefined;
    /**
     * Sets the remoteAssistanceSessionUrl property value. Url that allows a Remote Assistance session to be established with the device. This property is read-only.
     * @param value Value to set for the remoteAssistanceSessionUrl property.
     */
    set remoteAssistanceSessionUrl(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the serialNumber property value. SerialNumber. This property is read-only.
     * @returns a string
     */
    get serialNumber(): string | undefined;
    /**
     * Sets the serialNumber property value. SerialNumber. This property is read-only.
     * @param value Value to set for the serialNumber property.
     */
    set serialNumber(value: string | undefined);
    /**
     * Gets the subscriberCarrier property value. Subscriber Carrier. This property is read-only.
     * @returns a string
     */
    get subscriberCarrier(): string | undefined;
    /**
     * Sets the subscriberCarrier property value. Subscriber Carrier. This property is read-only.
     * @param value Value to set for the subscriberCarrier property.
     */
    set subscriberCarrier(value: string | undefined);
    /**
     * Gets the totalStorageSpaceInBytes property value. Total Storage in Bytes. This property is read-only.
     * @returns a int64
     */
    get totalStorageSpaceInBytes(): number | undefined;
    /**
     * Sets the totalStorageSpaceInBytes property value. Total Storage in Bytes. This property is read-only.
     * @param value Value to set for the totalStorageSpaceInBytes property.
     */
    set totalStorageSpaceInBytes(value: number | undefined);
    /**
     * Gets the udid property value. Unique Device Identifier for iOS and macOS devices. This property is read-only.
     * @returns a string
     */
    get udid(): string | undefined;
    /**
     * Sets the udid property value. Unique Device Identifier for iOS and macOS devices. This property is read-only.
     * @param value Value to set for the udid property.
     */
    set udid(value: string | undefined);
    /**
     * Gets the userDisplayName property value. User display name. This property is read-only.
     * @returns a string
     */
    get userDisplayName(): string | undefined;
    /**
     * Sets the userDisplayName property value. User display name. This property is read-only.
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value: string | undefined);
    /**
     * Gets the userId property value. Unique Identifier for the user associated with the device. This property is read-only.
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. Unique Identifier for the user associated with the device. This property is read-only.
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
    /**
     * Gets the userPrincipalName property value. Device user principal name. This property is read-only.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. Device user principal name. This property is read-only.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
    /**
     * Gets the wiFiMacAddress property value. Wi-Fi MAC. This property is read-only.
     * @returns a string
     */
    get wiFiMacAddress(): string | undefined;
    /**
     * Sets the wiFiMacAddress property value. Wi-Fi MAC. This property is read-only.
     * @param value Value to set for the wiFiMacAddress property.
     */
    set wiFiMacAddress(value: string | undefined);
}
