import { Importance } from './importance';
import { Recipient } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class MessageRuleActions implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** A list of categories to be assigned to a message. */
    private _assignCategories?;
    /** The ID of a folder that a message is to be copied to. */
    private _copyToFolder?;
    /** Indicates whether a message should be moved to the Deleted Items folder. */
    private _delete?;
    /** The email addresses of the recipients to which a message should be forwarded as an attachment. */
    private _forwardAsAttachmentTo?;
    /** The email addresses of the recipients to which a message should be forwarded. */
    private _forwardTo?;
    /** Indicates whether a message should be marked as read. */
    private _markAsRead?;
    /** Sets the importance of the message, which can be: low, normal, high. */
    private _markImportance?;
    /** The ID of the folder that a message will be moved to. */
    private _moveToFolder?;
    /** Indicates whether a message should be permanently deleted and not saved to the Deleted Items folder. */
    private _permanentDelete?;
    /** The email address to which a message should be redirected. */
    private _redirectTo?;
    /** Indicates whether subsequent rules should be evaluated. */
    private _stopProcessingRules?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the assignCategories property value. A list of categories to be assigned to a message.
     * @returns a string
     */
    get assignCategories(): string[] | undefined;
    /**
     * Sets the assignCategories property value. A list of categories to be assigned to a message.
     * @param value Value to set for the assignCategories property.
     */
    set assignCategories(value: string[] | undefined);
    /**
     * Instantiates a new messageRuleActions and sets the default values.
     */
    constructor();
    /**
     * Gets the copyToFolder property value. The ID of a folder that a message is to be copied to.
     * @returns a string
     */
    get copyToFolder(): string | undefined;
    /**
     * Sets the copyToFolder property value. The ID of a folder that a message is to be copied to.
     * @param value Value to set for the copyToFolder property.
     */
    set copyToFolder(value: string | undefined);
    /**
     * Gets the delete property value. Indicates whether a message should be moved to the Deleted Items folder.
     * @returns a boolean
     */
    get delete(): boolean | undefined;
    /**
     * Sets the delete property value. Indicates whether a message should be moved to the Deleted Items folder.
     * @param value Value to set for the delete property.
     */
    set delete(value: boolean | undefined);
    /**
     * Gets the forwardAsAttachmentTo property value. The email addresses of the recipients to which a message should be forwarded as an attachment.
     * @returns a recipient
     */
    get forwardAsAttachmentTo(): Recipient[] | undefined;
    /**
     * Sets the forwardAsAttachmentTo property value. The email addresses of the recipients to which a message should be forwarded as an attachment.
     * @param value Value to set for the forwardAsAttachmentTo property.
     */
    set forwardAsAttachmentTo(value: Recipient[] | undefined);
    /**
     * Gets the forwardTo property value. The email addresses of the recipients to which a message should be forwarded.
     * @returns a recipient
     */
    get forwardTo(): Recipient[] | undefined;
    /**
     * Sets the forwardTo property value. The email addresses of the recipients to which a message should be forwarded.
     * @param value Value to set for the forwardTo property.
     */
    set forwardTo(value: Recipient[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the markAsRead property value. Indicates whether a message should be marked as read.
     * @returns a boolean
     */
    get markAsRead(): boolean | undefined;
    /**
     * Sets the markAsRead property value. Indicates whether a message should be marked as read.
     * @param value Value to set for the markAsRead property.
     */
    set markAsRead(value: boolean | undefined);
    /**
     * Gets the markImportance property value. Sets the importance of the message, which can be: low, normal, high.
     * @returns a importance
     */
    get markImportance(): Importance | undefined;
    /**
     * Sets the markImportance property value. Sets the importance of the message, which can be: low, normal, high.
     * @param value Value to set for the markImportance property.
     */
    set markImportance(value: Importance | undefined);
    /**
     * Gets the moveToFolder property value. The ID of the folder that a message will be moved to.
     * @returns a string
     */
    get moveToFolder(): string | undefined;
    /**
     * Sets the moveToFolder property value. The ID of the folder that a message will be moved to.
     * @param value Value to set for the moveToFolder property.
     */
    set moveToFolder(value: string | undefined);
    /**
     * Gets the permanentDelete property value. Indicates whether a message should be permanently deleted and not saved to the Deleted Items folder.
     * @returns a boolean
     */
    get permanentDelete(): boolean | undefined;
    /**
     * Sets the permanentDelete property value. Indicates whether a message should be permanently deleted and not saved to the Deleted Items folder.
     * @param value Value to set for the permanentDelete property.
     */
    set permanentDelete(value: boolean | undefined);
    /**
     * Gets the redirectTo property value. The email address to which a message should be redirected.
     * @returns a recipient
     */
    get redirectTo(): Recipient[] | undefined;
    /**
     * Sets the redirectTo property value. The email address to which a message should be redirected.
     * @param value Value to set for the redirectTo property.
     */
    set redirectTo(value: Recipient[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the stopProcessingRules property value. Indicates whether subsequent rules should be evaluated.
     * @returns a boolean
     */
    get stopProcessingRules(): boolean | undefined;
    /**
     * Sets the stopProcessingRules property value. Indicates whether subsequent rules should be evaluated.
     * @param value Value to set for the stopProcessingRules property.
     */
    set stopProcessingRules(value: boolean | undefined);
}
