import { Entity } from './index';
import { MobileThreatPartnerTenantState } from './mobileThreatPartnerTenantState';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Entity which represents a connection to Mobile threat defense partner. */
export declare class MobileThreatDefenseConnector extends Entity implements Parsable {
    /** For Android, set whether Intune must receive data from the data sync partner prior to marking a device compliant */
    private _androidDeviceBlockedOnMissingPartnerData?;
    /** For Android, set whether data from the data sync partner should be used during compliance evaluations */
    private _androidEnabled?;
    /** For IOS, set whether Intune must receive data from the data sync partner prior to marking a device compliant */
    private _iosDeviceBlockedOnMissingPartnerData?;
    /** For IOS, get or set whether data from the data sync partner should be used during compliance evaluations */
    private _iosEnabled?;
    /** DateTime of last Heartbeat recieved from the Data Sync Partner */
    private _lastHeartbeatDateTime?;
    /** Data Sync Partner state for this account. Possible values are: unavailable, available, enabled, unresponsive. */
    private _partnerState?;
    /** Get or Set days the per tenant tolerance to unresponsiveness for this partner integration */
    private _partnerUnresponsivenessThresholdInDays?;
    /** Get or set whether to block devices on the enabled platforms that do not meet the minimum version requirements of the Data Sync Partner */
    private _partnerUnsupportedOsVersionBlocked?;
    /**
     * Gets the androidDeviceBlockedOnMissingPartnerData property value. For Android, set whether Intune must receive data from the data sync partner prior to marking a device compliant
     * @returns a boolean
     */
    get androidDeviceBlockedOnMissingPartnerData(): boolean | undefined;
    /**
     * Sets the androidDeviceBlockedOnMissingPartnerData property value. For Android, set whether Intune must receive data from the data sync partner prior to marking a device compliant
     * @param value Value to set for the androidDeviceBlockedOnMissingPartnerData property.
     */
    set androidDeviceBlockedOnMissingPartnerData(value: boolean | undefined);
    /**
     * Gets the androidEnabled property value. For Android, set whether data from the data sync partner should be used during compliance evaluations
     * @returns a boolean
     */
    get androidEnabled(): boolean | undefined;
    /**
     * Sets the androidEnabled property value. For Android, set whether data from the data sync partner should be used during compliance evaluations
     * @param value Value to set for the androidEnabled property.
     */
    set androidEnabled(value: boolean | undefined);
    /**
     * Instantiates a new mobileThreatDefenseConnector and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the iosDeviceBlockedOnMissingPartnerData property value. For IOS, set whether Intune must receive data from the data sync partner prior to marking a device compliant
     * @returns a boolean
     */
    get iosDeviceBlockedOnMissingPartnerData(): boolean | undefined;
    /**
     * Sets the iosDeviceBlockedOnMissingPartnerData property value. For IOS, set whether Intune must receive data from the data sync partner prior to marking a device compliant
     * @param value Value to set for the iosDeviceBlockedOnMissingPartnerData property.
     */
    set iosDeviceBlockedOnMissingPartnerData(value: boolean | undefined);
    /**
     * Gets the iosEnabled property value. For IOS, get or set whether data from the data sync partner should be used during compliance evaluations
     * @returns a boolean
     */
    get iosEnabled(): boolean | undefined;
    /**
     * Sets the iosEnabled property value. For IOS, get or set whether data from the data sync partner should be used during compliance evaluations
     * @param value Value to set for the iosEnabled property.
     */
    set iosEnabled(value: boolean | undefined);
    /**
     * Gets the lastHeartbeatDateTime property value. DateTime of last Heartbeat recieved from the Data Sync Partner
     * @returns a Date
     */
    get lastHeartbeatDateTime(): Date | undefined;
    /**
     * Sets the lastHeartbeatDateTime property value. DateTime of last Heartbeat recieved from the Data Sync Partner
     * @param value Value to set for the lastHeartbeatDateTime property.
     */
    set lastHeartbeatDateTime(value: Date | undefined);
    /**
     * Gets the partnerState property value. Data Sync Partner state for this account. Possible values are: unavailable, available, enabled, unresponsive.
     * @returns a mobileThreatPartnerTenantState
     */
    get partnerState(): MobileThreatPartnerTenantState | undefined;
    /**
     * Sets the partnerState property value. Data Sync Partner state for this account. Possible values are: unavailable, available, enabled, unresponsive.
     * @param value Value to set for the partnerState property.
     */
    set partnerState(value: MobileThreatPartnerTenantState | undefined);
    /**
     * Gets the partnerUnresponsivenessThresholdInDays property value. Get or Set days the per tenant tolerance to unresponsiveness for this partner integration
     * @returns a integer
     */
    get partnerUnresponsivenessThresholdInDays(): number | undefined;
    /**
     * Sets the partnerUnresponsivenessThresholdInDays property value. Get or Set days the per tenant tolerance to unresponsiveness for this partner integration
     * @param value Value to set for the partnerUnresponsivenessThresholdInDays property.
     */
    set partnerUnresponsivenessThresholdInDays(value: number | undefined);
    /**
     * Gets the partnerUnsupportedOsVersionBlocked property value. Get or set whether to block devices on the enabled platforms that do not meet the minimum version requirements of the Data Sync Partner
     * @returns a boolean
     */
    get partnerUnsupportedOsVersionBlocked(): boolean | undefined;
    /**
     * Sets the partnerUnsupportedOsVersionBlocked property value. Get or set whether to block devices on the enabled platforms that do not meet the minimum version requirements of the Data Sync Partner
     * @param value Value to set for the partnerUnsupportedOsVersionBlocked property.
     */
    set partnerUnsupportedOsVersionBlocked(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
