import { ConnectionDirection } from './connectionDirection';
import { ConnectionStatus } from './connectionStatus';
import { SecurityNetworkProtocol } from './securityNetworkProtocol';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class NetworkConnection implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Name of the application managing the network connection (for example, Facebook, SMTP, etc.). */
    private _applicationName?;
    /** Destination IP address (of the network connection). */
    private _destinationAddress?;
    /** Destination domain portion of the destination URL. (for example 'www.contoso.com'). */
    private _destinationDomain?;
    /** Location (by IP address mapping) associated with the destination of a network connection. */
    private _destinationLocation?;
    /** Destination port (of the network connection). */
    private _destinationPort?;
    /** Network connection URL/URI string - excluding parameters. (for example 'www.contoso.com/products/default.html') */
    private _destinationUrl?;
    /** Network connection direction. Possible values are: unknown, inbound, outbound. */
    private _direction?;
    /** Date when the destination domain was registered. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _domainRegisteredDateTime?;
    /** The local DNS name resolution as it appears in the host's local DNS cache (for example, in case the 'hosts' file was tampered with). */
    private _localDnsName?;
    /** Network Address Translation destination IP address. */
    private _natDestinationAddress?;
    /** Network Address Translation destination port. */
    private _natDestinationPort?;
    /** Network Address Translation source IP address. */
    private _natSourceAddress?;
    /** Network Address Translation source port. */
    private _natSourcePort?;
    /** Network protocol. Possible values are: unknown, ip, icmp, igmp, ggp, ipv4, tcp, pup, udp, idp, ipv6, ipv6RoutingHeader, ipv6FragmentHeader, ipSecEncapsulatingSecurityPayload, ipSecAuthenticationHeader, icmpV6, ipv6NoNextHeader, ipv6DestinationOptions, nd, raw, ipx, spx, spxII. */
    private _protocol?;
    /** Provider generated/calculated risk score of the network connection. Recommended value range of 0-1, which equates to a percentage. */
    private _riskScore?;
    /** Source (i.e. origin) IP address (of the network connection). */
    private _sourceAddress?;
    /** Location (by IP address mapping) associated with the source of a network connection. */
    private _sourceLocation?;
    /** Source (i.e. origin) IP port (of the network connection). */
    private _sourcePort?;
    /** Network connection status. Possible values are: unknown, attempted, succeeded, blocked, failed. */
    private _status?;
    /** Parameters (suffix) of the destination URL. */
    private _urlParameters?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the applicationName property value. Name of the application managing the network connection (for example, Facebook, SMTP, etc.).
     * @returns a string
     */
    get applicationName(): string | undefined;
    /**
     * Sets the applicationName property value. Name of the application managing the network connection (for example, Facebook, SMTP, etc.).
     * @param value Value to set for the applicationName property.
     */
    set applicationName(value: string | undefined);
    /**
     * Instantiates a new networkConnection and sets the default values.
     */
    constructor();
    /**
     * Gets the destinationAddress property value. Destination IP address (of the network connection).
     * @returns a string
     */
    get destinationAddress(): string | undefined;
    /**
     * Sets the destinationAddress property value. Destination IP address (of the network connection).
     * @param value Value to set for the destinationAddress property.
     */
    set destinationAddress(value: string | undefined);
    /**
     * Gets the destinationDomain property value. Destination domain portion of the destination URL. (for example 'www.contoso.com').
     * @returns a string
     */
    get destinationDomain(): string | undefined;
    /**
     * Sets the destinationDomain property value. Destination domain portion of the destination URL. (for example 'www.contoso.com').
     * @param value Value to set for the destinationDomain property.
     */
    set destinationDomain(value: string | undefined);
    /**
     * Gets the destinationLocation property value. Location (by IP address mapping) associated with the destination of a network connection.
     * @returns a string
     */
    get destinationLocation(): string | undefined;
    /**
     * Sets the destinationLocation property value. Location (by IP address mapping) associated with the destination of a network connection.
     * @param value Value to set for the destinationLocation property.
     */
    set destinationLocation(value: string | undefined);
    /**
     * Gets the destinationPort property value. Destination port (of the network connection).
     * @returns a string
     */
    get destinationPort(): string | undefined;
    /**
     * Sets the destinationPort property value. Destination port (of the network connection).
     * @param value Value to set for the destinationPort property.
     */
    set destinationPort(value: string | undefined);
    /**
     * Gets the destinationUrl property value. Network connection URL/URI string - excluding parameters. (for example 'www.contoso.com/products/default.html')
     * @returns a string
     */
    get destinationUrl(): string | undefined;
    /**
     * Sets the destinationUrl property value. Network connection URL/URI string - excluding parameters. (for example 'www.contoso.com/products/default.html')
     * @param value Value to set for the destinationUrl property.
     */
    set destinationUrl(value: string | undefined);
    /**
     * Gets the direction property value. Network connection direction. Possible values are: unknown, inbound, outbound.
     * @returns a connectionDirection
     */
    get direction(): ConnectionDirection | undefined;
    /**
     * Sets the direction property value. Network connection direction. Possible values are: unknown, inbound, outbound.
     * @param value Value to set for the direction property.
     */
    set direction(value: ConnectionDirection | undefined);
    /**
     * Gets the domainRegisteredDateTime property value. Date when the destination domain was registered. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get domainRegisteredDateTime(): Date | undefined;
    /**
     * Sets the domainRegisteredDateTime property value. Date when the destination domain was registered. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the domainRegisteredDateTime property.
     */
    set domainRegisteredDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the localDnsName property value. The local DNS name resolution as it appears in the host's local DNS cache (for example, in case the 'hosts' file was tampered with).
     * @returns a string
     */
    get localDnsName(): string | undefined;
    /**
     * Sets the localDnsName property value. The local DNS name resolution as it appears in the host's local DNS cache (for example, in case the 'hosts' file was tampered with).
     * @param value Value to set for the localDnsName property.
     */
    set localDnsName(value: string | undefined);
    /**
     * Gets the natDestinationAddress property value. Network Address Translation destination IP address.
     * @returns a string
     */
    get natDestinationAddress(): string | undefined;
    /**
     * Sets the natDestinationAddress property value. Network Address Translation destination IP address.
     * @param value Value to set for the natDestinationAddress property.
     */
    set natDestinationAddress(value: string | undefined);
    /**
     * Gets the natDestinationPort property value. Network Address Translation destination port.
     * @returns a string
     */
    get natDestinationPort(): string | undefined;
    /**
     * Sets the natDestinationPort property value. Network Address Translation destination port.
     * @param value Value to set for the natDestinationPort property.
     */
    set natDestinationPort(value: string | undefined);
    /**
     * Gets the natSourceAddress property value. Network Address Translation source IP address.
     * @returns a string
     */
    get natSourceAddress(): string | undefined;
    /**
     * Sets the natSourceAddress property value. Network Address Translation source IP address.
     * @param value Value to set for the natSourceAddress property.
     */
    set natSourceAddress(value: string | undefined);
    /**
     * Gets the natSourcePort property value. Network Address Translation source port.
     * @returns a string
     */
    get natSourcePort(): string | undefined;
    /**
     * Sets the natSourcePort property value. Network Address Translation source port.
     * @param value Value to set for the natSourcePort property.
     */
    set natSourcePort(value: string | undefined);
    /**
     * Gets the protocol property value. Network protocol. Possible values are: unknown, ip, icmp, igmp, ggp, ipv4, tcp, pup, udp, idp, ipv6, ipv6RoutingHeader, ipv6FragmentHeader, ipSecEncapsulatingSecurityPayload, ipSecAuthenticationHeader, icmpV6, ipv6NoNextHeader, ipv6DestinationOptions, nd, raw, ipx, spx, spxII.
     * @returns a securityNetworkProtocol
     */
    get protocol(): SecurityNetworkProtocol | undefined;
    /**
     * Sets the protocol property value. Network protocol. Possible values are: unknown, ip, icmp, igmp, ggp, ipv4, tcp, pup, udp, idp, ipv6, ipv6RoutingHeader, ipv6FragmentHeader, ipSecEncapsulatingSecurityPayload, ipSecAuthenticationHeader, icmpV6, ipv6NoNextHeader, ipv6DestinationOptions, nd, raw, ipx, spx, spxII.
     * @param value Value to set for the protocol property.
     */
    set protocol(value: SecurityNetworkProtocol | undefined);
    /**
     * Gets the riskScore property value. Provider generated/calculated risk score of the network connection. Recommended value range of 0-1, which equates to a percentage.
     * @returns a string
     */
    get riskScore(): string | undefined;
    /**
     * Sets the riskScore property value. Provider generated/calculated risk score of the network connection. Recommended value range of 0-1, which equates to a percentage.
     * @param value Value to set for the riskScore property.
     */
    set riskScore(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sourceAddress property value. Source (i.e. origin) IP address (of the network connection).
     * @returns a string
     */
    get sourceAddress(): string | undefined;
    /**
     * Sets the sourceAddress property value. Source (i.e. origin) IP address (of the network connection).
     * @param value Value to set for the sourceAddress property.
     */
    set sourceAddress(value: string | undefined);
    /**
     * Gets the sourceLocation property value. Location (by IP address mapping) associated with the source of a network connection.
     * @returns a string
     */
    get sourceLocation(): string | undefined;
    /**
     * Sets the sourceLocation property value. Location (by IP address mapping) associated with the source of a network connection.
     * @param value Value to set for the sourceLocation property.
     */
    set sourceLocation(value: string | undefined);
    /**
     * Gets the sourcePort property value. Source (i.e. origin) IP port (of the network connection).
     * @returns a string
     */
    get sourcePort(): string | undefined;
    /**
     * Sets the sourcePort property value. Source (i.e. origin) IP port (of the network connection).
     * @param value Value to set for the sourcePort property.
     */
    set sourcePort(value: string | undefined);
    /**
     * Gets the status property value. Network connection status. Possible values are: unknown, attempted, succeeded, blocked, failed.
     * @returns a connectionStatus
     */
    get status(): ConnectionStatus | undefined;
    /**
     * Sets the status property value. Network connection status. Possible values are: unknown, attempted, succeeded, blocked, failed.
     * @param value Value to set for the status property.
     */
    set status(value: ConnectionStatus | undefined);
    /**
     * Gets the urlParameters property value. Parameters (suffix) of the destination URL.
     * @returns a string
     */
    get urlParameters(): string | undefined;
    /**
     * Sets the urlParameters property value. Parameters (suffix) of the destination URL.
     * @param value Value to set for the urlParameters property.
     */
    set urlParameters(value: string | undefined);
}
