import { NotebookLinks, OnenoteEntityHierarchyModel, OnenoteSection, SectionGroup } from './index';
import { OnenoteUserRole } from './onenoteUserRole';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Notebook extends OnenoteEntityHierarchyModel implements Parsable {
    /** Indicates whether this is the user's default notebook. Read-only. */
    private _isDefault?;
    /** Indicates whether the notebook is shared. If true, the contents of the notebook can be seen by people other than the owner. Read-only. */
    private _isShared?;
    /** Links for opening the notebook. The oneNoteClientURL link opens the notebook in the OneNote native client if it's installed. The oneNoteWebURL link opens the notebook in OneNote on the web. */
    private _links?;
    /** The section groups in the notebook. Read-only. Nullable. */
    private _sectionGroups?;
    /** The URL for the sectionGroups navigation property, which returns all the section groups in the notebook. Read-only. */
    private _sectionGroupsUrl?;
    /** The sections in the notebook. Read-only. Nullable. */
    private _sections?;
    /** The URL for the sections navigation property, which returns all the sections in the notebook. Read-only. */
    private _sectionsUrl?;
    /** Possible values are: Owner, Contributor, Reader, None. Owner represents owner-level access to the notebook. Contributor represents read/write access to the notebook. Reader represents read-only access to the notebook. Read-only. */
    private _userRole?;
    /**
     * Instantiates a new notebook and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isDefault property value. Indicates whether this is the user's default notebook. Read-only.
     * @returns a boolean
     */
    get isDefault(): boolean | undefined;
    /**
     * Sets the isDefault property value. Indicates whether this is the user's default notebook. Read-only.
     * @param value Value to set for the isDefault property.
     */
    set isDefault(value: boolean | undefined);
    /**
     * Gets the isShared property value. Indicates whether the notebook is shared. If true, the contents of the notebook can be seen by people other than the owner. Read-only.
     * @returns a boolean
     */
    get isShared(): boolean | undefined;
    /**
     * Sets the isShared property value. Indicates whether the notebook is shared. If true, the contents of the notebook can be seen by people other than the owner. Read-only.
     * @param value Value to set for the isShared property.
     */
    set isShared(value: boolean | undefined);
    /**
     * Gets the links property value. Links for opening the notebook. The oneNoteClientURL link opens the notebook in the OneNote native client if it's installed. The oneNoteWebURL link opens the notebook in OneNote on the web.
     * @returns a notebookLinks
     */
    get links(): NotebookLinks | undefined;
    /**
     * Sets the links property value. Links for opening the notebook. The oneNoteClientURL link opens the notebook in the OneNote native client if it's installed. The oneNoteWebURL link opens the notebook in OneNote on the web.
     * @param value Value to set for the links property.
     */
    set links(value: NotebookLinks | undefined);
    /**
     * Gets the sectionGroups property value. The section groups in the notebook. Read-only. Nullable.
     * @returns a sectionGroup
     */
    get sectionGroups(): SectionGroup[] | undefined;
    /**
     * Sets the sectionGroups property value. The section groups in the notebook. Read-only. Nullable.
     * @param value Value to set for the sectionGroups property.
     */
    set sectionGroups(value: SectionGroup[] | undefined);
    /**
     * Gets the sectionGroupsUrl property value. The URL for the sectionGroups navigation property, which returns all the section groups in the notebook. Read-only.
     * @returns a string
     */
    get sectionGroupsUrl(): string | undefined;
    /**
     * Sets the sectionGroupsUrl property value. The URL for the sectionGroups navigation property, which returns all the section groups in the notebook. Read-only.
     * @param value Value to set for the sectionGroupsUrl property.
     */
    set sectionGroupsUrl(value: string | undefined);
    /**
     * Gets the sections property value. The sections in the notebook. Read-only. Nullable.
     * @returns a onenoteSection
     */
    get sections(): OnenoteSection[] | undefined;
    /**
     * Sets the sections property value. The sections in the notebook. Read-only. Nullable.
     * @param value Value to set for the sections property.
     */
    set sections(value: OnenoteSection[] | undefined);
    /**
     * Gets the sectionsUrl property value. The URL for the sections navigation property, which returns all the sections in the notebook. Read-only.
     * @returns a string
     */
    get sectionsUrl(): string | undefined;
    /**
     * Sets the sectionsUrl property value. The URL for the sections navigation property, which returns all the sections in the notebook. Read-only.
     * @param value Value to set for the sectionsUrl property.
     */
    set sectionsUrl(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the userRole property value. Possible values are: Owner, Contributor, Reader, None. Owner represents owner-level access to the notebook. Contributor represents read/write access to the notebook. Reader represents read-only access to the notebook. Read-only.
     * @returns a onenoteUserRole
     */
    get userRole(): OnenoteUserRole | undefined;
    /**
     * Sets the userRole property value. Possible values are: Owner, Contributor, Reader, None. Owner represents owner-level access to the notebook. Contributor represents read/write access to the notebook. Reader represents read-only access to the notebook. Read-only.
     * @param value Value to set for the userRole property.
     */
    set userRole(value: OnenoteUserRole | undefined);
}
