import { Entity, LocalizedNotificationMessage } from './index';
import { NotificationTemplateBrandingOptions } from './notificationTemplateBrandingOptions';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Notification messages are messages that are sent to end users who are determined to be not-compliant with the compliance policies defined by the administrator. Administrators choose notifications and configure them in the Intune Admin Console using the compliance policy creation page under the “Actions for non-compliance” section. Use the notificationMessageTemplate object to create your own custom notifications for administrators to choose while configuring actions for non-compliance. */
export declare class NotificationMessageTemplate extends Entity implements Parsable {
    /** The Message Template Branding Options. Branding is defined in the Intune Admin Console. Possible values are: none, includeCompanyLogo, includeCompanyName, includeContactInformation, includeCompanyPortalLink. */
    private _brandingOptions?;
    /** The default locale to fallback onto when the requested locale is not available. */
    private _defaultLocale?;
    /** Display name for the Notification Message Template. */
    private _displayName?;
    /** DateTime the object was last modified. */
    private _lastModifiedDateTime?;
    /** The list of localized messages for this Notification Message Template. */
    private _localizedNotificationMessages?;
    /**
     * Gets the brandingOptions property value. The Message Template Branding Options. Branding is defined in the Intune Admin Console. Possible values are: none, includeCompanyLogo, includeCompanyName, includeContactInformation, includeCompanyPortalLink.
     * @returns a notificationTemplateBrandingOptions
     */
    get brandingOptions(): NotificationTemplateBrandingOptions | undefined;
    /**
     * Sets the brandingOptions property value. The Message Template Branding Options. Branding is defined in the Intune Admin Console. Possible values are: none, includeCompanyLogo, includeCompanyName, includeContactInformation, includeCompanyPortalLink.
     * @param value Value to set for the brandingOptions property.
     */
    set brandingOptions(value: NotificationTemplateBrandingOptions | undefined);
    /**
     * Instantiates a new notificationMessageTemplate and sets the default values.
     */
    constructor();
    /**
     * Gets the defaultLocale property value. The default locale to fallback onto when the requested locale is not available.
     * @returns a string
     */
    get defaultLocale(): string | undefined;
    /**
     * Sets the defaultLocale property value. The default locale to fallback onto when the requested locale is not available.
     * @param value Value to set for the defaultLocale property.
     */
    set defaultLocale(value: string | undefined);
    /**
     * Gets the displayName property value. Display name for the Notification Message Template.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Display name for the Notification Message Template.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the localizedNotificationMessages property value. The list of localized messages for this Notification Message Template.
     * @returns a localizedNotificationMessage
     */
    get localizedNotificationMessages(): LocalizedNotificationMessage[] | undefined;
    /**
     * Sets the localizedNotificationMessages property value. The list of localized messages for this Notification Message Template.
     * @param value Value to set for the localizedNotificationMessages property.
     */
    set localizedNotificationMessages(value: LocalizedNotificationMessage[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
