import { Entity, Notebook, OnenoteOperation, OnenotePage, OnenoteResource, OnenoteSection, SectionGroup } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Onenote extends Entity implements Parsable {
    /** The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable. */
    private _notebooks?;
    /** The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable. */
    private _operations?;
    /** The pages in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable. */
    private _pages?;
    /** The image and other file resources in OneNote pages. Getting a resources collection is not supported, but you can get the binary content of a specific resource. Read-only. Nullable. */
    private _resources?;
    /** The section groups in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable. */
    private _sectionGroups?;
    /** The sections in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable. */
    private _sections?;
    /**
     * Instantiates a new onenote and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the notebooks property value. The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @returns a notebook
     */
    get notebooks(): Notebook[] | undefined;
    /**
     * Sets the notebooks property value. The collection of OneNote notebooks that are owned by the user or group. Read-only. Nullable.
     * @param value Value to set for the notebooks property.
     */
    set notebooks(value: Notebook[] | undefined);
    /**
     * Gets the operations property value. The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable.
     * @returns a onenoteOperation
     */
    get operations(): OnenoteOperation[] | undefined;
    /**
     * Sets the operations property value. The status of OneNote operations. Getting an operations collection is not supported, but you can get the status of long-running operations if the Operation-Location header is returned in the response. Read-only. Nullable.
     * @param value Value to set for the operations property.
     */
    set operations(value: OnenoteOperation[] | undefined);
    /**
     * Gets the pages property value. The pages in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @returns a onenotePage
     */
    get pages(): OnenotePage[] | undefined;
    /**
     * Sets the pages property value. The pages in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param value Value to set for the pages property.
     */
    set pages(value: OnenotePage[] | undefined);
    /**
     * Gets the resources property value. The image and other file resources in OneNote pages. Getting a resources collection is not supported, but you can get the binary content of a specific resource. Read-only. Nullable.
     * @returns a onenoteResource
     */
    get resources(): OnenoteResource[] | undefined;
    /**
     * Sets the resources property value. The image and other file resources in OneNote pages. Getting a resources collection is not supported, but you can get the binary content of a specific resource. Read-only. Nullable.
     * @param value Value to set for the resources property.
     */
    set resources(value: OnenoteResource[] | undefined);
    /**
     * Gets the sectionGroups property value. The section groups in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @returns a sectionGroup
     */
    get sectionGroups(): SectionGroup[] | undefined;
    /**
     * Sets the sectionGroups property value. The section groups in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param value Value to set for the sectionGroups property.
     */
    set sectionGroups(value: SectionGroup[] | undefined);
    /**
     * Gets the sections property value. The sections in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @returns a onenoteSection
     */
    get sections(): OnenoteSection[] | undefined;
    /**
     * Sets the sections property value. The sections in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param value Value to set for the sections property.
     */
    set sections(value: OnenoteSection[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
