import { Entity, IdentitySet, ItemReference, SharePointIdentitySet, SharingInvitation, SharingLink } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Permission extends Entity implements Parsable {
    /** A format of yyyy-MM-ddTHH:mm:ssZ of DateTimeOffset indicates the expiration time of the permission. DateTime.MinValue indicates there is no expiration set for this permission. Optional. */
    private _expirationDateTime?;
    /** The grantedTo property */
    private _grantedTo?;
    /** The grantedToIdentities property */
    private _grantedToIdentities?;
    /** For link type permissions, the details of the users to whom permission was granted. Read-only. */
    private _grantedToIdentitiesV2?;
    /** For user type permissions, the details of the users and applications for this permission. Read-only. */
    private _grantedToV2?;
    /** Indicates whether the password is set for this permission. This property only appears in the response. Optional. Read-only. For OneDrive Personal only. */
    private _hasPassword?;
    /** Provides a reference to the ancestor of the current permission, if it is inherited from an ancestor. Read-only. */
    private _inheritedFrom?;
    /** Details of any associated sharing invitation for this permission. Read-only. */
    private _invitation?;
    /** Provides the link details of the current permission, if it is a link type permissions. Read-only. */
    private _link?;
    /** The type of permission, for example, read. See below for the full list of roles. Read-only. */
    private _roles?;
    /** A unique token that can be used to access this shared item via the [shares API][]. Read-only. */
    private _shareId?;
    /**
     * Instantiates a new permission and sets the default values.
     */
    constructor();
    /**
     * Gets the expirationDateTime property value. A format of yyyy-MM-ddTHH:mm:ssZ of DateTimeOffset indicates the expiration time of the permission. DateTime.MinValue indicates there is no expiration set for this permission. Optional.
     * @returns a Date
     */
    get expirationDateTime(): Date | undefined;
    /**
     * Sets the expirationDateTime property value. A format of yyyy-MM-ddTHH:mm:ssZ of DateTimeOffset indicates the expiration time of the permission. DateTime.MinValue indicates there is no expiration set for this permission. Optional.
     * @param value Value to set for the expirationDateTime property.
     */
    set expirationDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the grantedTo property value. The grantedTo property
     * @returns a identitySet
     */
    get grantedTo(): IdentitySet | undefined;
    /**
     * Sets the grantedTo property value. The grantedTo property
     * @param value Value to set for the grantedTo property.
     */
    set grantedTo(value: IdentitySet | undefined);
    /**
     * Gets the grantedToIdentities property value. The grantedToIdentities property
     * @returns a identitySet
     */
    get grantedToIdentities(): IdentitySet[] | undefined;
    /**
     * Sets the grantedToIdentities property value. The grantedToIdentities property
     * @param value Value to set for the grantedToIdentities property.
     */
    set grantedToIdentities(value: IdentitySet[] | undefined);
    /**
     * Gets the grantedToIdentitiesV2 property value. For link type permissions, the details of the users to whom permission was granted. Read-only.
     * @returns a sharePointIdentitySet
     */
    get grantedToIdentitiesV2(): SharePointIdentitySet[] | undefined;
    /**
     * Sets the grantedToIdentitiesV2 property value. For link type permissions, the details of the users to whom permission was granted. Read-only.
     * @param value Value to set for the grantedToIdentitiesV2 property.
     */
    set grantedToIdentitiesV2(value: SharePointIdentitySet[] | undefined);
    /**
     * Gets the grantedToV2 property value. For user type permissions, the details of the users and applications for this permission. Read-only.
     * @returns a sharePointIdentitySet
     */
    get grantedToV2(): SharePointIdentitySet | undefined;
    /**
     * Sets the grantedToV2 property value. For user type permissions, the details of the users and applications for this permission. Read-only.
     * @param value Value to set for the grantedToV2 property.
     */
    set grantedToV2(value: SharePointIdentitySet | undefined);
    /**
     * Gets the hasPassword property value. Indicates whether the password is set for this permission. This property only appears in the response. Optional. Read-only. For OneDrive Personal only.
     * @returns a boolean
     */
    get hasPassword(): boolean | undefined;
    /**
     * Sets the hasPassword property value. Indicates whether the password is set for this permission. This property only appears in the response. Optional. Read-only. For OneDrive Personal only.
     * @param value Value to set for the hasPassword property.
     */
    set hasPassword(value: boolean | undefined);
    /**
     * Gets the inheritedFrom property value. Provides a reference to the ancestor of the current permission, if it is inherited from an ancestor. Read-only.
     * @returns a itemReference
     */
    get inheritedFrom(): ItemReference | undefined;
    /**
     * Sets the inheritedFrom property value. Provides a reference to the ancestor of the current permission, if it is inherited from an ancestor. Read-only.
     * @param value Value to set for the inheritedFrom property.
     */
    set inheritedFrom(value: ItemReference | undefined);
    /**
     * Gets the invitation property value. Details of any associated sharing invitation for this permission. Read-only.
     * @returns a sharingInvitation
     */
    get invitation(): SharingInvitation | undefined;
    /**
     * Sets the invitation property value. Details of any associated sharing invitation for this permission. Read-only.
     * @param value Value to set for the invitation property.
     */
    set invitation(value: SharingInvitation | undefined);
    /**
     * Gets the link property value. Provides the link details of the current permission, if it is a link type permissions. Read-only.
     * @returns a sharingLink
     */
    get link(): SharingLink | undefined;
    /**
     * Sets the link property value. Provides the link details of the current permission, if it is a link type permissions. Read-only.
     * @param value Value to set for the link property.
     */
    set link(value: SharingLink | undefined);
    /**
     * Gets the roles property value. The type of permission, for example, read. See below for the full list of roles. Read-only.
     * @returns a string
     */
    get roles(): string[] | undefined;
    /**
     * Sets the roles property value. The type of permission, for example, read. See below for the full list of roles. Read-only.
     * @param value Value to set for the roles property.
     */
    set roles(value: string[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shareId property value. A unique token that can be used to access this shared item via the [shares API][]. Read-only.
     * @returns a string
     */
    get shareId(): string | undefined;
    /**
     * Sets the shareId property value. A unique token that can be used to access this shared item via the [shares API][]. Read-only.
     * @param value Value to set for the shareId property.
     */
    set shareId(value: string | undefined);
}
