import { Entity, IdentitySet, PlannerAppliedCategories, PlannerAssignedToTaskBoardTaskFormat, PlannerAssignments, PlannerBucketTaskBoardTaskFormat, PlannerProgressTaskBoardTaskFormat, PlannerTaskDetails } from './index';
import { PlannerPreviewType } from './plannerPreviewType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class PlannerTask extends Entity implements Parsable {
    /** Number of checklist items with value set to false, representing incomplete items. */
    private _activeChecklistItemCount?;
    /** The categories to which the task has been applied. See applied Categories for possible values. */
    private _appliedCategories?;
    /** Read-only. Nullable. Used to render the task correctly in the task board view when grouped by assignedTo. */
    private _assignedToTaskBoardFormat?;
    /** Hint used to order items of this type in a list view. The format is defined as outlined here. */
    private _assigneePriority?;
    /** The set of assignees the task is assigned to. */
    private _assignments?;
    /** Bucket ID to which the task belongs. The bucket needs to be in the plan that the task is in. It is 28 characters long and case-sensitive. Format validation is done on the service. */
    private _bucketId?;
    /** Read-only. Nullable. Used to render the task correctly in the task board view when grouped by bucket. */
    private _bucketTaskBoardFormat?;
    /** Number of checklist items that are present on the task. */
    private _checklistItemCount?;
    /** Identity of the user that completed the task. */
    private _completedBy?;
    /** Read-only. Date and time at which the 'percentComplete' of the task is set to '100'. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _completedDateTime?;
    /** Thread ID of the conversation on the task. This is the ID of the conversation thread object created in the group. */
    private _conversationThreadId?;
    /** Identity of the user that created the task. */
    private _createdBy?;
    /** Read-only. Date and time at which the task is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _createdDateTime?;
    /** Read-only. Nullable. Additional details about the task. */
    private _details?;
    /** Date and time at which the task is due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _dueDateTime?;
    /** Read-only. Value is true if the details object of the task has a non-empty description and false otherwise. */
    private _hasDescription?;
    /** Hint used to order items of this type in a list view. The format is defined as outlined here. */
    private _orderHint?;
    /** Percentage of task completion. When set to 100, the task is considered completed. */
    private _percentComplete?;
    /** Plan ID to which the task belongs. */
    private _planId?;
    /** This sets the type of preview that shows up on the task. Possible values are: automatic, noPreview, checklist, description, reference. */
    private _previewType?;
    /** Priority of the task. Valid range of values is between 0 and 10 (inclusive), with increasing value being lower priority (0 has the highest priority and 10 has the lowest priority).  Currently, Planner interprets values 0 and 1 as 'urgent', 2 and 3 and 4 as 'important', 5, 6, and 7 as 'medium', and 8, 9, and 10 as 'low'.  Currently, Planner sets the value 1 for 'urgent', 3 for 'important', 5 for 'medium', and 9 for 'low'. */
    private _priority?;
    /** Read-only. Nullable. Used to render the task correctly in the task board view when grouped by progress. */
    private _progressTaskBoardFormat?;
    /** Number of external references that exist on the task. */
    private _referenceCount?;
    /** Date and time at which the task starts. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _startDateTime?;
    /** Title of the task. */
    private _title?;
    /**
     * Gets the activeChecklistItemCount property value. Number of checklist items with value set to false, representing incomplete items.
     * @returns a integer
     */
    get activeChecklistItemCount(): number | undefined;
    /**
     * Sets the activeChecklistItemCount property value. Number of checklist items with value set to false, representing incomplete items.
     * @param value Value to set for the activeChecklistItemCount property.
     */
    set activeChecklistItemCount(value: number | undefined);
    /**
     * Gets the appliedCategories property value. The categories to which the task has been applied. See applied Categories for possible values.
     * @returns a plannerAppliedCategories
     */
    get appliedCategories(): PlannerAppliedCategories | undefined;
    /**
     * Sets the appliedCategories property value. The categories to which the task has been applied. See applied Categories for possible values.
     * @param value Value to set for the appliedCategories property.
     */
    set appliedCategories(value: PlannerAppliedCategories | undefined);
    /**
     * Gets the assignedToTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by assignedTo.
     * @returns a plannerAssignedToTaskBoardTaskFormat
     */
    get assignedToTaskBoardFormat(): PlannerAssignedToTaskBoardTaskFormat | undefined;
    /**
     * Sets the assignedToTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by assignedTo.
     * @param value Value to set for the assignedToTaskBoardFormat property.
     */
    set assignedToTaskBoardFormat(value: PlannerAssignedToTaskBoardTaskFormat | undefined);
    /**
     * Gets the assigneePriority property value. Hint used to order items of this type in a list view. The format is defined as outlined here.
     * @returns a string
     */
    get assigneePriority(): string | undefined;
    /**
     * Sets the assigneePriority property value. Hint used to order items of this type in a list view. The format is defined as outlined here.
     * @param value Value to set for the assigneePriority property.
     */
    set assigneePriority(value: string | undefined);
    /**
     * Gets the assignments property value. The set of assignees the task is assigned to.
     * @returns a plannerAssignments
     */
    get assignments(): PlannerAssignments | undefined;
    /**
     * Sets the assignments property value. The set of assignees the task is assigned to.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: PlannerAssignments | undefined);
    /**
     * Gets the bucketId property value. Bucket ID to which the task belongs. The bucket needs to be in the plan that the task is in. It is 28 characters long and case-sensitive. Format validation is done on the service.
     * @returns a string
     */
    get bucketId(): string | undefined;
    /**
     * Sets the bucketId property value. Bucket ID to which the task belongs. The bucket needs to be in the plan that the task is in. It is 28 characters long and case-sensitive. Format validation is done on the service.
     * @param value Value to set for the bucketId property.
     */
    set bucketId(value: string | undefined);
    /**
     * Gets the bucketTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by bucket.
     * @returns a plannerBucketTaskBoardTaskFormat
     */
    get bucketTaskBoardFormat(): PlannerBucketTaskBoardTaskFormat | undefined;
    /**
     * Sets the bucketTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by bucket.
     * @param value Value to set for the bucketTaskBoardFormat property.
     */
    set bucketTaskBoardFormat(value: PlannerBucketTaskBoardTaskFormat | undefined);
    /**
     * Gets the checklistItemCount property value. Number of checklist items that are present on the task.
     * @returns a integer
     */
    get checklistItemCount(): number | undefined;
    /**
     * Sets the checklistItemCount property value. Number of checklist items that are present on the task.
     * @param value Value to set for the checklistItemCount property.
     */
    set checklistItemCount(value: number | undefined);
    /**
     * Gets the completedBy property value. Identity of the user that completed the task.
     * @returns a identitySet
     */
    get completedBy(): IdentitySet | undefined;
    /**
     * Sets the completedBy property value. Identity of the user that completed the task.
     * @param value Value to set for the completedBy property.
     */
    set completedBy(value: IdentitySet | undefined);
    /**
     * Gets the completedDateTime property value. Read-only. Date and time at which the 'percentComplete' of the task is set to '100'. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get completedDateTime(): Date | undefined;
    /**
     * Sets the completedDateTime property value. Read-only. Date and time at which the 'percentComplete' of the task is set to '100'. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the completedDateTime property.
     */
    set completedDateTime(value: Date | undefined);
    /**
     * Instantiates a new plannerTask and sets the default values.
     */
    constructor();
    /**
     * Gets the conversationThreadId property value. Thread ID of the conversation on the task. This is the ID of the conversation thread object created in the group.
     * @returns a string
     */
    get conversationThreadId(): string | undefined;
    /**
     * Sets the conversationThreadId property value. Thread ID of the conversation on the task. This is the ID of the conversation thread object created in the group.
     * @param value Value to set for the conversationThreadId property.
     */
    set conversationThreadId(value: string | undefined);
    /**
     * Gets the createdBy property value. Identity of the user that created the task.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Identity of the user that created the task.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the createdDateTime property value. Read-only. Date and time at which the task is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Read-only. Date and time at which the task is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the details property value. Read-only. Nullable. Additional details about the task.
     * @returns a plannerTaskDetails
     */
    get details(): PlannerTaskDetails | undefined;
    /**
     * Sets the details property value. Read-only. Nullable. Additional details about the task.
     * @param value Value to set for the details property.
     */
    set details(value: PlannerTaskDetails | undefined);
    /**
     * Gets the dueDateTime property value. Date and time at which the task is due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get dueDateTime(): Date | undefined;
    /**
     * Sets the dueDateTime property value. Date and time at which the task is due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the dueDateTime property.
     */
    set dueDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the hasDescription property value. Read-only. Value is true if the details object of the task has a non-empty description and false otherwise.
     * @returns a boolean
     */
    get hasDescription(): boolean | undefined;
    /**
     * Sets the hasDescription property value. Read-only. Value is true if the details object of the task has a non-empty description and false otherwise.
     * @param value Value to set for the hasDescription property.
     */
    set hasDescription(value: boolean | undefined);
    /**
     * Gets the orderHint property value. Hint used to order items of this type in a list view. The format is defined as outlined here.
     * @returns a string
     */
    get orderHint(): string | undefined;
    /**
     * Sets the orderHint property value. Hint used to order items of this type in a list view. The format is defined as outlined here.
     * @param value Value to set for the orderHint property.
     */
    set orderHint(value: string | undefined);
    /**
     * Gets the percentComplete property value. Percentage of task completion. When set to 100, the task is considered completed.
     * @returns a integer
     */
    get percentComplete(): number | undefined;
    /**
     * Sets the percentComplete property value. Percentage of task completion. When set to 100, the task is considered completed.
     * @param value Value to set for the percentComplete property.
     */
    set percentComplete(value: number | undefined);
    /**
     * Gets the planId property value. Plan ID to which the task belongs.
     * @returns a string
     */
    get planId(): string | undefined;
    /**
     * Sets the planId property value. Plan ID to which the task belongs.
     * @param value Value to set for the planId property.
     */
    set planId(value: string | undefined);
    /**
     * Gets the previewType property value. This sets the type of preview that shows up on the task. Possible values are: automatic, noPreview, checklist, description, reference.
     * @returns a plannerPreviewType
     */
    get previewType(): PlannerPreviewType | undefined;
    /**
     * Sets the previewType property value. This sets the type of preview that shows up on the task. Possible values are: automatic, noPreview, checklist, description, reference.
     * @param value Value to set for the previewType property.
     */
    set previewType(value: PlannerPreviewType | undefined);
    /**
     * Gets the priority property value. Priority of the task. Valid range of values is between 0 and 10 (inclusive), with increasing value being lower priority (0 has the highest priority and 10 has the lowest priority).  Currently, Planner interprets values 0 and 1 as 'urgent', 2 and 3 and 4 as 'important', 5, 6, and 7 as 'medium', and 8, 9, and 10 as 'low'.  Currently, Planner sets the value 1 for 'urgent', 3 for 'important', 5 for 'medium', and 9 for 'low'.
     * @returns a integer
     */
    get priority(): number | undefined;
    /**
     * Sets the priority property value. Priority of the task. Valid range of values is between 0 and 10 (inclusive), with increasing value being lower priority (0 has the highest priority and 10 has the lowest priority).  Currently, Planner interprets values 0 and 1 as 'urgent', 2 and 3 and 4 as 'important', 5, 6, and 7 as 'medium', and 8, 9, and 10 as 'low'.  Currently, Planner sets the value 1 for 'urgent', 3 for 'important', 5 for 'medium', and 9 for 'low'.
     * @param value Value to set for the priority property.
     */
    set priority(value: number | undefined);
    /**
     * Gets the progressTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by progress.
     * @returns a plannerProgressTaskBoardTaskFormat
     */
    get progressTaskBoardFormat(): PlannerProgressTaskBoardTaskFormat | undefined;
    /**
     * Sets the progressTaskBoardFormat property value. Read-only. Nullable. Used to render the task correctly in the task board view when grouped by progress.
     * @param value Value to set for the progressTaskBoardFormat property.
     */
    set progressTaskBoardFormat(value: PlannerProgressTaskBoardTaskFormat | undefined);
    /**
     * Gets the referenceCount property value. Number of external references that exist on the task.
     * @returns a integer
     */
    get referenceCount(): number | undefined;
    /**
     * Sets the referenceCount property value. Number of external references that exist on the task.
     * @param value Value to set for the referenceCount property.
     */
    set referenceCount(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the startDateTime property value. Date and time at which the task starts. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get startDateTime(): Date | undefined;
    /**
     * Sets the startDateTime property value. Date and time at which the task starts. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: Date | undefined);
    /**
     * Gets the title property value. Title of the task.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. Title of the task.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
}
