import { PrintConnector, Printer, PrinterShare, PrintOperation, PrintService, PrintSettings, PrintTaskDefinition } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Print implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** The list of available print connectors. */
    private _connectors?;
    /** The list of print long running operations. */
    private _operations?;
    /** The list of printers registered in the tenant. */
    private _printers?;
    /** The list of available Universal Print service endpoints. */
    private _services?;
    /** Tenant-wide settings for the Universal Print service. */
    private _settings?;
    /** The list of printer shares registered in the tenant. */
    private _shares?;
    /** List of abstract definition for a task that can be triggered when various events occur within Universal Print. */
    private _taskDefinitions?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the connectors property value. The list of available print connectors.
     * @returns a printConnector
     */
    get connectors(): PrintConnector[] | undefined;
    /**
     * Sets the connectors property value. The list of available print connectors.
     * @param value Value to set for the connectors property.
     */
    set connectors(value: PrintConnector[] | undefined);
    /**
     * Instantiates a new Print and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the operations property value. The list of print long running operations.
     * @returns a printOperation
     */
    get operations(): PrintOperation[] | undefined;
    /**
     * Sets the operations property value. The list of print long running operations.
     * @param value Value to set for the operations property.
     */
    set operations(value: PrintOperation[] | undefined);
    /**
     * Gets the printers property value. The list of printers registered in the tenant.
     * @returns a printer
     */
    get printers(): Printer[] | undefined;
    /**
     * Sets the printers property value. The list of printers registered in the tenant.
     * @param value Value to set for the printers property.
     */
    set printers(value: Printer[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the services property value. The list of available Universal Print service endpoints.
     * @returns a printService
     */
    get services(): PrintService[] | undefined;
    /**
     * Sets the services property value. The list of available Universal Print service endpoints.
     * @param value Value to set for the services property.
     */
    set services(value: PrintService[] | undefined);
    /**
     * Gets the settings property value. Tenant-wide settings for the Universal Print service.
     * @returns a printSettings
     */
    get settings(): PrintSettings | undefined;
    /**
     * Sets the settings property value. Tenant-wide settings for the Universal Print service.
     * @param value Value to set for the settings property.
     */
    set settings(value: PrintSettings | undefined);
    /**
     * Gets the shares property value. The list of printer shares registered in the tenant.
     * @returns a printerShare
     */
    get shares(): PrinterShare[] | undefined;
    /**
     * Sets the shares property value. The list of printer shares registered in the tenant.
     * @param value Value to set for the shares property.
     */
    set shares(value: PrinterShare[] | undefined);
    /**
     * Gets the taskDefinitions property value. List of abstract definition for a task that can be triggered when various events occur within Universal Print.
     * @returns a printTaskDefinition
     */
    get taskDefinitions(): PrintTaskDefinition[] | undefined;
    /**
     * Sets the taskDefinitions property value. List of abstract definition for a task that can be triggered when various events occur within Universal Print.
     * @param value Value to set for the taskDefinitions property.
     */
    set taskDefinitions(value: PrintTaskDefinition[] | undefined);
}
