import { IntegerRange, PrintMargin } from './index';
import { PrintColorMode } from './printColorMode';
import { PrintDuplexMode } from './printDuplexMode';
import { PrinterFeedOrientation } from './printerFeedOrientation';
import { PrintMultipageLayout } from './printMultipageLayout';
import { PrintOrientation } from './printOrientation';
import { PrintQuality } from './printQuality';
import { PrintScaling } from './printScaling';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PrintJobConfiguration implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Whether the printer should collate pages wehen printing multiple copies of a multi-page document. */
    private _collate?;
    /** The color mode the printer should use to print the job. Valid values are described in the table below. Read-only. */
    private _colorMode?;
    /** The number of copies that should be printed. Read-only. */
    private _copies?;
    /** The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only. */
    private _dpi?;
    /** The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only. */
    private _duplexMode?;
    /** The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only. */
    private _feedOrientation?;
    /** Finishing processes to use when printing. */
    private _finishings?;
    /** The fitPdfToPage property */
    private _fitPdfToPage?;
    /** The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins. */
    private _inputBin?;
    /** The margin settings to use when printing. */
    private _margin?;
    /** The media sizeto use when printing. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic. */
    private _mediaSize?;
    /** The default media (such as paper) type to print the document on. */
    private _mediaType?;
    /** The direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table. */
    private _multipageLayout?;
    /** The orientation setting the printer should use when printing the job. Valid values are described in the following table. */
    private _orientation?;
    /** The output bin to place completed prints into. See the printer's capabilities for a list of supported output bins. */
    private _outputBin?;
    /** The page ranges to print. Read-only. */
    private _pageRanges?;
    /** The number of document pages to print on each sheet. */
    private _pagesPerSheet?;
    /** The print quality to use when printing the job. Valid values are described in the table below. Read-only. */
    private _quality?;
    /** Specifies how the printer should scale the document data to fit the requested media. Valid values are described in the following table. */
    private _scaling?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the collate property value. Whether the printer should collate pages wehen printing multiple copies of a multi-page document.
     * @returns a boolean
     */
    get collate(): boolean | undefined;
    /**
     * Sets the collate property value. Whether the printer should collate pages wehen printing multiple copies of a multi-page document.
     * @param value Value to set for the collate property.
     */
    set collate(value: boolean | undefined);
    /**
     * Gets the colorMode property value. The color mode the printer should use to print the job. Valid values are described in the table below. Read-only.
     * @returns a printColorMode
     */
    get colorMode(): PrintColorMode | undefined;
    /**
     * Sets the colorMode property value. The color mode the printer should use to print the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the colorMode property.
     */
    set colorMode(value: PrintColorMode | undefined);
    /**
     * Instantiates a new printJobConfiguration and sets the default values.
     */
    constructor();
    /**
     * Gets the copies property value. The number of copies that should be printed. Read-only.
     * @returns a integer
     */
    get copies(): number | undefined;
    /**
     * Sets the copies property value. The number of copies that should be printed. Read-only.
     * @param value Value to set for the copies property.
     */
    set copies(value: number | undefined);
    /**
     * Gets the dpi property value. The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only.
     * @returns a integer
     */
    get dpi(): number | undefined;
    /**
     * Sets the dpi property value. The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only.
     * @param value Value to set for the dpi property.
     */
    set dpi(value: number | undefined);
    /**
     * Gets the duplexMode property value. The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only.
     * @returns a printDuplexMode
     */
    get duplexMode(): PrintDuplexMode | undefined;
    /**
     * Sets the duplexMode property value. The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the duplexMode property.
     */
    set duplexMode(value: PrintDuplexMode | undefined);
    /**
     * Gets the feedOrientation property value. The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only.
     * @returns a printerFeedOrientation
     */
    get feedOrientation(): PrinterFeedOrientation | undefined;
    /**
     * Sets the feedOrientation property value. The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only.
     * @param value Value to set for the feedOrientation property.
     */
    set feedOrientation(value: PrinterFeedOrientation | undefined);
    /**
     * Gets the finishings property value. Finishing processes to use when printing.
     * @returns a string
     */
    get finishings(): string[] | undefined;
    /**
     * Sets the finishings property value. Finishing processes to use when printing.
     * @param value Value to set for the finishings property.
     */
    set finishings(value: string[] | undefined);
    /**
     * Gets the fitPdfToPage property value. The fitPdfToPage property
     * @returns a boolean
     */
    get fitPdfToPage(): boolean | undefined;
    /**
     * Sets the fitPdfToPage property value. The fitPdfToPage property
     * @param value Value to set for the fitPdfToPage property.
     */
    set fitPdfToPage(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the inputBin property value. The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins.
     * @returns a string
     */
    get inputBin(): string | undefined;
    /**
     * Sets the inputBin property value. The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins.
     * @param value Value to set for the inputBin property.
     */
    set inputBin(value: string | undefined);
    /**
     * Gets the margin property value. The margin settings to use when printing.
     * @returns a printMargin
     */
    get margin(): PrintMargin | undefined;
    /**
     * Sets the margin property value. The margin settings to use when printing.
     * @param value Value to set for the margin property.
     */
    set margin(value: PrintMargin | undefined);
    /**
     * Gets the mediaSize property value. The media sizeto use when printing. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @returns a string
     */
    get mediaSize(): string | undefined;
    /**
     * Sets the mediaSize property value. The media sizeto use when printing. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @param value Value to set for the mediaSize property.
     */
    set mediaSize(value: string | undefined);
    /**
     * Gets the mediaType property value. The default media (such as paper) type to print the document on.
     * @returns a string
     */
    get mediaType(): string | undefined;
    /**
     * Sets the mediaType property value. The default media (such as paper) type to print the document on.
     * @param value Value to set for the mediaType property.
     */
    set mediaType(value: string | undefined);
    /**
     * Gets the multipageLayout property value. The direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @returns a printMultipageLayout
     */
    get multipageLayout(): PrintMultipageLayout | undefined;
    /**
     * Sets the multipageLayout property value. The direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @param value Value to set for the multipageLayout property.
     */
    set multipageLayout(value: PrintMultipageLayout | undefined);
    /**
     * Gets the orientation property value. The orientation setting the printer should use when printing the job. Valid values are described in the following table.
     * @returns a printOrientation
     */
    get orientation(): PrintOrientation | undefined;
    /**
     * Sets the orientation property value. The orientation setting the printer should use when printing the job. Valid values are described in the following table.
     * @param value Value to set for the orientation property.
     */
    set orientation(value: PrintOrientation | undefined);
    /**
     * Gets the outputBin property value. The output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @returns a string
     */
    get outputBin(): string | undefined;
    /**
     * Sets the outputBin property value. The output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @param value Value to set for the outputBin property.
     */
    set outputBin(value: string | undefined);
    /**
     * Gets the pageRanges property value. The page ranges to print. Read-only.
     * @returns a integerRange
     */
    get pageRanges(): IntegerRange[] | undefined;
    /**
     * Sets the pageRanges property value. The page ranges to print. Read-only.
     * @param value Value to set for the pageRanges property.
     */
    set pageRanges(value: IntegerRange[] | undefined);
    /**
     * Gets the pagesPerSheet property value. The number of document pages to print on each sheet.
     * @returns a integer
     */
    get pagesPerSheet(): number | undefined;
    /**
     * Sets the pagesPerSheet property value. The number of document pages to print on each sheet.
     * @param value Value to set for the pagesPerSheet property.
     */
    set pagesPerSheet(value: number | undefined);
    /**
     * Gets the quality property value. The print quality to use when printing the job. Valid values are described in the table below. Read-only.
     * @returns a printQuality
     */
    get quality(): PrintQuality | undefined;
    /**
     * Sets the quality property value. The print quality to use when printing the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the quality property.
     */
    set quality(value: PrintQuality | undefined);
    /**
     * Gets the scaling property value. Specifies how the printer should scale the document data to fit the requested media. Valid values are described in the following table.
     * @returns a printScaling
     */
    get scaling(): PrintScaling | undefined;
    /**
     * Sets the scaling property value. Specifies how the printer should scale the document data to fit the requested media. Valid values are described in the following table.
     * @param value Value to set for the scaling property.
     */
    set scaling(value: PrintScaling | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
