"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrintJobConfiguration = void 0;
const createIntegerRangeFromDiscriminatorValue_1 = require("./createIntegerRangeFromDiscriminatorValue");
const createPrintMarginFromDiscriminatorValue_1 = require("./createPrintMarginFromDiscriminatorValue");
const printColorMode_1 = require("./printColorMode");
const printDuplexMode_1 = require("./printDuplexMode");
const printerFeedOrientation_1 = require("./printerFeedOrientation");
const printMultipageLayout_1 = require("./printMultipageLayout");
const printOrientation_1 = require("./printOrientation");
const printQuality_1 = require("./printQuality");
const printScaling_1 = require("./printScaling");
class PrintJobConfiguration {
    /**
     * Instantiates a new printJobConfiguration and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    /**
     * Gets the collate property value. Whether the printer should collate pages wehen printing multiple copies of a multi-page document.
     * @returns a boolean
     */
    get collate() {
        return this._collate;
    }
    ;
    /**
     * Sets the collate property value. Whether the printer should collate pages wehen printing multiple copies of a multi-page document.
     * @param value Value to set for the collate property.
     */
    set collate(value) {
        this._collate = value;
    }
    ;
    /**
     * Gets the colorMode property value. The color mode the printer should use to print the job. Valid values are described in the table below. Read-only.
     * @returns a printColorMode
     */
    get colorMode() {
        return this._colorMode;
    }
    ;
    /**
     * Sets the colorMode property value. The color mode the printer should use to print the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the colorMode property.
     */
    set colorMode(value) {
        this._colorMode = value;
    }
    ;
    ;
    /**
     * Gets the copies property value. The number of copies that should be printed. Read-only.
     * @returns a integer
     */
    get copies() {
        return this._copies;
    }
    ;
    /**
     * Sets the copies property value. The number of copies that should be printed. Read-only.
     * @param value Value to set for the copies property.
     */
    set copies(value) {
        this._copies = value;
    }
    ;
    /**
     * Gets the dpi property value. The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only.
     * @returns a integer
     */
    get dpi() {
        return this._dpi;
    }
    ;
    /**
     * Sets the dpi property value. The resolution to use when printing the job, expressed in dots per inch (DPI). Read-only.
     * @param value Value to set for the dpi property.
     */
    set dpi(value) {
        this._dpi = value;
    }
    ;
    /**
     * Gets the duplexMode property value. The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only.
     * @returns a printDuplexMode
     */
    get duplexMode() {
        return this._duplexMode;
    }
    ;
    /**
     * Sets the duplexMode property value. The duplex mode the printer should use when printing the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the duplexMode property.
     */
    set duplexMode(value) {
        this._duplexMode = value;
    }
    ;
    /**
     * Gets the feedOrientation property value. The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only.
     * @returns a printerFeedOrientation
     */
    get feedOrientation() {
        return this._feedOrientation;
    }
    ;
    /**
     * Sets the feedOrientation property value. The orientation to use when feeding media into the printer. Valid values are described in the following table. Read-only.
     * @param value Value to set for the feedOrientation property.
     */
    set feedOrientation(value) {
        this._feedOrientation = value;
    }
    ;
    /**
     * Gets the finishings property value. Finishing processes to use when printing.
     * @returns a string
     */
    get finishings() {
        return this._finishings;
    }
    ;
    /**
     * Sets the finishings property value. Finishing processes to use when printing.
     * @param value Value to set for the finishings property.
     */
    set finishings(value) {
        this._finishings = value;
    }
    ;
    /**
     * Gets the fitPdfToPage property value. The fitPdfToPage property
     * @returns a boolean
     */
    get fitPdfToPage() {
        return this._fitPdfToPage;
    }
    ;
    /**
     * Sets the fitPdfToPage property value. The fitPdfToPage property
     * @param value Value to set for the fitPdfToPage property.
     */
    set fitPdfToPage(value) {
        this._fitPdfToPage = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "collate": n => { this.collate = n.getBooleanValue(); },
            "colorMode": n => { this.colorMode = n.getEnumValue(printColorMode_1.PrintColorMode); },
            "copies": n => { this.copies = n.getNumberValue(); },
            "dpi": n => { this.dpi = n.getNumberValue(); },
            "duplexMode": n => { this.duplexMode = n.getEnumValue(printDuplexMode_1.PrintDuplexMode); },
            "feedOrientation": n => { this.feedOrientation = n.getEnumValue(printerFeedOrientation_1.PrinterFeedOrientation); },
            "finishings": n => { this.finishings = n.getCollectionOfPrimitiveValues(); },
            "fitPdfToPage": n => { this.fitPdfToPage = n.getBooleanValue(); },
            "inputBin": n => { this.inputBin = n.getStringValue(); },
            "margin": n => { this.margin = n.getObjectValue(createPrintMarginFromDiscriminatorValue_1.createPrintMarginFromDiscriminatorValue); },
            "mediaSize": n => { this.mediaSize = n.getStringValue(); },
            "mediaType": n => { this.mediaType = n.getStringValue(); },
            "multipageLayout": n => { this.multipageLayout = n.getEnumValue(printMultipageLayout_1.PrintMultipageLayout); },
            "orientation": n => { this.orientation = n.getEnumValue(printOrientation_1.PrintOrientation); },
            "outputBin": n => { this.outputBin = n.getStringValue(); },
            "pageRanges": n => { this.pageRanges = n.getCollectionOfObjectValues(createIntegerRangeFromDiscriminatorValue_1.createIntegerRangeFromDiscriminatorValue); },
            "pagesPerSheet": n => { this.pagesPerSheet = n.getNumberValue(); },
            "quality": n => { this.quality = n.getEnumValue(printQuality_1.PrintQuality); },
            "scaling": n => { this.scaling = n.getEnumValue(printScaling_1.PrintScaling); },
        };
    }
    ;
    /**
     * Gets the inputBin property value. The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins.
     * @returns a string
     */
    get inputBin() {
        return this._inputBin;
    }
    ;
    /**
     * Sets the inputBin property value. The input bin (tray) to use when printing. See the printer's capabilities for a list of supported input bins.
     * @param value Value to set for the inputBin property.
     */
    set inputBin(value) {
        this._inputBin = value;
    }
    ;
    /**
     * Gets the margin property value. The margin settings to use when printing.
     * @returns a printMargin
     */
    get margin() {
        return this._margin;
    }
    ;
    /**
     * Sets the margin property value. The margin settings to use when printing.
     * @param value Value to set for the margin property.
     */
    set margin(value) {
        this._margin = value;
    }
    ;
    /**
     * Gets the mediaSize property value. The media sizeto use when printing. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @returns a string
     */
    get mediaSize() {
        return this._mediaSize;
    }
    ;
    /**
     * Sets the mediaSize property value. The media sizeto use when printing. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @param value Value to set for the mediaSize property.
     */
    set mediaSize(value) {
        this._mediaSize = value;
    }
    ;
    /**
     * Gets the mediaType property value. The default media (such as paper) type to print the document on.
     * @returns a string
     */
    get mediaType() {
        return this._mediaType;
    }
    ;
    /**
     * Sets the mediaType property value. The default media (such as paper) type to print the document on.
     * @param value Value to set for the mediaType property.
     */
    set mediaType(value) {
        this._mediaType = value;
    }
    ;
    /**
     * Gets the multipageLayout property value. The direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @returns a printMultipageLayout
     */
    get multipageLayout() {
        return this._multipageLayout;
    }
    ;
    /**
     * Sets the multipageLayout property value. The direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @param value Value to set for the multipageLayout property.
     */
    set multipageLayout(value) {
        this._multipageLayout = value;
    }
    ;
    /**
     * Gets the orientation property value. The orientation setting the printer should use when printing the job. Valid values are described in the following table.
     * @returns a printOrientation
     */
    get orientation() {
        return this._orientation;
    }
    ;
    /**
     * Sets the orientation property value. The orientation setting the printer should use when printing the job. Valid values are described in the following table.
     * @param value Value to set for the orientation property.
     */
    set orientation(value) {
        this._orientation = value;
    }
    ;
    /**
     * Gets the outputBin property value. The output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @returns a string
     */
    get outputBin() {
        return this._outputBin;
    }
    ;
    /**
     * Sets the outputBin property value. The output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @param value Value to set for the outputBin property.
     */
    set outputBin(value) {
        this._outputBin = value;
    }
    ;
    /**
     * Gets the pageRanges property value. The page ranges to print. Read-only.
     * @returns a integerRange
     */
    get pageRanges() {
        return this._pageRanges;
    }
    ;
    /**
     * Sets the pageRanges property value. The page ranges to print. Read-only.
     * @param value Value to set for the pageRanges property.
     */
    set pageRanges(value) {
        this._pageRanges = value;
    }
    ;
    /**
     * Gets the pagesPerSheet property value. The number of document pages to print on each sheet.
     * @returns a integer
     */
    get pagesPerSheet() {
        return this._pagesPerSheet;
    }
    ;
    /**
     * Sets the pagesPerSheet property value. The number of document pages to print on each sheet.
     * @param value Value to set for the pagesPerSheet property.
     */
    set pagesPerSheet(value) {
        this._pagesPerSheet = value;
    }
    ;
    /**
     * Gets the quality property value. The print quality to use when printing the job. Valid values are described in the table below. Read-only.
     * @returns a printQuality
     */
    get quality() {
        return this._quality;
    }
    ;
    /**
     * Sets the quality property value. The print quality to use when printing the job. Valid values are described in the table below. Read-only.
     * @param value Value to set for the quality property.
     */
    set quality(value) {
        this._quality = value;
    }
    ;
    /**
     * Gets the scaling property value. Specifies how the printer should scale the document data to fit the requested media. Valid values are described in the following table.
     * @returns a printScaling
     */
    get scaling() {
        return this._scaling;
    }
    ;
    /**
     * Sets the scaling property value. Specifies how the printer should scale the document data to fit the requested media. Valid values are described in the following table.
     * @param value Value to set for the scaling property.
     */
    set scaling(value) {
        this._scaling = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeBooleanValue("collate", this.collate);
        writer.writeEnumValue("colorMode", this.colorMode);
        writer.writeNumberValue("copies", this.copies);
        writer.writeNumberValue("dpi", this.dpi);
        writer.writeEnumValue("duplexMode", this.duplexMode);
        writer.writeEnumValue("feedOrientation", this.feedOrientation);
        writer.writeCollectionOfPrimitiveValues("finishings", this.finishings);
        writer.writeBooleanValue("fitPdfToPage", this.fitPdfToPage);
        writer.writeStringValue("inputBin", this.inputBin);
        writer.writeObjectValue("margin", this.margin);
        writer.writeStringValue("mediaSize", this.mediaSize);
        writer.writeStringValue("mediaType", this.mediaType);
        writer.writeEnumValue("multipageLayout", this.multipageLayout);
        writer.writeEnumValue("orientation", this.orientation);
        writer.writeStringValue("outputBin", this.outputBin);
        writer.writeCollectionOfObjectValues("pageRanges", this.pageRanges);
        writer.writeNumberValue("pagesPerSheet", this.pagesPerSheet);
        writer.writeEnumValue("quality", this.quality);
        writer.writeEnumValue("scaling", this.scaling);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
}
exports.PrintJobConfiguration = PrintJobConfiguration;
