"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Printer = void 0;
const createPrintConnectorFromDiscriminatorValue_1 = require("./createPrintConnectorFromDiscriminatorValue");
const createPrinterShareFromDiscriminatorValue_1 = require("./createPrinterShareFromDiscriminatorValue");
const createPrintTaskTriggerFromDiscriminatorValue_1 = require("./createPrintTaskTriggerFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the print singleton. */
class Printer extends index_1.PrinterBase {
    /**
     * Instantiates a new printer and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the connectors property value. The connectors that are associated with the printer.
     * @returns a printConnector
     */
    get connectors() {
        return this._connectors;
    }
    ;
    /**
     * Sets the connectors property value. The connectors that are associated with the printer.
     * @param value Value to set for the connectors property.
     */
    set connectors(value) {
        this._connectors = value;
    }
    ;
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "connectors": n => { this.connectors = n.getCollectionOfObjectValues(createPrintConnectorFromDiscriminatorValue_1.createPrintConnectorFromDiscriminatorValue); }, "hasPhysicalDevice": n => { this.hasPhysicalDevice = n.getBooleanValue(); }, "isShared": n => { this.isShared = n.getBooleanValue(); }, "lastSeenDateTime": n => { this.lastSeenDateTime = n.getDateValue(); }, "registeredDateTime": n => { this.registeredDateTime = n.getDateValue(); }, "shares": n => { this.shares = n.getCollectionOfObjectValues(createPrinterShareFromDiscriminatorValue_1.createPrinterShareFromDiscriminatorValue); }, "taskTriggers": n => { this.taskTriggers = n.getCollectionOfObjectValues(createPrintTaskTriggerFromDiscriminatorValue_1.createPrintTaskTriggerFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the hasPhysicalDevice property value. True if the printer has a physical device for printing. Read-only.
     * @returns a boolean
     */
    get hasPhysicalDevice() {
        return this._hasPhysicalDevice;
    }
    ;
    /**
     * Sets the hasPhysicalDevice property value. True if the printer has a physical device for printing. Read-only.
     * @param value Value to set for the hasPhysicalDevice property.
     */
    set hasPhysicalDevice(value) {
        this._hasPhysicalDevice = value;
    }
    ;
    /**
     * Gets the isShared property value. True if the printer is shared; false otherwise. Read-only.
     * @returns a boolean
     */
    get isShared() {
        return this._isShared;
    }
    ;
    /**
     * Sets the isShared property value. True if the printer is shared; false otherwise. Read-only.
     * @param value Value to set for the isShared property.
     */
    set isShared(value) {
        this._isShared = value;
    }
    ;
    /**
     * Gets the lastSeenDateTime property value. The most recent dateTimeOffset when a printer interacted with Universal Print. Read-only.
     * @returns a Date
     */
    get lastSeenDateTime() {
        return this._lastSeenDateTime;
    }
    ;
    /**
     * Sets the lastSeenDateTime property value. The most recent dateTimeOffset when a printer interacted with Universal Print. Read-only.
     * @param value Value to set for the lastSeenDateTime property.
     */
    set lastSeenDateTime(value) {
        this._lastSeenDateTime = value;
    }
    ;
    /**
     * Gets the registeredDateTime property value. The DateTimeOffset when the printer was registered. Read-only.
     * @returns a Date
     */
    get registeredDateTime() {
        return this._registeredDateTime;
    }
    ;
    /**
     * Sets the registeredDateTime property value. The DateTimeOffset when the printer was registered. Read-only.
     * @param value Value to set for the registeredDateTime property.
     */
    set registeredDateTime(value) {
        this._registeredDateTime = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("connectors", this.connectors);
        writer.writeBooleanValue("hasPhysicalDevice", this.hasPhysicalDevice);
        writer.writeBooleanValue("isShared", this.isShared);
        writer.writeDateValue("lastSeenDateTime", this.lastSeenDateTime);
        writer.writeDateValue("registeredDateTime", this.registeredDateTime);
        writer.writeCollectionOfObjectValues("shares", this.shares);
        writer.writeCollectionOfObjectValues("taskTriggers", this.taskTriggers);
    }
    ;
    /**
     * Gets the shares property value. The list of printerShares that are associated with the printer. Currently, only one printerShare can be associated with the printer. Read-only. Nullable.
     * @returns a printerShare
     */
    get shares() {
        return this._shares;
    }
    ;
    /**
     * Sets the shares property value. The list of printerShares that are associated with the printer. Currently, only one printerShare can be associated with the printer. Read-only. Nullable.
     * @param value Value to set for the shares property.
     */
    set shares(value) {
        this._shares = value;
    }
    ;
    /**
     * Gets the taskTriggers property value. A list of task triggers that are associated with the printer.
     * @returns a printTaskTrigger
     */
    get taskTriggers() {
        return this._taskTriggers;
    }
    ;
    /**
     * Sets the taskTriggers property value. A list of task triggers that are associated with the printer.
     * @param value Value to set for the taskTriggers property.
     */
    set taskTriggers(value) {
        this._taskTriggers = value;
    }
    ;
}
exports.Printer = Printer;
