import { Entity, PrinterCapabilities, PrinterDefaults, PrinterLocation, PrinterStatus, PrintJob } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the print singleton. */
export declare class PrinterBase extends Entity implements Parsable {
    /** The capabilities of the printer/printerShare. */
    private _capabilities?;
    /** The default print settings of printer/printerShare. */
    private _defaults?;
    /** The name of the printer/printerShare. */
    private _displayName?;
    /** Whether the printer/printerShare is currently accepting new print jobs. */
    private _isAcceptingJobs?;
    /** The list of jobs that are queued for printing by the printer/printerShare. */
    private _jobs?;
    /** The physical and/or organizational location of the printer/printerShare. */
    private _location?;
    /** The manufacturer of the printer/printerShare. */
    private _manufacturer?;
    /** The model name of the printer/printerShare. */
    private _model?;
    /** The status property */
    private _status?;
    /**
     * Gets the capabilities property value. The capabilities of the printer/printerShare.
     * @returns a printerCapabilities
     */
    get capabilities(): PrinterCapabilities | undefined;
    /**
     * Sets the capabilities property value. The capabilities of the printer/printerShare.
     * @param value Value to set for the capabilities property.
     */
    set capabilities(value: PrinterCapabilities | undefined);
    /**
     * Instantiates a new printerBase and sets the default values.
     */
    constructor();
    /**
     * Gets the defaults property value. The default print settings of printer/printerShare.
     * @returns a printerDefaults
     */
    get defaults(): PrinterDefaults | undefined;
    /**
     * Sets the defaults property value. The default print settings of printer/printerShare.
     * @param value Value to set for the defaults property.
     */
    set defaults(value: PrinterDefaults | undefined);
    /**
     * Gets the displayName property value. The name of the printer/printerShare.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the printer/printerShare.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isAcceptingJobs property value. Whether the printer/printerShare is currently accepting new print jobs.
     * @returns a boolean
     */
    get isAcceptingJobs(): boolean | undefined;
    /**
     * Sets the isAcceptingJobs property value. Whether the printer/printerShare is currently accepting new print jobs.
     * @param value Value to set for the isAcceptingJobs property.
     */
    set isAcceptingJobs(value: boolean | undefined);
    /**
     * Gets the jobs property value. The list of jobs that are queued for printing by the printer/printerShare.
     * @returns a printJob
     */
    get jobs(): PrintJob[] | undefined;
    /**
     * Sets the jobs property value. The list of jobs that are queued for printing by the printer/printerShare.
     * @param value Value to set for the jobs property.
     */
    set jobs(value: PrintJob[] | undefined);
    /**
     * Gets the location property value. The physical and/or organizational location of the printer/printerShare.
     * @returns a printerLocation
     */
    get location(): PrinterLocation | undefined;
    /**
     * Sets the location property value. The physical and/or organizational location of the printer/printerShare.
     * @param value Value to set for the location property.
     */
    set location(value: PrinterLocation | undefined);
    /**
     * Gets the manufacturer property value. The manufacturer of the printer/printerShare.
     * @returns a string
     */
    get manufacturer(): string | undefined;
    /**
     * Sets the manufacturer property value. The manufacturer of the printer/printerShare.
     * @param value Value to set for the manufacturer property.
     */
    set manufacturer(value: string | undefined);
    /**
     * Gets the model property value. The model name of the printer/printerShare.
     * @returns a string
     */
    get model(): string | undefined;
    /**
     * Sets the model property value. The model name of the printer/printerShare.
     * @param value Value to set for the model property.
     */
    set model(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. The status property
     * @returns a printerStatus
     */
    get status(): PrinterStatus | undefined;
    /**
     * Sets the status property value. The status property
     * @param value Value to set for the status property.
     */
    set status(value: PrinterStatus | undefined);
}
