"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrinterBase = void 0;
const createPrinterCapabilitiesFromDiscriminatorValue_1 = require("./createPrinterCapabilitiesFromDiscriminatorValue");
const createPrinterDefaultsFromDiscriminatorValue_1 = require("./createPrinterDefaultsFromDiscriminatorValue");
const createPrinterLocationFromDiscriminatorValue_1 = require("./createPrinterLocationFromDiscriminatorValue");
const createPrinterStatusFromDiscriminatorValue_1 = require("./createPrinterStatusFromDiscriminatorValue");
const createPrintJobFromDiscriminatorValue_1 = require("./createPrintJobFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the print singleton. */
class PrinterBase extends index_1.Entity {
    /**
     * Instantiates a new printerBase and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the capabilities property value. The capabilities of the printer/printerShare.
     * @returns a printerCapabilities
     */
    get capabilities() {
        return this._capabilities;
    }
    ;
    /**
     * Sets the capabilities property value. The capabilities of the printer/printerShare.
     * @param value Value to set for the capabilities property.
     */
    set capabilities(value) {
        this._capabilities = value;
    }
    ;
    ;
    /**
     * Gets the defaults property value. The default print settings of printer/printerShare.
     * @returns a printerDefaults
     */
    get defaults() {
        return this._defaults;
    }
    ;
    /**
     * Sets the defaults property value. The default print settings of printer/printerShare.
     * @param value Value to set for the defaults property.
     */
    set defaults(value) {
        this._defaults = value;
    }
    ;
    /**
     * Gets the displayName property value. The name of the printer/printerShare.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The name of the printer/printerShare.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "capabilities": n => { this.capabilities = n.getObjectValue(createPrinterCapabilitiesFromDiscriminatorValue_1.createPrinterCapabilitiesFromDiscriminatorValue); }, "defaults": n => { this.defaults = n.getObjectValue(createPrinterDefaultsFromDiscriminatorValue_1.createPrinterDefaultsFromDiscriminatorValue); }, "displayName": n => { this.displayName = n.getStringValue(); }, "isAcceptingJobs": n => { this.isAcceptingJobs = n.getBooleanValue(); }, "jobs": n => { this.jobs = n.getCollectionOfObjectValues(createPrintJobFromDiscriminatorValue_1.createPrintJobFromDiscriminatorValue); }, "location": n => { this.location = n.getObjectValue(createPrinterLocationFromDiscriminatorValue_1.createPrinterLocationFromDiscriminatorValue); }, "manufacturer": n => { this.manufacturer = n.getStringValue(); }, "model": n => { this.model = n.getStringValue(); }, "status": n => { this.status = n.getObjectValue(createPrinterStatusFromDiscriminatorValue_1.createPrinterStatusFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the isAcceptingJobs property value. Whether the printer/printerShare is currently accepting new print jobs.
     * @returns a boolean
     */
    get isAcceptingJobs() {
        return this._isAcceptingJobs;
    }
    ;
    /**
     * Sets the isAcceptingJobs property value. Whether the printer/printerShare is currently accepting new print jobs.
     * @param value Value to set for the isAcceptingJobs property.
     */
    set isAcceptingJobs(value) {
        this._isAcceptingJobs = value;
    }
    ;
    /**
     * Gets the jobs property value. The list of jobs that are queued for printing by the printer/printerShare.
     * @returns a printJob
     */
    get jobs() {
        return this._jobs;
    }
    ;
    /**
     * Sets the jobs property value. The list of jobs that are queued for printing by the printer/printerShare.
     * @param value Value to set for the jobs property.
     */
    set jobs(value) {
        this._jobs = value;
    }
    ;
    /**
     * Gets the location property value. The physical and/or organizational location of the printer/printerShare.
     * @returns a printerLocation
     */
    get location() {
        return this._location;
    }
    ;
    /**
     * Sets the location property value. The physical and/or organizational location of the printer/printerShare.
     * @param value Value to set for the location property.
     */
    set location(value) {
        this._location = value;
    }
    ;
    /**
     * Gets the manufacturer property value. The manufacturer of the printer/printerShare.
     * @returns a string
     */
    get manufacturer() {
        return this._manufacturer;
    }
    ;
    /**
     * Sets the manufacturer property value. The manufacturer of the printer/printerShare.
     * @param value Value to set for the manufacturer property.
     */
    set manufacturer(value) {
        this._manufacturer = value;
    }
    ;
    /**
     * Gets the model property value. The model name of the printer/printerShare.
     * @returns a string
     */
    get model() {
        return this._model;
    }
    ;
    /**
     * Sets the model property value. The model name of the printer/printerShare.
     * @param value Value to set for the model property.
     */
    set model(value) {
        this._model = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("capabilities", this.capabilities);
        writer.writeObjectValue("defaults", this.defaults);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeBooleanValue("isAcceptingJobs", this.isAcceptingJobs);
        writer.writeCollectionOfObjectValues("jobs", this.jobs);
        writer.writeObjectValue("location", this.location);
        writer.writeStringValue("manufacturer", this.manufacturer);
        writer.writeStringValue("model", this.model);
        writer.writeObjectValue("status", this.status);
    }
    ;
    /**
     * Gets the status property value. The status property
     * @returns a printerStatus
     */
    get status() {
        return this._status;
    }
    ;
    /**
     * Sets the status property value. The status property
     * @param value Value to set for the status property.
     */
    set status(value) {
        this._status = value;
    }
    ;
}
exports.PrinterBase = PrinterBase;
