import { IntegerRange } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PrinterCapabilities implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** A list of supported bottom margins(in microns) for the printer. */
    private _bottomMargins?;
    /** True if the printer supports collating when printing muliple copies of a multi-page document; false otherwise. */
    private _collation?;
    /** The color modes supported by the printer. Valid values are described in the following table. */
    private _colorModes?;
    /** A list of supported content (MIME) types that the printer supports. It is not guaranteed that the Universal Print service supports printing all of these MIME types. */
    private _contentTypes?;
    /** The range of copies per job supported by the printer. */
    private _copiesPerJob?;
    /** The list of print resolutions in DPI that are supported by the printer. */
    private _dpis?;
    /** The list of duplex modes that are supported by the printer. Valid values are described in the following table. */
    private _duplexModes?;
    /** The list of feed orientations that are supported by the printer. */
    private _feedOrientations?;
    /** Finishing processes the printer supports for a printed document. */
    private _finishings?;
    /** Supported input bins for the printer. */
    private _inputBins?;
    /** True if color printing is supported by the printer; false otherwise. Read-only. */
    private _isColorPrintingSupported?;
    /** True if the printer supports printing by page ranges; false otherwise. */
    private _isPageRangeSupported?;
    /** A list of supported left margins(in microns) for the printer. */
    private _leftMargins?;
    /** The media (i.e., paper) colors supported by the printer. */
    private _mediaColors?;
    /** The media sizes supported by the printer. Supports standard size names for ISO and ANSI media sizes. Valid values are in the following table. */
    private _mediaSizes?;
    /** The media types supported by the printer. */
    private _mediaTypes?;
    /** The presentation directions supported by the printer. Supported values are described in the following table. */
    private _multipageLayouts?;
    /** The print orientations supported by the printer. Valid values are described in the following table. */
    private _orientations?;
    /** The printer's supported output bins (trays). */
    private _outputBins?;
    /** Supported number of Input Pages to impose upon a single Impression. */
    private _pagesPerSheet?;
    /** The print qualities supported by the printer. */
    private _qualities?;
    /** A list of supported right margins(in microns) for the printer. */
    private _rightMargins?;
    /** Supported print scalings. */
    private _scalings?;
    /** True if the printer supports scaling PDF pages to match the print media size; false otherwise. */
    private _supportsFitPdfToPage?;
    /** A list of supported top margins(in microns) for the printer. */
    private _topMargins?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the bottomMargins property value. A list of supported bottom margins(in microns) for the printer.
     * @returns a integer
     */
    get bottomMargins(): number[] | undefined;
    /**
     * Sets the bottomMargins property value. A list of supported bottom margins(in microns) for the printer.
     * @param value Value to set for the bottomMargins property.
     */
    set bottomMargins(value: number[] | undefined);
    /**
     * Gets the collation property value. True if the printer supports collating when printing muliple copies of a multi-page document; false otherwise.
     * @returns a boolean
     */
    get collation(): boolean | undefined;
    /**
     * Sets the collation property value. True if the printer supports collating when printing muliple copies of a multi-page document; false otherwise.
     * @param value Value to set for the collation property.
     */
    set collation(value: boolean | undefined);
    /**
     * Gets the colorModes property value. The color modes supported by the printer. Valid values are described in the following table.
     * @returns a string
     */
    get colorModes(): string[] | undefined;
    /**
     * Sets the colorModes property value. The color modes supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the colorModes property.
     */
    set colorModes(value: string[] | undefined);
    /**
     * Instantiates a new printerCapabilities and sets the default values.
     */
    constructor();
    /**
     * Gets the contentTypes property value. A list of supported content (MIME) types that the printer supports. It is not guaranteed that the Universal Print service supports printing all of these MIME types.
     * @returns a string
     */
    get contentTypes(): string[] | undefined;
    /**
     * Sets the contentTypes property value. A list of supported content (MIME) types that the printer supports. It is not guaranteed that the Universal Print service supports printing all of these MIME types.
     * @param value Value to set for the contentTypes property.
     */
    set contentTypes(value: string[] | undefined);
    /**
     * Gets the copiesPerJob property value. The range of copies per job supported by the printer.
     * @returns a integerRange
     */
    get copiesPerJob(): IntegerRange | undefined;
    /**
     * Sets the copiesPerJob property value. The range of copies per job supported by the printer.
     * @param value Value to set for the copiesPerJob property.
     */
    set copiesPerJob(value: IntegerRange | undefined);
    /**
     * Gets the dpis property value. The list of print resolutions in DPI that are supported by the printer.
     * @returns a integer
     */
    get dpis(): number[] | undefined;
    /**
     * Sets the dpis property value. The list of print resolutions in DPI that are supported by the printer.
     * @param value Value to set for the dpis property.
     */
    set dpis(value: number[] | undefined);
    /**
     * Gets the duplexModes property value. The list of duplex modes that are supported by the printer. Valid values are described in the following table.
     * @returns a string
     */
    get duplexModes(): string[] | undefined;
    /**
     * Sets the duplexModes property value. The list of duplex modes that are supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the duplexModes property.
     */
    set duplexModes(value: string[] | undefined);
    /**
     * Gets the feedOrientations property value. The list of feed orientations that are supported by the printer.
     * @returns a string
     */
    get feedOrientations(): string[] | undefined;
    /**
     * Sets the feedOrientations property value. The list of feed orientations that are supported by the printer.
     * @param value Value to set for the feedOrientations property.
     */
    set feedOrientations(value: string[] | undefined);
    /**
     * Gets the finishings property value. Finishing processes the printer supports for a printed document.
     * @returns a string
     */
    get finishings(): string[] | undefined;
    /**
     * Sets the finishings property value. Finishing processes the printer supports for a printed document.
     * @param value Value to set for the finishings property.
     */
    set finishings(value: string[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the inputBins property value. Supported input bins for the printer.
     * @returns a string
     */
    get inputBins(): string[] | undefined;
    /**
     * Sets the inputBins property value. Supported input bins for the printer.
     * @param value Value to set for the inputBins property.
     */
    set inputBins(value: string[] | undefined);
    /**
     * Gets the isColorPrintingSupported property value. True if color printing is supported by the printer; false otherwise. Read-only.
     * @returns a boolean
     */
    get isColorPrintingSupported(): boolean | undefined;
    /**
     * Sets the isColorPrintingSupported property value. True if color printing is supported by the printer; false otherwise. Read-only.
     * @param value Value to set for the isColorPrintingSupported property.
     */
    set isColorPrintingSupported(value: boolean | undefined);
    /**
     * Gets the isPageRangeSupported property value. True if the printer supports printing by page ranges; false otherwise.
     * @returns a boolean
     */
    get isPageRangeSupported(): boolean | undefined;
    /**
     * Sets the isPageRangeSupported property value. True if the printer supports printing by page ranges; false otherwise.
     * @param value Value to set for the isPageRangeSupported property.
     */
    set isPageRangeSupported(value: boolean | undefined);
    /**
     * Gets the leftMargins property value. A list of supported left margins(in microns) for the printer.
     * @returns a integer
     */
    get leftMargins(): number[] | undefined;
    /**
     * Sets the leftMargins property value. A list of supported left margins(in microns) for the printer.
     * @param value Value to set for the leftMargins property.
     */
    set leftMargins(value: number[] | undefined);
    /**
     * Gets the mediaColors property value. The media (i.e., paper) colors supported by the printer.
     * @returns a string
     */
    get mediaColors(): string[] | undefined;
    /**
     * Sets the mediaColors property value. The media (i.e., paper) colors supported by the printer.
     * @param value Value to set for the mediaColors property.
     */
    set mediaColors(value: string[] | undefined);
    /**
     * Gets the mediaSizes property value. The media sizes supported by the printer. Supports standard size names for ISO and ANSI media sizes. Valid values are in the following table.
     * @returns a string
     */
    get mediaSizes(): string[] | undefined;
    /**
     * Sets the mediaSizes property value. The media sizes supported by the printer. Supports standard size names for ISO and ANSI media sizes. Valid values are in the following table.
     * @param value Value to set for the mediaSizes property.
     */
    set mediaSizes(value: string[] | undefined);
    /**
     * Gets the mediaTypes property value. The media types supported by the printer.
     * @returns a string
     */
    get mediaTypes(): string[] | undefined;
    /**
     * Sets the mediaTypes property value. The media types supported by the printer.
     * @param value Value to set for the mediaTypes property.
     */
    set mediaTypes(value: string[] | undefined);
    /**
     * Gets the multipageLayouts property value. The presentation directions supported by the printer. Supported values are described in the following table.
     * @returns a string
     */
    get multipageLayouts(): string[] | undefined;
    /**
     * Sets the multipageLayouts property value. The presentation directions supported by the printer. Supported values are described in the following table.
     * @param value Value to set for the multipageLayouts property.
     */
    set multipageLayouts(value: string[] | undefined);
    /**
     * Gets the orientations property value. The print orientations supported by the printer. Valid values are described in the following table.
     * @returns a string
     */
    get orientations(): string[] | undefined;
    /**
     * Sets the orientations property value. The print orientations supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the orientations property.
     */
    set orientations(value: string[] | undefined);
    /**
     * Gets the outputBins property value. The printer's supported output bins (trays).
     * @returns a string
     */
    get outputBins(): string[] | undefined;
    /**
     * Sets the outputBins property value. The printer's supported output bins (trays).
     * @param value Value to set for the outputBins property.
     */
    set outputBins(value: string[] | undefined);
    /**
     * Gets the pagesPerSheet property value. Supported number of Input Pages to impose upon a single Impression.
     * @returns a integer
     */
    get pagesPerSheet(): number[] | undefined;
    /**
     * Sets the pagesPerSheet property value. Supported number of Input Pages to impose upon a single Impression.
     * @param value Value to set for the pagesPerSheet property.
     */
    set pagesPerSheet(value: number[] | undefined);
    /**
     * Gets the qualities property value. The print qualities supported by the printer.
     * @returns a string
     */
    get qualities(): string[] | undefined;
    /**
     * Sets the qualities property value. The print qualities supported by the printer.
     * @param value Value to set for the qualities property.
     */
    set qualities(value: string[] | undefined);
    /**
     * Gets the rightMargins property value. A list of supported right margins(in microns) for the printer.
     * @returns a integer
     */
    get rightMargins(): number[] | undefined;
    /**
     * Sets the rightMargins property value. A list of supported right margins(in microns) for the printer.
     * @param value Value to set for the rightMargins property.
     */
    set rightMargins(value: number[] | undefined);
    /**
     * Gets the scalings property value. Supported print scalings.
     * @returns a string
     */
    get scalings(): string[] | undefined;
    /**
     * Sets the scalings property value. Supported print scalings.
     * @param value Value to set for the scalings property.
     */
    set scalings(value: string[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the supportsFitPdfToPage property value. True if the printer supports scaling PDF pages to match the print media size; false otherwise.
     * @returns a boolean
     */
    get supportsFitPdfToPage(): boolean | undefined;
    /**
     * Sets the supportsFitPdfToPage property value. True if the printer supports scaling PDF pages to match the print media size; false otherwise.
     * @param value Value to set for the supportsFitPdfToPage property.
     */
    set supportsFitPdfToPage(value: boolean | undefined);
    /**
     * Gets the topMargins property value. A list of supported top margins(in microns) for the printer.
     * @returns a integer
     */
    get topMargins(): number[] | undefined;
    /**
     * Sets the topMargins property value. A list of supported top margins(in microns) for the printer.
     * @param value Value to set for the topMargins property.
     */
    set topMargins(value: number[] | undefined);
}
