import { PrintColorMode } from './printColorMode';
import { PrintDuplexMode } from './printDuplexMode';
import { PrintMultipageLayout } from './printMultipageLayout';
import { PrintOrientation } from './printOrientation';
import { PrintQuality } from './printQuality';
import { PrintScaling } from './printScaling';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PrinterDefaults implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** The default color mode to use when printing the document. Valid values are described in the following table. */
    private _colorMode?;
    /** The default content (MIME) type to use when processing documents. */
    private _contentType?;
    /** The default number of copies printed per job. */
    private _copiesPerJob?;
    /** The default resolution in DPI to use when printing the job. */
    private _dpi?;
    /** The default duplex (double-sided) configuration to use when printing a document. Valid values are described in the following table. */
    private _duplexMode?;
    /** The default set of finishings to apply to print jobs. Valid values are described in the following table. */
    private _finishings?;
    /** The default fitPdfToPage setting. True to fit each page of a PDF document to a physical sheet of media; false to let the printer decide how to lay out impressions. */
    private _fitPdfToPage?;
    /** The default input bin that serves as the paper source. */
    private _inputBin?;
    /** The default media (such as paper) color to print the document on. */
    private _mediaColor?;
    /** The default media size to use. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic. */
    private _mediaSize?;
    /** The default media (such as paper) type to print the document on. */
    private _mediaType?;
    /** The default direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table. */
    private _multipageLayout?;
    /** The default orientation to use when printing the document. Valid values are described in the following table. */
    private _orientation?;
    /** The default output bin to place completed prints into. See the printer's capabilities for a list of supported output bins. */
    private _outputBin?;
    /** The default number of document pages to print on each sheet. */
    private _pagesPerSheet?;
    /** The default quality to use when printing the document. Valid values are described in the following table. */
    private _quality?;
    /** Specifies how the printer scales the document data to fit the requested media. Valid values are described in the following table. */
    private _scaling?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the colorMode property value. The default color mode to use when printing the document. Valid values are described in the following table.
     * @returns a printColorMode
     */
    get colorMode(): PrintColorMode | undefined;
    /**
     * Sets the colorMode property value. The default color mode to use when printing the document. Valid values are described in the following table.
     * @param value Value to set for the colorMode property.
     */
    set colorMode(value: PrintColorMode | undefined);
    /**
     * Instantiates a new printerDefaults and sets the default values.
     */
    constructor();
    /**
     * Gets the contentType property value. The default content (MIME) type to use when processing documents.
     * @returns a string
     */
    get contentType(): string | undefined;
    /**
     * Sets the contentType property value. The default content (MIME) type to use when processing documents.
     * @param value Value to set for the contentType property.
     */
    set contentType(value: string | undefined);
    /**
     * Gets the copiesPerJob property value. The default number of copies printed per job.
     * @returns a integer
     */
    get copiesPerJob(): number | undefined;
    /**
     * Sets the copiesPerJob property value. The default number of copies printed per job.
     * @param value Value to set for the copiesPerJob property.
     */
    set copiesPerJob(value: number | undefined);
    /**
     * Gets the dpi property value. The default resolution in DPI to use when printing the job.
     * @returns a integer
     */
    get dpi(): number | undefined;
    /**
     * Sets the dpi property value. The default resolution in DPI to use when printing the job.
     * @param value Value to set for the dpi property.
     */
    set dpi(value: number | undefined);
    /**
     * Gets the duplexMode property value. The default duplex (double-sided) configuration to use when printing a document. Valid values are described in the following table.
     * @returns a printDuplexMode
     */
    get duplexMode(): PrintDuplexMode | undefined;
    /**
     * Sets the duplexMode property value. The default duplex (double-sided) configuration to use when printing a document. Valid values are described in the following table.
     * @param value Value to set for the duplexMode property.
     */
    set duplexMode(value: PrintDuplexMode | undefined);
    /**
     * Gets the finishings property value. The default set of finishings to apply to print jobs. Valid values are described in the following table.
     * @returns a string
     */
    get finishings(): string[] | undefined;
    /**
     * Sets the finishings property value. The default set of finishings to apply to print jobs. Valid values are described in the following table.
     * @param value Value to set for the finishings property.
     */
    set finishings(value: string[] | undefined);
    /**
     * Gets the fitPdfToPage property value. The default fitPdfToPage setting. True to fit each page of a PDF document to a physical sheet of media; false to let the printer decide how to lay out impressions.
     * @returns a boolean
     */
    get fitPdfToPage(): boolean | undefined;
    /**
     * Sets the fitPdfToPage property value. The default fitPdfToPage setting. True to fit each page of a PDF document to a physical sheet of media; false to let the printer decide how to lay out impressions.
     * @param value Value to set for the fitPdfToPage property.
     */
    set fitPdfToPage(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the inputBin property value. The default input bin that serves as the paper source.
     * @returns a string
     */
    get inputBin(): string | undefined;
    /**
     * Sets the inputBin property value. The default input bin that serves as the paper source.
     * @param value Value to set for the inputBin property.
     */
    set inputBin(value: string | undefined);
    /**
     * Gets the mediaColor property value. The default media (such as paper) color to print the document on.
     * @returns a string
     */
    get mediaColor(): string | undefined;
    /**
     * Sets the mediaColor property value. The default media (such as paper) color to print the document on.
     * @param value Value to set for the mediaColor property.
     */
    set mediaColor(value: string | undefined);
    /**
     * Gets the mediaSize property value. The default media size to use. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @returns a string
     */
    get mediaSize(): string | undefined;
    /**
     * Sets the mediaSize property value. The default media size to use. Supports standard size names for ISO and ANSI media sizes. Valid values are listed in the printerCapabilities topic.
     * @param value Value to set for the mediaSize property.
     */
    set mediaSize(value: string | undefined);
    /**
     * Gets the mediaType property value. The default media (such as paper) type to print the document on.
     * @returns a string
     */
    get mediaType(): string | undefined;
    /**
     * Sets the mediaType property value. The default media (such as paper) type to print the document on.
     * @param value Value to set for the mediaType property.
     */
    set mediaType(value: string | undefined);
    /**
     * Gets the multipageLayout property value. The default direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @returns a printMultipageLayout
     */
    get multipageLayout(): PrintMultipageLayout | undefined;
    /**
     * Sets the multipageLayout property value. The default direction to lay out pages when multiple pages are being printed per sheet. Valid values are described in the following table.
     * @param value Value to set for the multipageLayout property.
     */
    set multipageLayout(value: PrintMultipageLayout | undefined);
    /**
     * Gets the orientation property value. The default orientation to use when printing the document. Valid values are described in the following table.
     * @returns a printOrientation
     */
    get orientation(): PrintOrientation | undefined;
    /**
     * Sets the orientation property value. The default orientation to use when printing the document. Valid values are described in the following table.
     * @param value Value to set for the orientation property.
     */
    set orientation(value: PrintOrientation | undefined);
    /**
     * Gets the outputBin property value. The default output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @returns a string
     */
    get outputBin(): string | undefined;
    /**
     * Sets the outputBin property value. The default output bin to place completed prints into. See the printer's capabilities for a list of supported output bins.
     * @param value Value to set for the outputBin property.
     */
    set outputBin(value: string | undefined);
    /**
     * Gets the pagesPerSheet property value. The default number of document pages to print on each sheet.
     * @returns a integer
     */
    get pagesPerSheet(): number | undefined;
    /**
     * Sets the pagesPerSheet property value. The default number of document pages to print on each sheet.
     * @param value Value to set for the pagesPerSheet property.
     */
    set pagesPerSheet(value: number | undefined);
    /**
     * Gets the quality property value. The default quality to use when printing the document. Valid values are described in the following table.
     * @returns a printQuality
     */
    get quality(): PrintQuality | undefined;
    /**
     * Sets the quality property value. The default quality to use when printing the document. Valid values are described in the following table.
     * @param value Value to set for the quality property.
     */
    set quality(value: PrintQuality | undefined);
    /**
     * Gets the scaling property value. Specifies how the printer scales the document data to fit the requested media. Valid values are described in the following table.
     * @returns a printScaling
     */
    get scaling(): PrintScaling | undefined;
    /**
     * Sets the scaling property value. Specifies how the printer scales the document data to fit the requested media. Valid values are described in the following table.
     * @param value Value to set for the scaling property.
     */
    set scaling(value: PrintScaling | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
