"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Process = void 0;
const createFileHashFromDiscriminatorValue_1 = require("./createFileHashFromDiscriminatorValue");
const processIntegrityLevel_1 = require("./processIntegrityLevel");
class Process {
    /**
     * Instantiates a new process and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the accountName property value. User account identifier (user account context the process ran under) for example, AccountName, SID, and so on.
     * @returns a string
     */
    get accountName() {
        return this._accountName;
    }
    ;
    /**
     * Sets the accountName property value. User account identifier (user account context the process ran under) for example, AccountName, SID, and so on.
     * @param value Value to set for the accountName property.
     */
    set accountName(value) {
        this._accountName = value;
    }
    ;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    /**
     * Gets the commandLine property value. The full process invocation commandline including all parameters.
     * @returns a string
     */
    get commandLine() {
        return this._commandLine;
    }
    ;
    /**
     * Sets the commandLine property value. The full process invocation commandline including all parameters.
     * @param value Value to set for the commandLine property.
     */
    set commandLine(value) {
        this._commandLine = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. Time at which the process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Time at which the process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the fileHash property value. Complex type containing file hashes (cryptographic and location-sensitive).
     * @returns a fileHash
     */
    get fileHash() {
        return this._fileHash;
    }
    ;
    /**
     * Sets the fileHash property value. Complex type containing file hashes (cryptographic and location-sensitive).
     * @param value Value to set for the fileHash property.
     */
    set fileHash(value) {
        this._fileHash = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "accountName": n => { this.accountName = n.getStringValue(); },
            "commandLine": n => { this.commandLine = n.getStringValue(); },
            "createdDateTime": n => { this.createdDateTime = n.getDateValue(); },
            "fileHash": n => { this.fileHash = n.getObjectValue(createFileHashFromDiscriminatorValue_1.createFileHashFromDiscriminatorValue); },
            "integrityLevel": n => { this.integrityLevel = n.getEnumValue(processIntegrityLevel_1.ProcessIntegrityLevel); },
            "isElevated": n => { this.isElevated = n.getBooleanValue(); },
            "name": n => { this.name = n.getStringValue(); },
            "parentProcessCreatedDateTime": n => { this.parentProcessCreatedDateTime = n.getDateValue(); },
            "parentProcessId": n => { this.parentProcessId = n.getNumberValue(); },
            "parentProcessName": n => { this.parentProcessName = n.getStringValue(); },
            "path": n => { this.path = n.getStringValue(); },
            "processId": n => { this.processId = n.getNumberValue(); },
        };
    }
    ;
    /**
     * Gets the integrityLevel property value. The integrity level of the process. Possible values are: unknown, untrusted, low, medium, high, system.
     * @returns a processIntegrityLevel
     */
    get integrityLevel() {
        return this._integrityLevel;
    }
    ;
    /**
     * Sets the integrityLevel property value. The integrity level of the process. Possible values are: unknown, untrusted, low, medium, high, system.
     * @param value Value to set for the integrityLevel property.
     */
    set integrityLevel(value) {
        this._integrityLevel = value;
    }
    ;
    /**
     * Gets the isElevated property value. True if the process is elevated.
     * @returns a boolean
     */
    get isElevated() {
        return this._isElevated;
    }
    ;
    /**
     * Sets the isElevated property value. True if the process is elevated.
     * @param value Value to set for the isElevated property.
     */
    set isElevated(value) {
        this._isElevated = value;
    }
    ;
    /**
     * Gets the name property value. The name of the process' Image file.
     * @returns a string
     */
    get name() {
        return this._name;
    }
    ;
    /**
     * Sets the name property value. The name of the process' Image file.
     * @param value Value to set for the name property.
     */
    set name(value) {
        this._name = value;
    }
    ;
    /**
     * Gets the parentProcessCreatedDateTime property value. DateTime at which the parent process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get parentProcessCreatedDateTime() {
        return this._parentProcessCreatedDateTime;
    }
    ;
    /**
     * Sets the parentProcessCreatedDateTime property value. DateTime at which the parent process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the parentProcessCreatedDateTime property.
     */
    set parentProcessCreatedDateTime(value) {
        this._parentProcessCreatedDateTime = value;
    }
    ;
    /**
     * Gets the parentProcessId property value. The Process ID (PID) of the parent process.
     * @returns a integer
     */
    get parentProcessId() {
        return this._parentProcessId;
    }
    ;
    /**
     * Sets the parentProcessId property value. The Process ID (PID) of the parent process.
     * @param value Value to set for the parentProcessId property.
     */
    set parentProcessId(value) {
        this._parentProcessId = value;
    }
    ;
    /**
     * Gets the parentProcessName property value. The name of the image file of the parent process.
     * @returns a string
     */
    get parentProcessName() {
        return this._parentProcessName;
    }
    ;
    /**
     * Sets the parentProcessName property value. The name of the image file of the parent process.
     * @param value Value to set for the parentProcessName property.
     */
    set parentProcessName(value) {
        this._parentProcessName = value;
    }
    ;
    /**
     * Gets the path property value. Full path, including filename.
     * @returns a string
     */
    get path() {
        return this._path;
    }
    ;
    /**
     * Sets the path property value. Full path, including filename.
     * @param value Value to set for the path property.
     */
    set path(value) {
        this._path = value;
    }
    ;
    /**
     * Gets the processId property value. The Process ID (PID) of the process.
     * @returns a integer
     */
    get processId() {
        return this._processId;
    }
    ;
    /**
     * Sets the processId property value. The Process ID (PID) of the process.
     * @param value Value to set for the processId property.
     */
    set processId(value) {
        this._processId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeStringValue("accountName", this.accountName);
        writer.writeStringValue("commandLine", this.commandLine);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeObjectValue("fileHash", this.fileHash);
        writer.writeEnumValue("integrityLevel", this.integrityLevel);
        writer.writeBooleanValue("isElevated", this.isElevated);
        writer.writeStringValue("name", this.name);
        writer.writeDateValue("parentProcessCreatedDateTime", this.parentProcessCreatedDateTime);
        writer.writeNumberValue("parentProcessId", this.parentProcessId);
        writer.writeStringValue("parentProcessName", this.parentProcessName);
        writer.writeStringValue("path", this.path);
        writer.writeNumberValue("processId", this.processId);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
}
exports.Process = Process;
