import { Entity, Initiator, ModifiedProperty, ProvisionedIdentity, ProvisioningServicePrincipal, ProvisioningStatusInfo, ProvisioningStep, ProvisioningSystem } from './index';
import { ProvisioningAction } from './provisioningAction';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the auditLogRoot singleton. */
export declare class ProvisioningObjectSummary extends Entity implements Parsable {
    /** The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z */
    private _activityDateTime?;
    /** Unique ID of this change in this cycle. */
    private _changeId?;
    /** Unique ID per job iteration. */
    private _cycleId?;
    /** Indicates how long this provisioning action took to finish. Measured in milliseconds. */
    private _durationInMilliseconds?;
    /** Details of who initiated this provisioning. */
    private _initiatedBy?;
    /** The unique ID for the whole provisioning job. */
    private _jobId?;
    /** Details of each property that was modified in this provisioning action on this object. */
    private _modifiedProperties?;
    /** Indicates the activity name or the operation name. Possible values are: create, update, delete, stageddelete, disable, other and unknownFutureValue. For a list of activities logged, refer to Azure AD activity list. */
    private _provisioningAction?;
    /** Details of provisioning status. */
    private _provisioningStatusInfo?;
    /** Details of each step in provisioning. */
    private _provisioningSteps?;
    /** Represents the service principal used for provisioning. */
    private _servicePrincipal?;
    /** Details of source object being provisioned. */
    private _sourceIdentity?;
    /** Details of source system of the object being provisioned. */
    private _sourceSystem?;
    /** Details of target object being provisioned. */
    private _targetIdentity?;
    /** Details of target system of the object being provisioned. */
    private _targetSystem?;
    /** Unique Azure AD tenant ID. */
    private _tenantId?;
    /**
     * Gets the activityDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get activityDateTime(): Date | undefined;
    /**
     * Sets the activityDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the activityDateTime property.
     */
    set activityDateTime(value: Date | undefined);
    /**
     * Gets the changeId property value. Unique ID of this change in this cycle.
     * @returns a string
     */
    get changeId(): string | undefined;
    /**
     * Sets the changeId property value. Unique ID of this change in this cycle.
     * @param value Value to set for the changeId property.
     */
    set changeId(value: string | undefined);
    /**
     * Instantiates a new provisioningObjectSummary and sets the default values.
     */
    constructor();
    /**
     * Gets the cycleId property value. Unique ID per job iteration.
     * @returns a string
     */
    get cycleId(): string | undefined;
    /**
     * Sets the cycleId property value. Unique ID per job iteration.
     * @param value Value to set for the cycleId property.
     */
    set cycleId(value: string | undefined);
    /**
     * Gets the durationInMilliseconds property value. Indicates how long this provisioning action took to finish. Measured in milliseconds.
     * @returns a integer
     */
    get durationInMilliseconds(): number | undefined;
    /**
     * Sets the durationInMilliseconds property value. Indicates how long this provisioning action took to finish. Measured in milliseconds.
     * @param value Value to set for the durationInMilliseconds property.
     */
    set durationInMilliseconds(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the initiatedBy property value. Details of who initiated this provisioning.
     * @returns a initiator
     */
    get initiatedBy(): Initiator | undefined;
    /**
     * Sets the initiatedBy property value. Details of who initiated this provisioning.
     * @param value Value to set for the initiatedBy property.
     */
    set initiatedBy(value: Initiator | undefined);
    /**
     * Gets the jobId property value. The unique ID for the whole provisioning job.
     * @returns a string
     */
    get jobId(): string | undefined;
    /**
     * Sets the jobId property value. The unique ID for the whole provisioning job.
     * @param value Value to set for the jobId property.
     */
    set jobId(value: string | undefined);
    /**
     * Gets the modifiedProperties property value. Details of each property that was modified in this provisioning action on this object.
     * @returns a modifiedProperty
     */
    get modifiedProperties(): ModifiedProperty[] | undefined;
    /**
     * Sets the modifiedProperties property value. Details of each property that was modified in this provisioning action on this object.
     * @param value Value to set for the modifiedProperties property.
     */
    set modifiedProperties(value: ModifiedProperty[] | undefined);
    /**
     * Gets the provisioningAction property value. Indicates the activity name or the operation name. Possible values are: create, update, delete, stageddelete, disable, other and unknownFutureValue. For a list of activities logged, refer to Azure AD activity list.
     * @returns a provisioningAction
     */
    get provisioningAction(): ProvisioningAction | undefined;
    /**
     * Sets the provisioningAction property value. Indicates the activity name or the operation name. Possible values are: create, update, delete, stageddelete, disable, other and unknownFutureValue. For a list of activities logged, refer to Azure AD activity list.
     * @param value Value to set for the provisioningAction property.
     */
    set provisioningAction(value: ProvisioningAction | undefined);
    /**
     * Gets the provisioningStatusInfo property value. Details of provisioning status.
     * @returns a provisioningStatusInfo
     */
    get provisioningStatusInfo(): ProvisioningStatusInfo | undefined;
    /**
     * Sets the provisioningStatusInfo property value. Details of provisioning status.
     * @param value Value to set for the provisioningStatusInfo property.
     */
    set provisioningStatusInfo(value: ProvisioningStatusInfo | undefined);
    /**
     * Gets the provisioningSteps property value. Details of each step in provisioning.
     * @returns a provisioningStep
     */
    get provisioningSteps(): ProvisioningStep[] | undefined;
    /**
     * Sets the provisioningSteps property value. Details of each step in provisioning.
     * @param value Value to set for the provisioningSteps property.
     */
    set provisioningSteps(value: ProvisioningStep[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the servicePrincipal property value. Represents the service principal used for provisioning.
     * @returns a provisioningServicePrincipal
     */
    get servicePrincipal(): ProvisioningServicePrincipal | undefined;
    /**
     * Sets the servicePrincipal property value. Represents the service principal used for provisioning.
     * @param value Value to set for the servicePrincipal property.
     */
    set servicePrincipal(value: ProvisioningServicePrincipal | undefined);
    /**
     * Gets the sourceIdentity property value. Details of source object being provisioned.
     * @returns a provisionedIdentity
     */
    get sourceIdentity(): ProvisionedIdentity | undefined;
    /**
     * Sets the sourceIdentity property value. Details of source object being provisioned.
     * @param value Value to set for the sourceIdentity property.
     */
    set sourceIdentity(value: ProvisionedIdentity | undefined);
    /**
     * Gets the sourceSystem property value. Details of source system of the object being provisioned.
     * @returns a provisioningSystem
     */
    get sourceSystem(): ProvisioningSystem | undefined;
    /**
     * Sets the sourceSystem property value. Details of source system of the object being provisioned.
     * @param value Value to set for the sourceSystem property.
     */
    set sourceSystem(value: ProvisioningSystem | undefined);
    /**
     * Gets the targetIdentity property value. Details of target object being provisioned.
     * @returns a provisionedIdentity
     */
    get targetIdentity(): ProvisionedIdentity | undefined;
    /**
     * Sets the targetIdentity property value. Details of target object being provisioned.
     * @param value Value to set for the targetIdentity property.
     */
    set targetIdentity(value: ProvisionedIdentity | undefined);
    /**
     * Gets the targetSystem property value. Details of target system of the object being provisioned.
     * @returns a provisioningSystem
     */
    get targetSystem(): ProvisioningSystem | undefined;
    /**
     * Sets the targetSystem property value. Details of target system of the object being provisioned.
     * @param value Value to set for the targetSystem property.
     */
    set targetSystem(value: ProvisioningSystem | undefined);
    /**
     * Gets the tenantId property value. Unique Azure AD tenant ID.
     * @returns a string
     */
    get tenantId(): string | undefined;
    /**
     * Sets the tenantId property value. Unique Azure AD tenant ID.
     * @param value Value to set for the tenantId property.
     */
    set tenantId(value: string | undefined);
}
