import { Entity, UnifiedRoleAssignment, UnifiedRoleAssignmentSchedule, UnifiedRoleAssignmentScheduleInstance, UnifiedRoleAssignmentScheduleRequest, UnifiedRoleDefinition, UnifiedRoleEligibilitySchedule, UnifiedRoleEligibilityScheduleInstance, UnifiedRoleEligibilityScheduleRequest } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the roleManagement singleton. */
export declare class RbacApplication extends Entity implements Parsable {
    /** Resource to grant access to users or groups. */
    private _roleAssignments?;
    /** Instances for active role assignments. */
    private _roleAssignmentScheduleInstances?;
    /** Requests for active role assignments to principals through PIM. */
    private _roleAssignmentScheduleRequests?;
    /** Schedules for active role assignment operations. */
    private _roleAssignmentSchedules?;
    /** Resource representing the roles allowed by RBAC providers and the permissions assigned to the roles. */
    private _roleDefinitions?;
    /** Instances for role eligibility requests. */
    private _roleEligibilityScheduleInstances?;
    /** Requests for role eligibilities for principals through PIM. */
    private _roleEligibilityScheduleRequests?;
    /** Schedules for role eligibility operations. */
    private _roleEligibilitySchedules?;
    /**
     * Instantiates a new rbacApplication and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the roleAssignments property value. Resource to grant access to users or groups.
     * @returns a unifiedRoleAssignment
     */
    get roleAssignments(): UnifiedRoleAssignment[] | undefined;
    /**
     * Sets the roleAssignments property value. Resource to grant access to users or groups.
     * @param value Value to set for the roleAssignments property.
     */
    set roleAssignments(value: UnifiedRoleAssignment[] | undefined);
    /**
     * Gets the roleAssignmentScheduleInstances property value. Instances for active role assignments.
     * @returns a unifiedRoleAssignmentScheduleInstance
     */
    get roleAssignmentScheduleInstances(): UnifiedRoleAssignmentScheduleInstance[] | undefined;
    /**
     * Sets the roleAssignmentScheduleInstances property value. Instances for active role assignments.
     * @param value Value to set for the roleAssignmentScheduleInstances property.
     */
    set roleAssignmentScheduleInstances(value: UnifiedRoleAssignmentScheduleInstance[] | undefined);
    /**
     * Gets the roleAssignmentScheduleRequests property value. Requests for active role assignments to principals through PIM.
     * @returns a unifiedRoleAssignmentScheduleRequest
     */
    get roleAssignmentScheduleRequests(): UnifiedRoleAssignmentScheduleRequest[] | undefined;
    /**
     * Sets the roleAssignmentScheduleRequests property value. Requests for active role assignments to principals through PIM.
     * @param value Value to set for the roleAssignmentScheduleRequests property.
     */
    set roleAssignmentScheduleRequests(value: UnifiedRoleAssignmentScheduleRequest[] | undefined);
    /**
     * Gets the roleAssignmentSchedules property value. Schedules for active role assignment operations.
     * @returns a unifiedRoleAssignmentSchedule
     */
    get roleAssignmentSchedules(): UnifiedRoleAssignmentSchedule[] | undefined;
    /**
     * Sets the roleAssignmentSchedules property value. Schedules for active role assignment operations.
     * @param value Value to set for the roleAssignmentSchedules property.
     */
    set roleAssignmentSchedules(value: UnifiedRoleAssignmentSchedule[] | undefined);
    /**
     * Gets the roleDefinitions property value. Resource representing the roles allowed by RBAC providers and the permissions assigned to the roles.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinitions(): UnifiedRoleDefinition[] | undefined;
    /**
     * Sets the roleDefinitions property value. Resource representing the roles allowed by RBAC providers and the permissions assigned to the roles.
     * @param value Value to set for the roleDefinitions property.
     */
    set roleDefinitions(value: UnifiedRoleDefinition[] | undefined);
    /**
     * Gets the roleEligibilityScheduleInstances property value. Instances for role eligibility requests.
     * @returns a unifiedRoleEligibilityScheduleInstance
     */
    get roleEligibilityScheduleInstances(): UnifiedRoleEligibilityScheduleInstance[] | undefined;
    /**
     * Sets the roleEligibilityScheduleInstances property value. Instances for role eligibility requests.
     * @param value Value to set for the roleEligibilityScheduleInstances property.
     */
    set roleEligibilityScheduleInstances(value: UnifiedRoleEligibilityScheduleInstance[] | undefined);
    /**
     * Gets the roleEligibilityScheduleRequests property value. Requests for role eligibilities for principals through PIM.
     * @returns a unifiedRoleEligibilityScheduleRequest
     */
    get roleEligibilityScheduleRequests(): UnifiedRoleEligibilityScheduleRequest[] | undefined;
    /**
     * Sets the roleEligibilityScheduleRequests property value. Requests for role eligibilities for principals through PIM.
     * @param value Value to set for the roleEligibilityScheduleRequests property.
     */
    set roleEligibilityScheduleRequests(value: UnifiedRoleEligibilityScheduleRequest[] | undefined);
    /**
     * Gets the roleEligibilitySchedules property value. Schedules for role eligibility operations.
     * @returns a unifiedRoleEligibilitySchedule
     */
    get roleEligibilitySchedules(): UnifiedRoleEligibilitySchedule[] | undefined;
    /**
     * Sets the roleEligibilitySchedules property value. Schedules for role eligibility operations.
     * @param value Value to set for the roleEligibilitySchedules property.
     */
    set roleEligibilitySchedules(value: UnifiedRoleEligibilitySchedule[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
