"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RecurrencePattern = void 0;
const dayOfWeek_1 = require("./dayOfWeek");
const recurrencePatternType_1 = require("./recurrencePatternType");
const weekIndex_1 = require("./weekIndex");
class RecurrencePattern {
    /**
     * Instantiates a new recurrencePattern and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    ;
    /**
     * Gets the dayOfMonth property value. The day of the month on which the event occurs. Required if type is absoluteMonthly or absoluteYearly.
     * @returns a integer
     */
    get dayOfMonth() {
        return this._dayOfMonth;
    }
    ;
    /**
     * Sets the dayOfMonth property value. The day of the month on which the event occurs. Required if type is absoluteMonthly or absoluteYearly.
     * @param value Value to set for the dayOfMonth property.
     */
    set dayOfMonth(value) {
        this._dayOfMonth = value;
    }
    ;
    /**
     * Gets the daysOfWeek property value. A collection of the days of the week on which the event occurs. The possible values are: sunday, monday, tuesday, wednesday, thursday, friday, saturday. If type is relativeMonthly or relativeYearly, and daysOfWeek specifies more than one day, the event falls on the first day that satisfies the pattern.  Required if type is weekly, relativeMonthly, or relativeYearly.
     * @returns a string
     */
    get daysOfWeek() {
        return this._daysOfWeek;
    }
    ;
    /**
     * Sets the daysOfWeek property value. A collection of the days of the week on which the event occurs. The possible values are: sunday, monday, tuesday, wednesday, thursday, friday, saturday. If type is relativeMonthly or relativeYearly, and daysOfWeek specifies more than one day, the event falls on the first day that satisfies the pattern.  Required if type is weekly, relativeMonthly, or relativeYearly.
     * @param value Value to set for the daysOfWeek property.
     */
    set daysOfWeek(value) {
        this._daysOfWeek = value;
    }
    ;
    /**
     * Gets the firstDayOfWeek property value. The first day of the week. The possible values are: sunday, monday, tuesday, wednesday, thursday, friday, saturday. Default is sunday. Required if type is weekly.
     * @returns a dayOfWeek
     */
    get firstDayOfWeek() {
        return this._firstDayOfWeek;
    }
    ;
    /**
     * Sets the firstDayOfWeek property value. The first day of the week. The possible values are: sunday, monday, tuesday, wednesday, thursday, friday, saturday. Default is sunday. Required if type is weekly.
     * @param value Value to set for the firstDayOfWeek property.
     */
    set firstDayOfWeek(value) {
        this._firstDayOfWeek = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "dayOfMonth": n => { this.dayOfMonth = n.getNumberValue(); },
            "daysOfWeek": n => { this.daysOfWeek = n.getCollectionOfPrimitiveValues(); },
            "firstDayOfWeek": n => { this.firstDayOfWeek = n.getEnumValue(dayOfWeek_1.DayOfWeek); },
            "index": n => { this.index = n.getEnumValue(weekIndex_1.WeekIndex); },
            "interval": n => { this.interval = n.getNumberValue(); },
            "month": n => { this.month = n.getNumberValue(); },
            "type": n => { this.type = n.getEnumValue(recurrencePatternType_1.RecurrencePatternType); },
        };
    }
    ;
    /**
     * Gets the index property value. Specifies on which instance of the allowed days specified in daysOfWeek the event occurs, counted from the first instance in the month. The possible values are: first, second, third, fourth, last. Default is first. Optional and used if type is relativeMonthly or relativeYearly.
     * @returns a weekIndex
     */
    get index() {
        return this._index;
    }
    ;
    /**
     * Sets the index property value. Specifies on which instance of the allowed days specified in daysOfWeek the event occurs, counted from the first instance in the month. The possible values are: first, second, third, fourth, last. Default is first. Optional and used if type is relativeMonthly or relativeYearly.
     * @param value Value to set for the index property.
     */
    set index(value) {
        this._index = value;
    }
    ;
    /**
     * Gets the interval property value. The number of units between occurrences, where units can be in days, weeks, months, or years, depending on the type. Required.
     * @returns a integer
     */
    get interval() {
        return this._interval;
    }
    ;
    /**
     * Sets the interval property value. The number of units between occurrences, where units can be in days, weeks, months, or years, depending on the type. Required.
     * @param value Value to set for the interval property.
     */
    set interval(value) {
        this._interval = value;
    }
    ;
    /**
     * Gets the month property value. The month in which the event occurs.  This is a number from 1 to 12.
     * @returns a integer
     */
    get month() {
        return this._month;
    }
    ;
    /**
     * Sets the month property value. The month in which the event occurs.  This is a number from 1 to 12.
     * @param value Value to set for the month property.
     */
    set month(value) {
        this._month = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeNumberValue("dayOfMonth", this.dayOfMonth);
        writer.writeCollectionOfPrimitiveValues("daysOfWeek", this.daysOfWeek);
        writer.writeEnumValue("firstDayOfWeek", this.firstDayOfWeek);
        writer.writeEnumValue("index", this.index);
        writer.writeNumberValue("interval", this.interval);
        writer.writeNumberValue("month", this.month);
        writer.writeEnumValue("type", this.type);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the type property value. The recurrence pattern type: daily, weekly, absoluteMonthly, relativeMonthly, absoluteYearly, relativeYearly. Required. For more information, see values of type property.
     * @returns a recurrencePatternType
     */
    get type() {
        return this._type;
    }
    ;
    /**
     * Sets the type property value. The recurrence pattern type: daily, weekly, absoluteMonthly, relativeMonthly, absoluteYearly, relativeYearly. Required. For more information, see values of type property.
     * @param value Value to set for the type property.
     */
    set type(value) {
        this._type = value;
    }
    ;
}
exports.RecurrencePattern = RecurrencePattern;
