"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegistryKeyState = void 0;
const registryHive_1 = require("./registryHive");
const registryOperation_1 = require("./registryOperation");
const registryValueType_1 = require("./registryValueType");
class RegistryKeyState {
    /**
     * Instantiates a new registryKeyState and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "hive": n => { this.hive = n.getEnumValue(registryHive_1.RegistryHive); },
            "key": n => { this.key = n.getStringValue(); },
            "oldKey": n => { this.oldKey = n.getStringValue(); },
            "oldValueData": n => { this.oldValueData = n.getStringValue(); },
            "oldValueName": n => { this.oldValueName = n.getStringValue(); },
            "operation": n => { this.operation = n.getEnumValue(registryOperation_1.RegistryOperation); },
            "processId": n => { this.processId = n.getNumberValue(); },
            "valueData": n => { this.valueData = n.getStringValue(); },
            "valueName": n => { this.valueName = n.getStringValue(); },
            "valueType": n => { this.valueType = n.getEnumValue(registryValueType_1.RegistryValueType); },
        };
    }
    ;
    /**
     * Gets the hive property value. A Windows registry hive : HKEY_CURRENT_CONFIG HKEY_CURRENT_USER HKEY_LOCAL_MACHINE/SAM HKEY_LOCAL_MACHINE/Security HKEY_LOCAL_MACHINE/Software HKEY_LOCAL_MACHINE/System HKEY_USERS/.Default. Possible values are: unknown, currentConfig, currentUser, localMachineSam, localMachineSecurity, localMachineSoftware, localMachineSystem, usersDefault.
     * @returns a registryHive
     */
    get hive() {
        return this._hive;
    }
    ;
    /**
     * Sets the hive property value. A Windows registry hive : HKEY_CURRENT_CONFIG HKEY_CURRENT_USER HKEY_LOCAL_MACHINE/SAM HKEY_LOCAL_MACHINE/Security HKEY_LOCAL_MACHINE/Software HKEY_LOCAL_MACHINE/System HKEY_USERS/.Default. Possible values are: unknown, currentConfig, currentUser, localMachineSam, localMachineSecurity, localMachineSoftware, localMachineSystem, usersDefault.
     * @param value Value to set for the hive property.
     */
    set hive(value) {
        this._hive = value;
    }
    ;
    /**
     * Gets the key property value. Current (i.e. changed) registry key (excludes HIVE).
     * @returns a string
     */
    get key() {
        return this._key;
    }
    ;
    /**
     * Sets the key property value. Current (i.e. changed) registry key (excludes HIVE).
     * @param value Value to set for the key property.
     */
    set key(value) {
        this._key = value;
    }
    ;
    /**
     * Gets the oldKey property value. Previous (i.e. before changed) registry key (excludes HIVE).
     * @returns a string
     */
    get oldKey() {
        return this._oldKey;
    }
    ;
    /**
     * Sets the oldKey property value. Previous (i.e. before changed) registry key (excludes HIVE).
     * @param value Value to set for the oldKey property.
     */
    set oldKey(value) {
        this._oldKey = value;
    }
    ;
    /**
     * Gets the oldValueData property value. Previous (i.e. before changed) registry key value data (contents).
     * @returns a string
     */
    get oldValueData() {
        return this._oldValueData;
    }
    ;
    /**
     * Sets the oldValueData property value. Previous (i.e. before changed) registry key value data (contents).
     * @param value Value to set for the oldValueData property.
     */
    set oldValueData(value) {
        this._oldValueData = value;
    }
    ;
    /**
     * Gets the oldValueName property value. Previous (i.e. before changed) registry key value name.
     * @returns a string
     */
    get oldValueName() {
        return this._oldValueName;
    }
    ;
    /**
     * Sets the oldValueName property value. Previous (i.e. before changed) registry key value name.
     * @param value Value to set for the oldValueName property.
     */
    set oldValueName(value) {
        this._oldValueName = value;
    }
    ;
    /**
     * Gets the operation property value. Operation that changed the registry key name and/or value. Possible values are: unknown, create, modify, delete.
     * @returns a registryOperation
     */
    get operation() {
        return this._operation;
    }
    ;
    /**
     * Sets the operation property value. Operation that changed the registry key name and/or value. Possible values are: unknown, create, modify, delete.
     * @param value Value to set for the operation property.
     */
    set operation(value) {
        this._operation = value;
    }
    ;
    /**
     * Gets the processId property value. Process ID (PID) of the process that modified the registry key (process details will appear in the alert 'processes' collection).
     * @returns a integer
     */
    get processId() {
        return this._processId;
    }
    ;
    /**
     * Sets the processId property value. Process ID (PID) of the process that modified the registry key (process details will appear in the alert 'processes' collection).
     * @param value Value to set for the processId property.
     */
    set processId(value) {
        this._processId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeEnumValue("hive", this.hive);
        writer.writeStringValue("key", this.key);
        writer.writeStringValue("oldKey", this.oldKey);
        writer.writeStringValue("oldValueData", this.oldValueData);
        writer.writeStringValue("oldValueName", this.oldValueName);
        writer.writeEnumValue("operation", this.operation);
        writer.writeNumberValue("processId", this.processId);
        writer.writeStringValue("valueData", this.valueData);
        writer.writeStringValue("valueName", this.valueName);
        writer.writeEnumValue("valueType", this.valueType);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the valueData property value. Current (i.e. changed) registry key value data (contents).
     * @returns a string
     */
    get valueData() {
        return this._valueData;
    }
    ;
    /**
     * Sets the valueData property value. Current (i.e. changed) registry key value data (contents).
     * @param value Value to set for the valueData property.
     */
    set valueData(value) {
        this._valueData = value;
    }
    ;
    /**
     * Gets the valueName property value. Current (i.e. changed) registry key value name
     * @returns a string
     */
    get valueName() {
        return this._valueName;
    }
    ;
    /**
     * Sets the valueName property value. Current (i.e. changed) registry key value name
     * @param value Value to set for the valueName property.
     */
    set valueName(value) {
        this._valueName = value;
    }
    ;
    /**
     * Gets the valueType property value. Registry key value type REG_BINARY REG_DWORD REG_DWORD_LITTLE_ENDIAN REG_DWORD_BIG_ENDIANREG_EXPAND_SZ REG_LINK REG_MULTI_SZ REG_NONE REG_QWORD REG_QWORD_LITTLE_ENDIAN REG_SZ Possible values are: unknown, binary, dword, dwordLittleEndian, dwordBigEndian, expandSz, link, multiSz, none, qword, qwordlittleEndian, sz.
     * @returns a registryValueType
     */
    get valueType() {
        return this._valueType;
    }
    ;
    /**
     * Sets the valueType property value. Registry key value type REG_BINARY REG_DWORD REG_DWORD_LITTLE_ENDIAN REG_DWORD_BIG_ENDIANREG_EXPAND_SZ REG_LINK REG_MULTI_SZ REG_NONE REG_QWORD REG_QWORD_LITTLE_ENDIAN REG_SZ Possible values are: unknown, binary, dword, dwordLittleEndian, dwordBigEndian, expandSz, link, multiSz, none, qword, qwordlittleEndian, sz.
     * @param value Value to set for the valueType property.
     */
    set valueType(value) {
        this._valueType = value;
    }
    ;
}
exports.RegistryKeyState = RegistryKeyState;
