import { File, FileSystemInfo, Folder, IdentitySet, Image, ItemReference, Package, Shared, SharepointIds, SpecialFolder, Video } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class RemoteItem implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** Identity of the user, device, and application which created the item. Read-only. */
    private _createdBy?;
    /** Date and time of item creation. Read-only. */
    private _createdDateTime?;
    /** Indicates that the remote item is a file. Read-only. */
    private _file?;
    /** Information about the remote item from the local file system. Read-only. */
    private _fileSystemInfo?;
    /** Indicates that the remote item is a folder. Read-only. */
    private _folder?;
    /** Unique identifier for the remote item in its drive. Read-only. */
    private _id?;
    /** Image metadata, if the item is an image. Read-only. */
    private _image?;
    /** Identity of the user, device, and application which last modified the item. Read-only. */
    private _lastModifiedBy?;
    /** Date and time the item was last modified. Read-only. */
    private _lastModifiedDateTime?;
    /** Optional. Filename of the remote item. Read-only. */
    private _name?;
    /** If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only. */
    private _package?;
    /** Properties of the parent of the remote item. Read-only. */
    private _parentReference?;
    /** Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only. */
    private _shared?;
    /** Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only. */
    private _sharepointIds?;
    /** Size of the remote item. Read-only. */
    private _size?;
    /** If the current item is also available as a special folder, this facet is returned. Read-only. */
    private _specialFolder?;
    /** Video metadata, if the item is a video. Read-only. */
    private _video?;
    /** DAV compatible URL for the item. */
    private _webDavUrl?;
    /** URL that displays the resource in the browser. Read-only. */
    private _webUrl?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new remoteItem and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Identity of the user, device, and application which created the item. Read-only.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Identity of the user, device, and application which created the item. Read-only.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the createdDateTime property value. Date and time of item creation. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Date and time of item creation. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the file property value. Indicates that the remote item is a file. Read-only.
     * @returns a file
     */
    get file(): File | undefined;
    /**
     * Sets the file property value. Indicates that the remote item is a file. Read-only.
     * @param value Value to set for the file property.
     */
    set file(value: File | undefined);
    /**
     * Gets the fileSystemInfo property value. Information about the remote item from the local file system. Read-only.
     * @returns a fileSystemInfo
     */
    get fileSystemInfo(): FileSystemInfo | undefined;
    /**
     * Sets the fileSystemInfo property value. Information about the remote item from the local file system. Read-only.
     * @param value Value to set for the fileSystemInfo property.
     */
    set fileSystemInfo(value: FileSystemInfo | undefined);
    /**
     * Gets the folder property value. Indicates that the remote item is a folder. Read-only.
     * @returns a folder
     */
    get folder(): Folder | undefined;
    /**
     * Sets the folder property value. Indicates that the remote item is a folder. Read-only.
     * @param value Value to set for the folder property.
     */
    set folder(value: Folder | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the id property value. Unique identifier for the remote item in its drive. Read-only.
     * @returns a string
     */
    get id(): string | undefined;
    /**
     * Sets the id property value. Unique identifier for the remote item in its drive. Read-only.
     * @param value Value to set for the id property.
     */
    set id(value: string | undefined);
    /**
     * Gets the image property value. Image metadata, if the item is an image. Read-only.
     * @returns a image
     */
    get image(): Image | undefined;
    /**
     * Sets the image property value. Image metadata, if the item is an image. Read-only.
     * @param value Value to set for the image property.
     */
    set image(value: Image | undefined);
    /**
     * Gets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @returns a identitySet
     */
    get lastModifiedBy(): IdentitySet | undefined;
    /**
     * Sets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @param value Value to set for the lastModifiedBy property.
     */
    set lastModifiedBy(value: IdentitySet | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the name property value. Optional. Filename of the remote item. Read-only.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. Optional. Filename of the remote item. Read-only.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
     * @returns a package
     */
    get package(): Package | undefined;
    /**
     * Sets the package property value. If present, indicates that this item is a package instead of a folder or file. Packages are treated like files in some contexts and folders in others. Read-only.
     * @param value Value to set for the package property.
     */
    set package(value: Package | undefined);
    /**
     * Gets the parentReference property value. Properties of the parent of the remote item. Read-only.
     * @returns a itemReference
     */
    get parentReference(): ItemReference | undefined;
    /**
     * Sets the parentReference property value. Properties of the parent of the remote item. Read-only.
     * @param value Value to set for the parentReference property.
     */
    set parentReference(value: ItemReference | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
     * @returns a shared
     */
    get shared(): Shared | undefined;
    /**
     * Sets the shared property value. Indicates that the item has been shared with others and provides information about the shared state of the item. Read-only.
     * @param value Value to set for the shared property.
     */
    set shared(value: Shared | undefined);
    /**
     * Gets the sharepointIds property value. Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Provides interop between items in OneDrive for Business and SharePoint with the full set of item identifiers. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the size property value. Size of the remote item. Read-only.
     * @returns a int64
     */
    get size(): number | undefined;
    /**
     * Sets the size property value. Size of the remote item. Read-only.
     * @param value Value to set for the size property.
     */
    set size(value: number | undefined);
    /**
     * Gets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
     * @returns a specialFolder
     */
    get specialFolder(): SpecialFolder | undefined;
    /**
     * Sets the specialFolder property value. If the current item is also available as a special folder, this facet is returned. Read-only.
     * @param value Value to set for the specialFolder property.
     */
    set specialFolder(value: SpecialFolder | undefined);
    /**
     * Gets the video property value. Video metadata, if the item is a video. Read-only.
     * @returns a video
     */
    get video(): Video | undefined;
    /**
     * Sets the video property value. Video metadata, if the item is a video. Read-only.
     * @param value Value to set for the video property.
     */
    set video(value: Video | undefined);
    /**
     * Gets the webDavUrl property value. DAV compatible URL for the item.
     * @returns a string
     */
    get webDavUrl(): string | undefined;
    /**
     * Sets the webDavUrl property value. DAV compatible URL for the item.
     * @param value Value to set for the webDavUrl property.
     */
    set webDavUrl(value: string | undefined);
    /**
     * Gets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
