"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RiskDetection = void 0;
const activityType_1 = require("./activityType");
const createSignInLocationFromDiscriminatorValue_1 = require("./createSignInLocationFromDiscriminatorValue");
const index_1 = require("./index");
const riskDetail_1 = require("./riskDetail");
const riskDetectionTimingType_1 = require("./riskDetectionTimingType");
const riskLevel_1 = require("./riskLevel");
const riskState_1 = require("./riskState");
const tokenIssuerType_1 = require("./tokenIssuerType");
/** Provides operations to manage the identityProtectionRoot singleton. */
class RiskDetection extends index_1.Entity {
    /**
     * Instantiates a new riskDetection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the activity property value. Indicates the activity type the detected risk is linked to. The possible values are signin, user, unknownFutureValue.
     * @returns a activityType
     */
    get activity() {
        return this._activity;
    }
    ;
    /**
     * Sets the activity property value. Indicates the activity type the detected risk is linked to. The possible values are signin, user, unknownFutureValue.
     * @param value Value to set for the activity property.
     */
    set activity(value) {
        this._activity = value;
    }
    ;
    /**
     * Gets the activityDateTime property value. Date and time that the risky activity occurred. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get activityDateTime() {
        return this._activityDateTime;
    }
    ;
    /**
     * Sets the activityDateTime property value. Date and time that the risky activity occurred. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the activityDateTime property.
     */
    set activityDateTime(value) {
        this._activityDateTime = value;
    }
    ;
    /**
     * Gets the additionalInfo property value. Additional information associated with the risk detection in JSON format.
     * @returns a string
     */
    get additionalInfo() {
        return this._additionalInfo;
    }
    ;
    /**
     * Sets the additionalInfo property value. Additional information associated with the risk detection in JSON format.
     * @param value Value to set for the additionalInfo property.
     */
    set additionalInfo(value) {
        this._additionalInfo = value;
    }
    ;
    ;
    /**
     * Gets the correlationId property value. Correlation ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @returns a string
     */
    get correlationId() {
        return this._correlationId;
    }
    ;
    /**
     * Sets the correlationId property value. Correlation ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value) {
        this._correlationId = value;
    }
    ;
    /**
     * Gets the detectedDateTime property value. Date and time that the risk was detected. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get detectedDateTime() {
        return this._detectedDateTime;
    }
    ;
    /**
     * Sets the detectedDateTime property value. Date and time that the risk was detected. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the detectedDateTime property.
     */
    set detectedDateTime(value) {
        this._detectedDateTime = value;
    }
    ;
    /**
     * Gets the detectionTimingType property value. Timing of the detected risk (real-time/offline). The possible values are notDefined, realtime, nearRealtime, offline, unknownFutureValue.
     * @returns a riskDetectionTimingType
     */
    get detectionTimingType() {
        return this._detectionTimingType;
    }
    ;
    /**
     * Sets the detectionTimingType property value. Timing of the detected risk (real-time/offline). The possible values are notDefined, realtime, nearRealtime, offline, unknownFutureValue.
     * @param value Value to set for the detectionTimingType property.
     */
    set detectionTimingType(value) {
        this._detectionTimingType = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "activity": n => { this.activity = n.getEnumValue(activityType_1.ActivityType); }, "activityDateTime": n => { this.activityDateTime = n.getDateValue(); }, "additionalInfo": n => { this.additionalInfo = n.getStringValue(); }, "correlationId": n => { this.correlationId = n.getStringValue(); }, "detectedDateTime": n => { this.detectedDateTime = n.getDateValue(); }, "detectionTimingType": n => { this.detectionTimingType = n.getEnumValue(riskDetectionTimingType_1.RiskDetectionTimingType); }, "ipAddress": n => { this.ipAddress = n.getStringValue(); }, "lastUpdatedDateTime": n => { this.lastUpdatedDateTime = n.getDateValue(); }, "location": n => { this.location = n.getObjectValue(createSignInLocationFromDiscriminatorValue_1.createSignInLocationFromDiscriminatorValue); }, "requestId": n => { this.requestId = n.getStringValue(); }, "riskDetail": n => { this.riskDetail = n.getEnumValue(riskDetail_1.RiskDetail); }, "riskEventType": n => { this.riskEventType = n.getStringValue(); }, "riskLevel": n => { this.riskLevel = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskState": n => { this.riskState = n.getEnumValue(riskState_1.RiskState); }, "source": n => { this.source = n.getStringValue(); }, "tokenIssuerType": n => { this.tokenIssuerType = n.getEnumValue(tokenIssuerType_1.TokenIssuerType); }, "userDisplayName": n => { this.userDisplayName = n.getStringValue(); }, "userId": n => { this.userId = n.getStringValue(); }, "userPrincipalName": n => { this.userPrincipalName = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the ipAddress property value. Provides the IP address of the client from where the risk occurred.
     * @returns a string
     */
    get ipAddress() {
        return this._ipAddress;
    }
    ;
    /**
     * Sets the ipAddress property value. Provides the IP address of the client from where the risk occurred.
     * @param value Value to set for the ipAddress property.
     */
    set ipAddress(value) {
        this._ipAddress = value;
    }
    ;
    /**
     * Gets the lastUpdatedDateTime property value. Date and time that the risk detection was last updated.
     * @returns a Date
     */
    get lastUpdatedDateTime() {
        return this._lastUpdatedDateTime;
    }
    ;
    /**
     * Sets the lastUpdatedDateTime property value. Date and time that the risk detection was last updated.
     * @param value Value to set for the lastUpdatedDateTime property.
     */
    set lastUpdatedDateTime(value) {
        this._lastUpdatedDateTime = value;
    }
    ;
    /**
     * Gets the location property value. Location of the sign-in.
     * @returns a signInLocation
     */
    get location() {
        return this._location;
    }
    ;
    /**
     * Sets the location property value. Location of the sign-in.
     * @param value Value to set for the location property.
     */
    set location(value) {
        this._location = value;
    }
    ;
    /**
     * Gets the requestId property value. Request ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @returns a string
     */
    get requestId() {
        return this._requestId;
    }
    ;
    /**
     * Sets the requestId property value. Request ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @param value Value to set for the requestId property.
     */
    set requestId(value) {
        this._requestId = value;
    }
    ;
    /**
     * Gets the riskDetail property value. Details of the detected risk. The possible values are none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, hidden, adminConfirmedUserCompromised, unknownFutureValue. Note: Details for this property are only available for Azure AD Premium P2 customers. P1 customers will be returned hidden.
     * @returns a riskDetail
     */
    get riskDetail() {
        return this._riskDetail;
    }
    ;
    /**
     * Sets the riskDetail property value. Details of the detected risk. The possible values are none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, hidden, adminConfirmedUserCompromised, unknownFutureValue. Note: Details for this property are only available for Azure AD Premium P2 customers. P1 customers will be returned hidden.
     * @param value Value to set for the riskDetail property.
     */
    set riskDetail(value) {
        this._riskDetail = value;
    }
    ;
    /**
     * Gets the riskEventType property value. The type of risk event detected. The possible values are unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic,adminConfirmedUserCompromised, mcasImpossibleTravel, mcasSuspiciousInboxManipulationRules, investigationsThreatIntelligenceSigninLinked, maliciousIPAddressValidCredentialsBlockedIP, and unknownFutureValue.  For more information about each value, see riskEventType values.
     * @returns a string
     */
    get riskEventType() {
        return this._riskEventType;
    }
    ;
    /**
     * Sets the riskEventType property value. The type of risk event detected. The possible values are unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic,adminConfirmedUserCompromised, mcasImpossibleTravel, mcasSuspiciousInboxManipulationRules, investigationsThreatIntelligenceSigninLinked, maliciousIPAddressValidCredentialsBlockedIP, and unknownFutureValue.  For more information about each value, see riskEventType values.
     * @param value Value to set for the riskEventType property.
     */
    set riskEventType(value) {
        this._riskEventType = value;
    }
    ;
    /**
     * Gets the riskLevel property value. Level of the detected risk. The possible values are low, medium, high, hidden, none, unknownFutureValue. Note: Details for this property are only available for Azure AD Premium P2 customers. P1 customers will be returned hidden.
     * @returns a riskLevel
     */
    get riskLevel() {
        return this._riskLevel;
    }
    ;
    /**
     * Sets the riskLevel property value. Level of the detected risk. The possible values are low, medium, high, hidden, none, unknownFutureValue. Note: Details for this property are only available for Azure AD Premium P2 customers. P1 customers will be returned hidden.
     * @param value Value to set for the riskLevel property.
     */
    set riskLevel(value) {
        this._riskLevel = value;
    }
    ;
    /**
     * Gets the riskState property value. The state of a detected risky user or sign-in. The possible values are none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, and unknownFutureValue.
     * @returns a riskState
     */
    get riskState() {
        return this._riskState;
    }
    ;
    /**
     * Sets the riskState property value. The state of a detected risky user or sign-in. The possible values are none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, and unknownFutureValue.
     * @param value Value to set for the riskState property.
     */
    set riskState(value) {
        this._riskState = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("activity", this.activity);
        writer.writeDateValue("activityDateTime", this.activityDateTime);
        writer.writeStringValue("additionalInfo", this.additionalInfo);
        writer.writeStringValue("correlationId", this.correlationId);
        writer.writeDateValue("detectedDateTime", this.detectedDateTime);
        writer.writeEnumValue("detectionTimingType", this.detectionTimingType);
        writer.writeStringValue("ipAddress", this.ipAddress);
        writer.writeDateValue("lastUpdatedDateTime", this.lastUpdatedDateTime);
        writer.writeObjectValue("location", this.location);
        writer.writeStringValue("requestId", this.requestId);
        writer.writeEnumValue("riskDetail", this.riskDetail);
        writer.writeStringValue("riskEventType", this.riskEventType);
        writer.writeEnumValue("riskLevel", this.riskLevel);
        writer.writeEnumValue("riskState", this.riskState);
        writer.writeStringValue("source", this.source);
        writer.writeEnumValue("tokenIssuerType", this.tokenIssuerType);
        writer.writeStringValue("userDisplayName", this.userDisplayName);
        writer.writeStringValue("userId", this.userId);
        writer.writeStringValue("userPrincipalName", this.userPrincipalName);
    }
    ;
    /**
     * Gets the source property value. Source of the risk detection. For example, activeDirectory.
     * @returns a string
     */
    get source() {
        return this._source;
    }
    ;
    /**
     * Sets the source property value. Source of the risk detection. For example, activeDirectory.
     * @param value Value to set for the source property.
     */
    set source(value) {
        this._source = value;
    }
    ;
    /**
     * Gets the tokenIssuerType property value. Indicates the type of token issuer for the detected sign-in risk. The possible values are AzureAD, ADFederationServices, and unknownFutureValue.
     * @returns a tokenIssuerType
     */
    get tokenIssuerType() {
        return this._tokenIssuerType;
    }
    ;
    /**
     * Sets the tokenIssuerType property value. Indicates the type of token issuer for the detected sign-in risk. The possible values are AzureAD, ADFederationServices, and unknownFutureValue.
     * @param value Value to set for the tokenIssuerType property.
     */
    set tokenIssuerType(value) {
        this._tokenIssuerType = value;
    }
    ;
    /**
     * Gets the userDisplayName property value. Name of the user.
     * @returns a string
     */
    get userDisplayName() {
        return this._userDisplayName;
    }
    ;
    /**
     * Sets the userDisplayName property value. Name of the user.
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value) {
        this._userDisplayName = value;
    }
    ;
    /**
     * Gets the userId property value. Unique ID of the user.  The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a string
     */
    get userId() {
        return this._userId;
    }
    ;
    /**
     * Sets the userId property value. Unique ID of the user.  The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the userId property.
     */
    set userId(value) {
        this._userId = value;
    }
    ;
    /**
     * Gets the userPrincipalName property value. The user principal name (UPN) of the user.
     * @returns a string
     */
    get userPrincipalName() {
        return this._userPrincipalName;
    }
    ;
    /**
     * Sets the userPrincipalName property value. The user principal name (UPN) of the user.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value) {
        this._userPrincipalName = value;
    }
    ;
}
exports.RiskDetection = RiskDetection;
