import { Entity, RoleAssignment, RolePermission } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** The Role Definition resource. The role definition is the foundation of role based access in Intune. The role combines an Intune resource such as a Mobile App and associated role permissions such as Create or Read for the resource. There are two types of roles, built-in and custom. Built-in roles cannot be modified. Both built-in roles and custom roles must have assignments to be enforced. Create custom roles if you want to define a role that allows any of the available resources and role permissions to be combined into a single role. */
export declare class RoleDefinition extends Entity implements Parsable {
    /** Description of the Role definition. */
    private _description?;
    /** Display Name of the Role definition. */
    private _displayName?;
    /** Type of Role. Set to True if it is built-in, or set to False if it is a custom role definition. */
    private _isBuiltIn?;
    /** List of Role assignments for this role definition. */
    private _roleAssignments?;
    /** List of Role Permissions this role is allowed to perform. These must match the actionName that is defined as part of the rolePermission. */
    private _rolePermissions?;
    /**
     * Instantiates a new roleDefinition and sets the default values.
     */
    constructor();
    /**
     * Gets the description property value. Description of the Role definition.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Description of the Role definition.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. Display Name of the Role definition.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Display Name of the Role definition.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isBuiltIn property value. Type of Role. Set to True if it is built-in, or set to False if it is a custom role definition.
     * @returns a boolean
     */
    get isBuiltIn(): boolean | undefined;
    /**
     * Sets the isBuiltIn property value. Type of Role. Set to True if it is built-in, or set to False if it is a custom role definition.
     * @param value Value to set for the isBuiltIn property.
     */
    set isBuiltIn(value: boolean | undefined);
    /**
     * Gets the roleAssignments property value. List of Role assignments for this role definition.
     * @returns a roleAssignment
     */
    get roleAssignments(): RoleAssignment[] | undefined;
    /**
     * Sets the roleAssignments property value. List of Role assignments for this role definition.
     * @param value Value to set for the roleAssignments property.
     */
    set roleAssignments(value: RoleAssignment[] | undefined);
    /**
     * Gets the rolePermissions property value. List of Role Permissions this role is allowed to perform. These must match the actionName that is defined as part of the rolePermission.
     * @returns a rolePermission
     */
    get rolePermissions(): RolePermission[] | undefined;
    /**
     * Sets the rolePermissions property value. List of Role Permissions this role is allowed to perform. These must match the actionName that is defined as part of the rolePermission.
     * @param value Value to set for the rolePermissions property.
     */
    set rolePermissions(value: RolePermission[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
