"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RoleDefinition = void 0;
const createRoleAssignmentFromDiscriminatorValue_1 = require("./createRoleAssignmentFromDiscriminatorValue");
const createRolePermissionFromDiscriminatorValue_1 = require("./createRolePermissionFromDiscriminatorValue");
const index_1 = require("./index");
/** The Role Definition resource. The role definition is the foundation of role based access in Intune. The role combines an Intune resource such as a Mobile App and associated role permissions such as Create or Read for the resource. There are two types of roles, built-in and custom. Built-in roles cannot be modified. Both built-in roles and custom roles must have assignments to be enforced. Create custom roles if you want to define a role that allows any of the available resources and role permissions to be combined into a single role. */
class RoleDefinition extends index_1.Entity {
    /**
     * Instantiates a new roleDefinition and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the description property value. Description of the Role definition.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Description of the Role definition.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * Gets the displayName property value. Display Name of the Role definition.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. Display Name of the Role definition.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "description": n => { this.description = n.getStringValue(); }, "displayName": n => { this.displayName = n.getStringValue(); }, "isBuiltIn": n => { this.isBuiltIn = n.getBooleanValue(); }, "roleAssignments": n => { this.roleAssignments = n.getCollectionOfObjectValues(createRoleAssignmentFromDiscriminatorValue_1.createRoleAssignmentFromDiscriminatorValue); }, "rolePermissions": n => { this.rolePermissions = n.getCollectionOfObjectValues(createRolePermissionFromDiscriminatorValue_1.createRolePermissionFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the isBuiltIn property value. Type of Role. Set to True if it is built-in, or set to False if it is a custom role definition.
     * @returns a boolean
     */
    get isBuiltIn() {
        return this._isBuiltIn;
    }
    ;
    /**
     * Sets the isBuiltIn property value. Type of Role. Set to True if it is built-in, or set to False if it is a custom role definition.
     * @param value Value to set for the isBuiltIn property.
     */
    set isBuiltIn(value) {
        this._isBuiltIn = value;
    }
    ;
    /**
     * Gets the roleAssignments property value. List of Role assignments for this role definition.
     * @returns a roleAssignment
     */
    get roleAssignments() {
        return this._roleAssignments;
    }
    ;
    /**
     * Sets the roleAssignments property value. List of Role assignments for this role definition.
     * @param value Value to set for the roleAssignments property.
     */
    set roleAssignments(value) {
        this._roleAssignments = value;
    }
    ;
    /**
     * Gets the rolePermissions property value. List of Role Permissions this role is allowed to perform. These must match the actionName that is defined as part of the rolePermission.
     * @returns a rolePermission
     */
    get rolePermissions() {
        return this._rolePermissions;
    }
    ;
    /**
     * Sets the rolePermissions property value. List of Role Permissions this role is allowed to perform. These must match the actionName that is defined as part of the rolePermission.
     * @param value Value to set for the rolePermissions property.
     */
    set rolePermissions(value) {
        this._rolePermissions = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeBooleanValue("isBuiltIn", this.isBuiltIn);
        writer.writeCollectionOfObjectValues("roleAssignments", this.roleAssignments);
        writer.writeCollectionOfObjectValues("rolePermissions", this.rolePermissions);
    }
    ;
}
exports.RoleDefinition = RoleDefinition;
