import { AuthenticationProtocol } from './authenticationProtocol';
import { IdentityProviderBase } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of domain entities. */
export declare class SamlOrWsFedProvider extends IdentityProviderBase implements Parsable {
    /** Issuer URI of the federation server. */
    private _issuerUri?;
    /** URI of the metadata exchange endpoint used for authentication from rich client applications. */
    private _metadataExchangeUri?;
    /** URI that web-based clients are directed to when signing in to Azure Active Directory (Azure AD) services. */
    private _passiveSignInUri?;
    /** Preferred authentication protocol. Supported values include saml or wsfed. */
    private _preferredAuthenticationProtocol?;
    /** Current certificate used to sign tokens passed to the Microsoft identity platform. The certificate is formatted as a Base64 encoded string of the public portion of the federated IdP's token signing certificate and must be compatible with the X509Certificate2 class.   This property is used in the following scenarios:  if a rollover is required outside of the autorollover update a new federation service is being set up  if the new token signing certificate isn't present in the federation properties after the federation service certificate has been updated.   Azure AD updates certificates via an autorollover process in which it attempts to retrieve a new certificate from the federation service metadata, 30 days before expiry of the current certificate. If a new certificate isn't available, Azure AD monitors the metadata daily and will update the federation settings for the domain when a new certificate is available. */
    private _signingCertificate?;
    /**
     * Instantiates a new samlOrWsFedProvider and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the issuerUri property value. Issuer URI of the federation server.
     * @returns a string
     */
    get issuerUri(): string | undefined;
    /**
     * Sets the issuerUri property value. Issuer URI of the federation server.
     * @param value Value to set for the issuerUri property.
     */
    set issuerUri(value: string | undefined);
    /**
     * Gets the metadataExchangeUri property value. URI of the metadata exchange endpoint used for authentication from rich client applications.
     * @returns a string
     */
    get metadataExchangeUri(): string | undefined;
    /**
     * Sets the metadataExchangeUri property value. URI of the metadata exchange endpoint used for authentication from rich client applications.
     * @param value Value to set for the metadataExchangeUri property.
     */
    set metadataExchangeUri(value: string | undefined);
    /**
     * Gets the passiveSignInUri property value. URI that web-based clients are directed to when signing in to Azure Active Directory (Azure AD) services.
     * @returns a string
     */
    get passiveSignInUri(): string | undefined;
    /**
     * Sets the passiveSignInUri property value. URI that web-based clients are directed to when signing in to Azure Active Directory (Azure AD) services.
     * @param value Value to set for the passiveSignInUri property.
     */
    set passiveSignInUri(value: string | undefined);
    /**
     * Gets the preferredAuthenticationProtocol property value. Preferred authentication protocol. Supported values include saml or wsfed.
     * @returns a authenticationProtocol
     */
    get preferredAuthenticationProtocol(): AuthenticationProtocol | undefined;
    /**
     * Sets the preferredAuthenticationProtocol property value. Preferred authentication protocol. Supported values include saml or wsfed.
     * @param value Value to set for the preferredAuthenticationProtocol property.
     */
    set preferredAuthenticationProtocol(value: AuthenticationProtocol | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the signingCertificate property value. Current certificate used to sign tokens passed to the Microsoft identity platform. The certificate is formatted as a Base64 encoded string of the public portion of the federated IdP's token signing certificate and must be compatible with the X509Certificate2 class.   This property is used in the following scenarios:  if a rollover is required outside of the autorollover update a new federation service is being set up  if the new token signing certificate isn't present in the federation properties after the federation service certificate has been updated.   Azure AD updates certificates via an autorollover process in which it attempts to retrieve a new certificate from the federation service metadata, 30 days before expiry of the current certificate. If a new certificate isn't available, Azure AD monitors the metadata daily and will update the federation settings for the domain when a new certificate is available.
     * @returns a string
     */
    get signingCertificate(): string | undefined;
    /**
     * Sets the signingCertificate property value. Current certificate used to sign tokens passed to the Microsoft identity platform. The certificate is formatted as a Base64 encoded string of the public portion of the federated IdP's token signing certificate and must be compatible with the X509Certificate2 class.   This property is used in the following scenarios:  if a rollover is required outside of the autorollover update a new federation service is being set up  if the new token signing certificate isn't present in the federation properties after the federation service certificate has been updated.   Azure AD updates certificates via an autorollover process in which it attempts to retrieve a new certificate from the federation service metadata, 30 days before expiry of the current certificate. If a new certificate isn't available, Azure AD monitors the metadata daily and will update the federation settings for the domain when a new certificate is available.
     * @param value Value to set for the signingCertificate property.
     */
    set signingCertificate(value: string | undefined);
}
