import { Entity, OfferShiftRequest, OpenShift, OpenShiftChangeRequest, SchedulingGroup, Shift, SwapShiftsChangeRequest, TimeOff, TimeOffReason, TimeOffRequest } from './index';
import { OperationStatus } from './operationStatus';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Schedule extends Entity implements Parsable {
    /** Indicates whether the schedule is enabled for the team. Required. */
    private _enabled?;
    /** The offerShiftRequests property */
    private _offerShiftRequests?;
    /** Indicates whether offer shift requests are enabled for the schedule. */
    private _offerShiftRequestsEnabled?;
    /** The openShiftChangeRequests property */
    private _openShiftChangeRequests?;
    /** The openShifts property */
    private _openShifts?;
    /** Indicates whether open shifts are enabled for the schedule. */
    private _openShiftsEnabled?;
    /** The status of the schedule provisioning. The possible values are notStarted, running, completed, failed. */
    private _provisionStatus?;
    /** Additional information about why schedule provisioning failed. */
    private _provisionStatusCode?;
    /** The logical grouping of users in the schedule (usually by role). */
    private _schedulingGroups?;
    /** The shifts in the schedule. */
    private _shifts?;
    /** The swapShiftsChangeRequests property */
    private _swapShiftsChangeRequests?;
    /** Indicates whether swap shifts requests are enabled for the schedule. */
    private _swapShiftsRequestsEnabled?;
    /** Indicates whether time clock is enabled for the schedule. */
    private _timeClockEnabled?;
    /** The set of reasons for a time off in the schedule. */
    private _timeOffReasons?;
    /** The timeOffRequests property */
    private _timeOffRequests?;
    /** Indicates whether time off requests are enabled for the schedule. */
    private _timeOffRequestsEnabled?;
    /** The instances of times off in the schedule. */
    private _timesOff?;
    /** Indicates the time zone of the schedule team using tz database format. Required. */
    private _timeZone?;
    /** The workforceIntegrationIds property */
    private _workforceIntegrationIds?;
    /**
     * Instantiates a new schedule and sets the default values.
     */
    constructor();
    /**
     * Gets the enabled property value. Indicates whether the schedule is enabled for the team. Required.
     * @returns a boolean
     */
    get enabled(): boolean | undefined;
    /**
     * Sets the enabled property value. Indicates whether the schedule is enabled for the team. Required.
     * @param value Value to set for the enabled property.
     */
    set enabled(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the offerShiftRequests property value. The offerShiftRequests property
     * @returns a offerShiftRequest
     */
    get offerShiftRequests(): OfferShiftRequest[] | undefined;
    /**
     * Sets the offerShiftRequests property value. The offerShiftRequests property
     * @param value Value to set for the offerShiftRequests property.
     */
    set offerShiftRequests(value: OfferShiftRequest[] | undefined);
    /**
     * Gets the offerShiftRequestsEnabled property value. Indicates whether offer shift requests are enabled for the schedule.
     * @returns a boolean
     */
    get offerShiftRequestsEnabled(): boolean | undefined;
    /**
     * Sets the offerShiftRequestsEnabled property value. Indicates whether offer shift requests are enabled for the schedule.
     * @param value Value to set for the offerShiftRequestsEnabled property.
     */
    set offerShiftRequestsEnabled(value: boolean | undefined);
    /**
     * Gets the openShiftChangeRequests property value. The openShiftChangeRequests property
     * @returns a openShiftChangeRequest
     */
    get openShiftChangeRequests(): OpenShiftChangeRequest[] | undefined;
    /**
     * Sets the openShiftChangeRequests property value. The openShiftChangeRequests property
     * @param value Value to set for the openShiftChangeRequests property.
     */
    set openShiftChangeRequests(value: OpenShiftChangeRequest[] | undefined);
    /**
     * Gets the openShifts property value. The openShifts property
     * @returns a openShift
     */
    get openShifts(): OpenShift[] | undefined;
    /**
     * Sets the openShifts property value. The openShifts property
     * @param value Value to set for the openShifts property.
     */
    set openShifts(value: OpenShift[] | undefined);
    /**
     * Gets the openShiftsEnabled property value. Indicates whether open shifts are enabled for the schedule.
     * @returns a boolean
     */
    get openShiftsEnabled(): boolean | undefined;
    /**
     * Sets the openShiftsEnabled property value. Indicates whether open shifts are enabled for the schedule.
     * @param value Value to set for the openShiftsEnabled property.
     */
    set openShiftsEnabled(value: boolean | undefined);
    /**
     * Gets the provisionStatus property value. The status of the schedule provisioning. The possible values are notStarted, running, completed, failed.
     * @returns a operationStatus
     */
    get provisionStatus(): OperationStatus | undefined;
    /**
     * Sets the provisionStatus property value. The status of the schedule provisioning. The possible values are notStarted, running, completed, failed.
     * @param value Value to set for the provisionStatus property.
     */
    set provisionStatus(value: OperationStatus | undefined);
    /**
     * Gets the provisionStatusCode property value. Additional information about why schedule provisioning failed.
     * @returns a string
     */
    get provisionStatusCode(): string | undefined;
    /**
     * Sets the provisionStatusCode property value. Additional information about why schedule provisioning failed.
     * @param value Value to set for the provisionStatusCode property.
     */
    set provisionStatusCode(value: string | undefined);
    /**
     * Gets the schedulingGroups property value. The logical grouping of users in the schedule (usually by role).
     * @returns a schedulingGroup
     */
    get schedulingGroups(): SchedulingGroup[] | undefined;
    /**
     * Sets the schedulingGroups property value. The logical grouping of users in the schedule (usually by role).
     * @param value Value to set for the schedulingGroups property.
     */
    set schedulingGroups(value: SchedulingGroup[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shifts property value. The shifts in the schedule.
     * @returns a shift
     */
    get shifts(): Shift[] | undefined;
    /**
     * Sets the shifts property value. The shifts in the schedule.
     * @param value Value to set for the shifts property.
     */
    set shifts(value: Shift[] | undefined);
    /**
     * Gets the swapShiftsChangeRequests property value. The swapShiftsChangeRequests property
     * @returns a swapShiftsChangeRequest
     */
    get swapShiftsChangeRequests(): SwapShiftsChangeRequest[] | undefined;
    /**
     * Sets the swapShiftsChangeRequests property value. The swapShiftsChangeRequests property
     * @param value Value to set for the swapShiftsChangeRequests property.
     */
    set swapShiftsChangeRequests(value: SwapShiftsChangeRequest[] | undefined);
    /**
     * Gets the swapShiftsRequestsEnabled property value. Indicates whether swap shifts requests are enabled for the schedule.
     * @returns a boolean
     */
    get swapShiftsRequestsEnabled(): boolean | undefined;
    /**
     * Sets the swapShiftsRequestsEnabled property value. Indicates whether swap shifts requests are enabled for the schedule.
     * @param value Value to set for the swapShiftsRequestsEnabled property.
     */
    set swapShiftsRequestsEnabled(value: boolean | undefined);
    /**
     * Gets the timeClockEnabled property value. Indicates whether time clock is enabled for the schedule.
     * @returns a boolean
     */
    get timeClockEnabled(): boolean | undefined;
    /**
     * Sets the timeClockEnabled property value. Indicates whether time clock is enabled for the schedule.
     * @param value Value to set for the timeClockEnabled property.
     */
    set timeClockEnabled(value: boolean | undefined);
    /**
     * Gets the timeOffReasons property value. The set of reasons for a time off in the schedule.
     * @returns a timeOffReason
     */
    get timeOffReasons(): TimeOffReason[] | undefined;
    /**
     * Sets the timeOffReasons property value. The set of reasons for a time off in the schedule.
     * @param value Value to set for the timeOffReasons property.
     */
    set timeOffReasons(value: TimeOffReason[] | undefined);
    /**
     * Gets the timeOffRequests property value. The timeOffRequests property
     * @returns a timeOffRequest
     */
    get timeOffRequests(): TimeOffRequest[] | undefined;
    /**
     * Sets the timeOffRequests property value. The timeOffRequests property
     * @param value Value to set for the timeOffRequests property.
     */
    set timeOffRequests(value: TimeOffRequest[] | undefined);
    /**
     * Gets the timeOffRequestsEnabled property value. Indicates whether time off requests are enabled for the schedule.
     * @returns a boolean
     */
    get timeOffRequestsEnabled(): boolean | undefined;
    /**
     * Sets the timeOffRequestsEnabled property value. Indicates whether time off requests are enabled for the schedule.
     * @param value Value to set for the timeOffRequestsEnabled property.
     */
    set timeOffRequestsEnabled(value: boolean | undefined);
    /**
     * Gets the timesOff property value. The instances of times off in the schedule.
     * @returns a timeOff
     */
    get timesOff(): TimeOff[] | undefined;
    /**
     * Sets the timesOff property value. The instances of times off in the schedule.
     * @param value Value to set for the timesOff property.
     */
    set timesOff(value: TimeOff[] | undefined);
    /**
     * Gets the timeZone property value. Indicates the time zone of the schedule team using tz database format. Required.
     * @returns a string
     */
    get timeZone(): string | undefined;
    /**
     * Sets the timeZone property value. Indicates the time zone of the schedule team using tz database format. Required.
     * @param value Value to set for the timeZone property.
     */
    set timeZone(value: string | undefined);
    /**
     * Gets the workforceIntegrationIds property value. The workforceIntegrationIds property
     * @returns a string
     */
    get workforceIntegrationIds(): string[] | undefined;
    /**
     * Sets the workforceIntegrationIds property value. The workforceIntegrationIds property
     * @param value Value to set for the workforceIntegrationIds property.
     */
    set workforceIntegrationIds(value: string[] | undefined);
}
