"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SchemaExtension = void 0;
const createExtensionSchemaPropertyFromDiscriminatorValue_1 = require("./createExtensionSchemaPropertyFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the collection of schemaExtension entities. */
class SchemaExtension extends index_1.Entity {
    /**
     * Instantiates a new schemaExtension and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the description property value. Description for the schema extension. Supports $filter (eq).
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Description for the schema extension. Supports $filter (eq).
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "description": n => { this.description = n.getStringValue(); }, "owner": n => { this.owner = n.getStringValue(); }, "properties": n => { this.properties = n.getCollectionOfObjectValues(createExtensionSchemaPropertyFromDiscriminatorValue_1.createExtensionSchemaPropertyFromDiscriminatorValue); }, "status": n => { this.status = n.getStringValue(); }, "targetTypes": n => { this.targetTypes = n.getCollectionOfPrimitiveValues(); } });
    }
    ;
    /**
     * Gets the owner property value. The appId of the application that is the owner of the schema extension. This property can be supplied on creation, to set the owner.  If not supplied, then the calling application's appId will be set as the owner. In either case, the signed-in user must be the owner of the application. So, for example, if creating a new schema extension definition using Graph Explorer, you must supply the owner property. Once set, this property is read-only and cannot be changed. Supports $filter (eq).
     * @returns a string
     */
    get owner() {
        return this._owner;
    }
    ;
    /**
     * Sets the owner property value. The appId of the application that is the owner of the schema extension. This property can be supplied on creation, to set the owner.  If not supplied, then the calling application's appId will be set as the owner. In either case, the signed-in user must be the owner of the application. So, for example, if creating a new schema extension definition using Graph Explorer, you must supply the owner property. Once set, this property is read-only and cannot be changed. Supports $filter (eq).
     * @param value Value to set for the owner property.
     */
    set owner(value) {
        this._owner = value;
    }
    ;
    /**
     * Gets the properties property value. The collection of property names and types that make up the schema extension definition.
     * @returns a extensionSchemaProperty
     */
    get properties() {
        return this._properties;
    }
    ;
    /**
     * Sets the properties property value. The collection of property names and types that make up the schema extension definition.
     * @param value Value to set for the properties property.
     */
    set properties(value) {
        this._properties = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("owner", this.owner);
        writer.writeCollectionOfObjectValues("properties", this.properties);
        writer.writeStringValue("status", this.status);
        writer.writeCollectionOfPrimitiveValues("targetTypes", this.targetTypes);
    }
    ;
    /**
     * Gets the status property value. The lifecycle state of the schema extension. Possible states are InDevelopment, Available, and Deprecated. Automatically set to InDevelopment on creation. Schema extensions provides more information on the possible state transitions and behaviors. Supports $filter (eq).
     * @returns a string
     */
    get status() {
        return this._status;
    }
    ;
    /**
     * Sets the status property value. The lifecycle state of the schema extension. Possible states are InDevelopment, Available, and Deprecated. Automatically set to InDevelopment on creation. Schema extensions provides more information on the possible state transitions and behaviors. Supports $filter (eq).
     * @param value Value to set for the status property.
     */
    set status(value) {
        this._status = value;
    }
    ;
    /**
     * Gets the targetTypes property value. Set of Microsoft Graph types (that can support extensions) that the schema extension can be applied to. Select from administrativeUnit, contact, device, event, group, message, organization, post, or user.
     * @returns a string
     */
    get targetTypes() {
        return this._targetTypes;
    }
    ;
    /**
     * Sets the targetTypes property value. Set of Microsoft Graph types (that can support extensions) that the schema extension can be applied to. Select from administrativeUnit, contact, device, event, group, message, organization, post, or user.
     * @param value Value to set for the targetTypes property.
     */
    set targetTypes(value) {
        this._targetTypes = value;
    }
    ;
}
exports.SchemaExtension = SchemaExtension;
