import { AverageComparativeScore, ControlScore, Entity, SecurityVendorInformation } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the security singleton. */
export declare class SecureScore extends Entity implements Parsable {
    /** Active user count of the given tenant. */
    private _activeUserCount?;
    /** Average score by different scopes (for example, average by industry, average by seating) and control category (Identity, Data, Device, Apps, Infrastructure) within the scope. */
    private _averageComparativeScores?;
    /** GUID string for tenant ID. */
    private _azureTenantId?;
    /** Contains tenant scores for a set of controls. */
    private _controlScores?;
    /** The date when the entity is created. */
    private _createdDateTime?;
    /** Tenant current attained score on specified date. */
    private _currentScore?;
    /** Microsoft-provided services for the tenant (for example, Exchange online, Skype, Sharepoint). */
    private _enabledServices?;
    /** Licensed user count of the given tenant. */
    private _licensedUserCount?;
    /** Tenant maximum possible score on specified date. */
    private _maxScore?;
    /** Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=SecureScore). Required. */
    private _vendorInformation?;
    /**
     * Gets the activeUserCount property value. Active user count of the given tenant.
     * @returns a integer
     */
    get activeUserCount(): number | undefined;
    /**
     * Sets the activeUserCount property value. Active user count of the given tenant.
     * @param value Value to set for the activeUserCount property.
     */
    set activeUserCount(value: number | undefined);
    /**
     * Gets the averageComparativeScores property value. Average score by different scopes (for example, average by industry, average by seating) and control category (Identity, Data, Device, Apps, Infrastructure) within the scope.
     * @returns a averageComparativeScore
     */
    get averageComparativeScores(): AverageComparativeScore[] | undefined;
    /**
     * Sets the averageComparativeScores property value. Average score by different scopes (for example, average by industry, average by seating) and control category (Identity, Data, Device, Apps, Infrastructure) within the scope.
     * @param value Value to set for the averageComparativeScores property.
     */
    set averageComparativeScores(value: AverageComparativeScore[] | undefined);
    /**
     * Gets the azureTenantId property value. GUID string for tenant ID.
     * @returns a string
     */
    get azureTenantId(): string | undefined;
    /**
     * Sets the azureTenantId property value. GUID string for tenant ID.
     * @param value Value to set for the azureTenantId property.
     */
    set azureTenantId(value: string | undefined);
    /**
     * Instantiates a new secureScore and sets the default values.
     */
    constructor();
    /**
     * Gets the controlScores property value. Contains tenant scores for a set of controls.
     * @returns a controlScore
     */
    get controlScores(): ControlScore[] | undefined;
    /**
     * Sets the controlScores property value. Contains tenant scores for a set of controls.
     * @param value Value to set for the controlScores property.
     */
    set controlScores(value: ControlScore[] | undefined);
    /**
     * Gets the createdDateTime property value. The date when the entity is created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The date when the entity is created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the currentScore property value. Tenant current attained score on specified date.
     * @returns a double
     */
    get currentScore(): number | undefined;
    /**
     * Sets the currentScore property value. Tenant current attained score on specified date.
     * @param value Value to set for the currentScore property.
     */
    set currentScore(value: number | undefined);
    /**
     * Gets the enabledServices property value. Microsoft-provided services for the tenant (for example, Exchange online, Skype, Sharepoint).
     * @returns a string
     */
    get enabledServices(): string[] | undefined;
    /**
     * Sets the enabledServices property value. Microsoft-provided services for the tenant (for example, Exchange online, Skype, Sharepoint).
     * @param value Value to set for the enabledServices property.
     */
    set enabledServices(value: string[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the licensedUserCount property value. Licensed user count of the given tenant.
     * @returns a integer
     */
    get licensedUserCount(): number | undefined;
    /**
     * Sets the licensedUserCount property value. Licensed user count of the given tenant.
     * @param value Value to set for the licensedUserCount property.
     */
    set licensedUserCount(value: number | undefined);
    /**
     * Gets the maxScore property value. Tenant maximum possible score on specified date.
     * @returns a double
     */
    get maxScore(): number | undefined;
    /**
     * Sets the maxScore property value. Tenant maximum possible score on specified date.
     * @param value Value to set for the maxScore property.
     */
    set maxScore(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=SecureScore). Required.
     * @returns a securityVendorInformation
     */
    get vendorInformation(): SecurityVendorInformation | undefined;
    /**
     * Sets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=SecureScore). Required.
     * @param value Value to set for the vendorInformation property.
     */
    set vendorInformation(value: SecurityVendorInformation | undefined);
}
