import { ComplianceInformation, Entity, SecureScoreControlStateUpdate, SecurityVendorInformation } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the security singleton. */
export declare class SecureScoreControlProfile extends Entity implements Parsable {
    /** Control action type (Config, Review, Behavior). */
    private _actionType?;
    /** URL to where the control can be actioned. */
    private _actionUrl?;
    /** GUID string for tenant ID. */
    private _azureTenantId?;
    /** The collection of compliance information associated with secure score control */
    private _complianceInformation?;
    /** Control action category (Account, Data, Device, Apps, Infrastructure). */
    private _controlCategory?;
    /** Flag to indicate where the tenant has marked a control (ignore, thirdParty, reviewed) (supports update). */
    private _controlStateUpdates?;
    /** Flag to indicate if a control is depreciated. */
    private _deprecated?;
    /** Resource cost of implemmentating control (low, moderate, high). */
    private _implementationCost?;
    /** Time at which the control profile entity was last modified. The Timestamp type represents date and time */
    private _lastModifiedDateTime?;
    /** Current obtained max score on specified date. */
    private _maxScore?;
    /** Microsoft's stack ranking of control. */
    private _rank?;
    /** Description of what the control will help remediate. */
    private _remediation?;
    /** Description of the impact on users of the remediation. */
    private _remediationImpact?;
    /** Service that owns the control (Exchange, Sharepoint, Azure AD). */
    private _service?;
    /** List of threats the control mitigates (accountBreach,dataDeletion,dataExfiltration,dataSpillage,elevationOfPrivilege,maliciousInsider,passwordCracking,phishingOrWhaling,spoofing). */
    private _threats?;
    /** Control tier (Core, Defense in Depth, Advanced.) */
    private _tier?;
    /** Title of the control. */
    private _title?;
    /** User impact of implementing control (low, moderate, high). */
    private _userImpact?;
    /** The vendorInformation property */
    private _vendorInformation?;
    /**
     * Gets the actionType property value. Control action type (Config, Review, Behavior).
     * @returns a string
     */
    get actionType(): string | undefined;
    /**
     * Sets the actionType property value. Control action type (Config, Review, Behavior).
     * @param value Value to set for the actionType property.
     */
    set actionType(value: string | undefined);
    /**
     * Gets the actionUrl property value. URL to where the control can be actioned.
     * @returns a string
     */
    get actionUrl(): string | undefined;
    /**
     * Sets the actionUrl property value. URL to where the control can be actioned.
     * @param value Value to set for the actionUrl property.
     */
    set actionUrl(value: string | undefined);
    /**
     * Gets the azureTenantId property value. GUID string for tenant ID.
     * @returns a string
     */
    get azureTenantId(): string | undefined;
    /**
     * Sets the azureTenantId property value. GUID string for tenant ID.
     * @param value Value to set for the azureTenantId property.
     */
    set azureTenantId(value: string | undefined);
    /**
     * Gets the complianceInformation property value. The collection of compliance information associated with secure score control
     * @returns a complianceInformation
     */
    get complianceInformation(): ComplianceInformation[] | undefined;
    /**
     * Sets the complianceInformation property value. The collection of compliance information associated with secure score control
     * @param value Value to set for the complianceInformation property.
     */
    set complianceInformation(value: ComplianceInformation[] | undefined);
    /**
     * Instantiates a new secureScoreControlProfile and sets the default values.
     */
    constructor();
    /**
     * Gets the controlCategory property value. Control action category (Account, Data, Device, Apps, Infrastructure).
     * @returns a string
     */
    get controlCategory(): string | undefined;
    /**
     * Sets the controlCategory property value. Control action category (Account, Data, Device, Apps, Infrastructure).
     * @param value Value to set for the controlCategory property.
     */
    set controlCategory(value: string | undefined);
    /**
     * Gets the controlStateUpdates property value. Flag to indicate where the tenant has marked a control (ignore, thirdParty, reviewed) (supports update).
     * @returns a secureScoreControlStateUpdate
     */
    get controlStateUpdates(): SecureScoreControlStateUpdate[] | undefined;
    /**
     * Sets the controlStateUpdates property value. Flag to indicate where the tenant has marked a control (ignore, thirdParty, reviewed) (supports update).
     * @param value Value to set for the controlStateUpdates property.
     */
    set controlStateUpdates(value: SecureScoreControlStateUpdate[] | undefined);
    /**
     * Gets the deprecated property value. Flag to indicate if a control is depreciated.
     * @returns a boolean
     */
    get deprecated(): boolean | undefined;
    /**
     * Sets the deprecated property value. Flag to indicate if a control is depreciated.
     * @param value Value to set for the deprecated property.
     */
    set deprecated(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the implementationCost property value. Resource cost of implemmentating control (low, moderate, high).
     * @returns a string
     */
    get implementationCost(): string | undefined;
    /**
     * Sets the implementationCost property value. Resource cost of implemmentating control (low, moderate, high).
     * @param value Value to set for the implementationCost property.
     */
    set implementationCost(value: string | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Time at which the control profile entity was last modified. The Timestamp type represents date and time
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Time at which the control profile entity was last modified. The Timestamp type represents date and time
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the maxScore property value. Current obtained max score on specified date.
     * @returns a double
     */
    get maxScore(): number | undefined;
    /**
     * Sets the maxScore property value. Current obtained max score on specified date.
     * @param value Value to set for the maxScore property.
     */
    set maxScore(value: number | undefined);
    /**
     * Gets the rank property value. Microsoft's stack ranking of control.
     * @returns a integer
     */
    get rank(): number | undefined;
    /**
     * Sets the rank property value. Microsoft's stack ranking of control.
     * @param value Value to set for the rank property.
     */
    set rank(value: number | undefined);
    /**
     * Gets the remediation property value. Description of what the control will help remediate.
     * @returns a string
     */
    get remediation(): string | undefined;
    /**
     * Sets the remediation property value. Description of what the control will help remediate.
     * @param value Value to set for the remediation property.
     */
    set remediation(value: string | undefined);
    /**
     * Gets the remediationImpact property value. Description of the impact on users of the remediation.
     * @returns a string
     */
    get remediationImpact(): string | undefined;
    /**
     * Sets the remediationImpact property value. Description of the impact on users of the remediation.
     * @param value Value to set for the remediationImpact property.
     */
    set remediationImpact(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the service property value. Service that owns the control (Exchange, Sharepoint, Azure AD).
     * @returns a string
     */
    get service(): string | undefined;
    /**
     * Sets the service property value. Service that owns the control (Exchange, Sharepoint, Azure AD).
     * @param value Value to set for the service property.
     */
    set service(value: string | undefined);
    /**
     * Gets the threats property value. List of threats the control mitigates (accountBreach,dataDeletion,dataExfiltration,dataSpillage,elevationOfPrivilege,maliciousInsider,passwordCracking,phishingOrWhaling,spoofing).
     * @returns a string
     */
    get threats(): string[] | undefined;
    /**
     * Sets the threats property value. List of threats the control mitigates (accountBreach,dataDeletion,dataExfiltration,dataSpillage,elevationOfPrivilege,maliciousInsider,passwordCracking,phishingOrWhaling,spoofing).
     * @param value Value to set for the threats property.
     */
    set threats(value: string[] | undefined);
    /**
     * Gets the tier property value. Control tier (Core, Defense in Depth, Advanced.)
     * @returns a string
     */
    get tier(): string | undefined;
    /**
     * Sets the tier property value. Control tier (Core, Defense in Depth, Advanced.)
     * @param value Value to set for the tier property.
     */
    set tier(value: string | undefined);
    /**
     * Gets the title property value. Title of the control.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. Title of the control.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
    /**
     * Gets the userImpact property value. User impact of implementing control (low, moderate, high).
     * @returns a string
     */
    get userImpact(): string | undefined;
    /**
     * Sets the userImpact property value. User impact of implementing control (low, moderate, high).
     * @param value Value to set for the userImpact property.
     */
    set userImpact(value: string | undefined);
    /**
     * Gets the vendorInformation property value. The vendorInformation property
     * @returns a securityVendorInformation
     */
    get vendorInformation(): SecurityVendorInformation | undefined;
    /**
     * Sets the vendorInformation property value. The vendorInformation property
     * @param value Value to set for the vendorInformation property.
     */
    set vendorInformation(value: SecurityVendorInformation | undefined);
}
