import { ServiceAnnouncementBase, ServiceHealthIssuePost } from './index';
import { ServiceHealthClassificationType } from './serviceHealthClassificationType';
import { ServiceHealthOrigin } from './serviceHealthOrigin';
import { ServiceHealthStatus } from './serviceHealthStatus';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the admin singleton. */
export declare class ServiceHealthIssue extends ServiceAnnouncementBase implements Parsable {
    /** The type of service health issue. Possible values are: advisory, incident, unknownFutureValue. */
    private _classification?;
    /** The feature name of the service issue. */
    private _feature?;
    /** The feature group name of the service issue. */
    private _featureGroup?;
    /** The description of the service issue impact. */
    private _impactDescription?;
    /** Indicates whether the issue is resolved. */
    private _isResolved?;
    /** Indicates the origin of the service issue. Possible values are: microsoft, thirdParty, customer, unknownFutureValue. */
    private _origin?;
    /** Collection of historical posts for the service issue. */
    private _posts?;
    /** Indicates the service affected by the issue. */
    private _service?;
    /** The status of the service issue. Possible values are: serviceOperational, investigating, restoringService, verifyingService, serviceRestored, postIncidentReviewPublished, serviceDegradation, serviceInterruption, extendedRecovery, falsePositive, investigationSuspended, resolved, mitigatedExternal, mitigated, resolvedExternal, confirmed, reported, unknownFutureValue. For more details, see serviceHealthStatus values. */
    private _status?;
    /**
     * Gets the classification property value. The type of service health issue. Possible values are: advisory, incident, unknownFutureValue.
     * @returns a serviceHealthClassificationType
     */
    get classification(): ServiceHealthClassificationType | undefined;
    /**
     * Sets the classification property value. The type of service health issue. Possible values are: advisory, incident, unknownFutureValue.
     * @param value Value to set for the classification property.
     */
    set classification(value: ServiceHealthClassificationType | undefined);
    /**
     * Instantiates a new serviceHealthIssue and sets the default values.
     */
    constructor();
    /**
     * Gets the feature property value. The feature name of the service issue.
     * @returns a string
     */
    get feature(): string | undefined;
    /**
     * Sets the feature property value. The feature name of the service issue.
     * @param value Value to set for the feature property.
     */
    set feature(value: string | undefined);
    /**
     * Gets the featureGroup property value. The feature group name of the service issue.
     * @returns a string
     */
    get featureGroup(): string | undefined;
    /**
     * Sets the featureGroup property value. The feature group name of the service issue.
     * @param value Value to set for the featureGroup property.
     */
    set featureGroup(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the impactDescription property value. The description of the service issue impact.
     * @returns a string
     */
    get impactDescription(): string | undefined;
    /**
     * Sets the impactDescription property value. The description of the service issue impact.
     * @param value Value to set for the impactDescription property.
     */
    set impactDescription(value: string | undefined);
    /**
     * Gets the isResolved property value. Indicates whether the issue is resolved.
     * @returns a boolean
     */
    get isResolved(): boolean | undefined;
    /**
     * Sets the isResolved property value. Indicates whether the issue is resolved.
     * @param value Value to set for the isResolved property.
     */
    set isResolved(value: boolean | undefined);
    /**
     * Gets the origin property value. Indicates the origin of the service issue. Possible values are: microsoft, thirdParty, customer, unknownFutureValue.
     * @returns a serviceHealthOrigin
     */
    get origin(): ServiceHealthOrigin | undefined;
    /**
     * Sets the origin property value. Indicates the origin of the service issue. Possible values are: microsoft, thirdParty, customer, unknownFutureValue.
     * @param value Value to set for the origin property.
     */
    set origin(value: ServiceHealthOrigin | undefined);
    /**
     * Gets the posts property value. Collection of historical posts for the service issue.
     * @returns a serviceHealthIssuePost
     */
    get posts(): ServiceHealthIssuePost[] | undefined;
    /**
     * Sets the posts property value. Collection of historical posts for the service issue.
     * @param value Value to set for the posts property.
     */
    set posts(value: ServiceHealthIssuePost[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the service property value. Indicates the service affected by the issue.
     * @returns a string
     */
    get service(): string | undefined;
    /**
     * Sets the service property value. Indicates the service affected by the issue.
     * @param value Value to set for the service property.
     */
    set service(value: string | undefined);
    /**
     * Gets the status property value. The status of the service issue. Possible values are: serviceOperational, investigating, restoringService, verifyingService, serviceRestored, postIncidentReviewPublished, serviceDegradation, serviceInterruption, extendedRecovery, falsePositive, investigationSuspended, resolved, mitigatedExternal, mitigated, resolvedExternal, confirmed, reported, unknownFutureValue. For more details, see serviceHealthStatus values.
     * @returns a serviceHealthStatus
     */
    get status(): ServiceHealthStatus | undefined;
    /**
     * Sets the status property value. The status of the service issue. Possible values are: serviceOperational, investigating, restoringService, verifyingService, serviceRestored, postIncidentReviewPublished, serviceDegradation, serviceInterruption, extendedRecovery, falsePositive, investigationSuspended, resolved, mitigatedExternal, mitigated, resolvedExternal, confirmed, reported, unknownFutureValue. For more details, see serviceHealthStatus values.
     * @param value Value to set for the status property.
     */
    set status(value: ServiceHealthStatus | undefined);
}
