import { BaseItem, DriveItem, IdentitySet, List, ListItem, Permission, Site } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of sharedDriveItem entities. */
export declare class SharedDriveItem extends BaseItem implements Parsable {
    /** Used to access the underlying driveItem */
    private _driveItem?;
    /** All driveItems contained in the sharing root. This collection cannot be enumerated. */
    private _items?;
    /** Used to access the underlying list */
    private _list?;
    /** Used to access the underlying listItem */
    private _listItem?;
    /** Information about the owner of the shared item being referenced. */
    private _owner?;
    /** Used to access the permission representing the underlying sharing link */
    private _permission?;
    /** Used to access the underlying driveItem. Deprecated -- use driveItem instead. */
    private _root?;
    /** Used to access the underlying site */
    private _site?;
    /**
     * Instantiates a new sharedDriveItem and sets the default values.
     */
    constructor();
    /**
     * Gets the driveItem property value. Used to access the underlying driveItem
     * @returns a driveItem
     */
    get driveItem(): DriveItem | undefined;
    /**
     * Sets the driveItem property value. Used to access the underlying driveItem
     * @param value Value to set for the driveItem property.
     */
    set driveItem(value: DriveItem | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the items property value. All driveItems contained in the sharing root. This collection cannot be enumerated.
     * @returns a driveItem
     */
    get items(): DriveItem[] | undefined;
    /**
     * Sets the items property value. All driveItems contained in the sharing root. This collection cannot be enumerated.
     * @param value Value to set for the items property.
     */
    set items(value: DriveItem[] | undefined);
    /**
     * Gets the list property value. Used to access the underlying list
     * @returns a list
     */
    get list(): List | undefined;
    /**
     * Sets the list property value. Used to access the underlying list
     * @param value Value to set for the list property.
     */
    set list(value: List | undefined);
    /**
     * Gets the listItem property value. Used to access the underlying listItem
     * @returns a listItem
     */
    get listItem(): ListItem | undefined;
    /**
     * Sets the listItem property value. Used to access the underlying listItem
     * @param value Value to set for the listItem property.
     */
    set listItem(value: ListItem | undefined);
    /**
     * Gets the owner property value. Information about the owner of the shared item being referenced.
     * @returns a identitySet
     */
    get owner(): IdentitySet | undefined;
    /**
     * Sets the owner property value. Information about the owner of the shared item being referenced.
     * @param value Value to set for the owner property.
     */
    set owner(value: IdentitySet | undefined);
    /**
     * Gets the permission property value. Used to access the permission representing the underlying sharing link
     * @returns a permission
     */
    get permission(): Permission | undefined;
    /**
     * Sets the permission property value. Used to access the permission representing the underlying sharing link
     * @param value Value to set for the permission property.
     */
    set permission(value: Permission | undefined);
    /**
     * Gets the root property value. Used to access the underlying driveItem. Deprecated -- use driveItem instead.
     * @returns a driveItem
     */
    get root(): DriveItem | undefined;
    /**
     * Sets the root property value. Used to access the underlying driveItem. Deprecated -- use driveItem instead.
     * @param value Value to set for the root property.
     */
    set root(value: DriveItem | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the site property value. Used to access the underlying site
     * @returns a site
     */
    get site(): Site | undefined;
    /**
     * Sets the site property value. Used to access the underlying site
     * @param value Value to set for the site property.
     */
    set site(value: Site | undefined);
}
