"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignIn = void 0;
const conditionalAccessStatus_1 = require("./conditionalAccessStatus");
const createAppliedConditionalAccessPolicyFromDiscriminatorValue_1 = require("./createAppliedConditionalAccessPolicyFromDiscriminatorValue");
const createDeviceDetailFromDiscriminatorValue_1 = require("./createDeviceDetailFromDiscriminatorValue");
const createSignInLocationFromDiscriminatorValue_1 = require("./createSignInLocationFromDiscriminatorValue");
const createSignInStatusFromDiscriminatorValue_1 = require("./createSignInStatusFromDiscriminatorValue");
const index_1 = require("./index");
const riskDetail_1 = require("./riskDetail");
const riskLevel_1 = require("./riskLevel");
const riskState_1 = require("./riskState");
/** Provides operations to manage the auditLogRoot singleton. */
class SignIn extends index_1.Entity {
    /**
     * Instantiates a new signIn and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appDisplayName property value. The application name displayed in the Azure Portal. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get appDisplayName() {
        return this._appDisplayName;
    }
    ;
    /**
     * Sets the appDisplayName property value. The application name displayed in the Azure Portal. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the appDisplayName property.
     */
    set appDisplayName(value) {
        this._appDisplayName = value;
    }
    ;
    /**
     * Gets the appId property value. The application identifier in Azure Active Directory. Supports $filter (eq operator only).
     * @returns a string
     */
    get appId() {
        return this._appId;
    }
    ;
    /**
     * Sets the appId property value. The application identifier in Azure Active Directory. Supports $filter (eq operator only).
     * @param value Value to set for the appId property.
     */
    set appId(value) {
        this._appId = value;
    }
    ;
    /**
     * Gets the appliedConditionalAccessPolicies property value. A list of conditional access policies that are triggered by the corresponding sign-in activity.
     * @returns a appliedConditionalAccessPolicy
     */
    get appliedConditionalAccessPolicies() {
        return this._appliedConditionalAccessPolicies;
    }
    ;
    /**
     * Sets the appliedConditionalAccessPolicies property value. A list of conditional access policies that are triggered by the corresponding sign-in activity.
     * @param value Value to set for the appliedConditionalAccessPolicies property.
     */
    set appliedConditionalAccessPolicies(value) {
        this._appliedConditionalAccessPolicies = value;
    }
    ;
    /**
     * Gets the clientAppUsed property value. The legacy client used for sign-in activity. For example: Browser, Exchange ActiveSync, Modern clients, IMAP, MAPI, SMTP, or POP. Supports $filter (eq operator only).
     * @returns a string
     */
    get clientAppUsed() {
        return this._clientAppUsed;
    }
    ;
    /**
     * Sets the clientAppUsed property value. The legacy client used for sign-in activity. For example: Browser, Exchange ActiveSync, Modern clients, IMAP, MAPI, SMTP, or POP. Supports $filter (eq operator only).
     * @param value Value to set for the clientAppUsed property.
     */
    set clientAppUsed(value) {
        this._clientAppUsed = value;
    }
    ;
    /**
     * Gets the conditionalAccessStatus property value. The status of the conditional access policy triggered. Possible values: success, failure, notApplied, or unknownFutureValue. Supports $filter (eq operator only).
     * @returns a conditionalAccessStatus
     */
    get conditionalAccessStatus() {
        return this._conditionalAccessStatus;
    }
    ;
    /**
     * Sets the conditionalAccessStatus property value. The status of the conditional access policy triggered. Possible values: success, failure, notApplied, or unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the conditionalAccessStatus property.
     */
    set conditionalAccessStatus(value) {
        this._conditionalAccessStatus = value;
    }
    ;
    ;
    /**
     * Gets the correlationId property value. The identifier that's sent from the client when sign-in is initiated. This is used for troubleshooting the corresponding sign-in activity when calling for support. Supports $filter (eq operator only).
     * @returns a string
     */
    get correlationId() {
        return this._correlationId;
    }
    ;
    /**
     * Sets the correlationId property value. The identifier that's sent from the client when sign-in is initiated. This is used for troubleshooting the corresponding sign-in activity when calling for support. Supports $filter (eq operator only).
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value) {
        this._correlationId = value;
    }
    ;
    /**
     * Gets the createdDateTime property value. The date and time the sign-in was initiated. The Timestamp type is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $orderby and $filter (eq, le, and ge operators only).
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. The date and time the sign-in was initiated. The Timestamp type is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Supports $orderby and $filter (eq, le, and ge operators only).
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the deviceDetail property value. The device information from where the sign-in occurred. Includes information such as deviceId, OS, and browser. Supports $filter (eq and startsWith operators only) on browser and operatingSystem properties.
     * @returns a deviceDetail
     */
    get deviceDetail() {
        return this._deviceDetail;
    }
    ;
    /**
     * Sets the deviceDetail property value. The device information from where the sign-in occurred. Includes information such as deviceId, OS, and browser. Supports $filter (eq and startsWith operators only) on browser and operatingSystem properties.
     * @param value Value to set for the deviceDetail property.
     */
    set deviceDetail(value) {
        this._deviceDetail = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appDisplayName": n => { this.appDisplayName = n.getStringValue(); }, "appId": n => { this.appId = n.getStringValue(); }, "appliedConditionalAccessPolicies": n => { this.appliedConditionalAccessPolicies = n.getCollectionOfObjectValues(createAppliedConditionalAccessPolicyFromDiscriminatorValue_1.createAppliedConditionalAccessPolicyFromDiscriminatorValue); }, "clientAppUsed": n => { this.clientAppUsed = n.getStringValue(); }, "conditionalAccessStatus": n => { this.conditionalAccessStatus = n.getEnumValue(conditionalAccessStatus_1.ConditionalAccessStatus); }, "correlationId": n => { this.correlationId = n.getStringValue(); }, "createdDateTime": n => { this.createdDateTime = n.getDateValue(); }, "deviceDetail": n => { this.deviceDetail = n.getObjectValue(createDeviceDetailFromDiscriminatorValue_1.createDeviceDetailFromDiscriminatorValue); }, "ipAddress": n => { this.ipAddress = n.getStringValue(); }, "isInteractive": n => { this.isInteractive = n.getBooleanValue(); }, "location": n => { this.location = n.getObjectValue(createSignInLocationFromDiscriminatorValue_1.createSignInLocationFromDiscriminatorValue); }, "resourceDisplayName": n => { this.resourceDisplayName = n.getStringValue(); }, "resourceId": n => { this.resourceId = n.getStringValue(); }, "riskDetail": n => { this.riskDetail = n.getEnumValue(riskDetail_1.RiskDetail); }, "riskEventTypes": n => { this.riskEventTypes = n.getCollectionOfPrimitiveValues(); }, "riskEventTypes_v2": n => { this.riskEventTypes_v2 = n.getCollectionOfPrimitiveValues(); }, "riskLevelAggregated": n => { this.riskLevelAggregated = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskLevelDuringSignIn": n => { this.riskLevelDuringSignIn = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskState": n => { this.riskState = n.getEnumValue(riskState_1.RiskState); }, "status": n => { this.status = n.getObjectValue(createSignInStatusFromDiscriminatorValue_1.createSignInStatusFromDiscriminatorValue); }, "userDisplayName": n => { this.userDisplayName = n.getStringValue(); }, "userId": n => { this.userId = n.getStringValue(); }, "userPrincipalName": n => { this.userPrincipalName = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the ipAddress property value. The IP address of the client from where the sign-in occurred. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get ipAddress() {
        return this._ipAddress;
    }
    ;
    /**
     * Sets the ipAddress property value. The IP address of the client from where the sign-in occurred. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the ipAddress property.
     */
    set ipAddress(value) {
        this._ipAddress = value;
    }
    ;
    /**
     * Gets the isInteractive property value. Indicates whether a user sign in is interactive. In interactive sign in, the user provides an authentication factor to Azure AD. These factors include passwords, responses to MFA challenges, biometric factors, or QR codes that a user provides to Azure AD or an associated app. In non-interactive sign in, the user doesn't provide an authentication factor. Instead, the client app uses a token or code to authenticate or access a resource on behalf of a user. Non-interactive sign ins are commonly used for a client to sign in on a user's behalf in a process transparent to the user.
     * @returns a boolean
     */
    get isInteractive() {
        return this._isInteractive;
    }
    ;
    /**
     * Sets the isInteractive property value. Indicates whether a user sign in is interactive. In interactive sign in, the user provides an authentication factor to Azure AD. These factors include passwords, responses to MFA challenges, biometric factors, or QR codes that a user provides to Azure AD or an associated app. In non-interactive sign in, the user doesn't provide an authentication factor. Instead, the client app uses a token or code to authenticate or access a resource on behalf of a user. Non-interactive sign ins are commonly used for a client to sign in on a user's behalf in a process transparent to the user.
     * @param value Value to set for the isInteractive property.
     */
    set isInteractive(value) {
        this._isInteractive = value;
    }
    ;
    /**
     * Gets the location property value. The city, state, and 2 letter country code from where the sign-in occurred. Supports $filter (eq and startsWith operators only) on city, state, and countryOrRegion properties.
     * @returns a signInLocation
     */
    get location() {
        return this._location;
    }
    ;
    /**
     * Sets the location property value. The city, state, and 2 letter country code from where the sign-in occurred. Supports $filter (eq and startsWith operators only) on city, state, and countryOrRegion properties.
     * @param value Value to set for the location property.
     */
    set location(value) {
        this._location = value;
    }
    ;
    /**
     * Gets the resourceDisplayName property value. The name of the resource that the user signed in to. Supports $filter (eq operator only).
     * @returns a string
     */
    get resourceDisplayName() {
        return this._resourceDisplayName;
    }
    ;
    /**
     * Sets the resourceDisplayName property value. The name of the resource that the user signed in to. Supports $filter (eq operator only).
     * @param value Value to set for the resourceDisplayName property.
     */
    set resourceDisplayName(value) {
        this._resourceDisplayName = value;
    }
    ;
    /**
     * Gets the resourceId property value. The identifier of the resource that the user signed in to. Supports $filter (eq operator only).
     * @returns a string
     */
    get resourceId() {
        return this._resourceId;
    }
    ;
    /**
     * Sets the resourceId property value. The identifier of the resource that the user signed in to. Supports $filter (eq operator only).
     * @param value Value to set for the resourceId property.
     */
    set resourceId(value) {
        this._resourceId = value;
    }
    ;
    /**
     * Gets the riskDetail property value. The reason behind a specific state of a risky user, sign-in, or a risk event. Possible values: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, or unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @returns a riskDetail
     */
    get riskDetail() {
        return this._riskDetail;
    }
    ;
    /**
     * Sets the riskDetail property value. The reason behind a specific state of a risky user, sign-in, or a risk event. Possible values: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, or unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @param value Value to set for the riskDetail property.
     */
    set riskDetail(value) {
        this._riskDetail = value;
    }
    ;
    /**
     * Gets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, and unknownFutureValue. Supports $filter (eq operator only).
     * @returns a string
     */
    get riskEventTypes() {
        return this._riskEventTypes;
    }
    ;
    /**
     * Sets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, and unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the riskEventTypes property.
     */
    set riskEventTypes(value) {
        this._riskEventTypes = value;
    }
    ;
    /**
     * Gets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, or unknownFutureValue. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get riskEventTypes_v2() {
        return this._riskEventTypes_v2;
    }
    ;
    /**
     * Sets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, or unknownFutureValue. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the riskEventTypes_v2 property.
     */
    set riskEventTypes_v2(value) {
        this._riskEventTypes_v2 = value;
    }
    ;
    /**
     * Gets the riskLevelAggregated property value. The aggregated risk level. Possible values: none, low, medium, high, hidden, or unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @returns a riskLevel
     */
    get riskLevelAggregated() {
        return this._riskLevelAggregated;
    }
    ;
    /**
     * Sets the riskLevelAggregated property value. The aggregated risk level. Possible values: none, low, medium, high, hidden, or unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @param value Value to set for the riskLevelAggregated property.
     */
    set riskLevelAggregated(value) {
        this._riskLevelAggregated = value;
    }
    ;
    /**
     * Gets the riskLevelDuringSignIn property value. The risk level during sign-in. Possible values: none, low, medium, high, hidden, or unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @returns a riskLevel
     */
    get riskLevelDuringSignIn() {
        return this._riskLevelDuringSignIn;
    }
    ;
    /**
     * Sets the riskLevelDuringSignIn property value. The risk level during sign-in. Possible values: none, low, medium, high, hidden, or unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers are returned hidden.
     * @param value Value to set for the riskLevelDuringSignIn property.
     */
    set riskLevelDuringSignIn(value) {
        this._riskLevelDuringSignIn = value;
    }
    ;
    /**
     * Gets the riskState property value. The risk state of a risky user, sign-in, or a risk event. Possible values: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, or unknownFutureValue. Supports $filter (eq operator only).
     * @returns a riskState
     */
    get riskState() {
        return this._riskState;
    }
    ;
    /**
     * Sets the riskState property value. The risk state of a risky user, sign-in, or a risk event. Possible values: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, or unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the riskState property.
     */
    set riskState(value) {
        this._riskState = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("appDisplayName", this.appDisplayName);
        writer.writeStringValue("appId", this.appId);
        writer.writeCollectionOfObjectValues("appliedConditionalAccessPolicies", this.appliedConditionalAccessPolicies);
        writer.writeStringValue("clientAppUsed", this.clientAppUsed);
        writer.writeEnumValue("conditionalAccessStatus", this.conditionalAccessStatus);
        writer.writeStringValue("correlationId", this.correlationId);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeObjectValue("deviceDetail", this.deviceDetail);
        writer.writeStringValue("ipAddress", this.ipAddress);
        writer.writeBooleanValue("isInteractive", this.isInteractive);
        writer.writeObjectValue("location", this.location);
        writer.writeStringValue("resourceDisplayName", this.resourceDisplayName);
        writer.writeStringValue("resourceId", this.resourceId);
        writer.writeEnumValue("riskDetail", this.riskDetail);
        writer.writeCollectionOfPrimitiveValues("riskEventTypes", this.riskEventTypes);
        writer.writeCollectionOfPrimitiveValues("riskEventTypes_v2", this.riskEventTypes_v2);
        writer.writeEnumValue("riskLevelAggregated", this.riskLevelAggregated);
        writer.writeEnumValue("riskLevelDuringSignIn", this.riskLevelDuringSignIn);
        writer.writeEnumValue("riskState", this.riskState);
        writer.writeObjectValue("status", this.status);
        writer.writeStringValue("userDisplayName", this.userDisplayName);
        writer.writeStringValue("userId", this.userId);
        writer.writeStringValue("userPrincipalName", this.userPrincipalName);
    }
    ;
    /**
     * Gets the status property value. The sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq operator only) on errorCode property.
     * @returns a signInStatus
     */
    get status() {
        return this._status;
    }
    ;
    /**
     * Sets the status property value. The sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq operator only) on errorCode property.
     * @param value Value to set for the status property.
     */
    set status(value) {
        this._status = value;
    }
    ;
    /**
     * Gets the userDisplayName property value. The display name of the user. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get userDisplayName() {
        return this._userDisplayName;
    }
    ;
    /**
     * Sets the userDisplayName property value. The display name of the user. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value) {
        this._userDisplayName = value;
    }
    ;
    /**
     * Gets the userId property value. The identifier of the user. Supports $filter (eq operator only).
     * @returns a string
     */
    get userId() {
        return this._userId;
    }
    ;
    /**
     * Sets the userId property value. The identifier of the user. Supports $filter (eq operator only).
     * @param value Value to set for the userId property.
     */
    set userId(value) {
        this._userId = value;
    }
    ;
    /**
     * Gets the userPrincipalName property value. The UPN of the user. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get userPrincipalName() {
        return this._userPrincipalName;
    }
    ;
    /**
     * Sets the userPrincipalName property value. The UPN of the user. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value) {
        this._userPrincipalName = value;
    }
    ;
}
exports.SignIn = SignIn;
