import { DataSubjectType } from './dataSubjectType';
import { AuthoredNote, DataSubject, Entity, Identity, IdentitySet, SubjectRightsRequestDetail, SubjectRightsRequestHistory, SubjectRightsRequestStageDetail, Team } from './index';
import { SubjectRightsRequestStatus } from './subjectRightsRequestStatus';
import { SubjectRightsRequestType } from './subjectRightsRequestType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the privacy singleton. */
export declare class SubjectRightsRequest extends Entity implements Parsable {
    /** Identity that the request is assigned to. */
    private _assignedTo?;
    /** The date and time when the request was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _closedDateTime?;
    /** Identity information for the entity that created the request. */
    private _createdBy?;
    /** The date and time when the request was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _createdDateTime?;
    /** Information about the data subject. */
    private _dataSubject?;
    /** The type of the data subject. Possible values are: customer, currentEmployee, formerEmployee, prospectiveEmployee, student, teacher, faculty, other, unknownFutureValue. */
    private _dataSubjectType?;
    /** Description for the request. */
    private _description?;
    /** The name of the request. */
    private _displayName?;
    /** Collection of history change events. */
    private _history?;
    /** Insight about the request. */
    private _insight?;
    /** The date and time when the request is internally due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _internalDueDateTime?;
    /** Identity information for the entity that last modified the request. */
    private _lastModifiedBy?;
    /** The date and time when the request was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _lastModifiedDateTime?;
    /** List of notes associated with the request. */
    private _notes?;
    /** List of regulations that this request will fulfill. */
    private _regulations?;
    /** Information about the different stages for the request. */
    private _stages?;
    /** The status of the request. Possible values are: active, closed, unknownFutureValue. */
    private _status?;
    /** Information about the Microsoft Teams team that was created for the request. */
    private _team?;
    /** The type of the request. Possible values are: export, delete, access, tagForAction, unknownFutureValue. */
    private _type?;
    /**
     * Gets the assignedTo property value. Identity that the request is assigned to.
     * @returns a identity
     */
    get assignedTo(): Identity | undefined;
    /**
     * Sets the assignedTo property value. Identity that the request is assigned to.
     * @param value Value to set for the assignedTo property.
     */
    set assignedTo(value: Identity | undefined);
    /**
     * Gets the closedDateTime property value. The date and time when the request was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get closedDateTime(): Date | undefined;
    /**
     * Sets the closedDateTime property value. The date and time when the request was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the closedDateTime property.
     */
    set closedDateTime(value: Date | undefined);
    /**
     * Instantiates a new subjectRightsRequest and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Identity information for the entity that created the request.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Identity information for the entity that created the request.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the createdDateTime property value. The date and time when the request was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The date and time when the request was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the dataSubject property value. Information about the data subject.
     * @returns a dataSubject
     */
    get dataSubject(): DataSubject | undefined;
    /**
     * Sets the dataSubject property value. Information about the data subject.
     * @param value Value to set for the dataSubject property.
     */
    set dataSubject(value: DataSubject | undefined);
    /**
     * Gets the dataSubjectType property value. The type of the data subject. Possible values are: customer, currentEmployee, formerEmployee, prospectiveEmployee, student, teacher, faculty, other, unknownFutureValue.
     * @returns a dataSubjectType
     */
    get dataSubjectType(): DataSubjectType | undefined;
    /**
     * Sets the dataSubjectType property value. The type of the data subject. Possible values are: customer, currentEmployee, formerEmployee, prospectiveEmployee, student, teacher, faculty, other, unknownFutureValue.
     * @param value Value to set for the dataSubjectType property.
     */
    set dataSubjectType(value: DataSubjectType | undefined);
    /**
     * Gets the description property value. Description for the request.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Description for the request.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. The name of the request.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the request.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the history property value. Collection of history change events.
     * @returns a subjectRightsRequestHistory
     */
    get history(): SubjectRightsRequestHistory[] | undefined;
    /**
     * Sets the history property value. Collection of history change events.
     * @param value Value to set for the history property.
     */
    set history(value: SubjectRightsRequestHistory[] | undefined);
    /**
     * Gets the insight property value. Insight about the request.
     * @returns a subjectRightsRequestDetail
     */
    get insight(): SubjectRightsRequestDetail | undefined;
    /**
     * Sets the insight property value. Insight about the request.
     * @param value Value to set for the insight property.
     */
    set insight(value: SubjectRightsRequestDetail | undefined);
    /**
     * Gets the internalDueDateTime property value. The date and time when the request is internally due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get internalDueDateTime(): Date | undefined;
    /**
     * Sets the internalDueDateTime property value. The date and time when the request is internally due. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the internalDueDateTime property.
     */
    set internalDueDateTime(value: Date | undefined);
    /**
     * Gets the lastModifiedBy property value. Identity information for the entity that last modified the request.
     * @returns a identitySet
     */
    get lastModifiedBy(): IdentitySet | undefined;
    /**
     * Sets the lastModifiedBy property value. Identity information for the entity that last modified the request.
     * @param value Value to set for the lastModifiedBy property.
     */
    set lastModifiedBy(value: IdentitySet | undefined);
    /**
     * Gets the lastModifiedDateTime property value. The date and time when the request was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The date and time when the request was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the notes property value. List of notes associated with the request.
     * @returns a authoredNote
     */
    get notes(): AuthoredNote[] | undefined;
    /**
     * Sets the notes property value. List of notes associated with the request.
     * @param value Value to set for the notes property.
     */
    set notes(value: AuthoredNote[] | undefined);
    /**
     * Gets the regulations property value. List of regulations that this request will fulfill.
     * @returns a string
     */
    get regulations(): string[] | undefined;
    /**
     * Sets the regulations property value. List of regulations that this request will fulfill.
     * @param value Value to set for the regulations property.
     */
    set regulations(value: string[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the stages property value. Information about the different stages for the request.
     * @returns a subjectRightsRequestStageDetail
     */
    get stages(): SubjectRightsRequestStageDetail[] | undefined;
    /**
     * Sets the stages property value. Information about the different stages for the request.
     * @param value Value to set for the stages property.
     */
    set stages(value: SubjectRightsRequestStageDetail[] | undefined);
    /**
     * Gets the status property value. The status of the request. Possible values are: active, closed, unknownFutureValue.
     * @returns a subjectRightsRequestStatus
     */
    get status(): SubjectRightsRequestStatus | undefined;
    /**
     * Sets the status property value. The status of the request. Possible values are: active, closed, unknownFutureValue.
     * @param value Value to set for the status property.
     */
    set status(value: SubjectRightsRequestStatus | undefined);
    /**
     * Gets the team property value. Information about the Microsoft Teams team that was created for the request.
     * @returns a team
     */
    get team(): Team | undefined;
    /**
     * Sets the team property value. Information about the Microsoft Teams team that was created for the request.
     * @param value Value to set for the team property.
     */
    set team(value: Team | undefined);
    /**
     * Gets the type property value. The type of the request. Possible values are: export, delete, access, tagForAction, unknownFutureValue.
     * @returns a subjectRightsRequestType
     */
    get type(): SubjectRightsRequestType | undefined;
    /**
     * Sets the type property value. The type of the request. Possible values are: export, delete, access, tagForAction, unknownFutureValue.
     * @param value Value to set for the type property.
     */
    set type(value: SubjectRightsRequestType | undefined);
}
