import { Entity, LicenseUnitsDetail, ServicePlanInfo } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of subscribedSku entities. */
export declare class SubscribedSku extends Entity implements Parsable {
    /** For example, 'User' or 'Company'. */
    private _appliesTo?;
    /** Possible values are: Enabled, Warning, Suspended, Deleted, LockedOut. The capabilityStatus is Enabled if the prepaidUnits property has at least 1 unit that is enabled, and LockedOut if the customer cancelled their subscription. */
    private _capabilityStatus?;
    /** The number of licenses that have been assigned. */
    private _consumedUnits?;
    /** Information about the number and status of prepaid licenses. */
    private _prepaidUnits?;
    /** Information about the service plans that are available with the SKU. Not nullable */
    private _servicePlans?;
    /** The unique identifier (GUID) for the service SKU. */
    private _skuId?;
    /** The SKU part number; for example: 'AAD_PREMIUM' or 'RMSBASIC'. To get a list of commercial subscriptions that an organization has acquired, see List subscribedSkus. */
    private _skuPartNumber?;
    /**
     * Gets the appliesTo property value. For example, 'User' or 'Company'.
     * @returns a string
     */
    get appliesTo(): string | undefined;
    /**
     * Sets the appliesTo property value. For example, 'User' or 'Company'.
     * @param value Value to set for the appliesTo property.
     */
    set appliesTo(value: string | undefined);
    /**
     * Gets the capabilityStatus property value. Possible values are: Enabled, Warning, Suspended, Deleted, LockedOut. The capabilityStatus is Enabled if the prepaidUnits property has at least 1 unit that is enabled, and LockedOut if the customer cancelled their subscription.
     * @returns a string
     */
    get capabilityStatus(): string | undefined;
    /**
     * Sets the capabilityStatus property value. Possible values are: Enabled, Warning, Suspended, Deleted, LockedOut. The capabilityStatus is Enabled if the prepaidUnits property has at least 1 unit that is enabled, and LockedOut if the customer cancelled their subscription.
     * @param value Value to set for the capabilityStatus property.
     */
    set capabilityStatus(value: string | undefined);
    /**
     * Instantiates a new subscribedSku and sets the default values.
     */
    constructor();
    /**
     * Gets the consumedUnits property value. The number of licenses that have been assigned.
     * @returns a integer
     */
    get consumedUnits(): number | undefined;
    /**
     * Sets the consumedUnits property value. The number of licenses that have been assigned.
     * @param value Value to set for the consumedUnits property.
     */
    set consumedUnits(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the prepaidUnits property value. Information about the number and status of prepaid licenses.
     * @returns a licenseUnitsDetail
     */
    get prepaidUnits(): LicenseUnitsDetail | undefined;
    /**
     * Sets the prepaidUnits property value. Information about the number and status of prepaid licenses.
     * @param value Value to set for the prepaidUnits property.
     */
    set prepaidUnits(value: LicenseUnitsDetail | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the servicePlans property value. Information about the service plans that are available with the SKU. Not nullable
     * @returns a servicePlanInfo
     */
    get servicePlans(): ServicePlanInfo[] | undefined;
    /**
     * Sets the servicePlans property value. Information about the service plans that are available with the SKU. Not nullable
     * @param value Value to set for the servicePlans property.
     */
    set servicePlans(value: ServicePlanInfo[] | undefined);
    /**
     * Gets the skuId property value. The unique identifier (GUID) for the service SKU.
     * @returns a string
     */
    get skuId(): string | undefined;
    /**
     * Sets the skuId property value. The unique identifier (GUID) for the service SKU.
     * @param value Value to set for the skuId property.
     */
    set skuId(value: string | undefined);
    /**
     * Gets the skuPartNumber property value. The SKU part number; for example: 'AAD_PREMIUM' or 'RMSBASIC'. To get a list of commercial subscriptions that an organization has acquired, see List subscribedSkus.
     * @returns a string
     */
    get skuPartNumber(): string | undefined;
    /**
     * Sets the skuPartNumber property value. The SKU part number; for example: 'AAD_PREMIUM' or 'RMSBASIC'. To get a list of commercial subscriptions that an organization has acquired, see List subscribedSkus.
     * @param value Value to set for the skuPartNumber property.
     */
    set skuPartNumber(value: string | undefined);
}
