import { Channel, ConversationMember, Entity, Group, Schedule, TeamFunSettings, TeamGuestSettings, TeamMemberSettings, TeamMessagingSettings, TeamsAppInstallation, TeamsAsyncOperation, TeamsTemplate } from './index';
import { TeamSpecialization } from './teamSpecialization';
import { TeamVisibilityType } from './teamVisibilityType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Team extends Entity implements Parsable {
    /** The collection of channels and messages associated with the team. */
    private _channels?;
    /** An optional label. Typically describes the data or business sensitivity of the team. Must match one of a pre-configured set in the tenant's directory. */
    private _classification?;
    /** Timestamp at which the team was created. */
    private _createdDateTime?;
    /** An optional description for the team. Maximum length: 1024 characters. */
    private _description?;
    /** The name of the team. */
    private _displayName?;
    /** Settings to configure use of Giphy, memes, and stickers in the team. */
    private _funSettings?;
    /** The group property */
    private _group?;
    /** Settings to configure whether guests can create, update, or delete channels in the team. */
    private _guestSettings?;
    /** The apps installed in this team. */
    private _installedApps?;
    /** A unique ID for the team that has been used in a few places such as the audit log/Office 365 Management Activity API. */
    private _internalId?;
    /** Whether this team is in read-only mode. */
    private _isArchived?;
    /** Members and owners of the team. */
    private _members?;
    /** Settings to configure whether members can perform certain actions, for example, create channels and add bots, in the team. */
    private _memberSettings?;
    /** Settings to configure messaging and mentions in the team. */
    private _messagingSettings?;
    /** The async operations that ran or are running on this team. */
    private _operations?;
    /** The general channel for the team. */
    private _primaryChannel?;
    /** The schedule of shifts for this team. */
    private _schedule?;
    /** Optional. Indicates whether the team is intended for a particular use case.  Each team specialization has access to unique behaviors and experiences targeted to its use case. */
    private _specialization?;
    /** The template this team was created from. See available templates. */
    private _template?;
    /** The visibility of the group and team. Defaults to Public. */
    private _visibility?;
    /** A hyperlink that will go to the team in the Microsoft Teams client. This is the URL that you get when you right-click a team in the Microsoft Teams client and select Get link to team. This URL should be treated as an opaque blob, and not parsed. */
    private _webUrl?;
    /**
     * Gets the channels property value. The collection of channels and messages associated with the team.
     * @returns a channel
     */
    get channels(): Channel[] | undefined;
    /**
     * Sets the channels property value. The collection of channels and messages associated with the team.
     * @param value Value to set for the channels property.
     */
    set channels(value: Channel[] | undefined);
    /**
     * Gets the classification property value. An optional label. Typically describes the data or business sensitivity of the team. Must match one of a pre-configured set in the tenant's directory.
     * @returns a string
     */
    get classification(): string | undefined;
    /**
     * Sets the classification property value. An optional label. Typically describes the data or business sensitivity of the team. Must match one of a pre-configured set in the tenant's directory.
     * @param value Value to set for the classification property.
     */
    set classification(value: string | undefined);
    /**
     * Instantiates a new team and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Timestamp at which the team was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Timestamp at which the team was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. An optional description for the team. Maximum length: 1024 characters.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. An optional description for the team. Maximum length: 1024 characters.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. The name of the team.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the team.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the funSettings property value. Settings to configure use of Giphy, memes, and stickers in the team.
     * @returns a teamFunSettings
     */
    get funSettings(): TeamFunSettings | undefined;
    /**
     * Sets the funSettings property value. Settings to configure use of Giphy, memes, and stickers in the team.
     * @param value Value to set for the funSettings property.
     */
    set funSettings(value: TeamFunSettings | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the group property value. The group property
     * @returns a group
     */
    get group(): Group | undefined;
    /**
     * Sets the group property value. The group property
     * @param value Value to set for the group property.
     */
    set group(value: Group | undefined);
    /**
     * Gets the guestSettings property value. Settings to configure whether guests can create, update, or delete channels in the team.
     * @returns a teamGuestSettings
     */
    get guestSettings(): TeamGuestSettings | undefined;
    /**
     * Sets the guestSettings property value. Settings to configure whether guests can create, update, or delete channels in the team.
     * @param value Value to set for the guestSettings property.
     */
    set guestSettings(value: TeamGuestSettings | undefined);
    /**
     * Gets the installedApps property value. The apps installed in this team.
     * @returns a teamsAppInstallation
     */
    get installedApps(): TeamsAppInstallation[] | undefined;
    /**
     * Sets the installedApps property value. The apps installed in this team.
     * @param value Value to set for the installedApps property.
     */
    set installedApps(value: TeamsAppInstallation[] | undefined);
    /**
     * Gets the internalId property value. A unique ID for the team that has been used in a few places such as the audit log/Office 365 Management Activity API.
     * @returns a string
     */
    get internalId(): string | undefined;
    /**
     * Sets the internalId property value. A unique ID for the team that has been used in a few places such as the audit log/Office 365 Management Activity API.
     * @param value Value to set for the internalId property.
     */
    set internalId(value: string | undefined);
    /**
     * Gets the isArchived property value. Whether this team is in read-only mode.
     * @returns a boolean
     */
    get isArchived(): boolean | undefined;
    /**
     * Sets the isArchived property value. Whether this team is in read-only mode.
     * @param value Value to set for the isArchived property.
     */
    set isArchived(value: boolean | undefined);
    /**
     * Gets the members property value. Members and owners of the team.
     * @returns a conversationMember
     */
    get members(): ConversationMember[] | undefined;
    /**
     * Sets the members property value. Members and owners of the team.
     * @param value Value to set for the members property.
     */
    set members(value: ConversationMember[] | undefined);
    /**
     * Gets the memberSettings property value. Settings to configure whether members can perform certain actions, for example, create channels and add bots, in the team.
     * @returns a teamMemberSettings
     */
    get memberSettings(): TeamMemberSettings | undefined;
    /**
     * Sets the memberSettings property value. Settings to configure whether members can perform certain actions, for example, create channels and add bots, in the team.
     * @param value Value to set for the memberSettings property.
     */
    set memberSettings(value: TeamMemberSettings | undefined);
    /**
     * Gets the messagingSettings property value. Settings to configure messaging and mentions in the team.
     * @returns a teamMessagingSettings
     */
    get messagingSettings(): TeamMessagingSettings | undefined;
    /**
     * Sets the messagingSettings property value. Settings to configure messaging and mentions in the team.
     * @param value Value to set for the messagingSettings property.
     */
    set messagingSettings(value: TeamMessagingSettings | undefined);
    /**
     * Gets the operations property value. The async operations that ran or are running on this team.
     * @returns a teamsAsyncOperation
     */
    get operations(): TeamsAsyncOperation[] | undefined;
    /**
     * Sets the operations property value. The async operations that ran or are running on this team.
     * @param value Value to set for the operations property.
     */
    set operations(value: TeamsAsyncOperation[] | undefined);
    /**
     * Gets the primaryChannel property value. The general channel for the team.
     * @returns a channel
     */
    get primaryChannel(): Channel | undefined;
    /**
     * Sets the primaryChannel property value. The general channel for the team.
     * @param value Value to set for the primaryChannel property.
     */
    set primaryChannel(value: Channel | undefined);
    /**
     * Gets the schedule property value. The schedule of shifts for this team.
     * @returns a schedule
     */
    get schedule(): Schedule | undefined;
    /**
     * Sets the schedule property value. The schedule of shifts for this team.
     * @param value Value to set for the schedule property.
     */
    set schedule(value: Schedule | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the specialization property value. Optional. Indicates whether the team is intended for a particular use case.  Each team specialization has access to unique behaviors and experiences targeted to its use case.
     * @returns a teamSpecialization
     */
    get specialization(): TeamSpecialization | undefined;
    /**
     * Sets the specialization property value. Optional. Indicates whether the team is intended for a particular use case.  Each team specialization has access to unique behaviors and experiences targeted to its use case.
     * @param value Value to set for the specialization property.
     */
    set specialization(value: TeamSpecialization | undefined);
    /**
     * Gets the template property value. The template this team was created from. See available templates.
     * @returns a teamsTemplate
     */
    get template(): TeamsTemplate | undefined;
    /**
     * Sets the template property value. The template this team was created from. See available templates.
     * @param value Value to set for the template property.
     */
    set template(value: TeamsTemplate | undefined);
    /**
     * Gets the visibility property value. The visibility of the group and team. Defaults to Public.
     * @returns a teamVisibilityType
     */
    get visibility(): TeamVisibilityType | undefined;
    /**
     * Sets the visibility property value. The visibility of the group and team. Defaults to Public.
     * @param value Value to set for the visibility property.
     */
    set visibility(value: TeamVisibilityType | undefined);
    /**
     * Gets the webUrl property value. A hyperlink that will go to the team in the Microsoft Teams client. This is the URL that you get when you right-click a team in the Microsoft Teams client and select Get link to team. This URL should be treated as an opaque blob, and not parsed.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. A hyperlink that will go to the team in the Microsoft Teams client. This is the URL that you get when you right-click a team in the Microsoft Teams client and select Get link to team. This URL should be treated as an opaque blob, and not parsed.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
