import { Entity, KeyValue } from '../';
import { LocalizedDescription, LocalizedLabel, Relation, Set } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class Term extends Entity implements Parsable {
    /** Children of current term. */
    private _children?;
    /** Date and time of term creation. Read-only. */
    private _createdDateTime?;
    /** Description about term that is dependent on the languageTag. */
    private _descriptions?;
    /** Label metadata for a term. */
    private _labels?;
    /** Last date and time of term modification. Read-only. */
    private _lastModifiedDateTime?;
    /** Collection of properties on the term. */
    private _properties?;
    /** To indicate which terms are related to the current term as either pinned or reused. */
    private _relations?;
    /** The [set] in which the term is created. */
    private _set?;
    /**
     * Gets the children property value. Children of current term.
     * @returns a term
     */
    get children(): Term[] | undefined;
    /**
     * Sets the children property value. Children of current term.
     * @param value Value to set for the children property.
     */
    set children(value: Term[] | undefined);
    /**
     * Instantiates a new term and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Date and time of term creation. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Date and time of term creation. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the descriptions property value. Description about term that is dependent on the languageTag.
     * @returns a localizedDescription
     */
    get descriptions(): LocalizedDescription[] | undefined;
    /**
     * Sets the descriptions property value. Description about term that is dependent on the languageTag.
     * @param value Value to set for the descriptions property.
     */
    set descriptions(value: LocalizedDescription[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the labels property value. Label metadata for a term.
     * @returns a localizedLabel
     */
    get labels(): LocalizedLabel[] | undefined;
    /**
     * Sets the labels property value. Label metadata for a term.
     * @param value Value to set for the labels property.
     */
    set labels(value: LocalizedLabel[] | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Last date and time of term modification. Read-only.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Last date and time of term modification. Read-only.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the properties property value. Collection of properties on the term.
     * @returns a keyValue
     */
    get properties(): KeyValue[] | undefined;
    /**
     * Sets the properties property value. Collection of properties on the term.
     * @param value Value to set for the properties property.
     */
    set properties(value: KeyValue[] | undefined);
    /**
     * Gets the relations property value. To indicate which terms are related to the current term as either pinned or reused.
     * @returns a relation
     */
    get relations(): Relation[] | undefined;
    /**
     * Sets the relations property value. To indicate which terms are related to the current term as either pinned or reused.
     * @param value Value to set for the relations property.
     */
    set relations(value: Relation[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the set property value. The [set] in which the term is created.
     * @returns a set
     */
    get set(): Set | undefined;
    /**
     * Sets the set property value. The [set] in which the term is created.
     * @param value Value to set for the set property.
     */
    set set(value: Set | undefined);
}
