"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TermsAndConditions = void 0;
const createTermsAndConditionsAcceptanceStatusFromDiscriminatorValue_1 = require("./createTermsAndConditionsAcceptanceStatusFromDiscriminatorValue");
const createTermsAndConditionsAssignmentFromDiscriminatorValue_1 = require("./createTermsAndConditionsAssignmentFromDiscriminatorValue");
const index_1 = require("./index");
/** A termsAndConditions entity represents the metadata and contents of a given Terms and Conditions (T&C) policy. T&C policies’ contents are presented to users upon their first attempt to enroll into Intune and subsequently upon edits where an administrator has required re-acceptance. They enable administrators to communicate the provisions to which a user must agree in order to have devices enrolled into Intune. */
class TermsAndConditions extends index_1.Entity {
    /**
     * Instantiates a new termsAndConditions and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the acceptanceStatement property value. Administrator-supplied explanation of the terms and conditions, typically describing what it means to accept the terms and conditions set out in the T&C policy. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get acceptanceStatement() {
        return this._acceptanceStatement;
    }
    ;
    /**
     * Sets the acceptanceStatement property value. Administrator-supplied explanation of the terms and conditions, typically describing what it means to accept the terms and conditions set out in the T&C policy. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the acceptanceStatement property.
     */
    set acceptanceStatement(value) {
        this._acceptanceStatement = value;
    }
    ;
    /**
     * Gets the acceptanceStatuses property value. The list of acceptance statuses for this T&C policy.
     * @returns a termsAndConditionsAcceptanceStatus
     */
    get acceptanceStatuses() {
        return this._acceptanceStatuses;
    }
    ;
    /**
     * Sets the acceptanceStatuses property value. The list of acceptance statuses for this T&C policy.
     * @param value Value to set for the acceptanceStatuses property.
     */
    set acceptanceStatuses(value) {
        this._acceptanceStatuses = value;
    }
    ;
    /**
     * Gets the assignments property value. The list of assignments for this T&C policy.
     * @returns a termsAndConditionsAssignment
     */
    get assignments() {
        return this._assignments;
    }
    ;
    /**
     * Sets the assignments property value. The list of assignments for this T&C policy.
     * @param value Value to set for the assignments property.
     */
    set assignments(value) {
        this._assignments = value;
    }
    ;
    /**
     * Gets the bodyText property value. Administrator-supplied body text of the terms and conditions, typically the terms themselves. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get bodyText() {
        return this._bodyText;
    }
    ;
    /**
     * Sets the bodyText property value. Administrator-supplied body text of the terms and conditions, typically the terms themselves. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the bodyText property.
     */
    set bodyText(value) {
        this._bodyText = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. DateTime the object was created.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. DateTime the object was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the description property value. Administrator-supplied description of the T&C policy.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Administrator-supplied description of the T&C policy.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * Gets the displayName property value. Administrator-supplied name for the T&C policy.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. Administrator-supplied name for the T&C policy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "acceptanceStatement": n => { this.acceptanceStatement = n.getStringValue(); }, "acceptanceStatuses": n => { this.acceptanceStatuses = n.getCollectionOfObjectValues(createTermsAndConditionsAcceptanceStatusFromDiscriminatorValue_1.createTermsAndConditionsAcceptanceStatusFromDiscriminatorValue); }, "assignments": n => { this.assignments = n.getCollectionOfObjectValues(createTermsAndConditionsAssignmentFromDiscriminatorValue_1.createTermsAndConditionsAssignmentFromDiscriminatorValue); }, "bodyText": n => { this.bodyText = n.getStringValue(); }, "createdDateTime": n => { this.createdDateTime = n.getDateValue(); }, "description": n => { this.description = n.getStringValue(); }, "displayName": n => { this.displayName = n.getStringValue(); }, "lastModifiedDateTime": n => { this.lastModifiedDateTime = n.getDateValue(); }, "title": n => { this.title = n.getStringValue(); }, "version": n => { this.version = n.getNumberValue(); } });
    }
    ;
    /**
     * Gets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime() {
        return this._lastModifiedDateTime;
    }
    ;
    /**
     * Sets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value) {
        this._lastModifiedDateTime = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("acceptanceStatement", this.acceptanceStatement);
        writer.writeCollectionOfObjectValues("acceptanceStatuses", this.acceptanceStatuses);
        writer.writeCollectionOfObjectValues("assignments", this.assignments);
        writer.writeStringValue("bodyText", this.bodyText);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeDateValue("lastModifiedDateTime", this.lastModifiedDateTime);
        writer.writeStringValue("title", this.title);
        writer.writeNumberValue("version", this.version);
    }
    ;
    /**
     * Gets the title property value. Administrator-supplied title of the terms and conditions. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get title() {
        return this._title;
    }
    ;
    /**
     * Sets the title property value. Administrator-supplied title of the terms and conditions. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the title property.
     */
    set title(value) {
        this._title = value;
    }
    ;
    /**
     * Gets the version property value. Integer indicating the current version of the terms. Incremented when an administrator makes a change to the terms and wishes to require users to re-accept the modified T&C policy.
     * @returns a integer
     */
    get version() {
        return this._version;
    }
    ;
    /**
     * Sets the version property value. Integer indicating the current version of the terms. Incremented when an administrator makes a change to the terms and wishes to require users to re-accept the modified T&C policy.
     * @param value Value to set for the version property.
     */
    set version(value) {
        this._version = value;
    }
    ;
}
exports.TermsAndConditions = TermsAndConditions;
