import { AppScope, DirectoryObject, Request, RequestSchedule, TicketInfo, UnifiedRoleAssignmentSchedule, UnifiedRoleDefinition, UnifiedRoleEligibilitySchedule } from './index';
import { UnifiedRoleScheduleRequestActions } from './unifiedRoleScheduleRequestActions';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the roleManagement singleton. */
export declare class UnifiedRoleAssignmentScheduleRequest extends Request implements Parsable {
    /** Represents the type of the operation on the role assignment. The possible values are: AdminAssign: For administrators to assign roles to users or groups.AdminRemove: For administrators to remove users or groups from roles. AdminUpdate: For administrators to change existing role assignments.AdminExtend: For administrators to extend expiring assignments.AdminRenew: For administrators to renew expired assignments.SelfActivate: For users to activate their assignments.SelfDeactivate: For users to deactivate their active assignments.SelfExtend: For users to request to extend their expiring assignments.SelfRenew: For users to request to renew their expired assignments. */
    private _action?;
    /** If the request is from an eligible administrator to activate a role, this parameter will show the related eligible assignment for that activation. */
    private _activatedUsing?;
    /** Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. */
    private _appScope?;
    /** Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units. */
    private _appScopeId?;
    /** Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only. */
    private _directoryScope?;
    /** Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. */
    private _directoryScopeId?;
    /** A boolean that determines whether the call is a validation or an actual call. Only set this property if you want to check whether an activation is subject to additional rules like MFA before actually submitting the request. */
    private _isValidationOnly?;
    /** A message provided by users and administrators when create the request about why it is needed. */
    private _justification?;
    /** Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only. */
    private _principal?;
    /** Identifier of the principal to which the assignment is being granted to. */
    private _principalId?;
    /** Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded. */
    private _roleDefinition?;
    /** Identifier of the unifiedRoleDefinition the assignment is for. Read only. */
    private _roleDefinitionId?;
    /** The schedule object of the role assignment request. */
    private _scheduleInfo?;
    /** Property indicating the schedule for an eligible role assignment. */
    private _targetSchedule?;
    /** Identifier of the schedule object attached to the assignment. */
    private _targetScheduleId?;
    /** The ticketInfo object attached to the role assignment request which includes details of the ticket number and ticket system. */
    private _ticketInfo?;
    /**
     * Gets the action property value. Represents the type of the operation on the role assignment. The possible values are: AdminAssign: For administrators to assign roles to users or groups.AdminRemove: For administrators to remove users or groups from roles. AdminUpdate: For administrators to change existing role assignments.AdminExtend: For administrators to extend expiring assignments.AdminRenew: For administrators to renew expired assignments.SelfActivate: For users to activate their assignments.SelfDeactivate: For users to deactivate their active assignments.SelfExtend: For users to request to extend their expiring assignments.SelfRenew: For users to request to renew their expired assignments.
     * @returns a unifiedRoleScheduleRequestActions
     */
    get action(): UnifiedRoleScheduleRequestActions | undefined;
    /**
     * Sets the action property value. Represents the type of the operation on the role assignment. The possible values are: AdminAssign: For administrators to assign roles to users or groups.AdminRemove: For administrators to remove users or groups from roles. AdminUpdate: For administrators to change existing role assignments.AdminExtend: For administrators to extend expiring assignments.AdminRenew: For administrators to renew expired assignments.SelfActivate: For users to activate their assignments.SelfDeactivate: For users to deactivate their active assignments.SelfExtend: For users to request to extend their expiring assignments.SelfRenew: For users to request to renew their expired assignments.
     * @param value Value to set for the action property.
     */
    set action(value: UnifiedRoleScheduleRequestActions | undefined);
    /**
     * Gets the activatedUsing property value. If the request is from an eligible administrator to activate a role, this parameter will show the related eligible assignment for that activation.
     * @returns a unifiedRoleEligibilitySchedule
     */
    get activatedUsing(): UnifiedRoleEligibilitySchedule | undefined;
    /**
     * Sets the activatedUsing property value. If the request is from an eligible administrator to activate a role, this parameter will show the related eligible assignment for that activation.
     * @param value Value to set for the activatedUsing property.
     */
    set activatedUsing(value: UnifiedRoleEligibilitySchedule | undefined);
    /**
     * Gets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @returns a appScope
     */
    get appScope(): AppScope | undefined;
    /**
     * Sets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @param value Value to set for the appScope property.
     */
    set appScope(value: AppScope | undefined);
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @returns a string
     */
    get appScopeId(): string | undefined;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value: string | undefined);
    /**
     * Instantiates a new unifiedRoleAssignmentScheduleRequest and sets the default values.
     */
    constructor();
    /**
     * Gets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get directoryScope(): DirectoryObject | undefined;
    /**
     * Sets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value: DirectoryObject | undefined);
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @returns a string
     */
    get directoryScopeId(): string | undefined;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isValidationOnly property value. A boolean that determines whether the call is a validation or an actual call. Only set this property if you want to check whether an activation is subject to additional rules like MFA before actually submitting the request.
     * @returns a boolean
     */
    get isValidationOnly(): boolean | undefined;
    /**
     * Sets the isValidationOnly property value. A boolean that determines whether the call is a validation or an actual call. Only set this property if you want to check whether an activation is subject to additional rules like MFA before actually submitting the request.
     * @param value Value to set for the isValidationOnly property.
     */
    set isValidationOnly(value: boolean | undefined);
    /**
     * Gets the justification property value. A message provided by users and administrators when create the request about why it is needed.
     * @returns a string
     */
    get justification(): string | undefined;
    /**
     * Sets the justification property value. A message provided by users and administrators when create the request about why it is needed.
     * @param value Value to set for the justification property.
     */
    set justification(value: string | undefined);
    /**
     * Gets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get principal(): DirectoryObject | undefined;
    /**
     * Sets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the principal property.
     */
    set principal(value: DirectoryObject | undefined);
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is being granted to.
     * @returns a string
     */
    get principalId(): string | undefined;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is being granted to.
     * @param value Value to set for the principalId property.
     */
    set principalId(value: string | undefined);
    /**
     * Gets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition(): UnifiedRoleDefinition | undefined;
    /**
     * Sets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value: UnifiedRoleDefinition | undefined);
    /**
     * Gets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.
     * @returns a string
     */
    get roleDefinitionId(): string | undefined;
    /**
     * Sets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value: string | undefined);
    /**
     * Gets the scheduleInfo property value. The schedule object of the role assignment request.
     * @returns a requestSchedule
     */
    get scheduleInfo(): RequestSchedule | undefined;
    /**
     * Sets the scheduleInfo property value. The schedule object of the role assignment request.
     * @param value Value to set for the scheduleInfo property.
     */
    set scheduleInfo(value: RequestSchedule | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the targetSchedule property value. Property indicating the schedule for an eligible role assignment.
     * @returns a unifiedRoleAssignmentSchedule
     */
    get targetSchedule(): UnifiedRoleAssignmentSchedule | undefined;
    /**
     * Sets the targetSchedule property value. Property indicating the schedule for an eligible role assignment.
     * @param value Value to set for the targetSchedule property.
     */
    set targetSchedule(value: UnifiedRoleAssignmentSchedule | undefined);
    /**
     * Gets the targetScheduleId property value. Identifier of the schedule object attached to the assignment.
     * @returns a string
     */
    get targetScheduleId(): string | undefined;
    /**
     * Sets the targetScheduleId property value. Identifier of the schedule object attached to the assignment.
     * @param value Value to set for the targetScheduleId property.
     */
    set targetScheduleId(value: string | undefined);
    /**
     * Gets the ticketInfo property value. The ticketInfo object attached to the role assignment request which includes details of the ticket number and ticket system.
     * @returns a ticketInfo
     */
    get ticketInfo(): TicketInfo | undefined;
    /**
     * Sets the ticketInfo property value. The ticketInfo object attached to the role assignment request which includes details of the ticket number and ticket system.
     * @param value Value to set for the ticketInfo property.
     */
    set ticketInfo(value: TicketInfo | undefined);
}
