"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnifiedRoleEligibilityScheduleRequest = void 0;
const createAppScopeFromDiscriminatorValue_1 = require("./createAppScopeFromDiscriminatorValue");
const createDirectoryObjectFromDiscriminatorValue_1 = require("./createDirectoryObjectFromDiscriminatorValue");
const createRequestScheduleFromDiscriminatorValue_1 = require("./createRequestScheduleFromDiscriminatorValue");
const createTicketInfoFromDiscriminatorValue_1 = require("./createTicketInfoFromDiscriminatorValue");
const createUnifiedRoleDefinitionFromDiscriminatorValue_1 = require("./createUnifiedRoleDefinitionFromDiscriminatorValue");
const createUnifiedRoleEligibilityScheduleFromDiscriminatorValue_1 = require("./createUnifiedRoleEligibilityScheduleFromDiscriminatorValue");
const index_1 = require("./index");
const unifiedRoleScheduleRequestActions_1 = require("./unifiedRoleScheduleRequestActions");
/** Provides operations to manage the roleManagement singleton. */
class UnifiedRoleEligibilityScheduleRequest extends index_1.Request {
    /**
     * Instantiates a new unifiedRoleEligibilityScheduleRequest and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the action property value. Represents the type of the operation on the role eligibility assignment. The possible values are: AdminAssign: For administrators to assign role eligibility to users or groups to roles.AdminExtend: For administrators to extend expiring assignments.AdminUpdate: For administrators to change existing role assignments.AdminRenew: For administrators to renew expired assignments.AdminRemove: For administrators to remove users or groups from eligible roles.UserAdd: For users to activate their eligible assignments.UserExtend: For users to request to extend their expiring eligible assignments.UserRemove: For users to deactivate their active eligible assignments.UserRenew: For users to request to renew their expired eligible assignments.
     * @returns a unifiedRoleScheduleRequestActions
     */
    get action() {
        return this._action;
    }
    ;
    /**
     * Sets the action property value. Represents the type of the operation on the role eligibility assignment. The possible values are: AdminAssign: For administrators to assign role eligibility to users or groups to roles.AdminExtend: For administrators to extend expiring assignments.AdminUpdate: For administrators to change existing role assignments.AdminRenew: For administrators to renew expired assignments.AdminRemove: For administrators to remove users or groups from eligible roles.UserAdd: For users to activate their eligible assignments.UserExtend: For users to request to extend their expiring eligible assignments.UserRemove: For users to deactivate their active eligible assignments.UserRenew: For users to request to renew their expired eligible assignments.
     * @param value Value to set for the action property.
     */
    set action(value) {
        this._action = value;
    }
    ;
    /**
     * Gets the appScope property value. Read-only property with details of the app-specific scope when the assignment scope is app-specific. Containment entity.
     * @returns a appScope
     */
    get appScope() {
        return this._appScope;
    }
    ;
    /**
     * Sets the appScope property value. Read-only property with details of the app-specific scope when the assignment scope is app-specific. Containment entity.
     * @param value Value to set for the appScope property.
     */
    set appScope(value) {
        this._appScope = value;
    }
    ;
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @returns a string
     */
    get appScopeId() {
        return this._appScopeId;
    }
    ;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value) {
        this._appScopeId = value;
    }
    ;
    ;
    /**
     * Gets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get directoryScope() {
        return this._directoryScope;
    }
    ;
    /**
     * Sets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value) {
        this._directoryScope = value;
    }
    ;
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @returns a string
     */
    get directoryScopeId() {
        return this._directoryScopeId;
    }
    ;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value) {
        this._directoryScopeId = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "action": n => { this.action = n.getEnumValue(unifiedRoleScheduleRequestActions_1.UnifiedRoleScheduleRequestActions); }, "appScope": n => { this.appScope = n.getObjectValue(createAppScopeFromDiscriminatorValue_1.createAppScopeFromDiscriminatorValue); }, "appScopeId": n => { this.appScopeId = n.getStringValue(); }, "directoryScope": n => { this.directoryScope = n.getObjectValue(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "directoryScopeId": n => { this.directoryScopeId = n.getStringValue(); }, "isValidationOnly": n => { this.isValidationOnly = n.getBooleanValue(); }, "justification": n => { this.justification = n.getStringValue(); }, "principal": n => { this.principal = n.getObjectValue(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "principalId": n => { this.principalId = n.getStringValue(); }, "roleDefinition": n => { this.roleDefinition = n.getObjectValue(createUnifiedRoleDefinitionFromDiscriminatorValue_1.createUnifiedRoleDefinitionFromDiscriminatorValue); }, "roleDefinitionId": n => { this.roleDefinitionId = n.getStringValue(); }, "scheduleInfo": n => { this.scheduleInfo = n.getObjectValue(createRequestScheduleFromDiscriminatorValue_1.createRequestScheduleFromDiscriminatorValue); }, "targetSchedule": n => { this.targetSchedule = n.getObjectValue(createUnifiedRoleEligibilityScheduleFromDiscriminatorValue_1.createUnifiedRoleEligibilityScheduleFromDiscriminatorValue); }, "targetScheduleId": n => { this.targetScheduleId = n.getStringValue(); }, "ticketInfo": n => { this.ticketInfo = n.getObjectValue(createTicketInfoFromDiscriminatorValue_1.createTicketInfoFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the isValidationOnly property value. A boolean that determines whether the call is a validation or an actual call. Only set this property if you want to check whether an activation is subject to additional rules like MFA before actually submitting the request.
     * @returns a boolean
     */
    get isValidationOnly() {
        return this._isValidationOnly;
    }
    ;
    /**
     * Sets the isValidationOnly property value. A boolean that determines whether the call is a validation or an actual call. Only set this property if you want to check whether an activation is subject to additional rules like MFA before actually submitting the request.
     * @param value Value to set for the isValidationOnly property.
     */
    set isValidationOnly(value) {
        this._isValidationOnly = value;
    }
    ;
    /**
     * Gets the justification property value. A message provided by users and administrators when create the request about why it is needed.
     * @returns a string
     */
    get justification() {
        return this._justification;
    }
    ;
    /**
     * Sets the justification property value. A message provided by users and administrators when create the request about why it is needed.
     * @param value Value to set for the justification property.
     */
    set justification(value) {
        this._justification = value;
    }
    ;
    /**
     * Gets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get principal() {
        return this._principal;
    }
    ;
    /**
     * Sets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the principal property.
     */
    set principal(value) {
        this._principal = value;
    }
    ;
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is being granted to. For example, a user or a group. For groups, they must be assignable to roles, that is, the isAssignableToRole of the group property set to true.
     * @returns a string
     */
    get principalId() {
        return this._principalId;
    }
    ;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is being granted to. For example, a user or a group. For groups, they must be assignable to roles, that is, the isAssignableToRole of the group property set to true.
     * @param value Value to set for the principalId property.
     */
    set principalId(value) {
        this._principalId = value;
    }
    ;
    /**
     * Gets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition() {
        return this._roleDefinition;
    }
    ;
    /**
     * Sets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value) {
        this._roleDefinition = value;
    }
    ;
    /**
     * Gets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.
     * @returns a string
     */
    get roleDefinitionId() {
        return this._roleDefinitionId;
    }
    ;
    /**
     * Sets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value) {
        this._roleDefinitionId = value;
    }
    ;
    /**
     * Gets the scheduleInfo property value. The schedule object of the role assignment request.
     * @returns a requestSchedule
     */
    get scheduleInfo() {
        return this._scheduleInfo;
    }
    ;
    /**
     * Sets the scheduleInfo property value. The schedule object of the role assignment request.
     * @param value Value to set for the scheduleInfo property.
     */
    set scheduleInfo(value) {
        this._scheduleInfo = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("action", this.action);
        writer.writeObjectValue("appScope", this.appScope);
        writer.writeStringValue("appScopeId", this.appScopeId);
        writer.writeObjectValue("directoryScope", this.directoryScope);
        writer.writeStringValue("directoryScopeId", this.directoryScopeId);
        writer.writeBooleanValue("isValidationOnly", this.isValidationOnly);
        writer.writeStringValue("justification", this.justification);
        writer.writeObjectValue("principal", this.principal);
        writer.writeStringValue("principalId", this.principalId);
        writer.writeObjectValue("roleDefinition", this.roleDefinition);
        writer.writeStringValue("roleDefinitionId", this.roleDefinitionId);
        writer.writeObjectValue("scheduleInfo", this.scheduleInfo);
        writer.writeObjectValue("targetSchedule", this.targetSchedule);
        writer.writeStringValue("targetScheduleId", this.targetScheduleId);
        writer.writeObjectValue("ticketInfo", this.ticketInfo);
    }
    ;
    /**
     * Gets the targetSchedule property value. Property indicating the schedule for an eligible role assignment.
     * @returns a unifiedRoleEligibilitySchedule
     */
    get targetSchedule() {
        return this._targetSchedule;
    }
    ;
    /**
     * Sets the targetSchedule property value. Property indicating the schedule for an eligible role assignment.
     * @param value Value to set for the targetSchedule property.
     */
    set targetSchedule(value) {
        this._targetSchedule = value;
    }
    ;
    /**
     * Gets the targetScheduleId property value. The time period for which the eligibility assignment is valid.
     * @returns a string
     */
    get targetScheduleId() {
        return this._targetScheduleId;
    }
    ;
    /**
     * Sets the targetScheduleId property value. The time period for which the eligibility assignment is valid.
     * @param value Value to set for the targetScheduleId property.
     */
    set targetScheduleId(value) {
        this._targetScheduleId = value;
    }
    ;
    /**
     * Gets the ticketInfo property value. The details of the ticket number and ticket system that is attached to the role assignment request.
     * @returns a ticketInfo
     */
    get ticketInfo() {
        return this._ticketInfo;
    }
    ;
    /**
     * Sets the ticketInfo property value. The details of the ticket number and ticket system that is attached to the role assignment request.
     * @param value Value to set for the ticketInfo property.
     */
    set ticketInfo(value) {
        this._ticketInfo = value;
    }
    ;
}
exports.UnifiedRoleEligibilityScheduleRequest = UnifiedRoleEligibilityScheduleRequest;
