import { Entity, Identity, UnifiedRoleManagementPolicyRule } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the policyRoot singleton. */
export declare class UnifiedRoleManagementPolicy extends Entity implements Parsable {
    /** Description for the policy. */
    private _description?;
    /** Display name for the policy. */
    private _displayName?;
    /** Not implemented. The list of effective rules like approval rules and expiration rules evaluated based on inherited referenced rules. For example, if there is a tenant-wide policy to enforce enabling an approval rule, the effective rule will be to enable approval even if the policy has a rule to disable approval. */
    private _effectiveRules?;
    /** This can only be set to true for a single tenant wide policy which will apply to all scopes and roles. Set the scopeId to '/' and scopeType to Directory. */
    private _isOrganizationDefault?;
    /** The identity who last modified the role setting. */
    private _lastModifiedBy?;
    /** The time when the role setting was last modified. */
    private _lastModifiedDateTime?;
    /** The collection of rules like approval rules and expiration rules. */
    private _rules?;
    /** The id of the scope where the policy is created. Can be / for the tenant or a group ID. Required. */
    private _scopeId?;
    /** The type of the scope where the policy is created. One of Directory, DirectoryRole. Required. */
    private _scopeType?;
    /**
     * Instantiates a new unifiedRoleManagementPolicy and sets the default values.
     */
    constructor();
    /**
     * Gets the description property value. Description for the policy.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Description for the policy.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. Display name for the policy.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Display name for the policy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the effectiveRules property value. Not implemented. The list of effective rules like approval rules and expiration rules evaluated based on inherited referenced rules. For example, if there is a tenant-wide policy to enforce enabling an approval rule, the effective rule will be to enable approval even if the policy has a rule to disable approval.
     * @returns a unifiedRoleManagementPolicyRule
     */
    get effectiveRules(): UnifiedRoleManagementPolicyRule[] | undefined;
    /**
     * Sets the effectiveRules property value. Not implemented. The list of effective rules like approval rules and expiration rules evaluated based on inherited referenced rules. For example, if there is a tenant-wide policy to enforce enabling an approval rule, the effective rule will be to enable approval even if the policy has a rule to disable approval.
     * @param value Value to set for the effectiveRules property.
     */
    set effectiveRules(value: UnifiedRoleManagementPolicyRule[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isOrganizationDefault property value. This can only be set to true for a single tenant wide policy which will apply to all scopes and roles. Set the scopeId to '/' and scopeType to Directory.
     * @returns a boolean
     */
    get isOrganizationDefault(): boolean | undefined;
    /**
     * Sets the isOrganizationDefault property value. This can only be set to true for a single tenant wide policy which will apply to all scopes and roles. Set the scopeId to '/' and scopeType to Directory.
     * @param value Value to set for the isOrganizationDefault property.
     */
    set isOrganizationDefault(value: boolean | undefined);
    /**
     * Gets the lastModifiedBy property value. The identity who last modified the role setting.
     * @returns a identity
     */
    get lastModifiedBy(): Identity | undefined;
    /**
     * Sets the lastModifiedBy property value. The identity who last modified the role setting.
     * @param value Value to set for the lastModifiedBy property.
     */
    set lastModifiedBy(value: Identity | undefined);
    /**
     * Gets the lastModifiedDateTime property value. The time when the role setting was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The time when the role setting was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the rules property value. The collection of rules like approval rules and expiration rules.
     * @returns a unifiedRoleManagementPolicyRule
     */
    get rules(): UnifiedRoleManagementPolicyRule[] | undefined;
    /**
     * Sets the rules property value. The collection of rules like approval rules and expiration rules.
     * @param value Value to set for the rules property.
     */
    set rules(value: UnifiedRoleManagementPolicyRule[] | undefined);
    /**
     * Gets the scopeId property value. The id of the scope where the policy is created. Can be / for the tenant or a group ID. Required.
     * @returns a string
     */
    get scopeId(): string | undefined;
    /**
     * Sets the scopeId property value. The id of the scope where the policy is created. Can be / for the tenant or a group ID. Required.
     * @param value Value to set for the scopeId property.
     */
    set scopeId(value: string | undefined);
    /**
     * Gets the scopeType property value. The type of the scope where the policy is created. One of Directory, DirectoryRole. Required.
     * @returns a string
     */
    get scopeType(): string | undefined;
    /**
     * Sets the scopeType property value. The type of the scope where the policy is created. One of Directory, DirectoryRole. Required.
     * @param value Value to set for the scopeType property.
     */
    set scopeType(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
