import { AppScope, DirectoryObject, Entity, UnifiedRoleDefinition } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the roleManagement singleton. */
export declare class UnifiedRoleScheduleBase extends Entity implements Parsable {
    /** Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. */
    private _appScope?;
    /** Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units or all users. */
    private _appScopeId?;
    /** Time that the schedule was created. */
    private _createdDateTime?;
    /** Identifier of the roleAssignmentScheduleRequest that created this schedule. */
    private _createdUsing?;
    /** Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only. */
    private _directoryScope?;
    /** Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. */
    private _directoryScopeId?;
    /** Last time the schedule was updated. */
    private _modifiedDateTime?;
    /** Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only. */
    private _principal?;
    /** Identifier of the principal to which the assignment is being granted to. Supports $filter (eq). */
    private _principalId?;
    /** Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded. */
    private _roleDefinition?;
    /** Identifier of the unifiedRoleDefinition the assignment is for. Read only. Supports $filter (eq). */
    private _roleDefinitionId?;
    /** Status for the roleAssignmentSchedule. It can include state related messages like Provisioned, Revoked, Pending Provisioning, and Pending Approval. Supports $filter (eq). */
    private _status?;
    /**
     * Gets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @returns a appScope
     */
    get appScope(): AppScope | undefined;
    /**
     * Sets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @param value Value to set for the appScope property.
     */
    set appScope(value: AppScope | undefined);
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units or all users.
     * @returns a string
     */
    get appScopeId(): string | undefined;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units or all users.
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value: string | undefined);
    /**
     * Instantiates a new unifiedRoleScheduleBase and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Time that the schedule was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Time that the schedule was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the createdUsing property value. Identifier of the roleAssignmentScheduleRequest that created this schedule.
     * @returns a string
     */
    get createdUsing(): string | undefined;
    /**
     * Sets the createdUsing property value. Identifier of the roleAssignmentScheduleRequest that created this schedule.
     * @param value Value to set for the createdUsing property.
     */
    set createdUsing(value: string | undefined);
    /**
     * Gets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get directoryScope(): DirectoryObject | undefined;
    /**
     * Sets the directoryScope property value. Property referencing the directory object that is the scope of the assignment. Provided so that callers can get the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value: DirectoryObject | undefined);
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @returns a string
     */
    get directoryScopeId(): string | undefined;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the modifiedDateTime property value. Last time the schedule was updated.
     * @returns a Date
     */
    get modifiedDateTime(): Date | undefined;
    /**
     * Sets the modifiedDateTime property value. Last time the schedule was updated.
     * @param value Value to set for the modifiedDateTime property.
     */
    set modifiedDateTime(value: Date | undefined);
    /**
     * Gets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get principal(): DirectoryObject | undefined;
    /**
     * Sets the principal property value. Property referencing the principal that is getting a role assignment through the request. Provided so that callers can get the principal using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the principal property.
     */
    set principal(value: DirectoryObject | undefined);
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is being granted to. Supports $filter (eq).
     * @returns a string
     */
    get principalId(): string | undefined;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is being granted to. Supports $filter (eq).
     * @param value Value to set for the principalId property.
     */
    set principalId(value: string | undefined);
    /**
     * Gets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition(): UnifiedRoleDefinition | undefined;
    /**
     * Sets the roleDefinition property value. Property indicating the roleDefinition the assignment is for. Provided so that callers can get the role definition using $expand at the same time as getting the role assignment. roleDefinition.Id will be auto expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value: UnifiedRoleDefinition | undefined);
    /**
     * Gets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only. Supports $filter (eq).
     * @returns a string
     */
    get roleDefinitionId(): string | undefined;
    /**
     * Sets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only. Supports $filter (eq).
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. Status for the roleAssignmentSchedule. It can include state related messages like Provisioned, Revoked, Pending Provisioning, and Pending Approval. Supports $filter (eq).
     * @returns a string
     */
    get status(): string | undefined;
    /**
     * Sets the status property value. Status for the roleAssignmentSchedule. It can include state related messages like Provisioned, Revoked, Pending Provisioning, and Pending Approval. Supports $filter (eq).
     * @param value Value to set for the status property.
     */
    set status(value: string | undefined);
}
