import { AppScope, DirectoryObject, Entity, UnifiedRoleDefinition } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the roleManagement singleton. */
export declare class UnifiedRoleScheduleInstanceBase extends Entity implements Parsable {
    /** Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. */
    private _appScope?;
    /** Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units. */
    private _appScopeId?;
    /** The directory object that is the scope of the assignment. Enables the retrieval of the directory object using $expand at the same time as getting the role assignment. Read-only. */
    private _directoryScope?;
    /** Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. */
    private _directoryScopeId?;
    /** The principal that is getting a role assignment through the request. Enables the retrieval of the principal using $expand at the same time as getting the role assignment. Read-only. */
    private _principal?;
    /** Identifier of the principal to which the assignment is being granted to. Can be a group or a user. */
    private _principalId?;
    /** The roleDefinition for the assignment. Enables the retrieval of the role definition using $expand at the same time as getting the role assignment. The roleDefinition.Id is automatically expanded. */
    private _roleDefinition?;
    /** Identifier of the unifiedRoleDefinition the assignment is for. Read only.  Supports $filter (eq). */
    private _roleDefinitionId?;
    /**
     * Gets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @returns a appScope
     */
    get appScope(): AppScope | undefined;
    /**
     * Sets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @param value Value to set for the appScope property.
     */
    set appScope(value: AppScope | undefined);
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @returns a string
     */
    get appScopeId(): string | undefined;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value: string | undefined);
    /**
     * Instantiates a new unifiedRoleScheduleInstanceBase and sets the default values.
     */
    constructor();
    /**
     * Gets the directoryScope property value. The directory object that is the scope of the assignment. Enables the retrieval of the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get directoryScope(): DirectoryObject | undefined;
    /**
     * Sets the directoryScope property value. The directory object that is the scope of the assignment. Enables the retrieval of the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value: DirectoryObject | undefined);
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @returns a string
     */
    get directoryScopeId(): string | undefined;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the principal property value. The principal that is getting a role assignment through the request. Enables the retrieval of the principal using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get principal(): DirectoryObject | undefined;
    /**
     * Sets the principal property value. The principal that is getting a role assignment through the request. Enables the retrieval of the principal using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the principal property.
     */
    set principal(value: DirectoryObject | undefined);
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is being granted to. Can be a group or a user.
     * @returns a string
     */
    get principalId(): string | undefined;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is being granted to. Can be a group or a user.
     * @param value Value to set for the principalId property.
     */
    set principalId(value: string | undefined);
    /**
     * Gets the roleDefinition property value. The roleDefinition for the assignment. Enables the retrieval of the role definition using $expand at the same time as getting the role assignment. The roleDefinition.Id is automatically expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition(): UnifiedRoleDefinition | undefined;
    /**
     * Sets the roleDefinition property value. The roleDefinition for the assignment. Enables the retrieval of the role definition using $expand at the same time as getting the role assignment. The roleDefinition.Id is automatically expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value: UnifiedRoleDefinition | undefined);
    /**
     * Gets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.  Supports $filter (eq).
     * @returns a string
     */
    get roleDefinitionId(): string | undefined;
    /**
     * Sets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.  Supports $filter (eq).
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
