"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnifiedRoleScheduleInstanceBase = void 0;
const createAppScopeFromDiscriminatorValue_1 = require("./createAppScopeFromDiscriminatorValue");
const createDirectoryObjectFromDiscriminatorValue_1 = require("./createDirectoryObjectFromDiscriminatorValue");
const createUnifiedRoleDefinitionFromDiscriminatorValue_1 = require("./createUnifiedRoleDefinitionFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the roleManagement singleton. */
class UnifiedRoleScheduleInstanceBase extends index_1.Entity {
    /**
     * Instantiates a new unifiedRoleScheduleInstanceBase and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @returns a appScope
     */
    get appScope() {
        return this._appScope;
    }
    ;
    /**
     * Sets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity.
     * @param value Value to set for the appScope property.
     */
    set appScope(value) {
        this._appScope = value;
    }
    ;
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @returns a string
     */
    get appScopeId() {
        return this._appScopeId;
    }
    ;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific. The scope of an assignment determines the set of resources for which the principal has been granted access. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units.
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value) {
        this._appScopeId = value;
    }
    ;
    ;
    /**
     * Gets the directoryScope property value. The directory object that is the scope of the assignment. Enables the retrieval of the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get directoryScope() {
        return this._directoryScope;
    }
    ;
    /**
     * Sets the directoryScope property value. The directory object that is the scope of the assignment. Enables the retrieval of the directory object using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value) {
        this._directoryScope = value;
    }
    ;
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @returns a string
     */
    get directoryScopeId() {
        return this._directoryScopeId;
    }
    ;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only.
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value) {
        this._directoryScopeId = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appScope": n => { this.appScope = n.getObjectValue(createAppScopeFromDiscriminatorValue_1.createAppScopeFromDiscriminatorValue); }, "appScopeId": n => { this.appScopeId = n.getStringValue(); }, "directoryScope": n => { this.directoryScope = n.getObjectValue(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "directoryScopeId": n => { this.directoryScopeId = n.getStringValue(); }, "principal": n => { this.principal = n.getObjectValue(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "principalId": n => { this.principalId = n.getStringValue(); }, "roleDefinition": n => { this.roleDefinition = n.getObjectValue(createUnifiedRoleDefinitionFromDiscriminatorValue_1.createUnifiedRoleDefinitionFromDiscriminatorValue); }, "roleDefinitionId": n => { this.roleDefinitionId = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the principal property value. The principal that is getting a role assignment through the request. Enables the retrieval of the principal using $expand at the same time as getting the role assignment. Read-only.
     * @returns a directoryObject
     */
    get principal() {
        return this._principal;
    }
    ;
    /**
     * Sets the principal property value. The principal that is getting a role assignment through the request. Enables the retrieval of the principal using $expand at the same time as getting the role assignment. Read-only.
     * @param value Value to set for the principal property.
     */
    set principal(value) {
        this._principal = value;
    }
    ;
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is being granted to. Can be a group or a user.
     * @returns a string
     */
    get principalId() {
        return this._principalId;
    }
    ;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is being granted to. Can be a group or a user.
     * @param value Value to set for the principalId property.
     */
    set principalId(value) {
        this._principalId = value;
    }
    ;
    /**
     * Gets the roleDefinition property value. The roleDefinition for the assignment. Enables the retrieval of the role definition using $expand at the same time as getting the role assignment. The roleDefinition.Id is automatically expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition() {
        return this._roleDefinition;
    }
    ;
    /**
     * Sets the roleDefinition property value. The roleDefinition for the assignment. Enables the retrieval of the role definition using $expand at the same time as getting the role assignment. The roleDefinition.Id is automatically expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value) {
        this._roleDefinition = value;
    }
    ;
    /**
     * Gets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.  Supports $filter (eq).
     * @returns a string
     */
    get roleDefinitionId() {
        return this._roleDefinitionId;
    }
    ;
    /**
     * Sets the roleDefinitionId property value. Identifier of the unifiedRoleDefinition the assignment is for. Read only.  Supports $filter (eq).
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value) {
        this._roleDefinitionId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("appScope", this.appScope);
        writer.writeStringValue("appScopeId", this.appScopeId);
        writer.writeObjectValue("directoryScope", this.directoryScope);
        writer.writeStringValue("directoryScopeId", this.directoryScopeId);
        writer.writeObjectValue("principal", this.principal);
        writer.writeStringValue("principalId", this.principalId);
        writer.writeObjectValue("roleDefinition", this.roleDefinition);
        writer.writeStringValue("roleDefinitionId", this.roleDefinitionId);
    }
    ;
}
exports.UnifiedRoleScheduleInstanceBase = UnifiedRoleScheduleInstanceBase;
