import { Entity, UserFlowLanguagePage } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityContainer singleton. */
export declare class UserFlowLanguageConfiguration extends Entity implements Parsable {
    /** Collection of pages with the default content to display in a user flow for a specified language. This collection does not allow any kind of modification. */
    private _defaultPages?;
    /** The language name to display. This property is read-only. */
    private _displayName?;
    /** Indicates whether the language is enabled within the user flow. */
    private _isEnabled?;
    /** Collection of pages with the overrides messages to display in a user flow for a specified language. This collection only allows to modify the content of the page, any other modification is not allowed (creation or deletion of pages). */
    private _overridesPages?;
    /**
     * Instantiates a new userFlowLanguageConfiguration and sets the default values.
     */
    constructor();
    /**
     * Gets the defaultPages property value. Collection of pages with the default content to display in a user flow for a specified language. This collection does not allow any kind of modification.
     * @returns a userFlowLanguagePage
     */
    get defaultPages(): UserFlowLanguagePage[] | undefined;
    /**
     * Sets the defaultPages property value. Collection of pages with the default content to display in a user flow for a specified language. This collection does not allow any kind of modification.
     * @param value Value to set for the defaultPages property.
     */
    set defaultPages(value: UserFlowLanguagePage[] | undefined);
    /**
     * Gets the displayName property value. The language name to display. This property is read-only.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The language name to display. This property is read-only.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isEnabled property value. Indicates whether the language is enabled within the user flow.
     * @returns a boolean
     */
    get isEnabled(): boolean | undefined;
    /**
     * Sets the isEnabled property value. Indicates whether the language is enabled within the user flow.
     * @param value Value to set for the isEnabled property.
     */
    set isEnabled(value: boolean | undefined);
    /**
     * Gets the overridesPages property value. Collection of pages with the overrides messages to display in a user flow for a specified language. This collection only allows to modify the content of the page, any other modification is not allowed (creation or deletion of pages).
     * @returns a userFlowLanguagePage
     */
    get overridesPages(): UserFlowLanguagePage[] | undefined;
    /**
     * Sets the overridesPages property value. Collection of pages with the overrides messages to display in a user flow for a specified language. This collection only allows to modify the content of the page, any other modification is not allowed (creation or deletion of pages).
     * @param value Value to set for the overridesPages property.
     */
    set overridesPages(value: UserFlowLanguagePage[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
