import { EmailRole } from './emailRole';
import { LogonType } from './logonType';
import { UserAccountSecurityType } from './userAccountSecurityType';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class UserSecurityState implements AdditionalDataHolder, Parsable {
    /** AAD User object identifier (GUID) - represents the physical/multi-account user entity. */
    private _aadUserId?;
    /** Account name of user account (without Active Directory domain or DNS domain) - (also called mailNickName). */
    private _accountName?;
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well. */
    private _additionalData;
    /** NetBIOS/Active Directory domain of user account (that is, domain/account format). */
    private _domainName?;
    /** For email-related alerts - user account's email 'role'. Possible values are: unknown, sender, recipient. */
    private _emailRole?;
    /** Indicates whether the user logged on through a VPN. */
    private _isVpn?;
    /** Time at which the sign-in occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. */
    private _logonDateTime?;
    /** User sign-in ID. */
    private _logonId?;
    /** IP Address the sign-in request originated from. */
    private _logonIp?;
    /** Location (by IP address mapping) associated with a user sign-in event by this user. */
    private _logonLocation?;
    /** Method of user sign in. Possible values are: unknown, interactive, remoteInteractive, network, batch, service. */
    private _logonType?;
    /** Active Directory (on-premises) Security Identifier (SID) of the user. */
    private _onPremisesSecurityIdentifier?;
    /** Provider-generated/calculated risk score of the user account. Recommended value range of 0-1, which equates to a percentage. */
    private _riskScore?;
    /** User account type (group membership), per Windows definition. Possible values are: unknown, standard, power, administrator. */
    private _userAccountType?;
    /** User sign-in name - internet format: (user account name)@(user account DNS domain name). */
    private _userPrincipalName?;
    /**
     * Gets the aadUserId property value. AAD User object identifier (GUID) - represents the physical/multi-account user entity.
     * @returns a string
     */
    get aadUserId(): string | undefined;
    /**
     * Sets the aadUserId property value. AAD User object identifier (GUID) - represents the physical/multi-account user entity.
     * @param value Value to set for the aadUserId property.
     */
    set aadUserId(value: string | undefined);
    /**
     * Gets the accountName property value. Account name of user account (without Active Directory domain or DNS domain) - (also called mailNickName).
     * @returns a string
     */
    get accountName(): string | undefined;
    /**
     * Sets the accountName property value. Account name of user account (without Active Directory domain or DNS domain) - (also called mailNickName).
     * @param value Value to set for the accountName property.
     */
    set accountName(value: string | undefined);
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new userSecurityState and sets the default values.
     */
    constructor();
    /**
     * Gets the domainName property value. NetBIOS/Active Directory domain of user account (that is, domain/account format).
     * @returns a string
     */
    get domainName(): string | undefined;
    /**
     * Sets the domainName property value. NetBIOS/Active Directory domain of user account (that is, domain/account format).
     * @param value Value to set for the domainName property.
     */
    set domainName(value: string | undefined);
    /**
     * Gets the emailRole property value. For email-related alerts - user account's email 'role'. Possible values are: unknown, sender, recipient.
     * @returns a emailRole
     */
    get emailRole(): EmailRole | undefined;
    /**
     * Sets the emailRole property value. For email-related alerts - user account's email 'role'. Possible values are: unknown, sender, recipient.
     * @param value Value to set for the emailRole property.
     */
    set emailRole(value: EmailRole | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the isVpn property value. Indicates whether the user logged on through a VPN.
     * @returns a boolean
     */
    get isVpn(): boolean | undefined;
    /**
     * Sets the isVpn property value. Indicates whether the user logged on through a VPN.
     * @param value Value to set for the isVpn property.
     */
    set isVpn(value: boolean | undefined);
    /**
     * Gets the logonDateTime property value. Time at which the sign-in occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get logonDateTime(): Date | undefined;
    /**
     * Sets the logonDateTime property value. Time at which the sign-in occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the logonDateTime property.
     */
    set logonDateTime(value: Date | undefined);
    /**
     * Gets the logonId property value. User sign-in ID.
     * @returns a string
     */
    get logonId(): string | undefined;
    /**
     * Sets the logonId property value. User sign-in ID.
     * @param value Value to set for the logonId property.
     */
    set logonId(value: string | undefined);
    /**
     * Gets the logonIp property value. IP Address the sign-in request originated from.
     * @returns a string
     */
    get logonIp(): string | undefined;
    /**
     * Sets the logonIp property value. IP Address the sign-in request originated from.
     * @param value Value to set for the logonIp property.
     */
    set logonIp(value: string | undefined);
    /**
     * Gets the logonLocation property value. Location (by IP address mapping) associated with a user sign-in event by this user.
     * @returns a string
     */
    get logonLocation(): string | undefined;
    /**
     * Sets the logonLocation property value. Location (by IP address mapping) associated with a user sign-in event by this user.
     * @param value Value to set for the logonLocation property.
     */
    set logonLocation(value: string | undefined);
    /**
     * Gets the logonType property value. Method of user sign in. Possible values are: unknown, interactive, remoteInteractive, network, batch, service.
     * @returns a logonType
     */
    get logonType(): LogonType | undefined;
    /**
     * Sets the logonType property value. Method of user sign in. Possible values are: unknown, interactive, remoteInteractive, network, batch, service.
     * @param value Value to set for the logonType property.
     */
    set logonType(value: LogonType | undefined);
    /**
     * Gets the onPremisesSecurityIdentifier property value. Active Directory (on-premises) Security Identifier (SID) of the user.
     * @returns a string
     */
    get onPremisesSecurityIdentifier(): string | undefined;
    /**
     * Sets the onPremisesSecurityIdentifier property value. Active Directory (on-premises) Security Identifier (SID) of the user.
     * @param value Value to set for the onPremisesSecurityIdentifier property.
     */
    set onPremisesSecurityIdentifier(value: string | undefined);
    /**
     * Gets the riskScore property value. Provider-generated/calculated risk score of the user account. Recommended value range of 0-1, which equates to a percentage.
     * @returns a string
     */
    get riskScore(): string | undefined;
    /**
     * Sets the riskScore property value. Provider-generated/calculated risk score of the user account. Recommended value range of 0-1, which equates to a percentage.
     * @param value Value to set for the riskScore property.
     */
    set riskScore(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the userAccountType property value. User account type (group membership), per Windows definition. Possible values are: unknown, standard, power, administrator.
     * @returns a userAccountSecurityType
     */
    get userAccountType(): UserAccountSecurityType | undefined;
    /**
     * Sets the userAccountType property value. User account type (group membership), per Windows definition. Possible values are: unknown, standard, power, administrator.
     * @param value Value to set for the userAccountType property.
     */
    set userAccountType(value: UserAccountSecurityType | undefined);
    /**
     * Gets the userPrincipalName property value. User sign-in name - internet format: (user account name)@(user account DNS domain name).
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. User sign-in name - internet format: (user account name)@(user account DNS domain name).
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
}
