import { Entity } from './index';
import { VppTokenAccountType } from './vppTokenAccountType';
import { VppTokenState } from './vppTokenState';
import { VppTokenSyncStatus } from './vppTokenSyncStatus';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** You purchase multiple licenses for iOS apps through the Apple Volume Purchase Program for Business or Education. This involves setting up an Apple VPP account from the Apple website and uploading the Apple VPP Business or Education token to Intune. You can then synchronize your volume purchase information with Intune and track your volume-purchased app use. You can upload multiple Apple VPP Business or Education tokens. */
export declare class VppToken extends Entity implements Parsable {
    /** The apple Id associated with the given Apple Volume Purchase Program Token. */
    private _appleId?;
    /** Whether or not apps for the VPP token will be automatically updated. */
    private _automaticallyUpdateApps?;
    /** Whether or not apps for the VPP token will be automatically updated. */
    private _countryOrRegion?;
    /** The expiration date time of the Apple Volume Purchase Program Token. */
    private _expirationDateTime?;
    /** Last modification date time associated with the Apple Volume Purchase Program Token. */
    private _lastModifiedDateTime?;
    /** The last time when an application sync was done with the Apple volume purchase program service using the the Apple Volume Purchase Program Token. */
    private _lastSyncDateTime?;
    /** Current sync status of the last application sync which was triggered using the Apple Volume Purchase Program Token. Possible values are: none, inProgress, completed, failed. Possible values are: none, inProgress, completed, failed. */
    private _lastSyncStatus?;
    /** The organization associated with the Apple Volume Purchase Program Token */
    private _organizationName?;
    /** Current state of the Apple Volume Purchase Program Token. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM, duplicateLocationId. */
    private _state?;
    /** The Apple Volume Purchase Program Token string downloaded from the Apple Volume Purchase Program. */
    private _token?;
    /** The type of volume purchase program which the given Apple Volume Purchase Program Token is associated with. Possible values are: business, education. Possible values are: business, education. */
    private _vppTokenAccountType?;
    /**
     * Gets the appleId property value. The apple Id associated with the given Apple Volume Purchase Program Token.
     * @returns a string
     */
    get appleId(): string | undefined;
    /**
     * Sets the appleId property value. The apple Id associated with the given Apple Volume Purchase Program Token.
     * @param value Value to set for the appleId property.
     */
    set appleId(value: string | undefined);
    /**
     * Gets the automaticallyUpdateApps property value. Whether or not apps for the VPP token will be automatically updated.
     * @returns a boolean
     */
    get automaticallyUpdateApps(): boolean | undefined;
    /**
     * Sets the automaticallyUpdateApps property value. Whether or not apps for the VPP token will be automatically updated.
     * @param value Value to set for the automaticallyUpdateApps property.
     */
    set automaticallyUpdateApps(value: boolean | undefined);
    /**
     * Instantiates a new vppToken and sets the default values.
     */
    constructor();
    /**
     * Gets the countryOrRegion property value. Whether or not apps for the VPP token will be automatically updated.
     * @returns a string
     */
    get countryOrRegion(): string | undefined;
    /**
     * Sets the countryOrRegion property value. Whether or not apps for the VPP token will be automatically updated.
     * @param value Value to set for the countryOrRegion property.
     */
    set countryOrRegion(value: string | undefined);
    /**
     * Gets the expirationDateTime property value. The expiration date time of the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get expirationDateTime(): Date | undefined;
    /**
     * Sets the expirationDateTime property value. The expiration date time of the Apple Volume Purchase Program Token.
     * @param value Value to set for the expirationDateTime property.
     */
    set expirationDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. Last modification date time associated with the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Last modification date time associated with the Apple Volume Purchase Program Token.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the lastSyncDateTime property value. The last time when an application sync was done with the Apple volume purchase program service using the the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get lastSyncDateTime(): Date | undefined;
    /**
     * Sets the lastSyncDateTime property value. The last time when an application sync was done with the Apple volume purchase program service using the the Apple Volume Purchase Program Token.
     * @param value Value to set for the lastSyncDateTime property.
     */
    set lastSyncDateTime(value: Date | undefined);
    /**
     * Gets the lastSyncStatus property value. Current sync status of the last application sync which was triggered using the Apple Volume Purchase Program Token. Possible values are: none, inProgress, completed, failed. Possible values are: none, inProgress, completed, failed.
     * @returns a vppTokenSyncStatus
     */
    get lastSyncStatus(): VppTokenSyncStatus | undefined;
    /**
     * Sets the lastSyncStatus property value. Current sync status of the last application sync which was triggered using the Apple Volume Purchase Program Token. Possible values are: none, inProgress, completed, failed. Possible values are: none, inProgress, completed, failed.
     * @param value Value to set for the lastSyncStatus property.
     */
    set lastSyncStatus(value: VppTokenSyncStatus | undefined);
    /**
     * Gets the organizationName property value. The organization associated with the Apple Volume Purchase Program Token
     * @returns a string
     */
    get organizationName(): string | undefined;
    /**
     * Sets the organizationName property value. The organization associated with the Apple Volume Purchase Program Token
     * @param value Value to set for the organizationName property.
     */
    set organizationName(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the state property value. Current state of the Apple Volume Purchase Program Token. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM, duplicateLocationId.
     * @returns a vppTokenState
     */
    get state(): VppTokenState | undefined;
    /**
     * Sets the state property value. Current state of the Apple Volume Purchase Program Token. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM, duplicateLocationId.
     * @param value Value to set for the state property.
     */
    set state(value: VppTokenState | undefined);
    /**
     * Gets the token property value. The Apple Volume Purchase Program Token string downloaded from the Apple Volume Purchase Program.
     * @returns a string
     */
    get token(): string | undefined;
    /**
     * Sets the token property value. The Apple Volume Purchase Program Token string downloaded from the Apple Volume Purchase Program.
     * @param value Value to set for the token property.
     */
    set token(value: string | undefined);
    /**
     * Gets the vppTokenAccountType property value. The type of volume purchase program which the given Apple Volume Purchase Program Token is associated with. Possible values are: business, education. Possible values are: business, education.
     * @returns a vppTokenAccountType
     */
    get vppTokenAccountType(): VppTokenAccountType | undefined;
    /**
     * Sets the vppTokenAccountType property value. The type of volume purchase program which the given Apple Volume Purchase Program Token is associated with. Possible values are: business, education. Possible values are: business, education.
     * @param value Value to set for the vppTokenAccountType property.
     */
    set vppTokenAccountType(value: VppTokenAccountType | undefined);
}
