"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VppToken = void 0;
const index_1 = require("./index");
const vppTokenAccountType_1 = require("./vppTokenAccountType");
const vppTokenState_1 = require("./vppTokenState");
const vppTokenSyncStatus_1 = require("./vppTokenSyncStatus");
/** You purchase multiple licenses for iOS apps through the Apple Volume Purchase Program for Business or Education. This involves setting up an Apple VPP account from the Apple website and uploading the Apple VPP Business or Education token to Intune. You can then synchronize your volume purchase information with Intune and track your volume-purchased app use. You can upload multiple Apple VPP Business or Education tokens. */
class VppToken extends index_1.Entity {
    /**
     * Instantiates a new vppToken and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appleId property value. The apple Id associated with the given Apple Volume Purchase Program Token.
     * @returns a string
     */
    get appleId() {
        return this._appleId;
    }
    ;
    /**
     * Sets the appleId property value. The apple Id associated with the given Apple Volume Purchase Program Token.
     * @param value Value to set for the appleId property.
     */
    set appleId(value) {
        this._appleId = value;
    }
    ;
    /**
     * Gets the automaticallyUpdateApps property value. Whether or not apps for the VPP token will be automatically updated.
     * @returns a boolean
     */
    get automaticallyUpdateApps() {
        return this._automaticallyUpdateApps;
    }
    ;
    /**
     * Sets the automaticallyUpdateApps property value. Whether or not apps for the VPP token will be automatically updated.
     * @param value Value to set for the automaticallyUpdateApps property.
     */
    set automaticallyUpdateApps(value) {
        this._automaticallyUpdateApps = value;
    }
    ;
    ;
    /**
     * Gets the countryOrRegion property value. Whether or not apps for the VPP token will be automatically updated.
     * @returns a string
     */
    get countryOrRegion() {
        return this._countryOrRegion;
    }
    ;
    /**
     * Sets the countryOrRegion property value. Whether or not apps for the VPP token will be automatically updated.
     * @param value Value to set for the countryOrRegion property.
     */
    set countryOrRegion(value) {
        this._countryOrRegion = value;
    }
    ;
    /**
     * Gets the expirationDateTime property value. The expiration date time of the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get expirationDateTime() {
        return this._expirationDateTime;
    }
    ;
    /**
     * Sets the expirationDateTime property value. The expiration date time of the Apple Volume Purchase Program Token.
     * @param value Value to set for the expirationDateTime property.
     */
    set expirationDateTime(value) {
        this._expirationDateTime = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appleId": n => { this.appleId = n.getStringValue(); }, "automaticallyUpdateApps": n => { this.automaticallyUpdateApps = n.getBooleanValue(); }, "countryOrRegion": n => { this.countryOrRegion = n.getStringValue(); }, "expirationDateTime": n => { this.expirationDateTime = n.getDateValue(); }, "lastModifiedDateTime": n => { this.lastModifiedDateTime = n.getDateValue(); }, "lastSyncDateTime": n => { this.lastSyncDateTime = n.getDateValue(); }, "lastSyncStatus": n => { this.lastSyncStatus = n.getEnumValue(vppTokenSyncStatus_1.VppTokenSyncStatus); }, "organizationName": n => { this.organizationName = n.getStringValue(); }, "state": n => { this.state = n.getEnumValue(vppTokenState_1.VppTokenState); }, "token": n => { this.token = n.getStringValue(); }, "vppTokenAccountType": n => { this.vppTokenAccountType = n.getEnumValue(vppTokenAccountType_1.VppTokenAccountType); } });
    }
    ;
    /**
     * Gets the lastModifiedDateTime property value. Last modification date time associated with the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get lastModifiedDateTime() {
        return this._lastModifiedDateTime;
    }
    ;
    /**
     * Sets the lastModifiedDateTime property value. Last modification date time associated with the Apple Volume Purchase Program Token.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value) {
        this._lastModifiedDateTime = value;
    }
    ;
    /**
     * Gets the lastSyncDateTime property value. The last time when an application sync was done with the Apple volume purchase program service using the the Apple Volume Purchase Program Token.
     * @returns a Date
     */
    get lastSyncDateTime() {
        return this._lastSyncDateTime;
    }
    ;
    /**
     * Sets the lastSyncDateTime property value. The last time when an application sync was done with the Apple volume purchase program service using the the Apple Volume Purchase Program Token.
     * @param value Value to set for the lastSyncDateTime property.
     */
    set lastSyncDateTime(value) {
        this._lastSyncDateTime = value;
    }
    ;
    /**
     * Gets the lastSyncStatus property value. Current sync status of the last application sync which was triggered using the Apple Volume Purchase Program Token. Possible values are: none, inProgress, completed, failed. Possible values are: none, inProgress, completed, failed.
     * @returns a vppTokenSyncStatus
     */
    get lastSyncStatus() {
        return this._lastSyncStatus;
    }
    ;
    /**
     * Sets the lastSyncStatus property value. Current sync status of the last application sync which was triggered using the Apple Volume Purchase Program Token. Possible values are: none, inProgress, completed, failed. Possible values are: none, inProgress, completed, failed.
     * @param value Value to set for the lastSyncStatus property.
     */
    set lastSyncStatus(value) {
        this._lastSyncStatus = value;
    }
    ;
    /**
     * Gets the organizationName property value. The organization associated with the Apple Volume Purchase Program Token
     * @returns a string
     */
    get organizationName() {
        return this._organizationName;
    }
    ;
    /**
     * Sets the organizationName property value. The organization associated with the Apple Volume Purchase Program Token
     * @param value Value to set for the organizationName property.
     */
    set organizationName(value) {
        this._organizationName = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("appleId", this.appleId);
        writer.writeBooleanValue("automaticallyUpdateApps", this.automaticallyUpdateApps);
        writer.writeStringValue("countryOrRegion", this.countryOrRegion);
        writer.writeDateValue("expirationDateTime", this.expirationDateTime);
        writer.writeDateValue("lastModifiedDateTime", this.lastModifiedDateTime);
        writer.writeDateValue("lastSyncDateTime", this.lastSyncDateTime);
        writer.writeEnumValue("lastSyncStatus", this.lastSyncStatus);
        writer.writeStringValue("organizationName", this.organizationName);
        writer.writeEnumValue("state", this.state);
        writer.writeStringValue("token", this.token);
        writer.writeEnumValue("vppTokenAccountType", this.vppTokenAccountType);
    }
    ;
    /**
     * Gets the state property value. Current state of the Apple Volume Purchase Program Token. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM, duplicateLocationId.
     * @returns a vppTokenState
     */
    get state() {
        return this._state;
    }
    ;
    /**
     * Sets the state property value. Current state of the Apple Volume Purchase Program Token. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM. Possible values are: unknown, valid, expired, invalid, assignedToExternalMDM, duplicateLocationId.
     * @param value Value to set for the state property.
     */
    set state(value) {
        this._state = value;
    }
    ;
    /**
     * Gets the token property value. The Apple Volume Purchase Program Token string downloaded from the Apple Volume Purchase Program.
     * @returns a string
     */
    get token() {
        return this._token;
    }
    ;
    /**
     * Sets the token property value. The Apple Volume Purchase Program Token string downloaded from the Apple Volume Purchase Program.
     * @param value Value to set for the token property.
     */
    set token(value) {
        this._token = value;
    }
    ;
    /**
     * Gets the vppTokenAccountType property value. The type of volume purchase program which the given Apple Volume Purchase Program Token is associated with. Possible values are: business, education. Possible values are: business, education.
     * @returns a vppTokenAccountType
     */
    get vppTokenAccountType() {
        return this._vppTokenAccountType;
    }
    ;
    /**
     * Sets the vppTokenAccountType property value. The type of volume purchase program which the given Apple Volume Purchase Program Token is associated with. Possible values are: business, education. Possible values are: business, education.
     * @param value Value to set for the vppTokenAccountType property.
     */
    set vppTokenAccountType(value) {
        this._vppTokenAccountType = value;
    }
    ;
}
exports.VppToken = VppToken;
