import { WindowsInformationProtection } from './index';
import { WindowsInformationProtectionPinCharacterRequirements } from './windowsInformationProtectionPinCharacterRequirements';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Policy for Windows information protection without MDM */
export declare class WindowsInformationProtectionPolicy extends WindowsInformationProtection implements Parsable {
    /** Offline interval before app data is wiped (days) */
    private _daysWithoutContactBeforeUnenroll?;
    /** Enrollment url for the MDM */
    private _mdmEnrollmentUrl?;
    /** Specifies the maximum amount of time (in minutes) allowed after the device is idle that will cause the device to become PIN or password locked.   Range is an integer X where 0 <= X <= 999. */
    private _minutesOfInactivityBeforeDeviceLock?;
    /** Integer value that specifies the number of past PINs that can be associated to a user account that can't be reused. The largest number you can configure for this policy setting is 50. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then storage of previous PINs is not required. This node was added in Windows 10, version 1511. Default is 0. */
    private _numberOfPastPinsRemembered?;
    /** The number of authentication failures allowed before the device will be wiped. A value of 0 disables device wipe functionality. Range is an integer X where 4 <= X <= 16 for desktop and 0 <= X <= 999 for mobile devices. */
    private _passwordMaximumAttemptCount?;
    /** Integer value specifies the period of time (in days) that a PIN can be used before the system requires the user to change it. The largest number you can configure for this policy setting is 730. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then the user's PIN will never expire. This node was added in Windows 10, version 1511. Default is 0. */
    private _pinExpirationDays?;
    /** Integer value that configures the use of lowercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow. */
    private _pinLowercaseLetters?;
    /** Integer value that sets the minimum number of characters required for the PIN. Default value is 4. The lowest number you can configure for this policy setting is 4. The largest number you can configure must be less than the number configured in the Maximum PIN length policy setting or the number 127, whichever is the lowest. */
    private _pinMinimumLength?;
    /** Integer value that configures the use of special characters in the Windows Hello for Business PIN. Valid special characters for Windows Hello for Business PIN gestures include: ! ' # $ % & ' ( )  + , - . / : ; < = > ? @ [ / ] ^  ` { */
    private _pinSpecialCharacters?;
    /** Integer value that configures the use of uppercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow. */
    private _pinUppercaseLetters?;
    /** New property in RS2, pending documentation */
    private _revokeOnMdmHandoffDisabled?;
    /** Boolean value that sets Windows Hello for Business as a method for signing into Windows. */
    private _windowsHelloForBusinessBlocked?;
    /**
     * Instantiates a new windowsInformationProtectionPolicy and sets the default values.
     */
    constructor();
    /**
     * Gets the daysWithoutContactBeforeUnenroll property value. Offline interval before app data is wiped (days)
     * @returns a integer
     */
    get daysWithoutContactBeforeUnenroll(): number | undefined;
    /**
     * Sets the daysWithoutContactBeforeUnenroll property value. Offline interval before app data is wiped (days)
     * @param value Value to set for the daysWithoutContactBeforeUnenroll property.
     */
    set daysWithoutContactBeforeUnenroll(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the mdmEnrollmentUrl property value. Enrollment url for the MDM
     * @returns a string
     */
    get mdmEnrollmentUrl(): string | undefined;
    /**
     * Sets the mdmEnrollmentUrl property value. Enrollment url for the MDM
     * @param value Value to set for the mdmEnrollmentUrl property.
     */
    set mdmEnrollmentUrl(value: string | undefined);
    /**
     * Gets the minutesOfInactivityBeforeDeviceLock property value. Specifies the maximum amount of time (in minutes) allowed after the device is idle that will cause the device to become PIN or password locked.   Range is an integer X where 0 <= X <= 999.
     * @returns a integer
     */
    get minutesOfInactivityBeforeDeviceLock(): number | undefined;
    /**
     * Sets the minutesOfInactivityBeforeDeviceLock property value. Specifies the maximum amount of time (in minutes) allowed after the device is idle that will cause the device to become PIN or password locked.   Range is an integer X where 0 <= X <= 999.
     * @param value Value to set for the minutesOfInactivityBeforeDeviceLock property.
     */
    set minutesOfInactivityBeforeDeviceLock(value: number | undefined);
    /**
     * Gets the numberOfPastPinsRemembered property value. Integer value that specifies the number of past PINs that can be associated to a user account that can't be reused. The largest number you can configure for this policy setting is 50. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then storage of previous PINs is not required. This node was added in Windows 10, version 1511. Default is 0.
     * @returns a integer
     */
    get numberOfPastPinsRemembered(): number | undefined;
    /**
     * Sets the numberOfPastPinsRemembered property value. Integer value that specifies the number of past PINs that can be associated to a user account that can't be reused. The largest number you can configure for this policy setting is 50. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then storage of previous PINs is not required. This node was added in Windows 10, version 1511. Default is 0.
     * @param value Value to set for the numberOfPastPinsRemembered property.
     */
    set numberOfPastPinsRemembered(value: number | undefined);
    /**
     * Gets the passwordMaximumAttemptCount property value. The number of authentication failures allowed before the device will be wiped. A value of 0 disables device wipe functionality. Range is an integer X where 4 <= X <= 16 for desktop and 0 <= X <= 999 for mobile devices.
     * @returns a integer
     */
    get passwordMaximumAttemptCount(): number | undefined;
    /**
     * Sets the passwordMaximumAttemptCount property value. The number of authentication failures allowed before the device will be wiped. A value of 0 disables device wipe functionality. Range is an integer X where 4 <= X <= 16 for desktop and 0 <= X <= 999 for mobile devices.
     * @param value Value to set for the passwordMaximumAttemptCount property.
     */
    set passwordMaximumAttemptCount(value: number | undefined);
    /**
     * Gets the pinExpirationDays property value. Integer value specifies the period of time (in days) that a PIN can be used before the system requires the user to change it. The largest number you can configure for this policy setting is 730. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then the user's PIN will never expire. This node was added in Windows 10, version 1511. Default is 0.
     * @returns a integer
     */
    get pinExpirationDays(): number | undefined;
    /**
     * Sets the pinExpirationDays property value. Integer value specifies the period of time (in days) that a PIN can be used before the system requires the user to change it. The largest number you can configure for this policy setting is 730. The lowest number you can configure for this policy setting is 0. If this policy is set to 0, then the user's PIN will never expire. This node was added in Windows 10, version 1511. Default is 0.
     * @param value Value to set for the pinExpirationDays property.
     */
    set pinExpirationDays(value: number | undefined);
    /**
     * Gets the pinLowercaseLetters property value. Integer value that configures the use of lowercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow.
     * @returns a windowsInformationProtectionPinCharacterRequirements
     */
    get pinLowercaseLetters(): WindowsInformationProtectionPinCharacterRequirements | undefined;
    /**
     * Sets the pinLowercaseLetters property value. Integer value that configures the use of lowercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow.
     * @param value Value to set for the pinLowercaseLetters property.
     */
    set pinLowercaseLetters(value: WindowsInformationProtectionPinCharacterRequirements | undefined);
    /**
     * Gets the pinMinimumLength property value. Integer value that sets the minimum number of characters required for the PIN. Default value is 4. The lowest number you can configure for this policy setting is 4. The largest number you can configure must be less than the number configured in the Maximum PIN length policy setting or the number 127, whichever is the lowest.
     * @returns a integer
     */
    get pinMinimumLength(): number | undefined;
    /**
     * Sets the pinMinimumLength property value. Integer value that sets the minimum number of characters required for the PIN. Default value is 4. The lowest number you can configure for this policy setting is 4. The largest number you can configure must be less than the number configured in the Maximum PIN length policy setting or the number 127, whichever is the lowest.
     * @param value Value to set for the pinMinimumLength property.
     */
    set pinMinimumLength(value: number | undefined);
    /**
     * Gets the pinSpecialCharacters property value. Integer value that configures the use of special characters in the Windows Hello for Business PIN. Valid special characters for Windows Hello for Business PIN gestures include: ! ' # $ % & ' ( )  + , - . / : ; < = > ? @ [ / ] ^  ` {
     * @returns a windowsInformationProtectionPinCharacterRequirements
     */
    get pinSpecialCharacters(): WindowsInformationProtectionPinCharacterRequirements | undefined;
    /**
     * Sets the pinSpecialCharacters property value. Integer value that configures the use of special characters in the Windows Hello for Business PIN. Valid special characters for Windows Hello for Business PIN gestures include: ! ' # $ % & ' ( )  + , - . / : ; < = > ? @ [ / ] ^  ` {
     * @param value Value to set for the pinSpecialCharacters property.
     */
    set pinSpecialCharacters(value: WindowsInformationProtectionPinCharacterRequirements | undefined);
    /**
     * Gets the pinUppercaseLetters property value. Integer value that configures the use of uppercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow.
     * @returns a windowsInformationProtectionPinCharacterRequirements
     */
    get pinUppercaseLetters(): WindowsInformationProtectionPinCharacterRequirements | undefined;
    /**
     * Sets the pinUppercaseLetters property value. Integer value that configures the use of uppercase letters in the Windows Hello for Business PIN. Default is NotAllow. Possible values are: notAllow, requireAtLeastOne, allow.
     * @param value Value to set for the pinUppercaseLetters property.
     */
    set pinUppercaseLetters(value: WindowsInformationProtectionPinCharacterRequirements | undefined);
    /**
     * Gets the revokeOnMdmHandoffDisabled property value. New property in RS2, pending documentation
     * @returns a boolean
     */
    get revokeOnMdmHandoffDisabled(): boolean | undefined;
    /**
     * Sets the revokeOnMdmHandoffDisabled property value. New property in RS2, pending documentation
     * @param value Value to set for the revokeOnMdmHandoffDisabled property.
     */
    set revokeOnMdmHandoffDisabled(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the windowsHelloForBusinessBlocked property value. Boolean value that sets Windows Hello for Business as a method for signing into Windows.
     * @returns a boolean
     */
    get windowsHelloForBusinessBlocked(): boolean | undefined;
    /**
     * Sets the windowsHelloForBusinessBlocked property value. Boolean value that sets Windows Hello for Business as a method for signing into Windows.
     * @param value Value to set for the windowsHelloForBusinessBlocked property.
     */
    set windowsHelloForBusinessBlocked(value: boolean | undefined);
}
