import { Entity, Json, WorkbookChartAxisFormat, WorkbookChartAxisTitle, WorkbookChartGridlines } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Casts the previous resource to user. */
export declare class WorkbookChartAxis extends Entity implements Parsable {
    /** Represents the formatting of a chart object, which includes line and font formatting. Read-only. */
    private _format?;
    /** Returns a gridlines object that represents the major gridlines for the specified axis. Read-only. */
    private _majorGridlines?;
    /** Represents the interval between two major tick marks. Can be set to a numeric value or an empty string.  The returned value is always a number. */
    private _majorUnit?;
    /** Represents the maximum value on the value axis.  Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number. */
    private _maximum?;
    /** Represents the minimum value on the value axis. Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number. */
    private _minimum?;
    /** Returns a Gridlines object that represents the minor gridlines for the specified axis. Read-only. */
    private _minorGridlines?;
    /** Represents the interval between two minor tick marks. 'Can be set to a numeric value or an empty string (for automatic axis values). The returned value is always a number. */
    private _minorUnit?;
    /** Represents the axis title. Read-only. */
    private _title?;
    /**
     * Instantiates a new workbookChartAxis and sets the default values.
     */
    constructor();
    /**
     * Gets the format property value. Represents the formatting of a chart object, which includes line and font formatting. Read-only.
     * @returns a workbookChartAxisFormat
     */
    get format(): WorkbookChartAxisFormat | undefined;
    /**
     * Sets the format property value. Represents the formatting of a chart object, which includes line and font formatting. Read-only.
     * @param value Value to set for the format property.
     */
    set format(value: WorkbookChartAxisFormat | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (node: ParseNode) => void>
     */
    getFieldDeserializers(): Record<string, (node: ParseNode) => void>;
    /**
     * Gets the majorGridlines property value. Returns a gridlines object that represents the major gridlines for the specified axis. Read-only.
     * @returns a workbookChartGridlines
     */
    get majorGridlines(): WorkbookChartGridlines | undefined;
    /**
     * Sets the majorGridlines property value. Returns a gridlines object that represents the major gridlines for the specified axis. Read-only.
     * @param value Value to set for the majorGridlines property.
     */
    set majorGridlines(value: WorkbookChartGridlines | undefined);
    /**
     * Gets the majorUnit property value. Represents the interval between two major tick marks. Can be set to a numeric value or an empty string.  The returned value is always a number.
     * @returns a Json
     */
    get majorUnit(): Json | undefined;
    /**
     * Sets the majorUnit property value. Represents the interval between two major tick marks. Can be set to a numeric value or an empty string.  The returned value is always a number.
     * @param value Value to set for the majorUnit property.
     */
    set majorUnit(value: Json | undefined);
    /**
     * Gets the maximum property value. Represents the maximum value on the value axis.  Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number.
     * @returns a Json
     */
    get maximum(): Json | undefined;
    /**
     * Sets the maximum property value. Represents the maximum value on the value axis.  Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number.
     * @param value Value to set for the maximum property.
     */
    set maximum(value: Json | undefined);
    /**
     * Gets the minimum property value. Represents the minimum value on the value axis. Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number.
     * @returns a Json
     */
    get minimum(): Json | undefined;
    /**
     * Sets the minimum property value. Represents the minimum value on the value axis. Can be set to a numeric value or an empty string (for automatic axis values).  The returned value is always a number.
     * @param value Value to set for the minimum property.
     */
    set minimum(value: Json | undefined);
    /**
     * Gets the minorGridlines property value. Returns a Gridlines object that represents the minor gridlines for the specified axis. Read-only.
     * @returns a workbookChartGridlines
     */
    get minorGridlines(): WorkbookChartGridlines | undefined;
    /**
     * Sets the minorGridlines property value. Returns a Gridlines object that represents the minor gridlines for the specified axis. Read-only.
     * @param value Value to set for the minorGridlines property.
     */
    set minorGridlines(value: WorkbookChartGridlines | undefined);
    /**
     * Gets the minorUnit property value. Represents the interval between two minor tick marks. 'Can be set to a numeric value or an empty string (for automatic axis values). The returned value is always a number.
     * @returns a Json
     */
    get minorUnit(): Json | undefined;
    /**
     * Sets the minorUnit property value. Represents the interval between two minor tick marks. 'Can be set to a numeric value or an empty string (for automatic axis values). The returned value is always a number.
     * @param value Value to set for the minorUnit property.
     */
    set minorUnit(value: Json | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the title property value. Represents the axis title. Read-only.
     * @returns a workbookChartAxisTitle
     */
    get title(): WorkbookChartAxisTitle | undefined;
    /**
     * Sets the title property value. Represents the axis title. Read-only.
     * @param value Value to set for the title property.
     */
    set title(value: WorkbookChartAxisTitle | undefined);
}
