import { AuthenticationMethodsPolicy } from '../../models/';
import { AuthenticationMethodConfigurationsRequestBuilder } from './authenticationMethodConfigurations/authenticationMethodConfigurationsRequestBuilder';
import { AuthenticationMethodConfigurationItemRequestBuilder } from './authenticationMethodConfigurations/item/authenticationMethodConfigurationItemRequestBuilder';
import { AuthenticationMethodsPolicyRequestBuilderDeleteRequestConfiguration } from './authenticationMethodsPolicyRequestBuilderDeleteRequestConfiguration';
import { AuthenticationMethodsPolicyRequestBuilderGetRequestConfiguration } from './authenticationMethodsPolicyRequestBuilderGetRequestConfiguration';
import { AuthenticationMethodsPolicyRequestBuilderPatchRequestConfiguration } from './authenticationMethodsPolicyRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the authenticationMethodsPolicy property of the microsoft.graph.policyRoot entity. */
export declare class AuthenticationMethodsPolicyRequestBuilder {
    /** The authenticationMethodConfigurations property */
    get authenticationMethodConfigurations(): AuthenticationMethodConfigurationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.authenticationMethodsPolicy.authenticationMethodConfigurations.item collection
     * @param id Unique identifier of the item
     * @returns a authenticationMethodConfigurationItemRequestBuilder
     */
    authenticationMethodConfigurationsById(id: string): AuthenticationMethodConfigurationItemRequestBuilder;
    /**
     * Instantiates a new AuthenticationMethodsPolicyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authenticationMethodsPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The authentication methods and the users that are allowed to use them to sign in and perform multi-factor authentication (MFA) in Azure Active Directory (Azure AD).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property authenticationMethodsPolicy in policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: AuthenticationMethodsPolicy | undefined, requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property authenticationMethodsPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The authentication methods and the users that are allowed to use them to sign in and perform multi-factor authentication (MFA) in Azure Active Directory (Azure AD).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AuthenticationMethodsPolicy
     */
    get(requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<AuthenticationMethodsPolicy | undefined>;
    /**
     * Update the navigation property authenticationMethodsPolicy in policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: AuthenticationMethodsPolicy | undefined, requestConfiguration?: AuthenticationMethodsPolicyRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
