import { AuthorizationPolicy } from '../../models/';
import { AuthorizationPolicyRequestBuilderDeleteRequestConfiguration } from './authorizationPolicyRequestBuilderDeleteRequestConfiguration';
import { AuthorizationPolicyRequestBuilderGetRequestConfiguration } from './authorizationPolicyRequestBuilderGetRequestConfiguration';
import { AuthorizationPolicyRequestBuilderPatchRequestConfiguration } from './authorizationPolicyRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the authorizationPolicy property of the microsoft.graph.policyRoot entity. */
export declare class AuthorizationPolicyRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new AuthorizationPolicyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authorizationPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: AuthorizationPolicyRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The policy that controls Azure AD authorization settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: AuthorizationPolicyRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property authorizationPolicy in policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: AuthorizationPolicy | undefined, requestConfiguration?: AuthorizationPolicyRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property authorizationPolicy for policies
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: AuthorizationPolicyRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The policy that controls Azure AD authorization settings.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AuthorizationPolicy
     */
    get(requestConfiguration?: AuthorizationPolicyRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<AuthorizationPolicy | undefined>;
    /**
     * Update the navigation property authorizationPolicy in policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: AuthorizationPolicy | undefined, requestConfiguration?: AuthorizationPolicyRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
