import { ConditionalAccessPolicy, ConditionalAccessPolicyCollectionResponse } from '../../models/';
import { ConditionalAccessPoliciesRequestBuilderGetRequestConfiguration } from './conditionalAccessPoliciesRequestBuilderGetRequestConfiguration';
import { ConditionalAccessPoliciesRequestBuilderPostRequestConfiguration } from './conditionalAccessPoliciesRequestBuilderPostRequestConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the conditionalAccessPolicies property of the microsoft.graph.policyRoot entity. */
export declare class ConditionalAccessPoliciesRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ConditionalAccessPoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The custom rules that define an access scenario.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ConditionalAccessPoliciesRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to conditionalAccessPolicies for policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ConditionalAccessPolicy | undefined, requestConfiguration?: ConditionalAccessPoliciesRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * The custom rules that define an access scenario.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ConditionalAccessPolicyCollectionResponse
     */
    get(requestConfiguration?: ConditionalAccessPoliciesRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ConditionalAccessPolicyCollectionResponse | undefined>;
    /**
     * Create new navigation property to conditionalAccessPolicies for policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ConditionalAccessPolicy
     */
    post(body: ConditionalAccessPolicy | undefined, requestConfiguration?: ConditionalAccessPoliciesRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ConditionalAccessPolicy | undefined>;
}
