import { DirectoryObject, DirectoryObjectCollectionResponse } from '../../../../models/';
import { AppliesToRequestBuilderGetRequestConfiguration } from './appliesToRequestBuilderGetRequestConfiguration';
import { AppliesToRequestBuilderPostRequestConfiguration } from './appliesToRequestBuilderPostRequestConfiguration';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { RefRequestBuilder } from './ref/refRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the appliesTo property of the microsoft.graph.featureRolloutPolicy entity. */
export declare class AppliesToRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The ref property */
    get ref(): RefRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new AppliesToRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Nullable. Specifies a list of directoryObjects that feature is enabled for.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: AppliesToRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to appliesTo for policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: DirectoryObject | undefined, requestConfiguration?: AppliesToRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Nullable. Specifies a list of directoryObjects that feature is enabled for.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObjectCollectionResponse
     */
    get(requestConfiguration?: AppliesToRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DirectoryObjectCollectionResponse | undefined>;
    /**
     * Create new navigation property to appliesTo for policies
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObject
     */
    post(body: DirectoryObject | undefined, requestConfiguration?: AppliesToRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DirectoryObject | undefined>;
}
