import { Print } from '../models/';
import { ConnectorsRequestBuilder } from './connectors/connectorsRequestBuilder';
import { PrintConnectorItemRequestBuilder } from './connectors/item/printConnectorItemRequestBuilder';
import { PrintOperationItemRequestBuilder } from './operations/item/printOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrinterItemRequestBuilder } from './printers/item/printerItemRequestBuilder';
import { PrintersRequestBuilder } from './printers/printersRequestBuilder';
import { PrintRequestBuilderGetRequestConfiguration } from './printRequestBuilderGetRequestConfiguration';
import { PrintRequestBuilderPatchRequestConfiguration } from './printRequestBuilderPatchRequestConfiguration';
import { PrintServiceItemRequestBuilder } from './services/item/printServiceItemRequestBuilder';
import { ServicesRequestBuilder } from './services/servicesRequestBuilder';
import { PrinterShareItemRequestBuilder } from './shares/item/printerShareItemRequestBuilder';
import { SharesRequestBuilder } from './shares/sharesRequestBuilder';
import { PrintTaskDefinitionItemRequestBuilder } from './taskDefinitions/item/printTaskDefinitionItemRequestBuilder';
import { TaskDefinitionsRequestBuilder } from './taskDefinitions/taskDefinitionsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the print singleton. */
export declare class PrintRequestBuilder {
    /** The connectors property */
    get connectors(): ConnectorsRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The printers property */
    get printers(): PrintersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The services property */
    get services(): ServicesRequestBuilder;
    /** The shares property */
    get shares(): SharesRequestBuilder;
    /** The taskDefinitions property */
    get taskDefinitions(): TaskDefinitionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.connectors.item collection
     * @param id Unique identifier of the item
     * @returns a printConnectorItemRequestBuilder
     */
    connectorsById(id: string): PrintConnectorItemRequestBuilder;
    /**
     * Instantiates a new PrintRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PrintRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Print | undefined, requestConfiguration?: PrintRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Print
     */
    get(requestConfiguration?: PrintRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Print | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.operations.item collection
     * @param id Unique identifier of the item
     * @returns a printOperationItemRequestBuilder
     */
    operationsById(id: string): PrintOperationItemRequestBuilder;
    /**
     * Update print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Print | undefined, requestConfiguration?: PrintRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.printers.item collection
     * @param id Unique identifier of the item
     * @returns a printerItemRequestBuilder
     */
    printersById(id: string): PrinterItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.services.item collection
     * @param id Unique identifier of the item
     * @returns a printServiceItemRequestBuilder
     */
    servicesById(id: string): PrintServiceItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item collection
     * @param id Unique identifier of the item
     * @returns a printerShareItemRequestBuilder
     */
    sharesById(id: string): PrinterShareItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.taskDefinitions.item collection
     * @param id Unique identifier of the item
     * @returns a printTaskDefinitionItemRequestBuilder
     */
    taskDefinitionsById(id: string): PrintTaskDefinitionItemRequestBuilder;
}
