import { PrintServiceEndpoint } from '../../../../../models/';
import { PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration } from './printServiceEndpointItemRequestBuilderDeleteRequestConfiguration';
import { PrintServiceEndpointItemRequestBuilderGetRequestConfiguration } from './printServiceEndpointItemRequestBuilderGetRequestConfiguration';
import { PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration } from './printServiceEndpointItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the endpoints property of the microsoft.graph.printService entity. */
export declare class PrintServiceEndpointItemRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PrintServiceEndpointItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property endpoints for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Endpoints that can be used to access the service. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PrintServiceEndpointItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property endpoints in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: PrintServiceEndpoint | undefined, requestConfiguration?: PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property endpoints for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: PrintServiceEndpointItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Endpoints that can be used to access the service. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PrintServiceEndpoint
     */
    get(requestConfiguration?: PrintServiceEndpointItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<PrintServiceEndpoint | undefined>;
    /**
     * Update the navigation property endpoints in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: PrintServiceEndpoint | undefined, requestConfiguration?: PrintServiceEndpointItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
