import { PrintService } from '../../../models/';
import { EndpointsRequestBuilder } from './endpoints/endpointsRequestBuilder';
import { PrintServiceEndpointItemRequestBuilder } from './endpoints/item/printServiceEndpointItemRequestBuilder';
import { PrintServiceItemRequestBuilderDeleteRequestConfiguration } from './printServiceItemRequestBuilderDeleteRequestConfiguration';
import { PrintServiceItemRequestBuilderGetRequestConfiguration } from './printServiceItemRequestBuilderGetRequestConfiguration';
import { PrintServiceItemRequestBuilderPatchRequestConfiguration } from './printServiceItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the services property of the microsoft.graph.print entity. */
export declare class PrintServiceItemRequestBuilder {
    /** The endpoints property */
    get endpoints(): EndpointsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PrintServiceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property services for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: PrintServiceItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The list of available Universal Print service endpoints.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PrintServiceItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property services in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: PrintService | undefined, requestConfiguration?: PrintServiceItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property services for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: PrintServiceItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.services.item.endpoints.item collection
     * @param id Unique identifier of the item
     * @returns a printServiceEndpointItemRequestBuilder
     */
    endpointsById(id: string): PrintServiceEndpointItemRequestBuilder;
    /**
     * The list of available Universal Print service endpoints.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PrintService
     */
    get(requestConfiguration?: PrintServiceItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<PrintService | undefined>;
    /**
     * Update the navigation property services in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: PrintService | undefined, requestConfiguration?: PrintServiceItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
