import { PrinterShare } from '../../../models/';
import { AllowedGroupsRequestBuilder } from './allowedGroups/allowedGroupsRequestBuilder';
import { GroupItemRequestBuilder } from './allowedGroups/item/groupItemRequestBuilder';
import { AllowedUsersRequestBuilder } from './allowedUsers/allowedUsersRequestBuilder';
import { UserItemRequestBuilder } from './allowedUsers/item/userItemRequestBuilder';
import { PrinterRequestBuilder } from './printer/printerRequestBuilder';
import { PrinterShareItemRequestBuilderDeleteRequestConfiguration } from './printerShareItemRequestBuilderDeleteRequestConfiguration';
import { PrinterShareItemRequestBuilderGetRequestConfiguration } from './printerShareItemRequestBuilderGetRequestConfiguration';
import { PrinterShareItemRequestBuilderPatchRequestConfiguration } from './printerShareItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the shares property of the microsoft.graph.print entity. */
export declare class PrinterShareItemRequestBuilder {
    /** The allowedGroups property */
    get allowedGroups(): AllowedGroupsRequestBuilder;
    /** The allowedUsers property */
    get allowedUsers(): AllowedUsersRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The printer property */
    get printer(): PrinterRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item.allowedGroups.item collection
     * @param id Unique identifier of the item
     * @returns a groupItemRequestBuilder
     */
    allowedGroupsById(id: string): GroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item.allowedUsers.item collection
     * @param id Unique identifier of the item
     * @returns a userItemRequestBuilder
     */
    allowedUsersById(id: string): UserItemRequestBuilder;
    /**
     * Instantiates a new PrinterShareItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property shares for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: PrinterShareItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The list of printer shares registered in the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PrinterShareItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property shares in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: PrinterShare | undefined, requestConfiguration?: PrinterShareItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property shares for print
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: PrinterShareItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The list of printer shares registered in the tenant.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PrinterShare
     */
    get(requestConfiguration?: PrinterShareItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<PrinterShare | undefined>;
    /**
     * Update the navigation property shares in print
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: PrinterShare | undefined, requestConfiguration?: PrinterShareItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
