import { Privacy } from '../models/';
import { PrivacyRequestBuilderGetRequestConfiguration } from './privacyRequestBuilderGetRequestConfiguration';
import { PrivacyRequestBuilderPatchRequestConfiguration } from './privacyRequestBuilderPatchRequestConfiguration';
import { SubjectRightsRequestItemRequestBuilder } from './subjectRightsRequests/item/subjectRightsRequestItemRequestBuilder';
import { SubjectRightsRequestsRequestBuilder } from './subjectRightsRequests/subjectRightsRequestsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the privacy singleton. */
export declare class PrivacyRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The subjectRightsRequests property */
    get subjectRightsRequests(): SubjectRightsRequestsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PrivacyRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PrivacyRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update privacy
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Privacy | undefined, requestConfiguration?: PrivacyRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Privacy
     */
    get(requestConfiguration?: PrivacyRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Privacy | undefined>;
    /**
     * Update privacy
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Privacy | undefined, requestConfiguration?: PrivacyRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.privacy.subjectRightsRequests.item collection
     * @param id Unique identifier of the item
     * @returns a subjectRightsRequestItemRequestBuilder
     */
    subjectRightsRequestsById(id: string): SubjectRightsRequestItemRequestBuilder;
}
