import { SubjectRightsRequest } from '../../../models/';
import { GetFinalAttachmentRequestBuilder } from './getFinalAttachment/getFinalAttachmentRequestBuilder';
import { GetFinalReportRequestBuilder } from './getFinalReport/getFinalReportRequestBuilder';
import { AuthoredNoteItemRequestBuilder } from './notes/item/authoredNoteItemRequestBuilder';
import { NotesRequestBuilder } from './notes/notesRequestBuilder';
import { SubjectRightsRequestItemRequestBuilderDeleteRequestConfiguration } from './subjectRightsRequestItemRequestBuilderDeleteRequestConfiguration';
import { SubjectRightsRequestItemRequestBuilderGetRequestConfiguration } from './subjectRightsRequestItemRequestBuilderGetRequestConfiguration';
import { SubjectRightsRequestItemRequestBuilderPatchRequestConfiguration } from './subjectRightsRequestItemRequestBuilderPatchRequestConfiguration';
import { TeamRequestBuilder } from './team/teamRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the subjectRightsRequests property of the microsoft.graph.privacy entity. */
export declare class SubjectRightsRequestItemRequestBuilder {
    /** The notes property */
    get notes(): NotesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The team property */
    get team(): TeamRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new SubjectRightsRequestItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property subjectRightsRequests for privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: SubjectRightsRequestItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get subjectRightsRequests from privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SubjectRightsRequestItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property subjectRightsRequests in privacy
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SubjectRightsRequest | undefined, requestConfiguration?: SubjectRightsRequestItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property subjectRightsRequests for privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: SubjectRightsRequestItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get subjectRightsRequests from privacy
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SubjectRightsRequest
     */
    get(requestConfiguration?: SubjectRightsRequestItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SubjectRightsRequest | undefined>;
    /**
     * Provides operations to call the getFinalAttachment method.
     * @returns a getFinalAttachmentRequestBuilder
     */
    getFinalAttachment(): GetFinalAttachmentRequestBuilder;
    /**
     * Provides operations to call the getFinalReport method.
     * @returns a getFinalReportRequestBuilder
     */
    getFinalReport(): GetFinalReportRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.privacy.subjectRightsRequests.item.notes.item collection
     * @param id Unique identifier of the item
     * @returns a authoredNoteItemRequestBuilder
     */
    notesById(id: string): AuthoredNoteItemRequestBuilder;
    /**
     * Update the navigation property subjectRightsRequests in privacy
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SubjectRightsRequest | undefined, requestConfiguration?: SubjectRightsRequestItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
