import { SearchEntity } from '../models/';
import { QueryRequestBuilder } from './query/queryRequestBuilder';
import { SearchRequestBuilderGetRequestConfiguration } from './searchRequestBuilderGetRequestConfiguration';
import { SearchRequestBuilderPatchRequestConfiguration } from './searchRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the searchEntity singleton. */
export declare class SearchRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The query property */
    get query(): QueryRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new SearchRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get search
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SearchRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update search
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SearchEntity | undefined, requestConfiguration?: SearchRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get search
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SearchEntity
     */
    get(requestConfiguration?: SearchRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SearchEntity | undefined>;
    /**
     * Update search
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SearchEntity | undefined, requestConfiguration?: SearchRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
