import { SecureScore, SecureScoreCollectionResponse } from '../../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { SecureScoresRequestBuilderGetRequestConfiguration } from './secureScoresRequestBuilderGetRequestConfiguration';
import { SecureScoresRequestBuilderPostRequestConfiguration } from './secureScoresRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the secureScores property of the microsoft.graph.security entity. */
export declare class SecureScoresRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new SecureScoresRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get secureScores from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SecureScoresRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create new navigation property to secureScores for security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: SecureScore | undefined, requestConfiguration?: SecureScoresRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get secureScores from security
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SecureScoreCollectionResponse
     */
    get(requestConfiguration?: SecureScoresRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SecureScoreCollectionResponse | undefined>;
    /**
     * Create new navigation property to secureScores for security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SecureScore
     */
    post(body: SecureScore | undefined, requestConfiguration?: SecureScoresRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SecureScore | undefined>;
}
