import { Security } from '../models/';
import { AlertsRequestBuilder } from './alerts/alertsRequestBuilder';
import { AlertItemRequestBuilder } from './alerts/item/alertItemRequestBuilder';
import { SecureScoreControlProfileItemRequestBuilder } from './secureScoreControlProfiles/item/secureScoreControlProfileItemRequestBuilder';
import { SecureScoreControlProfilesRequestBuilder } from './secureScoreControlProfiles/secureScoreControlProfilesRequestBuilder';
import { SecureScoreItemRequestBuilder } from './secureScores/item/secureScoreItemRequestBuilder';
import { SecureScoresRequestBuilder } from './secureScores/secureScoresRequestBuilder';
import { SecurityRequestBuilderGetRequestConfiguration } from './securityRequestBuilderGetRequestConfiguration';
import { SecurityRequestBuilderPatchRequestConfiguration } from './securityRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the security singleton. */
export declare class SecurityRequestBuilder {
    /** The alerts property */
    get alerts(): AlertsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The secureScoreControlProfiles property */
    get secureScoreControlProfiles(): SecureScoreControlProfilesRequestBuilder;
    /** The secureScores property */
    get secureScores(): SecureScoresRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.alerts.item collection
     * @param id Unique identifier of the item
     * @returns a alertItemRequestBuilder
     */
    alertsById(id: string): AlertItemRequestBuilder;
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * The security resource is the entry point for the Security object model. It returns a singleton security resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SecurityRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Security | undefined, requestConfiguration?: SecurityRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * The security resource is the entry point for the Security object model. It returns a singleton security resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Security
     */
    get(requestConfiguration?: SecurityRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Security | undefined>;
    /**
     * Update security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Security | undefined, requestConfiguration?: SecurityRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScoreControlProfiles.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreControlProfileItemRequestBuilder
     */
    secureScoreControlProfilesById(id: string): SecureScoreControlProfileItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScores.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreItemRequestBuilder
     */
    secureScoresById(id: string): SecureScoreItemRequestBuilder;
}
