"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityRequestBuilder = void 0;
const createSecurityFromDiscriminatorValue_1 = require("../models/createSecurityFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const alertsRequestBuilder_1 = require("./alerts/alertsRequestBuilder");
const alertItemRequestBuilder_1 = require("./alerts/item/alertItemRequestBuilder");
const secureScoreControlProfileItemRequestBuilder_1 = require("./secureScoreControlProfiles/item/secureScoreControlProfileItemRequestBuilder");
const secureScoreControlProfilesRequestBuilder_1 = require("./secureScoreControlProfiles/secureScoreControlProfilesRequestBuilder");
const secureScoreItemRequestBuilder_1 = require("./secureScores/item/secureScoreItemRequestBuilder");
const secureScoresRequestBuilder_1 = require("./secureScores/secureScoresRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the security singleton. */
class SecurityRequestBuilder {
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/security{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The alerts property */
    get alerts() {
        return new alertsRequestBuilder_1.AlertsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The secureScoreControlProfiles property */
    get secureScoreControlProfiles() {
        return new secureScoreControlProfilesRequestBuilder_1.SecureScoreControlProfilesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The secureScores property */
    get secureScores() {
        return new secureScoresRequestBuilder_1.SecureScoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.alerts.item collection
     * @param id Unique identifier of the item
     * @returns a alertItemRequestBuilder
     */
    alertsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["alert%2Did"] = id;
        return new alertItemRequestBuilder_1.AlertItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * The security resource is the entry point for the Security object model. It returns a singleton security resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * The security resource is the entry point for the Security object model. It returns a singleton security resource. It doesn't contain any usable properties.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Security
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createSecurityFromDiscriminatorValue_1.createSecurityFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update security
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScoreControlProfiles.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreControlProfileItemRequestBuilder
     */
    secureScoreControlProfilesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["secureScoreControlProfile%2Did"] = id;
        return new secureScoreControlProfileItemRequestBuilder_1.SecureScoreControlProfileItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScores.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreItemRequestBuilder
     */
    secureScoresById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["secureScore%2Did"] = id;
        return new secureScoreItemRequestBuilder_1.SecureScoreItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.SecurityRequestBuilder = SecurityRequestBuilder;
