"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DirectoryObjectItemRequestBuilder = void 0;
const createDirectoryObjectFromDiscriminatorValue_1 = require("../../../../models/createDirectoryObjectFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const applicationRequestBuilder_1 = require("./application/applicationRequestBuilder");
const deviceRequestBuilder_1 = require("./device/deviceRequestBuilder");
const groupRequestBuilder_1 = require("./group/groupRequestBuilder");
const orgContactRequestBuilder_1 = require("./orgContact/orgContactRequestBuilder");
const servicePrincipalRequestBuilder_1 = require("./servicePrincipal/servicePrincipalRequestBuilder");
const userRequestBuilder_1 = require("./user/userRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the transitiveMemberOf property of the microsoft.graph.servicePrincipal entity. */
class DirectoryObjectItemRequestBuilder {
    /**
     * Instantiates a new DirectoryObjectItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/servicePrincipals/{servicePrincipal%2Did}/transitiveMemberOf/{directoryObject%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The application property */
    get application() {
        return new applicationRequestBuilder_1.ApplicationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The device property */
    get device() {
        return new deviceRequestBuilder_1.DeviceRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The group property */
    get group() {
        return new groupRequestBuilder_1.GroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The orgContact property */
    get orgContact() {
        return new orgContactRequestBuilder_1.OrgContactRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The servicePrincipal property */
    get servicePrincipal() {
        return new servicePrincipalRequestBuilder_1.ServicePrincipalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The user property */
    get user() {
        return new userRequestBuilder_1.UserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Get transitiveMemberOf from servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get transitiveMemberOf from servicePrincipals
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObject
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.DirectoryObjectItemRequestBuilder = DirectoryObjectItemRequestBuilder;
