import { Permission } from '../../../models/';
import { GrantRequestBuilder } from './grant/grantRequestBuilder';
import { PermissionRequestBuilderDeleteRequestConfiguration } from './permissionRequestBuilderDeleteRequestConfiguration';
import { PermissionRequestBuilderGetRequestConfiguration } from './permissionRequestBuilderGetRequestConfiguration';
import { PermissionRequestBuilderPatchRequestConfiguration } from './permissionRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the permission property of the microsoft.graph.sharedDriveItem entity. */
export declare class PermissionRequestBuilder {
    /** The grant property */
    get grant(): GrantRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new PermissionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property permission for shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: PermissionRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Used to access the permission representing the underlying sharing link
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: PermissionRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property permission in shares
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Permission | undefined, requestConfiguration?: PermissionRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property permission for shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: PermissionRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Used to access the permission representing the underlying sharing link
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Permission
     */
    get(requestConfiguration?: PermissionRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Permission | undefined>;
    /**
     * Update the navigation property permission in shares
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Permission | undefined, requestConfiguration?: PermissionRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
