import { SharedDriveItem } from '../../models/';
import { DriveItemRequestBuilder } from './driveItem/driveItemRequestBuilder';
import { DriveItemItemRequestBuilder } from './items/item/driveItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListRequestBuilder } from './list/listRequestBuilder';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermissionRequestBuilder } from './permission/permissionRequestBuilder';
import { RootRequestBuilder } from './root/rootRequestBuilder';
import { SharedDriveItemItemRequestBuilderDeleteRequestConfiguration } from './sharedDriveItemItemRequestBuilderDeleteRequestConfiguration';
import { SharedDriveItemItemRequestBuilderGetRequestConfiguration } from './sharedDriveItemItemRequestBuilderGetRequestConfiguration';
import { SharedDriveItemItemRequestBuilderPatchRequestConfiguration } from './sharedDriveItemItemRequestBuilderPatchRequestConfiguration';
import { SiteRequestBuilder } from './site/siteRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of sharedDriveItem entities. */
export declare class SharedDriveItemItemRequestBuilder {
    /** The driveItem property */
    get driveItem(): DriveItemRequestBuilder;
    /** The items property */
    get items(): ItemsRequestBuilder;
    /** The list property */
    get list(): ListRequestBuilder;
    /** The listItem property */
    get listItem(): ListItemRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The permission property */
    get permission(): PermissionRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The root property */
    get root(): RootRequestBuilder;
    /** The site property */
    get site(): SiteRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new SharedDriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: SharedDriveItemItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Access a shared [DriveItem](../resources/driveitem.md) or a collection of shared items by using a **shareId** or sharing URL. To use a sharing URL with this API, your app needs to [transform the URL into a sharing token](#encoding-sharing-urls).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SharedDriveItemItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in shares
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SharedDriveItem | undefined, requestConfiguration?: SharedDriveItemItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from shares
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: SharedDriveItemItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Access a shared [DriveItem](../resources/driveitem.md) or a collection of shared items by using a **shareId** or sharing URL. To use a sharing URL with this API, your app needs to [transform the URL into a sharing token](#encoding-sharing-urls).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SharedDriveItem
     */
    get(requestConfiguration?: SharedDriveItemItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SharedDriveItem | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.shares.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    itemsById(id: string): DriveItemItemRequestBuilder;
    /**
     * Update entity in shares
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SharedDriveItem | undefined, requestConfiguration?: SharedDriveItemItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
