import { ColumnDefinition } from '../../../../models/';
import { ColumnDefinitionItemRequestBuilderDeleteRequestConfiguration } from './columnDefinitionItemRequestBuilderDeleteRequestConfiguration';
import { ColumnDefinitionItemRequestBuilderGetRequestConfiguration } from './columnDefinitionItemRequestBuilderGetRequestConfiguration';
import { ColumnDefinitionItemRequestBuilderPatchRequestConfiguration } from './columnDefinitionItemRequestBuilderPatchRequestConfiguration';
import { SourceColumnRequestBuilder } from './sourceColumn/sourceColumnRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the columns property of the microsoft.graph.site entity. */
export declare class ColumnDefinitionItemRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The sourceColumn property */
    get sourceColumn(): SourceColumnRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new ColumnDefinitionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property columns for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: ColumnDefinitionItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The collection of column definitions reusable across lists under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: ColumnDefinitionItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property columns in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ColumnDefinition | undefined, requestConfiguration?: ColumnDefinitionItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property columns for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: ColumnDefinitionItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The collection of column definitions reusable across lists under this site.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ColumnDefinition
     */
    get(requestConfiguration?: ColumnDefinitionItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<ColumnDefinition | undefined>;
    /**
     * Update the navigation property columns in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ColumnDefinition | undefined, requestConfiguration?: ColumnDefinitionItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
