import { Onenote } from '../../../models/';
import { NotebookItemRequestBuilder } from './notebooks/item/notebookItemRequestBuilder';
import { NotebooksRequestBuilder } from './notebooks/notebooksRequestBuilder';
import { OnenoteRequestBuilderDeleteRequestConfiguration } from './onenoteRequestBuilderDeleteRequestConfiguration';
import { OnenoteRequestBuilderGetRequestConfiguration } from './onenoteRequestBuilderGetRequestConfiguration';
import { OnenoteRequestBuilderPatchRequestConfiguration } from './onenoteRequestBuilderPatchRequestConfiguration';
import { OnenoteOperationItemRequestBuilder } from './operations/item/onenoteOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { OnenotePageItemRequestBuilder } from './pages/item/onenotePageItemRequestBuilder';
import { PagesRequestBuilder } from './pages/pagesRequestBuilder';
import { OnenoteResourceItemRequestBuilder } from './resources/item/onenoteResourceItemRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { SectionGroupItemRequestBuilder } from './sectionGroups/item/sectionGroupItemRequestBuilder';
import { SectionGroupsRequestBuilder } from './sectionGroups/sectionGroupsRequestBuilder';
import { OnenoteSectionItemRequestBuilder } from './sections/item/onenoteSectionItemRequestBuilder';
import { SectionsRequestBuilder } from './sections/sectionsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the onenote property of the microsoft.graph.site entity. */
export declare class OnenoteRequestBuilder {
    /** The notebooks property */
    get notebooks(): NotebooksRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** The pages property */
    get pages(): PagesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The resources property */
    get resources(): ResourcesRequestBuilder;
    /** The sectionGroups property */
    get sectionGroups(): SectionGroupsRequestBuilder;
    /** The sections property */
    get sections(): SectionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new OnenoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property onenote for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: OnenoteRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: OnenoteRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property onenote in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Onenote | undefined, requestConfiguration?: OnenoteRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property onenote for sites
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: OnenoteRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Onenote
     */
    get(requestConfiguration?: OnenoteRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Onenote | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.notebooks.item collection
     * @param id Unique identifier of the item
     * @returns a notebookItemRequestBuilder
     */
    notebooksById(id: string): NotebookItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.operations.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteOperationItemRequestBuilder
     */
    operationsById(id: string): OnenoteOperationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.pages.item collection
     * @param id Unique identifier of the item
     * @returns a onenotePageItemRequestBuilder
     */
    pagesById(id: string): OnenotePageItemRequestBuilder;
    /**
     * Update the navigation property onenote in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Onenote | undefined, requestConfiguration?: OnenoteRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.resources.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteResourceItemRequestBuilder
     */
    resourcesById(id: string): OnenoteResourceItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sectionGroups.item collection
     * @param id Unique identifier of the item
     * @returns a sectionGroupItemRequestBuilder
     */
    sectionGroupsById(id: string): SectionGroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sections.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteSectionItemRequestBuilder
     */
    sectionsById(id: string): OnenoteSectionItemRequestBuilder;
}
