"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SiteItemRequestBuilder = void 0;
const createSiteFromDiscriminatorValue_1 = require("../../models/createSiteFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const analyticsRequestBuilder_1 = require("./analytics/analyticsRequestBuilder");
const columnsRequestBuilder_1 = require("./columns/columnsRequestBuilder");
const columnDefinitionItemRequestBuilder_1 = require("./columns/item/columnDefinitionItemRequestBuilder");
const contentTypesRequestBuilder_1 = require("./contentTypes/contentTypesRequestBuilder");
const contentTypeItemRequestBuilder_1 = require("./contentTypes/item/contentTypeItemRequestBuilder");
const driveRequestBuilder_1 = require("./drive/driveRequestBuilder");
const drivesRequestBuilder_1 = require("./drives/drivesRequestBuilder");
const driveItemRequestBuilder_1 = require("./drives/item/driveItemRequestBuilder");
const externalColumnsRequestBuilder_1 = require("./externalColumns/externalColumnsRequestBuilder");
const columnDefinitionItemRequestBuilder_2 = require("./externalColumns/item/columnDefinitionItemRequestBuilder");
const getActivitiesByIntervalRequestBuilder_1 = require("./getActivitiesByInterval/getActivitiesByIntervalRequestBuilder");
const getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder_1 = require("./getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder");
const getApplicableContentTypesForListWithListIdRequestBuilder_1 = require("./getApplicableContentTypesForListWithListId/getApplicableContentTypesForListWithListIdRequestBuilder");
const getByPathWithPathRequestBuilder_1 = require("./getByPathWithPath/getByPathWithPathRequestBuilder");
const baseItemItemRequestBuilder_1 = require("./items/item/baseItemItemRequestBuilder");
const itemsRequestBuilder_1 = require("./items/itemsRequestBuilder");
const listItemRequestBuilder_1 = require("./lists/item/listItemRequestBuilder");
const listsRequestBuilder_1 = require("./lists/listsRequestBuilder");
const onenoteRequestBuilder_1 = require("./onenote/onenoteRequestBuilder");
const richLongRunningOperationItemRequestBuilder_1 = require("./operations/item/richLongRunningOperationItemRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const permissionItemRequestBuilder_1 = require("./permissions/item/permissionItemRequestBuilder");
const permissionsRequestBuilder_1 = require("./permissions/permissionsRequestBuilder");
const siteItemRequestBuilder_1 = require("./sites/item/siteItemRequestBuilder");
const sitesRequestBuilder_1 = require("./sites/sitesRequestBuilder");
const termStoreRequestBuilder_1 = require("./termStore/termStoreRequestBuilder");
const storeItemRequestBuilder_1 = require("./termStores/item/storeItemRequestBuilder");
const termStoresRequestBuilder_1 = require("./termStores/termStoresRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of site entities. */
class SiteItemRequestBuilder {
    /**
     * Instantiates a new SiteItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/sites/{site%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The analytics property */
    get analytics() {
        return new analyticsRequestBuilder_1.AnalyticsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The columns property */
    get columns() {
        return new columnsRequestBuilder_1.ColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The contentTypes property */
    get contentTypes() {
        return new contentTypesRequestBuilder_1.ContentTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The drive property */
    get drive() {
        return new driveRequestBuilder_1.DriveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The drives property */
    get drives() {
        return new drivesRequestBuilder_1.DrivesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The externalColumns property */
    get externalColumns() {
        return new externalColumnsRequestBuilder_1.ExternalColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The items property */
    get items() {
        return new itemsRequestBuilder_1.ItemsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The lists property */
    get lists() {
        return new listsRequestBuilder_1.ListsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The onenote property */
    get onenote() {
        return new onenoteRequestBuilder_1.OnenoteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The operations property */
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The permissions property */
    get permissions() {
        return new permissionsRequestBuilder_1.PermissionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The sites property */
    get sites() {
        return new sitesRequestBuilder_1.SitesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The termStore property */
    get termStore() {
        return new termStoreRequestBuilder_1.TermStoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The termStores property */
    get termStores() {
        return new termStoresRequestBuilder_1.TermStoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition%2Did"] = id;
        return new columnDefinitionItemRequestBuilder_1.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["contentType%2Did"] = id;
        return new contentTypeItemRequestBuilder_1.ContentTypeItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Retrieve properties and relationships for a [site][] resource.A **site** resource represents a team site in SharePoint.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update entity in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.drives.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemRequestBuilder
     */
    drivesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["drive%2Did"] = id;
        return new driveItemRequestBuilder_1.DriveItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.externalColumns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    externalColumnsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition%2Did"] = id;
        return new columnDefinitionItemRequestBuilder_2.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Retrieve properties and relationships for a [site][] resource.A **site** resource represents a team site in SharePoint.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Site
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createSiteFromDiscriminatorValue_1.createSiteFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @returns a getActivitiesByIntervalRequestBuilder
     */
    getActivitiesByInterval() {
        return new getActivitiesByIntervalRequestBuilder_1.GetActivitiesByIntervalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime, interval, startDateTime) {
        if (!endDateTime)
            throw new Error("endDateTime cannot be undefined");
        if (!interval)
            throw new Error("interval cannot be undefined");
        if (!startDateTime)
            throw new Error("startDateTime cannot be undefined");
        return new getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder_1.GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder(this.pathParameters, this.requestAdapter, endDateTime, interval, startDateTime);
    }
    ;
    /**
     * Provides operations to call the getApplicableContentTypesForList method.
     * @param listId Usage: listId='{listId}'
     * @returns a getApplicableContentTypesForListWithListIdRequestBuilder
     */
    getApplicableContentTypesForListWithListId(listId) {
        if (!listId)
            throw new Error("listId cannot be undefined");
        return new getApplicableContentTypesForListWithListIdRequestBuilder_1.GetApplicableContentTypesForListWithListIdRequestBuilder(this.pathParameters, this.requestAdapter, listId);
    }
    ;
    /**
     * Provides operations to call the getByPath method.
     * @param path Usage: path='{path}'
     * @returns a getByPathWithPathRequestBuilder
     */
    getByPathWithPath(path) {
        if (!path)
            throw new Error("path cannot be undefined");
        return new getByPathWithPathRequestBuilder_1.GetByPathWithPathRequestBuilder(this.pathParameters, this.requestAdapter, path);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a baseItemItemRequestBuilder
     */
    itemsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["baseItem%2Did"] = id;
        return new baseItemItemRequestBuilder_1.BaseItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item collection
     * @param id Unique identifier of the item
     * @returns a listItemRequestBuilder
     */
    listsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["list%2Did"] = id;
        return new listItemRequestBuilder_1.ListItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a richLongRunningOperationItemRequestBuilder
     */
    operationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["richLongRunningOperation%2Did"] = id;
        return new richLongRunningOperationItemRequestBuilder_1.RichLongRunningOperationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update entity in sites
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["permission%2Did"] = id;
        return new permissionItemRequestBuilder_1.PermissionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.sites.item collection
     * @param id Unique identifier of the item
     * @returns a siteItemRequestBuilder
     */
    sitesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["site%2Did1"] = id;
        return new siteItemRequestBuilder_1.SiteItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.termStores.item collection
     * @param id Unique identifier of the item
     * @returns a storeItemRequestBuilder
     */
    termStoresById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["store%2Did"] = id;
        return new storeItemRequestBuilder_1.StoreItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.SiteItemRequestBuilder = SiteItemRequestBuilder;
