"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BookingBusinessItemRequestBuilder = void 0;
const createBookingBusinessFromDiscriminatorValue_1 = require("../../../models/createBookingBusinessFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const appointmentsRequestBuilder_1 = require("./appointments/appointmentsRequestBuilder");
const bookingAppointmentItemRequestBuilder_1 = require("./appointments/item/bookingAppointmentItemRequestBuilder");
const calendarViewRequestBuilder_1 = require("./calendarView/calendarViewRequestBuilder");
const bookingAppointmentItemRequestBuilder_2 = require("./calendarView/item/bookingAppointmentItemRequestBuilder");
const customersRequestBuilder_1 = require("./customers/customersRequestBuilder");
const bookingCustomerBaseItemRequestBuilder_1 = require("./customers/item/bookingCustomerBaseItemRequestBuilder");
const customQuestionsRequestBuilder_1 = require("./customQuestions/customQuestionsRequestBuilder");
const bookingCustomQuestionItemRequestBuilder_1 = require("./customQuestions/item/bookingCustomQuestionItemRequestBuilder");
const publishRequestBuilder_1 = require("./publish/publishRequestBuilder");
const bookingServiceItemRequestBuilder_1 = require("./services/item/bookingServiceItemRequestBuilder");
const servicesRequestBuilder_1 = require("./services/servicesRequestBuilder");
const bookingStaffMemberBaseItemRequestBuilder_1 = require("./staffMembers/item/bookingStaffMemberBaseItemRequestBuilder");
const staffMembersRequestBuilder_1 = require("./staffMembers/staffMembersRequestBuilder");
const unpublishRequestBuilder_1 = require("./unpublish/unpublishRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the bookingBusinesses property of the microsoft.graph.solutionsRoot entity. */
class BookingBusinessItemRequestBuilder {
    /**
     * Instantiates a new BookingBusinessItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/solutions/bookingBusinesses/{bookingBusiness%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The appointments property */
    get appointments() {
        return new appointmentsRequestBuilder_1.AppointmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The calendarView property */
    get calendarView() {
        return new calendarViewRequestBuilder_1.CalendarViewRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The customers property */
    get customers() {
        return new customersRequestBuilder_1.CustomersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The customQuestions property */
    get customQuestions() {
        return new customQuestionsRequestBuilder_1.CustomQuestionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The publish property */
    get publish() {
        return new publishRequestBuilder_1.PublishRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The services property */
    get services() {
        return new servicesRequestBuilder_1.ServicesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The staffMembers property */
    get staffMembers() {
        return new staffMembersRequestBuilder_1.StaffMembersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The unpublish property */
    get unpublish() {
        return new unpublishRequestBuilder_1.UnpublishRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.appointments.item collection
     * @param id Unique identifier of the item
     * @returns a bookingAppointmentItemRequestBuilder
     */
    appointmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingAppointment%2Did"] = id;
        return new bookingAppointmentItemRequestBuilder_1.BookingAppointmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.calendarView.item collection
     * @param id Unique identifier of the item
     * @returns a bookingAppointmentItemRequestBuilder
     */
    calendarViewById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingAppointment%2Did"] = id;
        return new bookingAppointmentItemRequestBuilder_2.BookingAppointmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property bookingBusinesses for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get bookingBusinesses from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property bookingBusinesses in solutions
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.customers.item collection
     * @param id Unique identifier of the item
     * @returns a bookingCustomerBaseItemRequestBuilder
     */
    customersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingCustomerBase%2Did"] = id;
        return new bookingCustomerBaseItemRequestBuilder_1.BookingCustomerBaseItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.customQuestions.item collection
     * @param id Unique identifier of the item
     * @returns a bookingCustomQuestionItemRequestBuilder
     */
    customQuestionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingCustomQuestion%2Did"] = id;
        return new bookingCustomQuestionItemRequestBuilder_1.BookingCustomQuestionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property bookingBusinesses for solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Get bookingBusinesses from solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of BookingBusiness
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createBookingBusinessFromDiscriminatorValue_1.createBookingBusinessFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property bookingBusinesses in solutions
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.services.item collection
     * @param id Unique identifier of the item
     * @returns a bookingServiceItemRequestBuilder
     */
    servicesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingService%2Did"] = id;
        return new bookingServiceItemRequestBuilder_1.BookingServiceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item.staffMembers.item collection
     * @param id Unique identifier of the item
     * @returns a bookingStaffMemberBaseItemRequestBuilder
     */
    staffMembersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["bookingStaffMemberBase%2Did"] = id;
        return new bookingStaffMemberBaseItemRequestBuilder_1.BookingStaffMemberBaseItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.BookingBusinessItemRequestBuilder = BookingBusinessItemRequestBuilder;
