import { SolutionsRoot } from '../models/';
import { BookingBusinessesRequestBuilder } from './bookingBusinesses/bookingBusinessesRequestBuilder';
import { BookingBusinessItemRequestBuilder } from './bookingBusinesses/item/bookingBusinessItemRequestBuilder';
import { BookingCurrenciesRequestBuilder } from './bookingCurrencies/bookingCurrenciesRequestBuilder';
import { BookingCurrencyItemRequestBuilder } from './bookingCurrencies/item/bookingCurrencyItemRequestBuilder';
import { SolutionsRequestBuilderGetRequestConfiguration } from './solutionsRequestBuilderGetRequestConfiguration';
import { SolutionsRequestBuilderPatchRequestConfiguration } from './solutionsRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the solutionsRoot singleton. */
export declare class SolutionsRequestBuilder {
    /** The bookingBusinesses property */
    get bookingBusinesses(): BookingBusinessesRequestBuilder;
    /** The bookingCurrencies property */
    get bookingCurrencies(): BookingCurrenciesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingBusinesses.item collection
     * @param id Unique identifier of the item
     * @returns a bookingBusinessItemRequestBuilder
     */
    bookingBusinessesById(id: string): BookingBusinessItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.solutions.bookingCurrencies.item collection
     * @param id Unique identifier of the item
     * @returns a bookingCurrencyItemRequestBuilder
     */
    bookingCurrenciesById(id: string): BookingCurrencyItemRequestBuilder;
    /**
     * Instantiates a new SolutionsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SolutionsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update solutions
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SolutionsRoot | undefined, requestConfiguration?: SolutionsRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Get solutions
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SolutionsRoot
     */
    get(requestConfiguration?: SolutionsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SolutionsRoot | undefined>;
    /**
     * Update solutions
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SolutionsRoot | undefined, requestConfiguration?: SolutionsRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
