import { SubscribedSku } from '../../models/';
import { SubscribedSkuItemRequestBuilderDeleteRequestConfiguration } from './subscribedSkuItemRequestBuilderDeleteRequestConfiguration';
import { SubscribedSkuItemRequestBuilderGetRequestConfiguration } from './subscribedSkuItemRequestBuilderGetRequestConfiguration';
import { SubscribedSkuItemRequestBuilderPatchRequestConfiguration } from './subscribedSkuItemRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of subscribedSku entities. */
export declare class SubscribedSkuItemRequestBuilder {
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new SubscribedSkuItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: SubscribedSkuItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Get a specific commercial subscription that an organization has acquired.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: SubscribedSkuItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update entity in subscribedSkus
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: SubscribedSku | undefined, requestConfiguration?: SubscribedSkuItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from subscribedSkus
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: SubscribedSkuItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get a specific commercial subscription that an organization has acquired.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SubscribedSku
     */
    get(requestConfiguration?: SubscribedSkuItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<SubscribedSku | undefined>;
    /**
     * Update entity in subscribedSkus
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: SubscribedSku | undefined, requestConfiguration?: SubscribedSkuItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
