import { Team } from '../../models/';
import { ArchiveRequestBuilder } from './archive/archiveRequestBuilder';
import { ChannelsRequestBuilder } from './channels/channelsRequestBuilder';
import { ChannelItemRequestBuilder } from './channels/item/channelItemRequestBuilder';
import { CloneRequestBuilder } from './clone/cloneRequestBuilder';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { TeamsAppInstallationItemRequestBuilder } from './installedApps/item/teamsAppInstallationItemRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { TeamsAsyncOperationItemRequestBuilder } from './operations/item/teamsAsyncOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrimaryChannelRequestBuilder } from './primaryChannel/primaryChannelRequestBuilder';
import { ScheduleRequestBuilder } from './schedule/scheduleRequestBuilder';
import { SendActivityNotificationRequestBuilder } from './sendActivityNotification/sendActivityNotificationRequestBuilder';
import { TeamItemRequestBuilderDeleteRequestConfiguration } from './teamItemRequestBuilderDeleteRequestConfiguration';
import { TeamItemRequestBuilderGetRequestConfiguration } from './teamItemRequestBuilderGetRequestConfiguration';
import { TeamItemRequestBuilderPatchRequestConfiguration } from './teamItemRequestBuilderPatchRequestConfiguration';
import { TemplateRequestBuilder } from './template/templateRequestBuilder';
import { UnarchiveRequestBuilder } from './unarchive/unarchiveRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of team entities. */
export declare class TeamItemRequestBuilder {
    /** The archive property */
    get archive(): ArchiveRequestBuilder;
    /** The channels property */
    get channels(): ChannelsRequestBuilder;
    /** The clone property */
    get clone(): CloneRequestBuilder;
    /** The completeMigration property */
    get completeMigration(): CompleteMigrationRequestBuilder;
    /** The group property */
    get group(): GroupRequestBuilder;
    /** The installedApps property */
    get installedApps(): InstalledAppsRequestBuilder;
    /** The members property */
    get members(): MembersRequestBuilder;
    /** The operations property */
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The primaryChannel property */
    get primaryChannel(): PrimaryChannelRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The schedule property */
    get schedule(): ScheduleRequestBuilder;
    /** The sendActivityNotification property */
    get sendActivityNotification(): SendActivityNotificationRequestBuilder;
    /** The template property */
    get template(): TemplateRequestBuilder;
    /** The unarchive property */
    get unarchive(): UnarchiveRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.channels.item collection
     * @param id Unique identifier of the item
     * @returns a channelItemRequestBuilder
     */
    channelsById(id: string): ChannelItemRequestBuilder;
    /**
     * Instantiates a new TeamItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: TeamItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Retrieve the properties and relationships of the specified [team](../resources/team.md).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TeamItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the properties of the specified [team](../resources/team.md).
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Team | undefined, requestConfiguration?: TeamItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete entity from teams
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: TeamItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Retrieve the properties and relationships of the specified [team](../resources/team.md).
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    get(requestConfiguration?: TeamItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Team | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id: string): TeamsAppInstallationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.teams.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAsyncOperationItemRequestBuilder
     */
    operationsById(id: string): TeamsAsyncOperationItemRequestBuilder;
    /**
     * Update the properties of the specified [team](../resources/team.md).
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Team | undefined, requestConfiguration?: TeamItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
