import { Team, TeamCollectionResponse } from '../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { GetAllMessagesRequestBuilder } from './getAllMessages/getAllMessagesRequestBuilder';
import { TeamsRequestBuilderGetRequestConfiguration } from './teamsRequestBuilderGetRequestConfiguration';
import { TeamsRequestBuilderPostRequestConfiguration } from './teamsRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of team entities. */
export declare class TeamsRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new TeamsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * List all [teams](../resources/team.md) in an organization.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TeamsRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Create a new [team](../resources/team.md).
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: Team | undefined, requestConfiguration?: TeamsRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * List all [teams](../resources/team.md) in an organization.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of TeamCollectionResponse
     */
    get(requestConfiguration?: TeamsRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<TeamCollectionResponse | undefined>;
    /**
     * Provides operations to call the getAllMessages method.
     * @returns a getAllMessagesRequestBuilder
     */
    getAllMessages(): GetAllMessagesRequestBuilder;
    /**
     * Create a new [team](../resources/team.md).
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    post(body: Team | undefined, requestConfiguration?: TeamsRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Team | undefined>;
}
