import { Authentication } from '../../../models/';
import { AuthenticationRequestBuilderDeleteRequestConfiguration } from './authenticationRequestBuilderDeleteRequestConfiguration';
import { AuthenticationRequestBuilderGetRequestConfiguration } from './authenticationRequestBuilderGetRequestConfiguration';
import { AuthenticationRequestBuilderPatchRequestConfiguration } from './authenticationRequestBuilderPatchRequestConfiguration';
import { Fido2MethodsRequestBuilder } from './fido2Methods/fido2MethodsRequestBuilder';
import { Fido2AuthenticationMethodItemRequestBuilder } from './fido2Methods/item/fido2AuthenticationMethodItemRequestBuilder';
import { AuthenticationMethodItemRequestBuilder } from './methods/item/authenticationMethodItemRequestBuilder';
import { MethodsRequestBuilder } from './methods/methodsRequestBuilder';
import { MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder } from './microsoftAuthenticatorMethods/item/microsoftAuthenticatorAuthenticationMethodItemRequestBuilder';
import { MicrosoftAuthenticatorMethodsRequestBuilder } from './microsoftAuthenticatorMethods/microsoftAuthenticatorMethodsRequestBuilder';
import { WindowsHelloForBusinessAuthenticationMethodItemRequestBuilder } from './windowsHelloForBusinessMethods/item/windowsHelloForBusinessAuthenticationMethodItemRequestBuilder';
import { WindowsHelloForBusinessMethodsRequestBuilder } from './windowsHelloForBusinessMethods/windowsHelloForBusinessMethodsRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the authentication property of the microsoft.graph.user entity. */
export declare class AuthenticationRequestBuilder {
    /** The fido2Methods property */
    get fido2Methods(): Fido2MethodsRequestBuilder;
    /** The methods property */
    get methods(): MethodsRequestBuilder;
    /** The microsoftAuthenticatorMethods property */
    get microsoftAuthenticatorMethods(): MicrosoftAuthenticatorMethodsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /** The windowsHelloForBusinessMethods property */
    get windowsHelloForBusinessMethods(): WindowsHelloForBusinessMethodsRequestBuilder;
    /**
     * Instantiates a new AuthenticationRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property authentication for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: AuthenticationRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * TODO: Add Description
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: AuthenticationRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property authentication in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Authentication | undefined, requestConfiguration?: AuthenticationRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property authentication for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: AuthenticationRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.fido2Methods.item collection
     * @param id Unique identifier of the item
     * @returns a fido2AuthenticationMethodItemRequestBuilder
     */
    fido2MethodsById(id: string): Fido2AuthenticationMethodItemRequestBuilder;
    /**
     * TODO: Add Description
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Authentication
     */
    get(requestConfiguration?: AuthenticationRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Authentication | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.methods.item collection
     * @param id Unique identifier of the item
     * @returns a authenticationMethodItemRequestBuilder
     */
    methodsById(id: string): AuthenticationMethodItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item collection
     * @param id Unique identifier of the item
     * @returns a microsoftAuthenticatorAuthenticationMethodItemRequestBuilder
     */
    microsoftAuthenticatorMethodsById(id: string): MicrosoftAuthenticatorAuthenticationMethodItemRequestBuilder;
    /**
     * Update the navigation property authentication in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Authentication | undefined, requestConfiguration?: AuthenticationRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item collection
     * @param id Unique identifier of the item
     * @returns a windowsHelloForBusinessAuthenticationMethodItemRequestBuilder
     */
    windowsHelloForBusinessMethodsById(id: string): WindowsHelloForBusinessAuthenticationMethodItemRequestBuilder;
}
