import { Device } from '../../../../../../models/';
import { DeviceRequestBuilderDeleteRequestConfiguration } from './deviceRequestBuilderDeleteRequestConfiguration';
import { DeviceRequestBuilderGetRequestConfiguration } from './deviceRequestBuilderGetRequestConfiguration';
import { DeviceRequestBuilderPatchRequestConfiguration } from './deviceRequestBuilderPatchRequestConfiguration';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i6273be064a7d23653d3a118d566f23273454933149baa8d66e9cd2bc461570d0 } from './memberOf/item/directoryObjectItemRequestBuilder';
import { MemberOfRequestBuilder } from './memberOf/memberOfRequestBuilder';
import { DirectoryObjectItemRequestBuilder as ib4b80f30cf7382fdcbe4f94259904c32c2e22ffde3c0ece465fef7e5cd59e9fe } from './registeredOwners/item/directoryObjectItemRequestBuilder';
import { RegisteredOwnersRequestBuilder } from './registeredOwners/registeredOwnersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as ib56123924933387f3d527a6a2ef453456206373b86589e8b7f9f9f216bf0b2d6 } from './registeredUsers/item/directoryObjectItemRequestBuilder';
import { RegisteredUsersRequestBuilder } from './registeredUsers/registeredUsersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as iad1f66921ef4a3afaec8e39c72e53b5d0304fd9392c239556849669b1de53a54 } from './transitiveMemberOf/item/directoryObjectItemRequestBuilder';
import { TransitiveMemberOfRequestBuilder } from './transitiveMemberOf/transitiveMemberOfRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the device property of the microsoft.graph.microsoftAuthenticatorAuthenticationMethod entity. */
export declare class DeviceRequestBuilder {
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The memberOf property */
    get memberOf(): MemberOfRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The registeredOwners property */
    get registeredOwners(): RegisteredOwnersRequestBuilder;
    /** The registeredUsers property */
    get registeredUsers(): RegisteredUsersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The transitiveMemberOf property */
    get transitiveMemberOf(): TransitiveMemberOfRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DeviceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property device for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The registered device on which Microsoft Authenticator resides. This property is null if the device is not registered for passwordless Phone Sign-In.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property device in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property device for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item.device.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The registered device on which Microsoft Authenticator resides. This property is null if the device is not registered for passwordless Phone Sign-In.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Device
     */
    get(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Device | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item.device.memberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    memberOfById(id: string): i6273be064a7d23653d3a118d566f23273454933149baa8d66e9cd2bc461570d0;
    /**
     * Update the navigation property device in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item.device.registeredOwners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredOwnersById(id: string): ib4b80f30cf7382fdcbe4f94259904c32c2e22ffde3c0ece465fef7e5cd59e9fe;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item.device.registeredUsers.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredUsersById(id: string): ib56123924933387f3d527a6a2ef453456206373b86589e8b7f9f9f216bf0b2d6;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.microsoftAuthenticatorMethods.item.device.transitiveMemberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    transitiveMemberOfById(id: string): iad1f66921ef4a3afaec8e39c72e53b5d0304fd9392c239556849669b1de53a54;
}
