"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RegisteredUsersRequestBuilder = void 0;
const createDirectoryObjectCollectionResponseFromDiscriminatorValue_1 = require("../../../../../../../models/createDirectoryObjectCollectionResponseFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const appRoleAssignmentRequestBuilder_1 = require("./appRoleAssignment/appRoleAssignmentRequestBuilder");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const endpointRequestBuilder_1 = require("./endpoint/endpointRequestBuilder");
const servicePrincipalRequestBuilder_1 = require("./servicePrincipal/servicePrincipalRequestBuilder");
const userRequestBuilder_1 = require("./user/userRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the registeredUsers property of the microsoft.graph.device entity. */
class RegisteredUsersRequestBuilder {
    /**
     * Instantiates a new RegisteredUsersRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/users/{user%2Did}/authentication/microsoftAuthenticatorMethods/{microsoftAuthenticatorAuthenticationMethod%2Did}/device/registeredUsers{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The appRoleAssignment property */
    get appRoleAssignment() {
        return new appRoleAssignmentRequestBuilder_1.AppRoleAssignmentRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The count property */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The endpoint property */
    get endpoint() {
        return new endpointRequestBuilder_1.EndpointRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The servicePrincipal property */
    get servicePrincipal() {
        return new servicePrincipalRequestBuilder_1.ServicePrincipalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The user property */
    get user() {
        return new userRequestBuilder_1.UserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Collection of registered users of the device. For cloud joined devices and registered personal devices, registered users are set to the same value as registered owners at the time of registration. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Collection of registered users of the device. For cloud joined devices and registered personal devices, registered users are set to the same value as registered owners at the time of registration. Read-only. Nullable. Supports $expand.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DirectoryObjectCollectionResponse
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDirectoryObjectCollectionResponseFromDiscriminatorValue_1.createDirectoryObjectCollectionResponseFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.RegisteredUsersRequestBuilder = RegisteredUsersRequestBuilder;
