import { Device } from '../../../../../../models/';
import { DeviceRequestBuilderDeleteRequestConfiguration } from './deviceRequestBuilderDeleteRequestConfiguration';
import { DeviceRequestBuilderGetRequestConfiguration } from './deviceRequestBuilderGetRequestConfiguration';
import { DeviceRequestBuilderPatchRequestConfiguration } from './deviceRequestBuilderPatchRequestConfiguration';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i144bde85a1dc37bef274f1f1047dbe8f46ab462ca15075f3c3f2af4100a3d153 } from './memberOf/item/directoryObjectItemRequestBuilder';
import { MemberOfRequestBuilder } from './memberOf/memberOfRequestBuilder';
import { DirectoryObjectItemRequestBuilder as iebe4df9035bad7f9ff6722615d9a10094f882e6df2ad9b9b6338f614c6a54809 } from './registeredOwners/item/directoryObjectItemRequestBuilder';
import { RegisteredOwnersRequestBuilder } from './registeredOwners/registeredOwnersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as if6ae4459e60b2457da004aea499b47b92ae888cf55056587c39f9f30b00fe7cb } from './registeredUsers/item/directoryObjectItemRequestBuilder';
import { RegisteredUsersRequestBuilder } from './registeredUsers/registeredUsersRequestBuilder';
import { DirectoryObjectItemRequestBuilder as i2a015add602cb3d2c4d2fb8daa3226a2871f79a7ca41d3b4f1f865d39137d35e } from './transitiveMemberOf/item/directoryObjectItemRequestBuilder';
import { TransitiveMemberOfRequestBuilder } from './transitiveMemberOf/transitiveMemberOfRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the device property of the microsoft.graph.windowsHelloForBusinessAuthenticationMethod entity. */
export declare class DeviceRequestBuilder {
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The memberOf property */
    get memberOf(): MemberOfRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The registeredOwners property */
    get registeredOwners(): RegisteredOwnersRequestBuilder;
    /** The registeredUsers property */
    get registeredUsers(): RegisteredUsersRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The transitiveMemberOf property */
    get transitiveMemberOf(): TransitiveMemberOfRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new DeviceRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property device for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property device in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property device for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: DeviceRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item.device.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Device
     */
    get(requestConfiguration?: DeviceRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Device | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item.device.memberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    memberOfById(id: string): i144bde85a1dc37bef274f1f1047dbe8f46ab462ca15075f3c3f2af4100a3d153;
    /**
     * Update the navigation property device in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Device | undefined, requestConfiguration?: DeviceRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item.device.registeredOwners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredOwnersById(id: string): iebe4df9035bad7f9ff6722615d9a10094f882e6df2ad9b9b6338f614c6a54809;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item.device.registeredUsers.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    registeredUsersById(id: string): if6ae4459e60b2457da004aea499b47b92ae888cf55056587c39f9f30b00fe7cb;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.authentication.windowsHelloForBusinessMethods.item.device.transitiveMemberOf.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    transitiveMemberOfById(id: string): i2a015add602cb3d2c4d2fb8daa3226a2871f79a7ca41d3b4f1f865d39137d35e;
}
