"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventItemRequestBuilder = void 0;
const createEventFromDiscriminatorValue_1 = require("../../../../models/createEventFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const acceptRequestBuilder_1 = require("./accept/acceptRequestBuilder");
const attachmentsRequestBuilder_1 = require("./attachments/attachmentsRequestBuilder");
const attachmentItemRequestBuilder_1 = require("./attachments/item/attachmentItemRequestBuilder");
const calendarRequestBuilder_1 = require("./calendar/calendarRequestBuilder");
const cancelRequestBuilder_1 = require("./cancel/cancelRequestBuilder");
const declineRequestBuilder_1 = require("./decline/declineRequestBuilder");
const dismissReminderRequestBuilder_1 = require("./dismissReminder/dismissReminderRequestBuilder");
const extensionsRequestBuilder_1 = require("./extensions/extensionsRequestBuilder");
const extensionItemRequestBuilder_1 = require("./extensions/item/extensionItemRequestBuilder");
const forwardRequestBuilder_1 = require("./forward/forwardRequestBuilder");
const instancesRequestBuilder_1 = require("./instances/instancesRequestBuilder");
const eventItemRequestBuilder_1 = require("./instances/item/eventItemRequestBuilder");
const multiValueLegacyExtendedPropertyItemRequestBuilder_1 = require("./multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder");
const multiValueExtendedPropertiesRequestBuilder_1 = require("./multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder");
const singleValueLegacyExtendedPropertyItemRequestBuilder_1 = require("./singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder");
const singleValueExtendedPropertiesRequestBuilder_1 = require("./singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder");
const snoozeReminderRequestBuilder_1 = require("./snoozeReminder/snoozeReminderRequestBuilder");
const tentativelyAcceptRequestBuilder_1 = require("./tentativelyAccept/tentativelyAcceptRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the events property of the microsoft.graph.user entity. */
class EventItemRequestBuilder {
    /**
     * Instantiates a new EventItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/users/{user%2Did}/events/{event%2Did}{?%24select}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The accept property */
    get accept() {
        return new acceptRequestBuilder_1.AcceptRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The attachments property */
    get attachments() {
        return new attachmentsRequestBuilder_1.AttachmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The calendar property */
    get calendar() {
        return new calendarRequestBuilder_1.CalendarRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The cancel property */
    get cancel() {
        return new cancelRequestBuilder_1.CancelRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The decline property */
    get decline() {
        return new declineRequestBuilder_1.DeclineRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The dismissReminder property */
    get dismissReminder() {
        return new dismissReminderRequestBuilder_1.DismissReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The extensions property */
    get extensions() {
        return new extensionsRequestBuilder_1.ExtensionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The forward property */
    get forward() {
        return new forwardRequestBuilder_1.ForwardRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The instances property */
    get instances() {
        return new instancesRequestBuilder_1.InstancesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The multiValueExtendedProperties property */
    get multiValueExtendedProperties() {
        return new multiValueExtendedPropertiesRequestBuilder_1.MultiValueExtendedPropertiesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The singleValueExtendedProperties property */
    get singleValueExtendedProperties() {
        return new singleValueExtendedPropertiesRequestBuilder_1.SingleValueExtendedPropertiesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The snoozeReminder property */
    get snoozeReminder() {
        return new snoozeReminderRequestBuilder_1.SnoozeReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The tentativelyAccept property */
    get tentativelyAccept() {
        return new tentativelyAcceptRequestBuilder_1.TentativelyAcceptRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.events.item.attachments.item collection
     * @param id Unique identifier of the item
     * @returns a attachmentItemRequestBuilder
     */
    attachmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["attachment%2Did"] = id;
        return new attachmentItemRequestBuilder_1.AttachmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property events for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * The user's events. Default is to show events under the Default Calendar. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property events in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property events for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.events.item.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["extension%2Did"] = id;
        return new extensionItemRequestBuilder_1.ExtensionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * The user's events. Default is to show events under the Default Calendar. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Event
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createEventFromDiscriminatorValue_1.createEventFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.events.item.instances.item collection
     * @param id Unique identifier of the item
     * @returns a eventItemRequestBuilder
     */
    instancesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["event%2Did1"] = id;
        return new eventItemRequestBuilder_1.EventItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.events.item.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["multiValueLegacyExtendedProperty%2Did"] = id;
        return new multiValueLegacyExtendedPropertyItemRequestBuilder_1.MultiValueLegacyExtendedPropertyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property events in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.events.item.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["singleValueLegacyExtendedProperty%2Did"] = id;
        return new singleValueLegacyExtendedPropertyItemRequestBuilder_1.SingleValueLegacyExtendedPropertyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.EventItemRequestBuilder = EventItemRequestBuilder;
