import { Message } from '../../../../models/';
import { AttachmentsRequestBuilder } from './attachments/attachmentsRequestBuilder';
import { AttachmentItemRequestBuilder } from './attachments/item/attachmentItemRequestBuilder';
import { CalendarSharingMessageRequestBuilder } from './calendarSharingMessage/calendarSharingMessageRequestBuilder';
import { CopyRequestBuilder } from './copy/copyRequestBuilder';
import { CreateForwardRequestBuilder } from './createForward/createForwardRequestBuilder';
import { CreateReplyRequestBuilder } from './createReply/createReplyRequestBuilder';
import { CreateReplyAllRequestBuilder } from './createReplyAll/createReplyAllRequestBuilder';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { ForwardRequestBuilder } from './forward/forwardRequestBuilder';
import { MessageItemRequestBuilderDeleteRequestConfiguration } from './messageItemRequestBuilderDeleteRequestConfiguration';
import { MessageItemRequestBuilderGetRequestConfiguration } from './messageItemRequestBuilderGetRequestConfiguration';
import { MessageItemRequestBuilderPatchRequestConfiguration } from './messageItemRequestBuilderPatchRequestConfiguration';
import { MoveRequestBuilder } from './move/moveRequestBuilder';
import { MultiValueLegacyExtendedPropertyItemRequestBuilder } from './multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder';
import { MultiValueExtendedPropertiesRequestBuilder } from './multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder';
import { ReplyRequestBuilder } from './reply/replyRequestBuilder';
import { ReplyAllRequestBuilder } from './replyAll/replyAllRequestBuilder';
import { SendRequestBuilder } from './send/sendRequestBuilder';
import { SingleValueLegacyExtendedPropertyItemRequestBuilder } from './singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder';
import { SingleValueExtendedPropertiesRequestBuilder } from './singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder';
import { ContentRequestBuilder } from './value/contentRequestBuilder';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.user entity. */
export declare class MessageItemRequestBuilder {
    /** The attachments property */
    get attachments(): AttachmentsRequestBuilder;
    /** The calendarSharingMessage property */
    get calendarSharingMessage(): CalendarSharingMessageRequestBuilder;
    /** The Content property */
    get content(): ContentRequestBuilder;
    /** The copy property */
    get copy(): CopyRequestBuilder;
    /** The createForward property */
    get createForward(): CreateForwardRequestBuilder;
    /** The createReply property */
    get createReply(): CreateReplyRequestBuilder;
    /** The createReplyAll property */
    get createReplyAll(): CreateReplyAllRequestBuilder;
    /** The extensions property */
    get extensions(): ExtensionsRequestBuilder;
    /** The forward property */
    get forward(): ForwardRequestBuilder;
    /** The move property */
    get move(): MoveRequestBuilder;
    /** The multiValueExtendedProperties property */
    get multiValueExtendedProperties(): MultiValueExtendedPropertiesRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The reply property */
    get reply(): ReplyRequestBuilder;
    /** The replyAll property */
    get replyAll(): ReplyAllRequestBuilder;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The send property */
    get send(): SendRequestBuilder;
    /** The singleValueExtendedProperties property */
    get singleValueExtendedProperties(): SingleValueExtendedPropertiesRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.attachments.item collection
     * @param id Unique identifier of the item
     * @returns a attachmentItemRequestBuilder
     */
    attachmentsById(id: string): AttachmentItemRequestBuilder;
    /**
     * Instantiates a new MessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: MessageItemRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * The messages in a mailbox or folder. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: MessageItemRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property messages in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Message | undefined, requestConfiguration?: MessageItemRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property messages for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: MessageItemRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The messages in a mailbox or folder. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Message
     */
    get(requestConfiguration?: MessageItemRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Message | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id: string): MultiValueLegacyExtendedPropertyItemRequestBuilder;
    /**
     * Update the navigation property messages in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Message | undefined, requestConfiguration?: MessageItemRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id: string): SingleValueLegacyExtendedPropertyItemRequestBuilder;
}
