import { UserTeamwork } from '../../../models/';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { UserScopeTeamsAppInstallationItemRequestBuilder } from './installedApps/item/userScopeTeamsAppInstallationItemRequestBuilder';
import { SendActivityNotificationRequestBuilder } from './sendActivityNotification/sendActivityNotificationRequestBuilder';
import { TeamworkRequestBuilderDeleteRequestConfiguration } from './teamworkRequestBuilderDeleteRequestConfiguration';
import { TeamworkRequestBuilderGetRequestConfiguration } from './teamworkRequestBuilderGetRequestConfiguration';
import { TeamworkRequestBuilderPatchRequestConfiguration } from './teamworkRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the teamwork property of the microsoft.graph.user entity. */
export declare class TeamworkRequestBuilder {
    /** The installedApps property */
    get installedApps(): InstalledAppsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** The sendActivityNotification property */
    get sendActivityNotification(): SendActivityNotificationRequestBuilder;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new TeamworkRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property teamwork for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: TeamworkRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * A container for Microsoft Teams features available for the user. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TeamworkRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property teamwork in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: UserTeamwork | undefined, requestConfiguration?: TeamworkRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property teamwork for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: TeamworkRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * A container for Microsoft Teams features available for the user. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of UserTeamwork
     */
    get(requestConfiguration?: TeamworkRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<UserTeamwork | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.teamwork.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a userScopeTeamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id: string): UserScopeTeamsAppInstallationItemRequestBuilder;
    /**
     * Update the navigation property teamwork in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: UserTeamwork | undefined, requestConfiguration?: TeamworkRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
