import { Todo } from '../../../models/';
import { TodoTaskListItemRequestBuilder } from './lists/item/todoTaskListItemRequestBuilder';
import { ListsRequestBuilder } from './lists/listsRequestBuilder';
import { TodoRequestBuilderDeleteRequestConfiguration } from './todoRequestBuilderDeleteRequestConfiguration';
import { TodoRequestBuilderGetRequestConfiguration } from './todoRequestBuilderGetRequestConfiguration';
import { TodoRequestBuilderPatchRequestConfiguration } from './todoRequestBuilderPatchRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the todo property of the microsoft.graph.user entity. */
export declare class TodoRequestBuilder {
    /** The lists property */
    get lists(): ListsRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new TodoRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property todo for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration?: TodoRequestBuilderDeleteRequestConfiguration | undefined): RequestInformation;
    /**
     * Represents the To Do services available to a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: TodoRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Update the navigation property todo in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Todo | undefined, requestConfiguration?: TodoRequestBuilderPatchRequestConfiguration | undefined): RequestInformation;
    /**
     * Delete navigation property todo for users
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration?: TodoRequestBuilderDeleteRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Represents the To Do services available to a user.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Todo
     */
    get(requestConfiguration?: TodoRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<Todo | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.todo.lists.item collection
     * @param id Unique identifier of the item
     * @returns a todoTaskListItemRequestBuilder
     */
    listsById(id: string): TodoTaskListItemRequestBuilder;
    /**
     * Update the navigation property todo in users
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Todo | undefined, requestConfiguration?: TodoRequestBuilderPatchRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
