"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriveItemItemRequestBuilder = void 0;
const createDriveItemFromDiscriminatorValue_1 = require("../../models/createDriveItemFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/oDataErrors/createODataErrorFromDiscriminatorValue");
const analyticsRequestBuilder_1 = require("./analytics/analyticsRequestBuilder");
const checkinRequestBuilder_1 = require("./checkin/checkinRequestBuilder");
const checkoutRequestBuilder_1 = require("./checkout/checkoutRequestBuilder");
const childrenRequestBuilder_1 = require("./children/childrenRequestBuilder");
const driveItemItemRequestBuilder_1 = require("./children/item/driveItemItemRequestBuilder");
const contentRequestBuilder_1 = require("./content/contentRequestBuilder");
const copyRequestBuilder_1 = require("./copy/copyRequestBuilder");
const createLinkRequestBuilder_1 = require("./createLink/createLinkRequestBuilder");
const createUploadSessionRequestBuilder_1 = require("./createUploadSession/createUploadSessionRequestBuilder");
const deltaRequestBuilder_1 = require("./delta/deltaRequestBuilder");
const deltaWithTokenRequestBuilder_1 = require("./deltaWithToken/deltaWithTokenRequestBuilder");
const followRequestBuilder_1 = require("./follow/followRequestBuilder");
const getActivitiesByIntervalRequestBuilder_1 = require("./getActivitiesByInterval/getActivitiesByIntervalRequestBuilder");
const getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder_1 = require("./getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder");
const inviteRequestBuilder_1 = require("./invite/inviteRequestBuilder");
const listItemRequestBuilder_1 = require("./listItem/listItemRequestBuilder");
const permissionItemRequestBuilder_1 = require("./permissions/item/permissionItemRequestBuilder");
const permissionsRequestBuilder_1 = require("./permissions/permissionsRequestBuilder");
const previewRequestBuilder_1 = require("./preview/previewRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const searchWithQRequestBuilder_1 = require("./searchWithQ/searchWithQRequestBuilder");
const subscriptionItemRequestBuilder_1 = require("./subscriptions/item/subscriptionItemRequestBuilder");
const subscriptionsRequestBuilder_1 = require("./subscriptions/subscriptionsRequestBuilder");
const thumbnailSetItemRequestBuilder_1 = require("./thumbnails/item/thumbnailSetItemRequestBuilder");
const thumbnailsRequestBuilder_1 = require("./thumbnails/thumbnailsRequestBuilder");
const unfollowRequestBuilder_1 = require("./unfollow/unfollowRequestBuilder");
const validatePermissionRequestBuilder_1 = require("./validatePermission/validatePermissionRequestBuilder");
const driveItemVersionItemRequestBuilder_1 = require("./versions/item/driveItemVersionItemRequestBuilder");
const versionsRequestBuilder_1 = require("./versions/versionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of driveItem entities. */
class DriveItemItemRequestBuilder {
    /**
     * Instantiates a new DriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/workbooks/{driveItem%2Did}{?%24select,%24expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    /** The analytics property */
    get analytics() {
        return new analyticsRequestBuilder_1.AnalyticsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The checkin property */
    get checkin() {
        return new checkinRequestBuilder_1.CheckinRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The checkout property */
    get checkout() {
        return new checkoutRequestBuilder_1.CheckoutRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The children property */
    get children() {
        return new childrenRequestBuilder_1.ChildrenRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The content property */
    get content() {
        return new contentRequestBuilder_1.ContentRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The copy property */
    get copy() {
        return new copyRequestBuilder_1.CopyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The createLink property */
    get createLink() {
        return new createLinkRequestBuilder_1.CreateLinkRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The createUploadSession property */
    get createUploadSession() {
        return new createUploadSessionRequestBuilder_1.CreateUploadSessionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The follow property */
    get follow() {
        return new followRequestBuilder_1.FollowRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The invite property */
    get invite() {
        return new inviteRequestBuilder_1.InviteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The listItem property */
    get listItem() {
        return new listItemRequestBuilder_1.ListItemRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The permissions property */
    get permissions() {
        return new permissionsRequestBuilder_1.PermissionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The preview property */
    get preview() {
        return new previewRequestBuilder_1.PreviewRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The restore property */
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The subscriptions property */
    get subscriptions() {
        return new subscriptionsRequestBuilder_1.SubscriptionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The thumbnails property */
    get thumbnails() {
        return new thumbnailsRequestBuilder_1.ThumbnailsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The unfollow property */
    get unfollow() {
        return new unfollowRequestBuilder_1.UnfollowRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The validatePermission property */
    get validatePermission() {
        return new validatePermissionRequestBuilder_1.ValidatePermissionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /** The versions property */
    get versions() {
        return new versionsRequestBuilder_1.VersionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.children.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    childrenById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["driveItem%2Did1"] = id;
        return new driveItemItemRequestBuilder_1.DriveItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete entity from workbooks
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Get entity from workbooks by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.setQueryStringParametersFromRawObject(requestConfiguration.queryParameters);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        return requestInfo;
    }
    ;
    /**
     * Update entity in workbooks
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (requestConfiguration) {
            requestInfo.addRequestHeaders(requestConfiguration.headers);
            requestInfo.addRequestOptions(requestConfiguration.options);
        }
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        return requestInfo;
    }
    ;
    /**
     * Delete entity from workbooks
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Provides operations to call the delta method.
     * @returns a deltaRequestBuilder
     */
    delta() {
        return new deltaRequestBuilder_1.DeltaRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Provides operations to call the delta method.
     * @param token Usage: token='{token}'
     * @returns a deltaWithTokenRequestBuilder
     */
    deltaWithToken(token) {
        if (!token)
            throw new Error("token cannot be undefined");
        return new deltaWithTokenRequestBuilder_1.DeltaWithTokenRequestBuilder(this.pathParameters, this.requestAdapter, token);
    }
    ;
    /**
     * Get entity from workbooks by key
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItem
     */
    get(requestConfiguration, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @returns a getActivitiesByIntervalRequestBuilder
     */
    getActivitiesByInterval() {
        return new getActivitiesByIntervalRequestBuilder_1.GetActivitiesByIntervalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime, interval, startDateTime) {
        if (!endDateTime)
            throw new Error("endDateTime cannot be undefined");
        if (!interval)
            throw new Error("interval cannot be undefined");
        if (!startDateTime)
            throw new Error("startDateTime cannot be undefined");
        return new getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder_1.GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder(this.pathParameters, this.requestAdapter, endDateTime, interval, startDateTime);
    }
    ;
    /**
     * Update entity in workbooks
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, requestConfiguration, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["permission%2Did"] = id;
        return new permissionItemRequestBuilder_1.PermissionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q) {
        if (!q)
            throw new Error("q cannot be undefined");
        return new searchWithQRequestBuilder_1.SearchWithQRequestBuilder(this.pathParameters, this.requestAdapter, q);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["subscription%2Did"] = id;
        return new subscriptionItemRequestBuilder_1.SubscriptionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.thumbnails.item collection
     * @param id Unique identifier of the item
     * @returns a thumbnailSetItemRequestBuilder
     */
    thumbnailsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["thumbnailSet%2Did"] = id;
        return new thumbnailSetItemRequestBuilder_1.ThumbnailSetItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.versions.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemVersionItemRequestBuilder
     */
    versionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["driveItemVersion%2Did"] = id;
        return new driveItemVersionItemRequestBuilder_1.DriveItemVersionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.DriveItemItemRequestBuilder = DriveItemItemRequestBuilder;
