import { DriveItem, DriveItemCollectionResponse } from '../models/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { WorkbooksRequestBuilderGetRequestConfiguration } from './workbooksRequestBuilderGetRequestConfiguration';
import { WorkbooksRequestBuilderPostRequestConfiguration } from './workbooksRequestBuilderPostRequestConfiguration';
import { RequestAdapter, RequestInformation, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of driveItem entities. */
export declare class WorkbooksRequestBuilder {
    /** The count property */
    get count(): CountRequestBuilder;
    /** Path parameters for the request */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests. */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder */
    private readonly urlTemplate;
    /**
     * Instantiates a new WorkbooksRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get entities from workbooks
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createGetRequestInformation(requestConfiguration?: WorkbooksRequestBuilderGetRequestConfiguration | undefined): RequestInformation;
    /**
     * Add new entity to workbooks
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: DriveItem | undefined, requestConfiguration?: WorkbooksRequestBuilderPostRequestConfiguration | undefined): RequestInformation;
    /**
     * Get entities from workbooks
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItemCollectionResponse
     */
    get(requestConfiguration?: WorkbooksRequestBuilderGetRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DriveItemCollectionResponse | undefined>;
    /**
     * Add new entity to workbooks
     * @param body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItem
     */
    post(body: DriveItem | undefined, requestConfiguration?: WorkbooksRequestBuilderPostRequestConfiguration | undefined, responseHandler?: ResponseHandler | undefined): Promise<DriveItem | undefined>;
}
